From cbd12a10f1abbf3d622369799afdc0157b654079 Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter@eisentraut.org>
Date: Wed, 11 Dec 2019 09:48:43 +0100
Subject: [PATCH v1 1/2] Add support for other normal forms to Unicode
 normalization API

It previously only supported NFKC, for use by SASLprep.  This expands
the API to offer the choice of all four normalization forms.  Right
now, there are no internal users of the forms other than NFKC.
---
 src/common/saslprep.c                         |    2 +-
 .../unicode/generate-norm_test_table.pl       |    9 +-
 .../unicode/generate-unicode_norm_table.pl    |   20 +-
 src/common/unicode/norm_test.c                |   23 +-
 src/common/unicode_norm.c                     |   31 +-
 src/include/common/unicode_norm.h             |   10 +-
 src/include/common/unicode_norm_table.h       | 7334 +++++++++--------
 7 files changed, 3727 insertions(+), 3702 deletions(-)

diff --git a/src/common/saslprep.c b/src/common/saslprep.c
index 23379610ae..762a01301d 100644
--- a/src/common/saslprep.c
+++ b/src/common/saslprep.c
@@ -1162,7 +1162,7 @@ pg_saslprep(const char *input, char **output)
 	 * 2) Normalize -- Normalize the result of step 1 using Unicode
 	 * normalization.
 	 */
-	output_chars = unicode_normalize_kc(input_chars);
+	output_chars = unicode_normalize(UNICODE_NFKC, input_chars);
 	if (!output_chars)
 		goto oom;
 
diff --git a/src/common/unicode/generate-norm_test_table.pl b/src/common/unicode/generate-norm_test_table.pl
index 3ff5ee3c5e..fbf2b56410 100644
--- a/src/common/unicode/generate-norm_test_table.pl
+++ b/src/common/unicode/generate-norm_test_table.pl
@@ -48,7 +48,7 @@
 {
 	int			linenum;
 	pg_wchar	input[50];
-	pg_wchar	output[50];
+	pg_wchar	output[4][50];
 } pg_unicode_test;
 
 /* test table */
@@ -89,13 +89,16 @@ sub codepoint_string_to_hex
 	my ($source, $nfc, $nfd, $nfkc, $nfkd) = split(';', $line);
 
 	my $source_utf8 = codepoint_string_to_hex($source);
+	my $nfc_utf8    = codepoint_string_to_hex($nfc);
+	my $nfd_utf8    = codepoint_string_to_hex($nfd);
 	my $nfkc_utf8   = codepoint_string_to_hex($nfkc);
+	my $nfkd_utf8   = codepoint_string_to_hex($nfkd);
 
-	print $OUTPUT "\t{ $linenum, { $source_utf8 }, { $nfkc_utf8 } },\n";
+	print $OUTPUT "\t{ $linenum, { $source_utf8 }, { { $nfc_utf8 }, { $nfd_utf8 }, { $nfkc_utf8 }, { $nfkd_utf8 } } },\n";
 }
 
 # Output terminator entry
-print $OUTPUT "\t{ 0, { 0 }, { 0 } }";
+print $OUTPUT "\t{ 0, { 0 }, { { 0 }, { 0 }, { 0 }, { 0 } } }";
 print $OUTPUT "\n};\n";
 
 close $OUTPUT;
diff --git a/src/common/unicode/generate-unicode_norm_table.pl b/src/common/unicode/generate-unicode_norm_table.pl
index 7002fdf98c..bb5803f37d 100644
--- a/src/common/unicode/generate-unicode_norm_table.pl
+++ b/src/common/unicode/generate-unicode_norm_table.pl
@@ -99,10 +99,12 @@
 #define DECOMP_NO_COMPOSE	0x80	/* don't use for re-composition */
 #define DECOMP_INLINE		0x40	/* decomposition is stored inline in
 									 * dec_index */
+#define DECOMP_COMPAT		0x20	/* compatibility mapping */
 
-#define DECOMPOSITION_SIZE(x) ((x)->dec_size_flags & 0x3F)
-#define DECOMPOSITION_NO_COMPOSE(x) (((x)->dec_size_flags & DECOMP_NO_COMPOSE) != 0)
+#define DECOMPOSITION_SIZE(x) ((x)->dec_size_flags & 0x1F)
+#define DECOMPOSITION_NO_COMPOSE(x) (((x)->dec_size_flags & (DECOMP_NO_COMPOSE | DECOMP_COMPAT)) != 0)
 #define DECOMPOSITION_IS_INLINE(x) (((x)->dec_size_flags & DECOMP_INLINE) != 0)
+#define DECOMPOSITION_IS_COMPAT(x) (((x)->dec_size_flags & DECOMP_COMPAT) != 0)
 
 /* Table of Unicode codepoints and their decompositions */
 static const pg_unicode_decomposition UnicodeDecompMain[$num_characters] =
@@ -136,22 +138,22 @@
 	# Decomposition size
 	# Print size of decomposition
 	my $decomp_size = scalar(@decomp_elts);
+	die if $decomp_size > 0x1F;		# to not overrun bitmask
 
 	my $first_decomp = shift @decomp_elts;
 
 	my $flags   = "";
 	my $comment = "";
 
-	if ($decomp_size == 2)
+	if ($compat)
 	{
+		$flags .= " | DECOMP_COMPAT";
+	}
 
+	if ($decomp_size == 2)
+	{
 		# Should this be used for recomposition?
-		if ($compat)
-		{
-			$flags .= " | DECOMP_NO_COMPOSE";
-			$comment = "compatibility mapping";
-		}
-		elsif ($character_hash{$first_decomp}
+		if ($character_hash{$first_decomp}
 			&& $character_hash{$first_decomp}->{class} != 0)
 		{
 			$flags .= " | DECOMP_NO_COMPOSE";
diff --git a/src/common/unicode/norm_test.c b/src/common/unicode/norm_test.c
index de7d6a72c7..e556c241d3 100644
--- a/src/common/unicode/norm_test.c
+++ b/src/common/unicode/norm_test.c
@@ -63,18 +63,21 @@ main(int argc, char **argv)
 
 	for (test = UnicodeNormalizationTests; test->input[0] != 0; test++)
 	{
-		pg_wchar   *result;
+		for (int form = 0; form < 4; form++)
+		{
+			pg_wchar   *result;
 
-		result = unicode_normalize_kc(test->input);
+			result = unicode_normalize(form, test->input);
 
-		if (pg_wcscmp(test->output, result) != 0)
-		{
-			printf("FAILURE (NormalizationTest.txt line %d):\n", test->linenum);
-			printf("input:    %s\n", print_wchar_str(test->input));
-			printf("expected: %s\n", print_wchar_str(test->output));
-			printf("got:      %s\n", print_wchar_str(result));
-			printf("\n");
-			exit(1);
+			if (pg_wcscmp(test->output[form], result) != 0)
+			{
+				printf("FAILURE (NormalizationTest.txt line %d form %d):\n", test->linenum, form);
+				printf("input:    %s\n", print_wchar_str(test->input));
+				printf("expected: %s\n", print_wchar_str(test->output[form]));
+				printf("got:      %s\n", print_wchar_str(result));
+				printf("\n");
+				exit(1);
+			}
 		}
 	}
 
diff --git a/src/common/unicode_norm.c b/src/common/unicode_norm.c
index 7509f81437..370fbf949d 100644
--- a/src/common/unicode_norm.c
+++ b/src/common/unicode_norm.c
@@ -1,6 +1,6 @@
 /*-------------------------------------------------------------------------
  * unicode_norm.c
- *		Normalize a Unicode string to NFKC form
+ *		Normalize a Unicode string
  *
  * This implements Unicode normalization, per the documentation at
  * https://www.unicode.org/reports/tr15/.
@@ -98,7 +98,7 @@ get_code_decomposition(pg_unicode_decomposition *entry, int *dec_size)
  * are, in turn, decomposable.
  */
 static int
-get_decomposed_size(pg_wchar code)
+get_decomposed_size(pg_wchar code, bool compat)
 {
 	pg_unicode_decomposition *entry;
 	int			size = 0;
@@ -131,7 +131,8 @@ get_decomposed_size(pg_wchar code)
 	 * Just count current code if no other decompositions.  A NULL entry is
 	 * equivalent to a character with class 0 and no decompositions.
 	 */
-	if (entry == NULL || DECOMPOSITION_SIZE(entry) == 0)
+	if (entry == NULL || DECOMPOSITION_SIZE(entry) == 0 ||
+		(!compat && DECOMPOSITION_IS_COMPAT(entry)))
 		return 1;
 
 	/*
@@ -143,7 +144,7 @@ get_decomposed_size(pg_wchar code)
 	{
 		uint32		lcode = decomp[i];
 
-		size += get_decomposed_size(lcode);
+		size += get_decomposed_size(lcode, compat);
 	}
 
 	return size;
@@ -224,7 +225,7 @@ recompose_code(uint32 start, uint32 code, uint32 *result)
  * in the array result.
  */
 static void
-decompose_code(pg_wchar code, pg_wchar **result, int *current)
+decompose_code(pg_wchar code, bool compat, pg_wchar **result, int *current)
 {
 	pg_unicode_decomposition *entry;
 	int			i;
@@ -272,7 +273,8 @@ decompose_code(pg_wchar code, pg_wchar **result, int *current)
 	 * character with class 0 and no decompositions, so just leave also in
 	 * this case.
 	 */
-	if (entry == NULL || DECOMPOSITION_SIZE(entry) == 0)
+	if (entry == NULL || DECOMPOSITION_SIZE(entry) == 0 ||
+		(!compat && DECOMPOSITION_IS_COMPAT(entry)))
 	{
 		pg_wchar   *res = *result;
 
@@ -290,12 +292,12 @@ decompose_code(pg_wchar code, pg_wchar **result, int *current)
 		pg_wchar	lcode = (pg_wchar) decomp[i];
 
 		/* Leave if no more decompositions */
-		decompose_code(lcode, result, current);
+		decompose_code(lcode, compat, result, current);
 	}
 }
 
 /*
- * unicode_normalize_kc - Normalize a Unicode string to NFKC form.
+ * unicode_normalize - Normalize a Unicode string to the specified form.
  *
  * The input is a 0-terminated array of codepoints.
  *
@@ -304,8 +306,10 @@ decompose_code(pg_wchar code, pg_wchar **result, int *current)
  * string is palloc'd instead, and OOM is reported with ereport().
  */
 pg_wchar *
-unicode_normalize_kc(const pg_wchar *input)
+unicode_normalize(UnicodeNormalizationForm form, const pg_wchar *input)
 {
+	bool		compat = (form == UNICODE_NFKC || form == UNICODE_NFKD);
+	bool		recompose = (form == UNICODE_NFC || form == UNICODE_NFKC);
 	pg_wchar   *decomp_chars;
 	pg_wchar   *recomp_chars;
 	int			decomp_size,
@@ -326,7 +330,7 @@ unicode_normalize_kc(const pg_wchar *input)
 	 */
 	decomp_size = 0;
 	for (p = input; *p; p++)
-		decomp_size += get_decomposed_size(*p);
+		decomp_size += get_decomposed_size(*p, compat);
 
 	decomp_chars = (pg_wchar *) ALLOC((decomp_size + 1) * sizeof(pg_wchar));
 	if (decomp_chars == NULL)
@@ -338,7 +342,7 @@ unicode_normalize_kc(const pg_wchar *input)
 	 */
 	current_size = 0;
 	for (p = input; *p; p++)
-		decompose_code(*p, &decomp_chars, &current_size);
+		decompose_code(*p, compat, &decomp_chars, &current_size);
 	decomp_chars[decomp_size] = '\0';
 	Assert(decomp_size == current_size);
 
@@ -385,8 +389,11 @@ unicode_normalize_kc(const pg_wchar *input)
 			count -= 2;
 	}
 
+	if (!recompose)
+		return decomp_chars;
+
 	/*
-	 * The last phase of NFKC is the recomposition of the reordered Unicode
+	 * The last phase of NFC and NFKC is the recomposition of the reordered Unicode
 	 * string using combining classes. The recomposed string cannot be longer
 	 * than the decomposed one, so make the allocation of the output string
 	 * based on that assumption.
diff --git a/src/include/common/unicode_norm.h b/src/include/common/unicode_norm.h
index 99167d2952..bed8407f3e 100644
--- a/src/include/common/unicode_norm.h
+++ b/src/include/common/unicode_norm.h
@@ -16,6 +16,14 @@
 
 #include "mb/pg_wchar.h"
 
-extern pg_wchar *unicode_normalize_kc(const pg_wchar *input);
+typedef enum
+{
+	UNICODE_NFC = 0,
+	UNICODE_NFD = 1,
+	UNICODE_NFKC = 2,
+	UNICODE_NFKD = 3,
+} UnicodeNormalizationForm;
+
+extern pg_wchar *unicode_normalize(UnicodeNormalizationForm form, const pg_wchar *input);
 
 #endif							/* UNICODE_NORM_H */
diff --git a/src/include/common/unicode_norm_table.h b/src/include/common/unicode_norm_table.h
index 8b1335ffc9..13724933f6 100644
--- a/src/include/common/unicode_norm_table.h
+++ b/src/include/common/unicode_norm_table.h
@@ -28,28 +28,30 @@ typedef struct
 #define DECOMP_NO_COMPOSE	0x80	/* don't use for re-composition */
 #define DECOMP_INLINE		0x40	/* decomposition is stored inline in
 									 * dec_index */
+#define DECOMP_COMPAT		0x20	/* compatibility mapping */
 
-#define DECOMPOSITION_SIZE(x) ((x)->dec_size_flags & 0x3F)
-#define DECOMPOSITION_NO_COMPOSE(x) (((x)->dec_size_flags & DECOMP_NO_COMPOSE) != 0)
+#define DECOMPOSITION_SIZE(x) ((x)->dec_size_flags & 0x1F)
+#define DECOMPOSITION_NO_COMPOSE(x) (((x)->dec_size_flags & (DECOMP_NO_COMPOSE | DECOMP_COMPAT)) != 0)
 #define DECOMPOSITION_IS_INLINE(x) (((x)->dec_size_flags & DECOMP_INLINE) != 0)
+#define DECOMPOSITION_IS_COMPAT(x) (((x)->dec_size_flags & DECOMP_COMPAT) != 0)
 
 /* Table of Unicode codepoints and their decompositions */
 static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 {
-	{0x00A0, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x00A8, 0, 2 | DECOMP_NO_COMPOSE, 0},	/* compatibility mapping */
-	{0x00AA, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x00AF, 0, 2 | DECOMP_NO_COMPOSE, 2},	/* compatibility mapping */
-	{0x00B2, 0, 1 | DECOMP_INLINE, 0x0032},
-	{0x00B3, 0, 1 | DECOMP_INLINE, 0x0033},
-	{0x00B4, 0, 2 | DECOMP_NO_COMPOSE, 4},	/* compatibility mapping */
-	{0x00B5, 0, 1 | DECOMP_INLINE, 0x03BC},
-	{0x00B8, 0, 2 | DECOMP_NO_COMPOSE, 6},	/* compatibility mapping */
-	{0x00B9, 0, 1 | DECOMP_INLINE, 0x0031},
-	{0x00BA, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x00BC, 0, 3, 8},
-	{0x00BD, 0, 3, 11},
-	{0x00BE, 0, 3, 14},
+	{0x00A0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x00A8, 0, 2 | DECOMP_COMPAT, 0},
+	{0x00AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x00AF, 0, 2 | DECOMP_COMPAT, 2},
+	{0x00B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
+	{0x00B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
+	{0x00B4, 0, 2 | DECOMP_COMPAT, 4},
+	{0x00B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
+	{0x00B8, 0, 2 | DECOMP_COMPAT, 6},
+	{0x00B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
+	{0x00BA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x00BC, 0, 3 | DECOMP_COMPAT, 8},
+	{0x00BD, 0, 3 | DECOMP_COMPAT, 11},
+	{0x00BE, 0, 3 | DECOMP_COMPAT, 14},
 	{0x00C0, 0, 2, 17},
 	{0x00C1, 0, 2, 19},
 	{0x00C2, 0, 2, 21},
@@ -148,8 +150,8 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x012E, 0, 2, 207},
 	{0x012F, 0, 2, 209},
 	{0x0130, 0, 2, 211},
-	{0x0132, 0, 2 | DECOMP_NO_COMPOSE, 213},	/* compatibility mapping */
-	{0x0133, 0, 2 | DECOMP_NO_COMPOSE, 215},	/* compatibility mapping */
+	{0x0132, 0, 2 | DECOMP_COMPAT, 213},
+	{0x0133, 0, 2 | DECOMP_COMPAT, 215},
 	{0x0134, 0, 2, 217},
 	{0x0135, 0, 2, 219},
 	{0x0136, 0, 2, 221},
@@ -160,15 +162,15 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x013C, 0, 2, 231},
 	{0x013D, 0, 2, 233},
 	{0x013E, 0, 2, 235},
-	{0x013F, 0, 2 | DECOMP_NO_COMPOSE, 237},	/* compatibility mapping */
-	{0x0140, 0, 2 | DECOMP_NO_COMPOSE, 239},	/* compatibility mapping */
+	{0x013F, 0, 2 | DECOMP_COMPAT, 237},
+	{0x0140, 0, 2 | DECOMP_COMPAT, 239},
 	{0x0143, 0, 2, 241},
 	{0x0144, 0, 2, 243},
 	{0x0145, 0, 2, 245},
 	{0x0146, 0, 2, 247},
 	{0x0147, 0, 2, 249},
 	{0x0148, 0, 2, 251},
-	{0x0149, 0, 2 | DECOMP_NO_COMPOSE, 253},	/* compatibility mapping */
+	{0x0149, 0, 2 | DECOMP_COMPAT, 253},
 	{0x014C, 0, 2, 255},
 	{0x014D, 0, 2, 257},
 	{0x014E, 0, 2, 259},
@@ -216,20 +218,20 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x017C, 0, 2, 343},
 	{0x017D, 0, 2, 345},
 	{0x017E, 0, 2, 347},
-	{0x017F, 0, 1 | DECOMP_INLINE, 0x0073},
+	{0x017F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
 	{0x01A0, 0, 2, 349},
 	{0x01A1, 0, 2, 351},
 	{0x01AF, 0, 2, 353},
 	{0x01B0, 0, 2, 355},
-	{0x01C4, 0, 2 | DECOMP_NO_COMPOSE, 357},	/* compatibility mapping */
-	{0x01C5, 0, 2 | DECOMP_NO_COMPOSE, 359},	/* compatibility mapping */
-	{0x01C6, 0, 2 | DECOMP_NO_COMPOSE, 361},	/* compatibility mapping */
-	{0x01C7, 0, 2 | DECOMP_NO_COMPOSE, 363},	/* compatibility mapping */
-	{0x01C8, 0, 2 | DECOMP_NO_COMPOSE, 365},	/* compatibility mapping */
-	{0x01C9, 0, 2 | DECOMP_NO_COMPOSE, 367},	/* compatibility mapping */
-	{0x01CA, 0, 2 | DECOMP_NO_COMPOSE, 369},	/* compatibility mapping */
-	{0x01CB, 0, 2 | DECOMP_NO_COMPOSE, 371},	/* compatibility mapping */
-	{0x01CC, 0, 2 | DECOMP_NO_COMPOSE, 373},	/* compatibility mapping */
+	{0x01C4, 0, 2 | DECOMP_COMPAT, 357},
+	{0x01C5, 0, 2 | DECOMP_COMPAT, 359},
+	{0x01C6, 0, 2 | DECOMP_COMPAT, 361},
+	{0x01C7, 0, 2 | DECOMP_COMPAT, 363},
+	{0x01C8, 0, 2 | DECOMP_COMPAT, 365},
+	{0x01C9, 0, 2 | DECOMP_COMPAT, 367},
+	{0x01CA, 0, 2 | DECOMP_COMPAT, 369},
+	{0x01CB, 0, 2 | DECOMP_COMPAT, 371},
+	{0x01CC, 0, 2 | DECOMP_COMPAT, 373},
 	{0x01CD, 0, 2, 375},
 	{0x01CE, 0, 2, 377},
 	{0x01CF, 0, 2, 379},
@@ -263,9 +265,9 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x01EE, 0, 2, 435},
 	{0x01EF, 0, 2, 437},
 	{0x01F0, 0, 2, 439},
-	{0x01F1, 0, 2 | DECOMP_NO_COMPOSE, 441},	/* compatibility mapping */
-	{0x01F2, 0, 2 | DECOMP_NO_COMPOSE, 443},	/* compatibility mapping */
-	{0x01F3, 0, 2 | DECOMP_NO_COMPOSE, 445},	/* compatibility mapping */
+	{0x01F1, 0, 2 | DECOMP_COMPAT, 441},
+	{0x01F2, 0, 2 | DECOMP_COMPAT, 443},
+	{0x01F3, 0, 2 | DECOMP_COMPAT, 445},
 	{0x01F4, 0, 2, 447},
 	{0x01F5, 0, 2, 449},
 	{0x01F8, 0, 2, 451},
@@ -320,26 +322,26 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x0231, 0, 2, 549},
 	{0x0232, 0, 2, 551},
 	{0x0233, 0, 2, 553},
-	{0x02B0, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x02B1, 0, 1 | DECOMP_INLINE, 0x0266},
-	{0x02B2, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x02B3, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x02B4, 0, 1 | DECOMP_INLINE, 0x0279},
-	{0x02B5, 0, 1 | DECOMP_INLINE, 0x027B},
-	{0x02B6, 0, 1 | DECOMP_INLINE, 0x0281},
-	{0x02B7, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x02B8, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x02D8, 0, 2 | DECOMP_NO_COMPOSE, 555},	/* compatibility mapping */
-	{0x02D9, 0, 2 | DECOMP_NO_COMPOSE, 557},	/* compatibility mapping */
-	{0x02DA, 0, 2 | DECOMP_NO_COMPOSE, 559},	/* compatibility mapping */
-	{0x02DB, 0, 2 | DECOMP_NO_COMPOSE, 561},	/* compatibility mapping */
-	{0x02DC, 0, 2 | DECOMP_NO_COMPOSE, 563},	/* compatibility mapping */
-	{0x02DD, 0, 2 | DECOMP_NO_COMPOSE, 565},	/* compatibility mapping */
-	{0x02E0, 0, 1 | DECOMP_INLINE, 0x0263},
-	{0x02E1, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x02E2, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x02E3, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x02E4, 0, 1 | DECOMP_INLINE, 0x0295},
+	{0x02B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x02B1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0266},
+	{0x02B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x02B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x02B4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0279},
+	{0x02B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x027B},
+	{0x02B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0281},
+	{0x02B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x02B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x02D8, 0, 2 | DECOMP_COMPAT, 555},
+	{0x02D9, 0, 2 | DECOMP_COMPAT, 557},
+	{0x02DA, 0, 2 | DECOMP_COMPAT, 559},
+	{0x02DB, 0, 2 | DECOMP_COMPAT, 561},
+	{0x02DC, 0, 2 | DECOMP_COMPAT, 563},
+	{0x02DD, 0, 2 | DECOMP_COMPAT, 565},
+	{0x02E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0263},
+	{0x02E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x02E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x02E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x02E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0295},
 	{0x0300, 230, 0, 0},
 	{0x0301, 230, 0, 0},
 	{0x0302, 230, 0, 0},
@@ -452,9 +454,9 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x036E, 230, 0, 0},
 	{0x036F, 230, 0, 0},
 	{0x0374, 0, 1 | DECOMP_INLINE, 0x02B9},
-	{0x037A, 0, 2 | DECOMP_NO_COMPOSE, 569},	/* compatibility mapping */
+	{0x037A, 0, 2 | DECOMP_COMPAT, 569},
 	{0x037E, 0, 1 | DECOMP_INLINE, 0x003B},
-	{0x0384, 0, 2 | DECOMP_NO_COMPOSE, 571},	/* compatibility mapping */
+	{0x0384, 0, 2 | DECOMP_COMPAT, 571},
 	{0x0385, 0, 2, 573},
 	{0x0386, 0, 2, 575},
 	{0x0387, 0, 1 | DECOMP_INLINE, 0x00B7},
@@ -477,19 +479,19 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x03CC, 0, 2, 609},
 	{0x03CD, 0, 2, 611},
 	{0x03CE, 0, 2, 613},
-	{0x03D0, 0, 1 | DECOMP_INLINE, 0x03B2},
-	{0x03D1, 0, 1 | DECOMP_INLINE, 0x03B8},
-	{0x03D2, 0, 1 | DECOMP_INLINE, 0x03A5},
+	{0x03D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
+	{0x03D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
+	{0x03D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
 	{0x03D3, 0, 2, 615},
 	{0x03D4, 0, 2, 617},
-	{0x03D5, 0, 1 | DECOMP_INLINE, 0x03C6},
-	{0x03D6, 0, 1 | DECOMP_INLINE, 0x03C0},
-	{0x03F0, 0, 1 | DECOMP_INLINE, 0x03BA},
-	{0x03F1, 0, 1 | DECOMP_INLINE, 0x03C1},
-	{0x03F2, 0, 1 | DECOMP_INLINE, 0x03C2},
-	{0x03F4, 0, 1 | DECOMP_INLINE, 0x0398},
-	{0x03F5, 0, 1 | DECOMP_INLINE, 0x03B5},
-	{0x03F9, 0, 1 | DECOMP_INLINE, 0x03A3},
+	{0x03D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
+	{0x03D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
+	{0x03F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
+	{0x03F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
+	{0x03F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
+	{0x03F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
+	{0x03F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
+	{0x03F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
 	{0x0400, 0, 2, 619},
 	{0x0401, 0, 2, 621},
 	{0x0403, 0, 2, 623},
@@ -547,7 +549,7 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x04F5, 0, 2, 717},
 	{0x04F8, 0, 2, 719},
 	{0x04F9, 0, 2, 721},
-	{0x0587, 0, 2 | DECOMP_NO_COMPOSE, 723},	/* compatibility mapping */
+	{0x0587, 0, 2 | DECOMP_COMPAT, 723},
 	{0x0591, 220, 0, 0},
 	{0x0592, 230, 0, 0},
 	{0x0593, 230, 0, 0},
@@ -637,10 +639,10 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x065E, 230, 0, 0},
 	{0x065F, 220, 0, 0},
 	{0x0670, 35, 0, 0},
-	{0x0675, 0, 2 | DECOMP_NO_COMPOSE, 735},	/* compatibility mapping */
-	{0x0676, 0, 2 | DECOMP_NO_COMPOSE, 737},	/* compatibility mapping */
-	{0x0677, 0, 2 | DECOMP_NO_COMPOSE, 739},	/* compatibility mapping */
-	{0x0678, 0, 2 | DECOMP_NO_COMPOSE, 741},	/* compatibility mapping */
+	{0x0675, 0, 2 | DECOMP_COMPAT, 735},
+	{0x0676, 0, 2 | DECOMP_COMPAT, 737},
+	{0x0677, 0, 2 | DECOMP_COMPAT, 739},
+	{0x0678, 0, 2 | DECOMP_COMPAT, 741},
 	{0x06C0, 0, 2, 743},
 	{0x06C2, 0, 2, 745},
 	{0x06D3, 0, 2, 747},
@@ -838,7 +840,7 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x0DDC, 0, 2, 831},
 	{0x0DDD, 0, 2, 833},
 	{0x0DDE, 0, 2, 835},
-	{0x0E33, 0, 2 | DECOMP_NO_COMPOSE, 837},	/* compatibility mapping */
+	{0x0E33, 0, 2 | DECOMP_COMPAT, 837},
 	{0x0E38, 103, 0, 0},
 	{0x0E39, 103, 0, 0},
 	{0x0E3A, 9, 0, 0},
@@ -846,7 +848,7 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x0E49, 107, 0, 0},
 	{0x0E4A, 107, 0, 0},
 	{0x0E4B, 107, 0, 0},
-	{0x0EB3, 0, 2 | DECOMP_NO_COMPOSE, 839},	/* compatibility mapping */
+	{0x0EB3, 0, 2 | DECOMP_COMPAT, 839},
 	{0x0EB8, 118, 0, 0},
 	{0x0EB9, 118, 0, 0},
 	{0x0EBA, 9, 0, 0},
@@ -854,9 +856,9 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x0EC9, 122, 0, 0},
 	{0x0ECA, 122, 0, 0},
 	{0x0ECB, 122, 0, 0},
-	{0x0EDC, 0, 2 | DECOMP_NO_COMPOSE, 841},	/* compatibility mapping */
-	{0x0EDD, 0, 2 | DECOMP_NO_COMPOSE, 843},	/* compatibility mapping */
-	{0x0F0C, 0, 1 | DECOMP_INLINE, 0x0F0B},
+	{0x0EDC, 0, 2 | DECOMP_COMPAT, 841},
+	{0x0EDD, 0, 2 | DECOMP_COMPAT, 843},
+	{0x0F0C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0F0B},
 	{0x0F18, 220, 0, 0},
 	{0x0F19, 220, 0, 0},
 	{0x0F35, 220, 0, 0},
@@ -874,9 +876,9 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x0F74, 132, 0, 0},
 	{0x0F75, 0, 2 | DECOMP_NO_COMPOSE, 859},	/* non-starter decomposition */
 	{0x0F76, 0, 2 | DECOMP_NO_COMPOSE, 861},	/* in exclusion list */
-	{0x0F77, 0, 2 | DECOMP_NO_COMPOSE, 863},	/* compatibility mapping */
+	{0x0F77, 0, 2 | DECOMP_COMPAT, 863},
 	{0x0F78, 0, 2 | DECOMP_NO_COMPOSE, 865},	/* in exclusion list */
-	{0x0F79, 0, 2 | DECOMP_NO_COMPOSE, 867},	/* compatibility mapping */
+	{0x0F79, 0, 2 | DECOMP_COMPAT, 867},
 	{0x0F7A, 130, 0, 0},
 	{0x0F7B, 130, 0, 0},
 	{0x0F7C, 130, 0, 0},
@@ -900,7 +902,7 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x1039, 9, 0, 0},
 	{0x103A, 9, 0, 0},
 	{0x108D, 220, 0, 0},
-	{0x10FC, 0, 1 | DECOMP_INLINE, 0x10DC},
+	{0x10FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x10DC},
 	{0x135D, 230, 0, 0},
 	{0x135E, 230, 0, 0},
 	{0x135F, 230, 0, 0},
@@ -993,104 +995,104 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x1CF4, 230, 0, 0},
 	{0x1CF8, 230, 0, 0},
 	{0x1CF9, 230, 0, 0},
-	{0x1D2C, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D2D, 0, 1 | DECOMP_INLINE, 0x00C6},
-	{0x1D2E, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D30, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D31, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D32, 0, 1 | DECOMP_INLINE, 0x018E},
-	{0x1D33, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D34, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1D35, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D36, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D37, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D38, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D39, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D3A, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D3C, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D3D, 0, 1 | DECOMP_INLINE, 0x0222},
-	{0x1D3E, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D3F, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1D40, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D41, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D42, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D43, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D44, 0, 1 | DECOMP_INLINE, 0x0250},
-	{0x1D45, 0, 1 | DECOMP_INLINE, 0x0251},
-	{0x1D46, 0, 1 | DECOMP_INLINE, 0x1D02},
-	{0x1D47, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D48, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D49, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D4A, 0, 1 | DECOMP_INLINE, 0x0259},
-	{0x1D4B, 0, 1 | DECOMP_INLINE, 0x025B},
-	{0x1D4C, 0, 1 | DECOMP_INLINE, 0x025C},
-	{0x1D4D, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D4F, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D50, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D51, 0, 1 | DECOMP_INLINE, 0x014B},
-	{0x1D52, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D53, 0, 1 | DECOMP_INLINE, 0x0254},
-	{0x1D54, 0, 1 | DECOMP_INLINE, 0x1D16},
-	{0x1D55, 0, 1 | DECOMP_INLINE, 0x1D17},
-	{0x1D56, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D57, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D58, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D59, 0, 1 | DECOMP_INLINE, 0x1D1D},
-	{0x1D5A, 0, 1 | DECOMP_INLINE, 0x026F},
-	{0x1D5B, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D5C, 0, 1 | DECOMP_INLINE, 0x1D25},
-	{0x1D5D, 0, 1 | DECOMP_INLINE, 0x03B2},
-	{0x1D5E, 0, 1 | DECOMP_INLINE, 0x03B3},
-	{0x1D5F, 0, 1 | DECOMP_INLINE, 0x03B4},
-	{0x1D60, 0, 1 | DECOMP_INLINE, 0x03C6},
-	{0x1D61, 0, 1 | DECOMP_INLINE, 0x03C7},
-	{0x1D62, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D63, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D64, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D65, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D66, 0, 1 | DECOMP_INLINE, 0x03B2},
-	{0x1D67, 0, 1 | DECOMP_INLINE, 0x03B3},
-	{0x1D68, 0, 1 | DECOMP_INLINE, 0x03C1},
-	{0x1D69, 0, 1 | DECOMP_INLINE, 0x03C6},
-	{0x1D6A, 0, 1 | DECOMP_INLINE, 0x03C7},
-	{0x1D78, 0, 1 | DECOMP_INLINE, 0x043D},
-	{0x1D9B, 0, 1 | DECOMP_INLINE, 0x0252},
-	{0x1D9C, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D9D, 0, 1 | DECOMP_INLINE, 0x0255},
-	{0x1D9E, 0, 1 | DECOMP_INLINE, 0x00F0},
-	{0x1D9F, 0, 1 | DECOMP_INLINE, 0x025C},
-	{0x1DA0, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1DA1, 0, 1 | DECOMP_INLINE, 0x025F},
-	{0x1DA2, 0, 1 | DECOMP_INLINE, 0x0261},
-	{0x1DA3, 0, 1 | DECOMP_INLINE, 0x0265},
-	{0x1DA4, 0, 1 | DECOMP_INLINE, 0x0268},
-	{0x1DA5, 0, 1 | DECOMP_INLINE, 0x0269},
-	{0x1DA6, 0, 1 | DECOMP_INLINE, 0x026A},
-	{0x1DA7, 0, 1 | DECOMP_INLINE, 0x1D7B},
-	{0x1DA8, 0, 1 | DECOMP_INLINE, 0x029D},
-	{0x1DA9, 0, 1 | DECOMP_INLINE, 0x026D},
-	{0x1DAA, 0, 1 | DECOMP_INLINE, 0x1D85},
-	{0x1DAB, 0, 1 | DECOMP_INLINE, 0x029F},
-	{0x1DAC, 0, 1 | DECOMP_INLINE, 0x0271},
-	{0x1DAD, 0, 1 | DECOMP_INLINE, 0x0270},
-	{0x1DAE, 0, 1 | DECOMP_INLINE, 0x0272},
-	{0x1DAF, 0, 1 | DECOMP_INLINE, 0x0273},
-	{0x1DB0, 0, 1 | DECOMP_INLINE, 0x0274},
-	{0x1DB1, 0, 1 | DECOMP_INLINE, 0x0275},
-	{0x1DB2, 0, 1 | DECOMP_INLINE, 0x0278},
-	{0x1DB3, 0, 1 | DECOMP_INLINE, 0x0282},
-	{0x1DB4, 0, 1 | DECOMP_INLINE, 0x0283},
-	{0x1DB5, 0, 1 | DECOMP_INLINE, 0x01AB},
-	{0x1DB6, 0, 1 | DECOMP_INLINE, 0x0289},
-	{0x1DB7, 0, 1 | DECOMP_INLINE, 0x028A},
-	{0x1DB8, 0, 1 | DECOMP_INLINE, 0x1D1C},
-	{0x1DB9, 0, 1 | DECOMP_INLINE, 0x028B},
-	{0x1DBA, 0, 1 | DECOMP_INLINE, 0x028C},
-	{0x1DBB, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1DBC, 0, 1 | DECOMP_INLINE, 0x0290},
-	{0x1DBD, 0, 1 | DECOMP_INLINE, 0x0291},
-	{0x1DBE, 0, 1 | DECOMP_INLINE, 0x0292},
-	{0x1DBF, 0, 1 | DECOMP_INLINE, 0x03B8},
+	{0x1D2C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D2D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00C6},
+	{0x1D2E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D30, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D31, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D32, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x018E},
+	{0x1D33, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D34, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1D35, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D36, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D37, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D38, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D39, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D3A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D3C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D3D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0222},
+	{0x1D3E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D3F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1D40, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D41, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D42, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D43, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D44, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0250},
+	{0x1D45, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0251},
+	{0x1D46, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D02},
+	{0x1D47, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D48, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D49, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D4A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0259},
+	{0x1D4B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025B},
+	{0x1D4C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025C},
+	{0x1D4D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D4F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D50, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x014B},
+	{0x1D52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D53, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0254},
+	{0x1D54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D16},
+	{0x1D55, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D17},
+	{0x1D56, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D58, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D1D},
+	{0x1D5A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026F},
+	{0x1D5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D25},
+	{0x1D5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
+	{0x1D5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
+	{0x1D5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
+	{0x1D60, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
+	{0x1D61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
+	{0x1D62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D63, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D65, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D66, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
+	{0x1D67, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
+	{0x1D68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
+	{0x1D69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
+	{0x1D6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
+	{0x1D78, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x043D},
+	{0x1D9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0252},
+	{0x1D9C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D9D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0255},
+	{0x1D9E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00F0},
+	{0x1D9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025C},
+	{0x1DA0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1DA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x025F},
+	{0x1DA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0261},
+	{0x1DA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0265},
+	{0x1DA4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0268},
+	{0x1DA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0269},
+	{0x1DA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026A},
+	{0x1DA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D7B},
+	{0x1DA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x029D},
+	{0x1DA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026D},
+	{0x1DAA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D85},
+	{0x1DAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x029F},
+	{0x1DAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0271},
+	{0x1DAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0270},
+	{0x1DAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0272},
+	{0x1DAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0273},
+	{0x1DB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0274},
+	{0x1DB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0275},
+	{0x1DB2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0278},
+	{0x1DB3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0282},
+	{0x1DB4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0283},
+	{0x1DB5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x01AB},
+	{0x1DB6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0289},
+	{0x1DB7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028A},
+	{0x1DB8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1D1C},
+	{0x1DB9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028B},
+	{0x1DBA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x028C},
+	{0x1DBB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1DBC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0290},
+	{0x1DBD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0291},
+	{0x1DBE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0292},
+	{0x1DBF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
 	{0x1DC0, 230, 0, 0},
 	{0x1DC1, 230, 0, 0},
 	{0x1DC2, 220, 0, 0},
@@ -1308,7 +1310,7 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x1E97, 0, 2, 1209},
 	{0x1E98, 0, 2, 1211},
 	{0x1E99, 0, 2, 1213},
-	{0x1E9A, 0, 2 | DECOMP_NO_COMPOSE, 1215},	/* compatibility mapping */
+	{0x1E9A, 0, 2 | DECOMP_COMPAT, 1215},
 	{0x1E9B, 0, 2, 1217},
 	{0x1EA0, 0, 2, 1219},
 	{0x1EA1, 0, 2, 1221},
@@ -1574,10 +1576,10 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x1FBA, 0, 2, 1727},
 	{0x1FBB, 0, 1 | DECOMP_INLINE, 0x0386},
 	{0x1FBC, 0, 2, 1729},
-	{0x1FBD, 0, 2 | DECOMP_NO_COMPOSE, 1731},	/* compatibility mapping */
+	{0x1FBD, 0, 2 | DECOMP_COMPAT, 1731},
 	{0x1FBE, 0, 1 | DECOMP_INLINE, 0x03B9},
-	{0x1FBF, 0, 2 | DECOMP_NO_COMPOSE, 1733},	/* compatibility mapping */
-	{0x1FC0, 0, 2 | DECOMP_NO_COMPOSE, 1735},	/* compatibility mapping */
+	{0x1FBF, 0, 2 | DECOMP_COMPAT, 1733},
+	{0x1FC0, 0, 2 | DECOMP_COMPAT, 1735},
 	{0x1FC1, 0, 2, 1737},
 	{0x1FC2, 0, 2, 1739},
 	{0x1FC3, 0, 2, 1741},
@@ -1632,78 +1634,78 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x1FFB, 0, 1 | DECOMP_INLINE, 0x038F},
 	{0x1FFC, 0, 2, 1821},
 	{0x1FFD, 0, 1 | DECOMP_INLINE, 0x00B4},
-	{0x1FFE, 0, 2 | DECOMP_NO_COMPOSE, 1823},	/* compatibility mapping */
+	{0x1FFE, 0, 2 | DECOMP_COMPAT, 1823},
 	{0x2000, 0, 1 | DECOMP_INLINE, 0x2002},
 	{0x2001, 0, 1 | DECOMP_INLINE, 0x2003},
-	{0x2002, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x2003, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x2004, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x2005, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x2006, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x2007, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x2008, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x2009, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x200A, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x2011, 0, 1 | DECOMP_INLINE, 0x2010},
-	{0x2017, 0, 2 | DECOMP_NO_COMPOSE, 1825},	/* compatibility mapping */
-	{0x2024, 0, 1 | DECOMP_INLINE, 0x002E},
-	{0x2025, 0, 2 | DECOMP_NO_COMPOSE, 1827},	/* compatibility mapping */
-	{0x2026, 0, 3, 1829},
-	{0x202F, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x2033, 0, 2 | DECOMP_NO_COMPOSE, 1832},	/* compatibility mapping */
-	{0x2034, 0, 3, 1834},
-	{0x2036, 0, 2 | DECOMP_NO_COMPOSE, 1837},	/* compatibility mapping */
-	{0x2037, 0, 3, 1839},
-	{0x203C, 0, 2 | DECOMP_NO_COMPOSE, 1842},	/* compatibility mapping */
-	{0x203E, 0, 2 | DECOMP_NO_COMPOSE, 1844},	/* compatibility mapping */
-	{0x2047, 0, 2 | DECOMP_NO_COMPOSE, 1846},	/* compatibility mapping */
-	{0x2048, 0, 2 | DECOMP_NO_COMPOSE, 1848},	/* compatibility mapping */
-	{0x2049, 0, 2 | DECOMP_NO_COMPOSE, 1850},	/* compatibility mapping */
-	{0x2057, 0, 4, 1852},
-	{0x205F, 0, 1 | DECOMP_INLINE, 0x0020},
-	{0x2070, 0, 1 | DECOMP_INLINE, 0x0030},
-	{0x2071, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x2074, 0, 1 | DECOMP_INLINE, 0x0034},
-	{0x2075, 0, 1 | DECOMP_INLINE, 0x0035},
-	{0x2076, 0, 1 | DECOMP_INLINE, 0x0036},
-	{0x2077, 0, 1 | DECOMP_INLINE, 0x0037},
-	{0x2078, 0, 1 | DECOMP_INLINE, 0x0038},
-	{0x2079, 0, 1 | DECOMP_INLINE, 0x0039},
-	{0x207A, 0, 1 | DECOMP_INLINE, 0x002B},
-	{0x207B, 0, 1 | DECOMP_INLINE, 0x2212},
-	{0x207C, 0, 1 | DECOMP_INLINE, 0x003D},
-	{0x207D, 0, 1 | DECOMP_INLINE, 0x0028},
-	{0x207E, 0, 1 | DECOMP_INLINE, 0x0029},
-	{0x207F, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x2080, 0, 1 | DECOMP_INLINE, 0x0030},
-	{0x2081, 0, 1 | DECOMP_INLINE, 0x0031},
-	{0x2082, 0, 1 | DECOMP_INLINE, 0x0032},
-	{0x2083, 0, 1 | DECOMP_INLINE, 0x0033},
-	{0x2084, 0, 1 | DECOMP_INLINE, 0x0034},
-	{0x2085, 0, 1 | DECOMP_INLINE, 0x0035},
-	{0x2086, 0, 1 | DECOMP_INLINE, 0x0036},
-	{0x2087, 0, 1 | DECOMP_INLINE, 0x0037},
-	{0x2088, 0, 1 | DECOMP_INLINE, 0x0038},
-	{0x2089, 0, 1 | DECOMP_INLINE, 0x0039},
-	{0x208A, 0, 1 | DECOMP_INLINE, 0x002B},
-	{0x208B, 0, 1 | DECOMP_INLINE, 0x2212},
-	{0x208C, 0, 1 | DECOMP_INLINE, 0x003D},
-	{0x208D, 0, 1 | DECOMP_INLINE, 0x0028},
-	{0x208E, 0, 1 | DECOMP_INLINE, 0x0029},
-	{0x2090, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x2091, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x2092, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x2093, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x2094, 0, 1 | DECOMP_INLINE, 0x0259},
-	{0x2095, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x2096, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x2097, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x2098, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x2099, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x209A, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x209B, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x209C, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x20A8, 0, 2 | DECOMP_NO_COMPOSE, 1856},	/* compatibility mapping */
+	{0x2002, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x2003, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x2004, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x2005, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x2006, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x2007, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x2008, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x2009, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x200A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x2011, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2010},
+	{0x2017, 0, 2 | DECOMP_COMPAT, 1825},
+	{0x2024, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002E},
+	{0x2025, 0, 2 | DECOMP_COMPAT, 1827},
+	{0x2026, 0, 3 | DECOMP_COMPAT, 1829},
+	{0x202F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x2033, 0, 2 | DECOMP_COMPAT, 1832},
+	{0x2034, 0, 3 | DECOMP_COMPAT, 1834},
+	{0x2036, 0, 2 | DECOMP_COMPAT, 1837},
+	{0x2037, 0, 3 | DECOMP_COMPAT, 1839},
+	{0x203C, 0, 2 | DECOMP_COMPAT, 1842},
+	{0x203E, 0, 2 | DECOMP_COMPAT, 1844},
+	{0x2047, 0, 2 | DECOMP_COMPAT, 1846},
+	{0x2048, 0, 2 | DECOMP_COMPAT, 1848},
+	{0x2049, 0, 2 | DECOMP_COMPAT, 1850},
+	{0x2057, 0, 4 | DECOMP_COMPAT, 1852},
+	{0x205F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
+	{0x2070, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
+	{0x2071, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x2074, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
+	{0x2075, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
+	{0x2076, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
+	{0x2077, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
+	{0x2078, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
+	{0x2079, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
+	{0x207A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002B},
+	{0x207B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2212},
+	{0x207C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003D},
+	{0x207D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0028},
+	{0x207E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0029},
+	{0x207F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x2080, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
+	{0x2081, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
+	{0x2082, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
+	{0x2083, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
+	{0x2084, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
+	{0x2085, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
+	{0x2086, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
+	{0x2087, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
+	{0x2088, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
+	{0x2089, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
+	{0x208A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002B},
+	{0x208B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2212},
+	{0x208C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003D},
+	{0x208D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0028},
+	{0x208E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0029},
+	{0x2090, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x2091, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x2092, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x2093, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x2094, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0259},
+	{0x2095, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x2096, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x2097, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x2098, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x2099, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x209A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x209B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x209C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x20A8, 0, 2 | DECOMP_COMPAT, 1856},
 	{0x20D0, 230, 0, 0},
 	{0x20D1, 230, 0, 0},
 	{0x20D2, 1, 0, 0},
@@ -1730,111 +1732,111 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x20EE, 220, 0, 0},
 	{0x20EF, 220, 0, 0},
 	{0x20F0, 230, 0, 0},
-	{0x2100, 0, 3, 1858},
-	{0x2101, 0, 3, 1861},
-	{0x2102, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x2103, 0, 2 | DECOMP_NO_COMPOSE, 1864},	/* compatibility mapping */
-	{0x2105, 0, 3, 1866},
-	{0x2106, 0, 3, 1869},
-	{0x2107, 0, 1 | DECOMP_INLINE, 0x0190},
-	{0x2109, 0, 2 | DECOMP_NO_COMPOSE, 1872},	/* compatibility mapping */
-	{0x210A, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x210B, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x210C, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x210D, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x210E, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x210F, 0, 1 | DECOMP_INLINE, 0x0127},
-	{0x2110, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x2111, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x2112, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x2113, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x2115, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x2116, 0, 2 | DECOMP_NO_COMPOSE, 1874},	/* compatibility mapping */
-	{0x2119, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x211A, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x211B, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x211C, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x211D, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x2120, 0, 2 | DECOMP_NO_COMPOSE, 1876},	/* compatibility mapping */
-	{0x2121, 0, 3, 1878},
-	{0x2122, 0, 2 | DECOMP_NO_COMPOSE, 1881},	/* compatibility mapping */
-	{0x2124, 0, 1 | DECOMP_INLINE, 0x005A},
+	{0x2100, 0, 3 | DECOMP_COMPAT, 1858},
+	{0x2101, 0, 3 | DECOMP_COMPAT, 1861},
+	{0x2102, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x2103, 0, 2 | DECOMP_COMPAT, 1864},
+	{0x2105, 0, 3 | DECOMP_COMPAT, 1866},
+	{0x2106, 0, 3 | DECOMP_COMPAT, 1869},
+	{0x2107, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0190},
+	{0x2109, 0, 2 | DECOMP_COMPAT, 1872},
+	{0x210A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x210B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x210C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x210D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x210E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x210F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0127},
+	{0x2110, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x2111, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x2112, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x2113, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x2115, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x2116, 0, 2 | DECOMP_COMPAT, 1874},
+	{0x2119, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x211A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x211B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x211C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x211D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x2120, 0, 2 | DECOMP_COMPAT, 1876},
+	{0x2121, 0, 3 | DECOMP_COMPAT, 1878},
+	{0x2122, 0, 2 | DECOMP_COMPAT, 1881},
+	{0x2124, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
 	{0x2126, 0, 1 | DECOMP_INLINE, 0x03A9},
-	{0x2128, 0, 1 | DECOMP_INLINE, 0x005A},
+	{0x2128, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
 	{0x212A, 0, 1 | DECOMP_INLINE, 0x004B},
 	{0x212B, 0, 1 | DECOMP_INLINE, 0x00C5},
-	{0x212C, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x212D, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x212F, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x2130, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x2131, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x2133, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x2134, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x2135, 0, 1 | DECOMP_INLINE, 0x05D0},
-	{0x2136, 0, 1 | DECOMP_INLINE, 0x05D1},
-	{0x2137, 0, 1 | DECOMP_INLINE, 0x05D2},
-	{0x2138, 0, 1 | DECOMP_INLINE, 0x05D3},
-	{0x2139, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x213B, 0, 3, 1883},
-	{0x213C, 0, 1 | DECOMP_INLINE, 0x03C0},
-	{0x213D, 0, 1 | DECOMP_INLINE, 0x03B3},
-	{0x213E, 0, 1 | DECOMP_INLINE, 0x0393},
-	{0x213F, 0, 1 | DECOMP_INLINE, 0x03A0},
-	{0x2140, 0, 1 | DECOMP_INLINE, 0x2211},
-	{0x2145, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x2146, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x2147, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x2148, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x2149, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x2150, 0, 3, 1886},
-	{0x2151, 0, 3, 1889},
-	{0x2152, 0, 4, 1892},
-	{0x2153, 0, 3, 1896},
-	{0x2154, 0, 3, 1899},
-	{0x2155, 0, 3, 1902},
-	{0x2156, 0, 3, 1905},
-	{0x2157, 0, 3, 1908},
-	{0x2158, 0, 3, 1911},
-	{0x2159, 0, 3, 1914},
-	{0x215A, 0, 3, 1917},
-	{0x215B, 0, 3, 1920},
-	{0x215C, 0, 3, 1923},
-	{0x215D, 0, 3, 1926},
-	{0x215E, 0, 3, 1929},
-	{0x215F, 0, 2 | DECOMP_NO_COMPOSE, 1932},	/* compatibility mapping */
-	{0x2160, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x2161, 0, 2 | DECOMP_NO_COMPOSE, 1934},	/* compatibility mapping */
-	{0x2162, 0, 3, 1936},
-	{0x2163, 0, 2 | DECOMP_NO_COMPOSE, 1939},	/* compatibility mapping */
-	{0x2164, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x2165, 0, 2 | DECOMP_NO_COMPOSE, 1941},	/* compatibility mapping */
-	{0x2166, 0, 3, 1943},
-	{0x2167, 0, 4, 1946},
-	{0x2168, 0, 2 | DECOMP_NO_COMPOSE, 1950},	/* compatibility mapping */
-	{0x2169, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x216A, 0, 2 | DECOMP_NO_COMPOSE, 1952},	/* compatibility mapping */
-	{0x216B, 0, 3, 1954},
-	{0x216C, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x216D, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x216E, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x216F, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x2170, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x2171, 0, 2 | DECOMP_NO_COMPOSE, 1957},	/* compatibility mapping */
-	{0x2172, 0, 3, 1959},
-	{0x2173, 0, 2 | DECOMP_NO_COMPOSE, 1962},	/* compatibility mapping */
-	{0x2174, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x2175, 0, 2 | DECOMP_NO_COMPOSE, 1964},	/* compatibility mapping */
-	{0x2176, 0, 3, 1966},
-	{0x2177, 0, 4, 1969},
-	{0x2178, 0, 2 | DECOMP_NO_COMPOSE, 1973},	/* compatibility mapping */
-	{0x2179, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x217A, 0, 2 | DECOMP_NO_COMPOSE, 1975},	/* compatibility mapping */
-	{0x217B, 0, 3, 1977},
-	{0x217C, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x217D, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x217E, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x217F, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x2189, 0, 3, 1980},
+	{0x212C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x212D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x212F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x2130, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x2131, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x2133, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x2134, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x2135, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D0},
+	{0x2136, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D1},
+	{0x2137, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D2},
+	{0x2138, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D3},
+	{0x2139, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x213B, 0, 3 | DECOMP_COMPAT, 1883},
+	{0x213C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
+	{0x213D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
+	{0x213E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
+	{0x213F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
+	{0x2140, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2211},
+	{0x2145, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x2146, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x2147, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x2148, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x2149, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x2150, 0, 3 | DECOMP_COMPAT, 1886},
+	{0x2151, 0, 3 | DECOMP_COMPAT, 1889},
+	{0x2152, 0, 4 | DECOMP_COMPAT, 1892},
+	{0x2153, 0, 3 | DECOMP_COMPAT, 1896},
+	{0x2154, 0, 3 | DECOMP_COMPAT, 1899},
+	{0x2155, 0, 3 | DECOMP_COMPAT, 1902},
+	{0x2156, 0, 3 | DECOMP_COMPAT, 1905},
+	{0x2157, 0, 3 | DECOMP_COMPAT, 1908},
+	{0x2158, 0, 3 | DECOMP_COMPAT, 1911},
+	{0x2159, 0, 3 | DECOMP_COMPAT, 1914},
+	{0x215A, 0, 3 | DECOMP_COMPAT, 1917},
+	{0x215B, 0, 3 | DECOMP_COMPAT, 1920},
+	{0x215C, 0, 3 | DECOMP_COMPAT, 1923},
+	{0x215D, 0, 3 | DECOMP_COMPAT, 1926},
+	{0x215E, 0, 3 | DECOMP_COMPAT, 1929},
+	{0x215F, 0, 2 | DECOMP_COMPAT, 1932},
+	{0x2160, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x2161, 0, 2 | DECOMP_COMPAT, 1934},
+	{0x2162, 0, 3 | DECOMP_COMPAT, 1936},
+	{0x2163, 0, 2 | DECOMP_COMPAT, 1939},
+	{0x2164, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x2165, 0, 2 | DECOMP_COMPAT, 1941},
+	{0x2166, 0, 3 | DECOMP_COMPAT, 1943},
+	{0x2167, 0, 4 | DECOMP_COMPAT, 1946},
+	{0x2168, 0, 2 | DECOMP_COMPAT, 1950},
+	{0x2169, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x216A, 0, 2 | DECOMP_COMPAT, 1952},
+	{0x216B, 0, 3 | DECOMP_COMPAT, 1954},
+	{0x216C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x216D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x216E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x216F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x2170, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x2171, 0, 2 | DECOMP_COMPAT, 1957},
+	{0x2172, 0, 3 | DECOMP_COMPAT, 1959},
+	{0x2173, 0, 2 | DECOMP_COMPAT, 1962},
+	{0x2174, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x2175, 0, 2 | DECOMP_COMPAT, 1964},
+	{0x2176, 0, 3 | DECOMP_COMPAT, 1966},
+	{0x2177, 0, 4 | DECOMP_COMPAT, 1969},
+	{0x2178, 0, 2 | DECOMP_COMPAT, 1973},
+	{0x2179, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x217A, 0, 2 | DECOMP_COMPAT, 1975},
+	{0x217B, 0, 3 | DECOMP_COMPAT, 1977},
+	{0x217C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x217D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x217E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x217F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x2189, 0, 3 | DECOMP_COMPAT, 1980},
 	{0x219A, 0, 2, 1983},
 	{0x219B, 0, 2, 1985},
 	{0x21AE, 0, 2, 1987},
@@ -1846,10 +1848,10 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x220C, 0, 2, 1999},
 	{0x2224, 0, 2, 2001},
 	{0x2226, 0, 2, 2003},
-	{0x222C, 0, 2 | DECOMP_NO_COMPOSE, 2005},	/* compatibility mapping */
-	{0x222D, 0, 3, 2007},
-	{0x222F, 0, 2 | DECOMP_NO_COMPOSE, 2010},	/* compatibility mapping */
-	{0x2230, 0, 3, 2012},
+	{0x222C, 0, 2 | DECOMP_COMPAT, 2005},
+	{0x222D, 0, 3 | DECOMP_COMPAT, 2007},
+	{0x222F, 0, 2 | DECOMP_COMPAT, 2010},
+	{0x2230, 0, 3 | DECOMP_COMPAT, 2012},
 	{0x2241, 0, 2, 2015},
 	{0x2244, 0, 2, 2017},
 	{0x2247, 0, 2, 2019},
@@ -1885,156 +1887,156 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x22ED, 0, 2, 2079},
 	{0x2329, 0, 1 | DECOMP_INLINE, 0x3008},
 	{0x232A, 0, 1 | DECOMP_INLINE, 0x3009},
-	{0x2460, 0, 1 | DECOMP_INLINE, 0x0031},
-	{0x2461, 0, 1 | DECOMP_INLINE, 0x0032},
-	{0x2462, 0, 1 | DECOMP_INLINE, 0x0033},
-	{0x2463, 0, 1 | DECOMP_INLINE, 0x0034},
-	{0x2464, 0, 1 | DECOMP_INLINE, 0x0035},
-	{0x2465, 0, 1 | DECOMP_INLINE, 0x0036},
-	{0x2466, 0, 1 | DECOMP_INLINE, 0x0037},
-	{0x2467, 0, 1 | DECOMP_INLINE, 0x0038},
-	{0x2468, 0, 1 | DECOMP_INLINE, 0x0039},
-	{0x2469, 0, 2 | DECOMP_NO_COMPOSE, 2081},	/* compatibility mapping */
-	{0x246A, 0, 2 | DECOMP_NO_COMPOSE, 2083},	/* compatibility mapping */
-	{0x246B, 0, 2 | DECOMP_NO_COMPOSE, 2085},	/* compatibility mapping */
-	{0x246C, 0, 2 | DECOMP_NO_COMPOSE, 2087},	/* compatibility mapping */
-	{0x246D, 0, 2 | DECOMP_NO_COMPOSE, 2089},	/* compatibility mapping */
-	{0x246E, 0, 2 | DECOMP_NO_COMPOSE, 2091},	/* compatibility mapping */
-	{0x246F, 0, 2 | DECOMP_NO_COMPOSE, 2093},	/* compatibility mapping */
-	{0x2470, 0, 2 | DECOMP_NO_COMPOSE, 2095},	/* compatibility mapping */
-	{0x2471, 0, 2 | DECOMP_NO_COMPOSE, 2097},	/* compatibility mapping */
-	{0x2472, 0, 2 | DECOMP_NO_COMPOSE, 2099},	/* compatibility mapping */
-	{0x2473, 0, 2 | DECOMP_NO_COMPOSE, 2101},	/* compatibility mapping */
-	{0x2474, 0, 3, 2103},
-	{0x2475, 0, 3, 2106},
-	{0x2476, 0, 3, 2109},
-	{0x2477, 0, 3, 2112},
-	{0x2478, 0, 3, 2115},
-	{0x2479, 0, 3, 2118},
-	{0x247A, 0, 3, 2121},
-	{0x247B, 0, 3, 2124},
-	{0x247C, 0, 3, 2127},
-	{0x247D, 0, 4, 2130},
-	{0x247E, 0, 4, 2134},
-	{0x247F, 0, 4, 2138},
-	{0x2480, 0, 4, 2142},
-	{0x2481, 0, 4, 2146},
-	{0x2482, 0, 4, 2150},
-	{0x2483, 0, 4, 2154},
-	{0x2484, 0, 4, 2158},
-	{0x2485, 0, 4, 2162},
-	{0x2486, 0, 4, 2166},
-	{0x2487, 0, 4, 2170},
-	{0x2488, 0, 2 | DECOMP_NO_COMPOSE, 2174},	/* compatibility mapping */
-	{0x2489, 0, 2 | DECOMP_NO_COMPOSE, 2176},	/* compatibility mapping */
-	{0x248A, 0, 2 | DECOMP_NO_COMPOSE, 2178},	/* compatibility mapping */
-	{0x248B, 0, 2 | DECOMP_NO_COMPOSE, 2180},	/* compatibility mapping */
-	{0x248C, 0, 2 | DECOMP_NO_COMPOSE, 2182},	/* compatibility mapping */
-	{0x248D, 0, 2 | DECOMP_NO_COMPOSE, 2184},	/* compatibility mapping */
-	{0x248E, 0, 2 | DECOMP_NO_COMPOSE, 2186},	/* compatibility mapping */
-	{0x248F, 0, 2 | DECOMP_NO_COMPOSE, 2188},	/* compatibility mapping */
-	{0x2490, 0, 2 | DECOMP_NO_COMPOSE, 2190},	/* compatibility mapping */
-	{0x2491, 0, 3, 2192},
-	{0x2492, 0, 3, 2195},
-	{0x2493, 0, 3, 2198},
-	{0x2494, 0, 3, 2201},
-	{0x2495, 0, 3, 2204},
-	{0x2496, 0, 3, 2207},
-	{0x2497, 0, 3, 2210},
-	{0x2498, 0, 3, 2213},
-	{0x2499, 0, 3, 2216},
-	{0x249A, 0, 3, 2219},
-	{0x249B, 0, 3, 2222},
-	{0x249C, 0, 3, 2225},
-	{0x249D, 0, 3, 2228},
-	{0x249E, 0, 3, 2231},
-	{0x249F, 0, 3, 2234},
-	{0x24A0, 0, 3, 2237},
-	{0x24A1, 0, 3, 2240},
-	{0x24A2, 0, 3, 2243},
-	{0x24A3, 0, 3, 2246},
-	{0x24A4, 0, 3, 2249},
-	{0x24A5, 0, 3, 2252},
-	{0x24A6, 0, 3, 2255},
-	{0x24A7, 0, 3, 2258},
-	{0x24A8, 0, 3, 2261},
-	{0x24A9, 0, 3, 2264},
-	{0x24AA, 0, 3, 2267},
-	{0x24AB, 0, 3, 2270},
-	{0x24AC, 0, 3, 2273},
-	{0x24AD, 0, 3, 2276},
-	{0x24AE, 0, 3, 2279},
-	{0x24AF, 0, 3, 2282},
-	{0x24B0, 0, 3, 2285},
-	{0x24B1, 0, 3, 2288},
-	{0x24B2, 0, 3, 2291},
-	{0x24B3, 0, 3, 2294},
-	{0x24B4, 0, 3, 2297},
-	{0x24B5, 0, 3, 2300},
-	{0x24B6, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x24B7, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x24B8, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x24B9, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x24BA, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x24BB, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x24BC, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x24BD, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x24BE, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x24BF, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x24C0, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x24C1, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x24C2, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x24C3, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x24C4, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x24C5, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x24C6, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x24C7, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x24C8, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x24C9, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x24CA, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x24CB, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x24CC, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x24CD, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x24CE, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x24CF, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x24D0, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x24D1, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x24D2, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x24D3, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x24D4, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x24D5, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x24D6, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x24D7, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x24D8, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x24D9, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x24DA, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x24DB, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x24DC, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x24DD, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x24DE, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x24DF, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x24E0, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x24E1, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x24E2, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x24E3, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x24E4, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x24E5, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x24E6, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x24E7, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x24E8, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x24E9, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x24EA, 0, 1 | DECOMP_INLINE, 0x0030},
-	{0x2A0C, 0, 4, 2303},
-	{0x2A74, 0, 3, 2307},
-	{0x2A75, 0, 2 | DECOMP_NO_COMPOSE, 2310},	/* compatibility mapping */
-	{0x2A76, 0, 3, 2312},
+	{0x2460, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
+	{0x2461, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
+	{0x2462, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
+	{0x2463, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
+	{0x2464, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
+	{0x2465, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
+	{0x2466, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
+	{0x2467, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
+	{0x2468, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
+	{0x2469, 0, 2 | DECOMP_COMPAT, 2081},
+	{0x246A, 0, 2 | DECOMP_COMPAT, 2083},
+	{0x246B, 0, 2 | DECOMP_COMPAT, 2085},
+	{0x246C, 0, 2 | DECOMP_COMPAT, 2087},
+	{0x246D, 0, 2 | DECOMP_COMPAT, 2089},
+	{0x246E, 0, 2 | DECOMP_COMPAT, 2091},
+	{0x246F, 0, 2 | DECOMP_COMPAT, 2093},
+	{0x2470, 0, 2 | DECOMP_COMPAT, 2095},
+	{0x2471, 0, 2 | DECOMP_COMPAT, 2097},
+	{0x2472, 0, 2 | DECOMP_COMPAT, 2099},
+	{0x2473, 0, 2 | DECOMP_COMPAT, 2101},
+	{0x2474, 0, 3 | DECOMP_COMPAT, 2103},
+	{0x2475, 0, 3 | DECOMP_COMPAT, 2106},
+	{0x2476, 0, 3 | DECOMP_COMPAT, 2109},
+	{0x2477, 0, 3 | DECOMP_COMPAT, 2112},
+	{0x2478, 0, 3 | DECOMP_COMPAT, 2115},
+	{0x2479, 0, 3 | DECOMP_COMPAT, 2118},
+	{0x247A, 0, 3 | DECOMP_COMPAT, 2121},
+	{0x247B, 0, 3 | DECOMP_COMPAT, 2124},
+	{0x247C, 0, 3 | DECOMP_COMPAT, 2127},
+	{0x247D, 0, 4 | DECOMP_COMPAT, 2130},
+	{0x247E, 0, 4 | DECOMP_COMPAT, 2134},
+	{0x247F, 0, 4 | DECOMP_COMPAT, 2138},
+	{0x2480, 0, 4 | DECOMP_COMPAT, 2142},
+	{0x2481, 0, 4 | DECOMP_COMPAT, 2146},
+	{0x2482, 0, 4 | DECOMP_COMPAT, 2150},
+	{0x2483, 0, 4 | DECOMP_COMPAT, 2154},
+	{0x2484, 0, 4 | DECOMP_COMPAT, 2158},
+	{0x2485, 0, 4 | DECOMP_COMPAT, 2162},
+	{0x2486, 0, 4 | DECOMP_COMPAT, 2166},
+	{0x2487, 0, 4 | DECOMP_COMPAT, 2170},
+	{0x2488, 0, 2 | DECOMP_COMPAT, 2174},
+	{0x2489, 0, 2 | DECOMP_COMPAT, 2176},
+	{0x248A, 0, 2 | DECOMP_COMPAT, 2178},
+	{0x248B, 0, 2 | DECOMP_COMPAT, 2180},
+	{0x248C, 0, 2 | DECOMP_COMPAT, 2182},
+	{0x248D, 0, 2 | DECOMP_COMPAT, 2184},
+	{0x248E, 0, 2 | DECOMP_COMPAT, 2186},
+	{0x248F, 0, 2 | DECOMP_COMPAT, 2188},
+	{0x2490, 0, 2 | DECOMP_COMPAT, 2190},
+	{0x2491, 0, 3 | DECOMP_COMPAT, 2192},
+	{0x2492, 0, 3 | DECOMP_COMPAT, 2195},
+	{0x2493, 0, 3 | DECOMP_COMPAT, 2198},
+	{0x2494, 0, 3 | DECOMP_COMPAT, 2201},
+	{0x2495, 0, 3 | DECOMP_COMPAT, 2204},
+	{0x2496, 0, 3 | DECOMP_COMPAT, 2207},
+	{0x2497, 0, 3 | DECOMP_COMPAT, 2210},
+	{0x2498, 0, 3 | DECOMP_COMPAT, 2213},
+	{0x2499, 0, 3 | DECOMP_COMPAT, 2216},
+	{0x249A, 0, 3 | DECOMP_COMPAT, 2219},
+	{0x249B, 0, 3 | DECOMP_COMPAT, 2222},
+	{0x249C, 0, 3 | DECOMP_COMPAT, 2225},
+	{0x249D, 0, 3 | DECOMP_COMPAT, 2228},
+	{0x249E, 0, 3 | DECOMP_COMPAT, 2231},
+	{0x249F, 0, 3 | DECOMP_COMPAT, 2234},
+	{0x24A0, 0, 3 | DECOMP_COMPAT, 2237},
+	{0x24A1, 0, 3 | DECOMP_COMPAT, 2240},
+	{0x24A2, 0, 3 | DECOMP_COMPAT, 2243},
+	{0x24A3, 0, 3 | DECOMP_COMPAT, 2246},
+	{0x24A4, 0, 3 | DECOMP_COMPAT, 2249},
+	{0x24A5, 0, 3 | DECOMP_COMPAT, 2252},
+	{0x24A6, 0, 3 | DECOMP_COMPAT, 2255},
+	{0x24A7, 0, 3 | DECOMP_COMPAT, 2258},
+	{0x24A8, 0, 3 | DECOMP_COMPAT, 2261},
+	{0x24A9, 0, 3 | DECOMP_COMPAT, 2264},
+	{0x24AA, 0, 3 | DECOMP_COMPAT, 2267},
+	{0x24AB, 0, 3 | DECOMP_COMPAT, 2270},
+	{0x24AC, 0, 3 | DECOMP_COMPAT, 2273},
+	{0x24AD, 0, 3 | DECOMP_COMPAT, 2276},
+	{0x24AE, 0, 3 | DECOMP_COMPAT, 2279},
+	{0x24AF, 0, 3 | DECOMP_COMPAT, 2282},
+	{0x24B0, 0, 3 | DECOMP_COMPAT, 2285},
+	{0x24B1, 0, 3 | DECOMP_COMPAT, 2288},
+	{0x24B2, 0, 3 | DECOMP_COMPAT, 2291},
+	{0x24B3, 0, 3 | DECOMP_COMPAT, 2294},
+	{0x24B4, 0, 3 | DECOMP_COMPAT, 2297},
+	{0x24B5, 0, 3 | DECOMP_COMPAT, 2300},
+	{0x24B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x24B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x24B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x24B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x24BA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x24BB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x24BC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x24BD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x24BE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x24BF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x24C0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x24C1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x24C2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x24C3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x24C4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x24C5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x24C6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x24C7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x24C8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x24C9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x24CA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x24CB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x24CC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x24CD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x24CE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x24CF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x24D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x24D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x24D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x24D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x24D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x24D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x24D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x24D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x24D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x24D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x24DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x24DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x24DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x24DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x24DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x24DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x24E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x24E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x24E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x24E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x24E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x24E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x24E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x24E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x24E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x24E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x24EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
+	{0x2A0C, 0, 4 | DECOMP_COMPAT, 2303},
+	{0x2A74, 0, 3 | DECOMP_COMPAT, 2307},
+	{0x2A75, 0, 2 | DECOMP_COMPAT, 2310},
+	{0x2A76, 0, 3 | DECOMP_COMPAT, 2312},
 	{0x2ADC, 0, 2 | DECOMP_NO_COMPOSE, 2315},	/* in exclusion list */
-	{0x2C7C, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x2C7D, 0, 1 | DECOMP_INLINE, 0x0056},
+	{0x2C7C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x2C7D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
 	{0x2CEF, 230, 0, 0},
 	{0x2CF0, 230, 0, 0},
 	{0x2CF1, 230, 0, 0},
-	{0x2D6F, 0, 1 | DECOMP_INLINE, 0x2D61},
+	{0x2D6F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2D61},
 	{0x2D7F, 9, 0, 0},
 	{0x2DE0, 230, 0, 0},
 	{0x2DE1, 230, 0, 0},
@@ -2068,233 +2070,233 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x2DFD, 230, 0, 0},
 	{0x2DFE, 230, 0, 0},
 	{0x2DFF, 230, 0, 0},
-	{0x2E9F, 0, 1 | DECOMP_INLINE, 0x6BCD},
-	{0x2EF3, 0, 1 | DECOMP_INLINE, 0x9F9F},
-	{0x2F00, 0, 1 | DECOMP_INLINE, 0x4E00},
-	{0x2F01, 0, 1 | DECOMP_INLINE, 0x4E28},
-	{0x2F02, 0, 1 | DECOMP_INLINE, 0x4E36},
-	{0x2F03, 0, 1 | DECOMP_INLINE, 0x4E3F},
-	{0x2F04, 0, 1 | DECOMP_INLINE, 0x4E59},
-	{0x2F05, 0, 1 | DECOMP_INLINE, 0x4E85},
-	{0x2F06, 0, 1 | DECOMP_INLINE, 0x4E8C},
-	{0x2F07, 0, 1 | DECOMP_INLINE, 0x4EA0},
-	{0x2F08, 0, 1 | DECOMP_INLINE, 0x4EBA},
-	{0x2F09, 0, 1 | DECOMP_INLINE, 0x513F},
-	{0x2F0A, 0, 1 | DECOMP_INLINE, 0x5165},
-	{0x2F0B, 0, 1 | DECOMP_INLINE, 0x516B},
-	{0x2F0C, 0, 1 | DECOMP_INLINE, 0x5182},
-	{0x2F0D, 0, 1 | DECOMP_INLINE, 0x5196},
-	{0x2F0E, 0, 1 | DECOMP_INLINE, 0x51AB},
-	{0x2F0F, 0, 1 | DECOMP_INLINE, 0x51E0},
-	{0x2F10, 0, 1 | DECOMP_INLINE, 0x51F5},
-	{0x2F11, 0, 1 | DECOMP_INLINE, 0x5200},
-	{0x2F12, 0, 1 | DECOMP_INLINE, 0x529B},
-	{0x2F13, 0, 1 | DECOMP_INLINE, 0x52F9},
-	{0x2F14, 0, 1 | DECOMP_INLINE, 0x5315},
-	{0x2F15, 0, 1 | DECOMP_INLINE, 0x531A},
-	{0x2F16, 0, 1 | DECOMP_INLINE, 0x5338},
-	{0x2F17, 0, 1 | DECOMP_INLINE, 0x5341},
-	{0x2F18, 0, 1 | DECOMP_INLINE, 0x535C},
-	{0x2F19, 0, 1 | DECOMP_INLINE, 0x5369},
-	{0x2F1A, 0, 1 | DECOMP_INLINE, 0x5382},
-	{0x2F1B, 0, 1 | DECOMP_INLINE, 0x53B6},
-	{0x2F1C, 0, 1 | DECOMP_INLINE, 0x53C8},
-	{0x2F1D, 0, 1 | DECOMP_INLINE, 0x53E3},
-	{0x2F1E, 0, 1 | DECOMP_INLINE, 0x56D7},
-	{0x2F1F, 0, 1 | DECOMP_INLINE, 0x571F},
-	{0x2F20, 0, 1 | DECOMP_INLINE, 0x58EB},
-	{0x2F21, 0, 1 | DECOMP_INLINE, 0x5902},
-	{0x2F22, 0, 1 | DECOMP_INLINE, 0x590A},
-	{0x2F23, 0, 1 | DECOMP_INLINE, 0x5915},
-	{0x2F24, 0, 1 | DECOMP_INLINE, 0x5927},
-	{0x2F25, 0, 1 | DECOMP_INLINE, 0x5973},
-	{0x2F26, 0, 1 | DECOMP_INLINE, 0x5B50},
-	{0x2F27, 0, 1 | DECOMP_INLINE, 0x5B80},
-	{0x2F28, 0, 1 | DECOMP_INLINE, 0x5BF8},
-	{0x2F29, 0, 1 | DECOMP_INLINE, 0x5C0F},
-	{0x2F2A, 0, 1 | DECOMP_INLINE, 0x5C22},
-	{0x2F2B, 0, 1 | DECOMP_INLINE, 0x5C38},
-	{0x2F2C, 0, 1 | DECOMP_INLINE, 0x5C6E},
-	{0x2F2D, 0, 1 | DECOMP_INLINE, 0x5C71},
-	{0x2F2E, 0, 1 | DECOMP_INLINE, 0x5DDB},
-	{0x2F2F, 0, 1 | DECOMP_INLINE, 0x5DE5},
-	{0x2F30, 0, 1 | DECOMP_INLINE, 0x5DF1},
-	{0x2F31, 0, 1 | DECOMP_INLINE, 0x5DFE},
-	{0x2F32, 0, 1 | DECOMP_INLINE, 0x5E72},
-	{0x2F33, 0, 1 | DECOMP_INLINE, 0x5E7A},
-	{0x2F34, 0, 1 | DECOMP_INLINE, 0x5E7F},
-	{0x2F35, 0, 1 | DECOMP_INLINE, 0x5EF4},
-	{0x2F36, 0, 1 | DECOMP_INLINE, 0x5EFE},
-	{0x2F37, 0, 1 | DECOMP_INLINE, 0x5F0B},
-	{0x2F38, 0, 1 | DECOMP_INLINE, 0x5F13},
-	{0x2F39, 0, 1 | DECOMP_INLINE, 0x5F50},
-	{0x2F3A, 0, 1 | DECOMP_INLINE, 0x5F61},
-	{0x2F3B, 0, 1 | DECOMP_INLINE, 0x5F73},
-	{0x2F3C, 0, 1 | DECOMP_INLINE, 0x5FC3},
-	{0x2F3D, 0, 1 | DECOMP_INLINE, 0x6208},
-	{0x2F3E, 0, 1 | DECOMP_INLINE, 0x6236},
-	{0x2F3F, 0, 1 | DECOMP_INLINE, 0x624B},
-	{0x2F40, 0, 1 | DECOMP_INLINE, 0x652F},
-	{0x2F41, 0, 1 | DECOMP_INLINE, 0x6534},
-	{0x2F42, 0, 1 | DECOMP_INLINE, 0x6587},
-	{0x2F43, 0, 1 | DECOMP_INLINE, 0x6597},
-	{0x2F44, 0, 1 | DECOMP_INLINE, 0x65A4},
-	{0x2F45, 0, 1 | DECOMP_INLINE, 0x65B9},
-	{0x2F46, 0, 1 | DECOMP_INLINE, 0x65E0},
-	{0x2F47, 0, 1 | DECOMP_INLINE, 0x65E5},
-	{0x2F48, 0, 1 | DECOMP_INLINE, 0x66F0},
-	{0x2F49, 0, 1 | DECOMP_INLINE, 0x6708},
-	{0x2F4A, 0, 1 | DECOMP_INLINE, 0x6728},
-	{0x2F4B, 0, 1 | DECOMP_INLINE, 0x6B20},
-	{0x2F4C, 0, 1 | DECOMP_INLINE, 0x6B62},
-	{0x2F4D, 0, 1 | DECOMP_INLINE, 0x6B79},
-	{0x2F4E, 0, 1 | DECOMP_INLINE, 0x6BB3},
-	{0x2F4F, 0, 1 | DECOMP_INLINE, 0x6BCB},
-	{0x2F50, 0, 1 | DECOMP_INLINE, 0x6BD4},
-	{0x2F51, 0, 1 | DECOMP_INLINE, 0x6BDB},
-	{0x2F52, 0, 1 | DECOMP_INLINE, 0x6C0F},
-	{0x2F53, 0, 1 | DECOMP_INLINE, 0x6C14},
-	{0x2F54, 0, 1 | DECOMP_INLINE, 0x6C34},
-	{0x2F55, 0, 1 | DECOMP_INLINE, 0x706B},
-	{0x2F56, 0, 1 | DECOMP_INLINE, 0x722A},
-	{0x2F57, 0, 1 | DECOMP_INLINE, 0x7236},
-	{0x2F58, 0, 1 | DECOMP_INLINE, 0x723B},
-	{0x2F59, 0, 1 | DECOMP_INLINE, 0x723F},
-	{0x2F5A, 0, 1 | DECOMP_INLINE, 0x7247},
-	{0x2F5B, 0, 1 | DECOMP_INLINE, 0x7259},
-	{0x2F5C, 0, 1 | DECOMP_INLINE, 0x725B},
-	{0x2F5D, 0, 1 | DECOMP_INLINE, 0x72AC},
-	{0x2F5E, 0, 1 | DECOMP_INLINE, 0x7384},
-	{0x2F5F, 0, 1 | DECOMP_INLINE, 0x7389},
-	{0x2F60, 0, 1 | DECOMP_INLINE, 0x74DC},
-	{0x2F61, 0, 1 | DECOMP_INLINE, 0x74E6},
-	{0x2F62, 0, 1 | DECOMP_INLINE, 0x7518},
-	{0x2F63, 0, 1 | DECOMP_INLINE, 0x751F},
-	{0x2F64, 0, 1 | DECOMP_INLINE, 0x7528},
-	{0x2F65, 0, 1 | DECOMP_INLINE, 0x7530},
-	{0x2F66, 0, 1 | DECOMP_INLINE, 0x758B},
-	{0x2F67, 0, 1 | DECOMP_INLINE, 0x7592},
-	{0x2F68, 0, 1 | DECOMP_INLINE, 0x7676},
-	{0x2F69, 0, 1 | DECOMP_INLINE, 0x767D},
-	{0x2F6A, 0, 1 | DECOMP_INLINE, 0x76AE},
-	{0x2F6B, 0, 1 | DECOMP_INLINE, 0x76BF},
-	{0x2F6C, 0, 1 | DECOMP_INLINE, 0x76EE},
-	{0x2F6D, 0, 1 | DECOMP_INLINE, 0x77DB},
-	{0x2F6E, 0, 1 | DECOMP_INLINE, 0x77E2},
-	{0x2F6F, 0, 1 | DECOMP_INLINE, 0x77F3},
-	{0x2F70, 0, 1 | DECOMP_INLINE, 0x793A},
-	{0x2F71, 0, 1 | DECOMP_INLINE, 0x79B8},
-	{0x2F72, 0, 1 | DECOMP_INLINE, 0x79BE},
-	{0x2F73, 0, 1 | DECOMP_INLINE, 0x7A74},
-	{0x2F74, 0, 1 | DECOMP_INLINE, 0x7ACB},
-	{0x2F75, 0, 1 | DECOMP_INLINE, 0x7AF9},
-	{0x2F76, 0, 1 | DECOMP_INLINE, 0x7C73},
-	{0x2F77, 0, 1 | DECOMP_INLINE, 0x7CF8},
-	{0x2F78, 0, 1 | DECOMP_INLINE, 0x7F36},
-	{0x2F79, 0, 1 | DECOMP_INLINE, 0x7F51},
-	{0x2F7A, 0, 1 | DECOMP_INLINE, 0x7F8A},
-	{0x2F7B, 0, 1 | DECOMP_INLINE, 0x7FBD},
-	{0x2F7C, 0, 1 | DECOMP_INLINE, 0x8001},
-	{0x2F7D, 0, 1 | DECOMP_INLINE, 0x800C},
-	{0x2F7E, 0, 1 | DECOMP_INLINE, 0x8012},
-	{0x2F7F, 0, 1 | DECOMP_INLINE, 0x8033},
-	{0x2F80, 0, 1 | DECOMP_INLINE, 0x807F},
-	{0x2F81, 0, 1 | DECOMP_INLINE, 0x8089},
-	{0x2F82, 0, 1 | DECOMP_INLINE, 0x81E3},
-	{0x2F83, 0, 1 | DECOMP_INLINE, 0x81EA},
-	{0x2F84, 0, 1 | DECOMP_INLINE, 0x81F3},
-	{0x2F85, 0, 1 | DECOMP_INLINE, 0x81FC},
-	{0x2F86, 0, 1 | DECOMP_INLINE, 0x820C},
-	{0x2F87, 0, 1 | DECOMP_INLINE, 0x821B},
-	{0x2F88, 0, 1 | DECOMP_INLINE, 0x821F},
-	{0x2F89, 0, 1 | DECOMP_INLINE, 0x826E},
-	{0x2F8A, 0, 1 | DECOMP_INLINE, 0x8272},
-	{0x2F8B, 0, 1 | DECOMP_INLINE, 0x8278},
-	{0x2F8C, 0, 1 | DECOMP_INLINE, 0x864D},
-	{0x2F8D, 0, 1 | DECOMP_INLINE, 0x866B},
-	{0x2F8E, 0, 1 | DECOMP_INLINE, 0x8840},
-	{0x2F8F, 0, 1 | DECOMP_INLINE, 0x884C},
-	{0x2F90, 0, 1 | DECOMP_INLINE, 0x8863},
-	{0x2F91, 0, 1 | DECOMP_INLINE, 0x897E},
-	{0x2F92, 0, 1 | DECOMP_INLINE, 0x898B},
-	{0x2F93, 0, 1 | DECOMP_INLINE, 0x89D2},
-	{0x2F94, 0, 1 | DECOMP_INLINE, 0x8A00},
-	{0x2F95, 0, 1 | DECOMP_INLINE, 0x8C37},
-	{0x2F96, 0, 1 | DECOMP_INLINE, 0x8C46},
-	{0x2F97, 0, 1 | DECOMP_INLINE, 0x8C55},
-	{0x2F98, 0, 1 | DECOMP_INLINE, 0x8C78},
-	{0x2F99, 0, 1 | DECOMP_INLINE, 0x8C9D},
-	{0x2F9A, 0, 1 | DECOMP_INLINE, 0x8D64},
-	{0x2F9B, 0, 1 | DECOMP_INLINE, 0x8D70},
-	{0x2F9C, 0, 1 | DECOMP_INLINE, 0x8DB3},
-	{0x2F9D, 0, 1 | DECOMP_INLINE, 0x8EAB},
-	{0x2F9E, 0, 1 | DECOMP_INLINE, 0x8ECA},
-	{0x2F9F, 0, 1 | DECOMP_INLINE, 0x8F9B},
-	{0x2FA0, 0, 1 | DECOMP_INLINE, 0x8FB0},
-	{0x2FA1, 0, 1 | DECOMP_INLINE, 0x8FB5},
-	{0x2FA2, 0, 1 | DECOMP_INLINE, 0x9091},
-	{0x2FA3, 0, 1 | DECOMP_INLINE, 0x9149},
-	{0x2FA4, 0, 1 | DECOMP_INLINE, 0x91C6},
-	{0x2FA5, 0, 1 | DECOMP_INLINE, 0x91CC},
-	{0x2FA6, 0, 1 | DECOMP_INLINE, 0x91D1},
-	{0x2FA7, 0, 1 | DECOMP_INLINE, 0x9577},
-	{0x2FA8, 0, 1 | DECOMP_INLINE, 0x9580},
-	{0x2FA9, 0, 1 | DECOMP_INLINE, 0x961C},
-	{0x2FAA, 0, 1 | DECOMP_INLINE, 0x96B6},
-	{0x2FAB, 0, 1 | DECOMP_INLINE, 0x96B9},
-	{0x2FAC, 0, 1 | DECOMP_INLINE, 0x96E8},
-	{0x2FAD, 0, 1 | DECOMP_INLINE, 0x9751},
-	{0x2FAE, 0, 1 | DECOMP_INLINE, 0x975E},
-	{0x2FAF, 0, 1 | DECOMP_INLINE, 0x9762},
-	{0x2FB0, 0, 1 | DECOMP_INLINE, 0x9769},
-	{0x2FB1, 0, 1 | DECOMP_INLINE, 0x97CB},
-	{0x2FB2, 0, 1 | DECOMP_INLINE, 0x97ED},
-	{0x2FB3, 0, 1 | DECOMP_INLINE, 0x97F3},
-	{0x2FB4, 0, 1 | DECOMP_INLINE, 0x9801},
-	{0x2FB5, 0, 1 | DECOMP_INLINE, 0x98A8},
-	{0x2FB6, 0, 1 | DECOMP_INLINE, 0x98DB},
-	{0x2FB7, 0, 1 | DECOMP_INLINE, 0x98DF},
-	{0x2FB8, 0, 1 | DECOMP_INLINE, 0x9996},
-	{0x2FB9, 0, 1 | DECOMP_INLINE, 0x9999},
-	{0x2FBA, 0, 1 | DECOMP_INLINE, 0x99AC},
-	{0x2FBB, 0, 1 | DECOMP_INLINE, 0x9AA8},
-	{0x2FBC, 0, 1 | DECOMP_INLINE, 0x9AD8},
-	{0x2FBD, 0, 1 | DECOMP_INLINE, 0x9ADF},
-	{0x2FBE, 0, 1 | DECOMP_INLINE, 0x9B25},
-	{0x2FBF, 0, 1 | DECOMP_INLINE, 0x9B2F},
-	{0x2FC0, 0, 1 | DECOMP_INLINE, 0x9B32},
-	{0x2FC1, 0, 1 | DECOMP_INLINE, 0x9B3C},
-	{0x2FC2, 0, 1 | DECOMP_INLINE, 0x9B5A},
-	{0x2FC3, 0, 1 | DECOMP_INLINE, 0x9CE5},
-	{0x2FC4, 0, 1 | DECOMP_INLINE, 0x9E75},
-	{0x2FC5, 0, 1 | DECOMP_INLINE, 0x9E7F},
-	{0x2FC6, 0, 1 | DECOMP_INLINE, 0x9EA5},
-	{0x2FC7, 0, 1 | DECOMP_INLINE, 0x9EBB},
-	{0x2FC8, 0, 1 | DECOMP_INLINE, 0x9EC3},
-	{0x2FC9, 0, 1 | DECOMP_INLINE, 0x9ECD},
-	{0x2FCA, 0, 1 | DECOMP_INLINE, 0x9ED1},
-	{0x2FCB, 0, 1 | DECOMP_INLINE, 0x9EF9},
-	{0x2FCC, 0, 1 | DECOMP_INLINE, 0x9EFD},
-	{0x2FCD, 0, 1 | DECOMP_INLINE, 0x9F0E},
-	{0x2FCE, 0, 1 | DECOMP_INLINE, 0x9F13},
-	{0x2FCF, 0, 1 | DECOMP_INLINE, 0x9F20},
-	{0x2FD0, 0, 1 | DECOMP_INLINE, 0x9F3B},
-	{0x2FD1, 0, 1 | DECOMP_INLINE, 0x9F4A},
-	{0x2FD2, 0, 1 | DECOMP_INLINE, 0x9F52},
-	{0x2FD3, 0, 1 | DECOMP_INLINE, 0x9F8D},
-	{0x2FD4, 0, 1 | DECOMP_INLINE, 0x9F9C},
-	{0x2FD5, 0, 1 | DECOMP_INLINE, 0x9FA0},
-	{0x3000, 0, 1 | DECOMP_INLINE, 0x0020},
+	{0x2E9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BCD},
+	{0x2EF3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F9F},
+	{0x2F00, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E00},
+	{0x2F01, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E28},
+	{0x2F02, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E36},
+	{0x2F03, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E3F},
+	{0x2F04, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E59},
+	{0x2F05, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E85},
+	{0x2F06, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E8C},
+	{0x2F07, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4EA0},
+	{0x2F08, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4EBA},
+	{0x2F09, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x513F},
+	{0x2F0A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5165},
+	{0x2F0B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x516B},
+	{0x2F0C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5182},
+	{0x2F0D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5196},
+	{0x2F0E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x51AB},
+	{0x2F0F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x51E0},
+	{0x2F10, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x51F5},
+	{0x2F11, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5200},
+	{0x2F12, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x529B},
+	{0x2F13, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x52F9},
+	{0x2F14, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5315},
+	{0x2F15, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x531A},
+	{0x2F16, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5338},
+	{0x2F17, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5341},
+	{0x2F18, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x535C},
+	{0x2F19, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5369},
+	{0x2F1A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5382},
+	{0x2F1B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53B6},
+	{0x2F1C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53C8},
+	{0x2F1D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53E3},
+	{0x2F1E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x56D7},
+	{0x2F1F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x571F},
+	{0x2F20, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x58EB},
+	{0x2F21, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5902},
+	{0x2F22, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x590A},
+	{0x2F23, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5915},
+	{0x2F24, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5927},
+	{0x2F25, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5973},
+	{0x2F26, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B50},
+	{0x2F27, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B80},
+	{0x2F28, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5BF8},
+	{0x2F29, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C0F},
+	{0x2F2A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C22},
+	{0x2F2B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C38},
+	{0x2F2C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C6E},
+	{0x2F2D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5C71},
+	{0x2F2E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DDB},
+	{0x2F2F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DE5},
+	{0x2F30, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DF1},
+	{0x2F31, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DFE},
+	{0x2F32, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E72},
+	{0x2F33, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E7A},
+	{0x2F34, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E7F},
+	{0x2F35, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5EF4},
+	{0x2F36, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5EFE},
+	{0x2F37, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F0B},
+	{0x2F38, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F13},
+	{0x2F39, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F50},
+	{0x2F3A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F61},
+	{0x2F3B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F73},
+	{0x2F3C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5FC3},
+	{0x2F3D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6208},
+	{0x2F3E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6236},
+	{0x2F3F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x624B},
+	{0x2F40, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x652F},
+	{0x2F41, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6534},
+	{0x2F42, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6587},
+	{0x2F43, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6597},
+	{0x2F44, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65A4},
+	{0x2F45, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65B9},
+	{0x2F46, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65E0},
+	{0x2F47, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65E5},
+	{0x2F48, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x66F0},
+	{0x2F49, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6708},
+	{0x2F4A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6728},
+	{0x2F4B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B20},
+	{0x2F4C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B62},
+	{0x2F4D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B79},
+	{0x2F4E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BB3},
+	{0x2F4F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BCB},
+	{0x2F50, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BD4},
+	{0x2F51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6BDB},
+	{0x2F52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6C0F},
+	{0x2F53, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6C14},
+	{0x2F54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6C34},
+	{0x2F55, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x706B},
+	{0x2F56, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x722A},
+	{0x2F57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7236},
+	{0x2F58, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x723B},
+	{0x2F59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x723F},
+	{0x2F5A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7247},
+	{0x2F5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7259},
+	{0x2F5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x725B},
+	{0x2F5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x72AC},
+	{0x2F5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7384},
+	{0x2F5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7389},
+	{0x2F60, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x74DC},
+	{0x2F61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x74E6},
+	{0x2F62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7518},
+	{0x2F63, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x751F},
+	{0x2F64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7528},
+	{0x2F65, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7530},
+	{0x2F66, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x758B},
+	{0x2F67, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7592},
+	{0x2F68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7676},
+	{0x2F69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x767D},
+	{0x2F6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76AE},
+	{0x2F6B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76BF},
+	{0x2F6C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76EE},
+	{0x2F6D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x77DB},
+	{0x2F6E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x77E2},
+	{0x2F6F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x77F3},
+	{0x2F70, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x793A},
+	{0x2F71, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x79B8},
+	{0x2F72, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x79BE},
+	{0x2F73, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7A74},
+	{0x2F74, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7ACB},
+	{0x2F75, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7AF9},
+	{0x2F76, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7C73},
+	{0x2F77, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7CF8},
+	{0x2F78, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7F36},
+	{0x2F79, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7F51},
+	{0x2F7A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7F8A},
+	{0x2F7B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7FBD},
+	{0x2F7C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8001},
+	{0x2F7D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x800C},
+	{0x2F7E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8012},
+	{0x2F7F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8033},
+	{0x2F80, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x807F},
+	{0x2F81, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8089},
+	{0x2F82, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81E3},
+	{0x2F83, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81EA},
+	{0x2F84, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81F3},
+	{0x2F85, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x81FC},
+	{0x2F86, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x820C},
+	{0x2F87, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x821B},
+	{0x2F88, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x821F},
+	{0x2F89, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x826E},
+	{0x2F8A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8272},
+	{0x2F8B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8278},
+	{0x2F8C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x864D},
+	{0x2F8D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x866B},
+	{0x2F8E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8840},
+	{0x2F8F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x884C},
+	{0x2F90, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8863},
+	{0x2F91, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x897E},
+	{0x2F92, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x898B},
+	{0x2F93, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x89D2},
+	{0x2F94, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8A00},
+	{0x2F95, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C37},
+	{0x2F96, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C46},
+	{0x2F97, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C55},
+	{0x2F98, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C78},
+	{0x2F99, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8C9D},
+	{0x2F9A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8D64},
+	{0x2F9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8D70},
+	{0x2F9C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8DB3},
+	{0x2F9D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8EAB},
+	{0x2F9E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8ECA},
+	{0x2F9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8F9B},
+	{0x2FA0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8FB0},
+	{0x2FA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8FB5},
+	{0x2FA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9091},
+	{0x2FA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9149},
+	{0x2FA4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x91C6},
+	{0x2FA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x91CC},
+	{0x2FA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x91D1},
+	{0x2FA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9577},
+	{0x2FA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9580},
+	{0x2FA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x961C},
+	{0x2FAA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x96B6},
+	{0x2FAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x96B9},
+	{0x2FAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x96E8},
+	{0x2FAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9751},
+	{0x2FAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x975E},
+	{0x2FAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9762},
+	{0x2FB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9769},
+	{0x2FB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x97CB},
+	{0x2FB2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x97ED},
+	{0x2FB3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x97F3},
+	{0x2FB4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9801},
+	{0x2FB5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x98A8},
+	{0x2FB6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x98DB},
+	{0x2FB7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x98DF},
+	{0x2FB8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9996},
+	{0x2FB9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9999},
+	{0x2FBA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x99AC},
+	{0x2FBB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9AA8},
+	{0x2FBC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9AD8},
+	{0x2FBD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9ADF},
+	{0x2FBE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B25},
+	{0x2FBF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B2F},
+	{0x2FC0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B32},
+	{0x2FC1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B3C},
+	{0x2FC2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9B5A},
+	{0x2FC3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9CE5},
+	{0x2FC4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9E75},
+	{0x2FC5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9E7F},
+	{0x2FC6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EA5},
+	{0x2FC7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EBB},
+	{0x2FC8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EC3},
+	{0x2FC9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9ECD},
+	{0x2FCA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9ED1},
+	{0x2FCB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EF9},
+	{0x2FCC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9EFD},
+	{0x2FCD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F0E},
+	{0x2FCE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F13},
+	{0x2FCF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F20},
+	{0x2FD0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F3B},
+	{0x2FD1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F4A},
+	{0x2FD2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F52},
+	{0x2FD3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F8D},
+	{0x2FD4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9F9C},
+	{0x2FD5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9FA0},
+	{0x3000, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0020},
 	{0x302A, 218, 0, 0},
 	{0x302B, 228, 0, 0},
 	{0x302C, 232, 0, 0},
 	{0x302D, 222, 0, 0},
 	{0x302E, 224, 0, 0},
 	{0x302F, 224, 0, 0},
-	{0x3036, 0, 1 | DECOMP_INLINE, 0x3012},
-	{0x3038, 0, 1 | DECOMP_INLINE, 0x5341},
-	{0x3039, 0, 1 | DECOMP_INLINE, 0x5344},
-	{0x303A, 0, 1 | DECOMP_INLINE, 0x5345},
+	{0x3036, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3012},
+	{0x3038, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5341},
+	{0x3039, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5344},
+	{0x303A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5345},
 	{0x304C, 0, 2, 2317},
 	{0x304E, 0, 2, 2319},
 	{0x3050, 0, 2, 2321},
@@ -2323,10 +2325,10 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x3094, 0, 2, 2367},
 	{0x3099, 8, 0, 0},
 	{0x309A, 8, 0, 0},
-	{0x309B, 0, 2 | DECOMP_NO_COMPOSE, 2369},	/* compatibility mapping */
-	{0x309C, 0, 2 | DECOMP_NO_COMPOSE, 2371},	/* compatibility mapping */
+	{0x309B, 0, 2 | DECOMP_COMPAT, 2369},
+	{0x309C, 0, 2 | DECOMP_COMPAT, 2371},
 	{0x309E, 0, 2, 2373},
-	{0x309F, 0, 2 | DECOMP_NO_COMPOSE, 2375},	/* compatibility mapping */
+	{0x309F, 0, 2 | DECOMP_COMPAT, 2375},
 	{0x30AC, 0, 2, 2377},
 	{0x30AE, 0, 2, 2379},
 	{0x30B0, 0, 2, 2381},
@@ -2358,617 +2360,617 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x30F9, 0, 2, 2433},
 	{0x30FA, 0, 2, 2435},
 	{0x30FE, 0, 2, 2437},
-	{0x30FF, 0, 2 | DECOMP_NO_COMPOSE, 2439},	/* compatibility mapping */
-	{0x3131, 0, 1 | DECOMP_INLINE, 0x1100},
-	{0x3132, 0, 1 | DECOMP_INLINE, 0x1101},
-	{0x3133, 0, 1 | DECOMP_INLINE, 0x11AA},
-	{0x3134, 0, 1 | DECOMP_INLINE, 0x1102},
-	{0x3135, 0, 1 | DECOMP_INLINE, 0x11AC},
-	{0x3136, 0, 1 | DECOMP_INLINE, 0x11AD},
-	{0x3137, 0, 1 | DECOMP_INLINE, 0x1103},
-	{0x3138, 0, 1 | DECOMP_INLINE, 0x1104},
-	{0x3139, 0, 1 | DECOMP_INLINE, 0x1105},
-	{0x313A, 0, 1 | DECOMP_INLINE, 0x11B0},
-	{0x313B, 0, 1 | DECOMP_INLINE, 0x11B1},
-	{0x313C, 0, 1 | DECOMP_INLINE, 0x11B2},
-	{0x313D, 0, 1 | DECOMP_INLINE, 0x11B3},
-	{0x313E, 0, 1 | DECOMP_INLINE, 0x11B4},
-	{0x313F, 0, 1 | DECOMP_INLINE, 0x11B5},
-	{0x3140, 0, 1 | DECOMP_INLINE, 0x111A},
-	{0x3141, 0, 1 | DECOMP_INLINE, 0x1106},
-	{0x3142, 0, 1 | DECOMP_INLINE, 0x1107},
-	{0x3143, 0, 1 | DECOMP_INLINE, 0x1108},
-	{0x3144, 0, 1 | DECOMP_INLINE, 0x1121},
-	{0x3145, 0, 1 | DECOMP_INLINE, 0x1109},
-	{0x3146, 0, 1 | DECOMP_INLINE, 0x110A},
-	{0x3147, 0, 1 | DECOMP_INLINE, 0x110B},
-	{0x3148, 0, 1 | DECOMP_INLINE, 0x110C},
-	{0x3149, 0, 1 | DECOMP_INLINE, 0x110D},
-	{0x314A, 0, 1 | DECOMP_INLINE, 0x110E},
-	{0x314B, 0, 1 | DECOMP_INLINE, 0x110F},
-	{0x314C, 0, 1 | DECOMP_INLINE, 0x1110},
-	{0x314D, 0, 1 | DECOMP_INLINE, 0x1111},
-	{0x314E, 0, 1 | DECOMP_INLINE, 0x1112},
-	{0x314F, 0, 1 | DECOMP_INLINE, 0x1161},
-	{0x3150, 0, 1 | DECOMP_INLINE, 0x1162},
-	{0x3151, 0, 1 | DECOMP_INLINE, 0x1163},
-	{0x3152, 0, 1 | DECOMP_INLINE, 0x1164},
-	{0x3153, 0, 1 | DECOMP_INLINE, 0x1165},
-	{0x3154, 0, 1 | DECOMP_INLINE, 0x1166},
-	{0x3155, 0, 1 | DECOMP_INLINE, 0x1167},
-	{0x3156, 0, 1 | DECOMP_INLINE, 0x1168},
-	{0x3157, 0, 1 | DECOMP_INLINE, 0x1169},
-	{0x3158, 0, 1 | DECOMP_INLINE, 0x116A},
-	{0x3159, 0, 1 | DECOMP_INLINE, 0x116B},
-	{0x315A, 0, 1 | DECOMP_INLINE, 0x116C},
-	{0x315B, 0, 1 | DECOMP_INLINE, 0x116D},
-	{0x315C, 0, 1 | DECOMP_INLINE, 0x116E},
-	{0x315D, 0, 1 | DECOMP_INLINE, 0x116F},
-	{0x315E, 0, 1 | DECOMP_INLINE, 0x1170},
-	{0x315F, 0, 1 | DECOMP_INLINE, 0x1171},
-	{0x3160, 0, 1 | DECOMP_INLINE, 0x1172},
-	{0x3161, 0, 1 | DECOMP_INLINE, 0x1173},
-	{0x3162, 0, 1 | DECOMP_INLINE, 0x1174},
-	{0x3163, 0, 1 | DECOMP_INLINE, 0x1175},
-	{0x3164, 0, 1 | DECOMP_INLINE, 0x1160},
-	{0x3165, 0, 1 | DECOMP_INLINE, 0x1114},
-	{0x3166, 0, 1 | DECOMP_INLINE, 0x1115},
-	{0x3167, 0, 1 | DECOMP_INLINE, 0x11C7},
-	{0x3168, 0, 1 | DECOMP_INLINE, 0x11C8},
-	{0x3169, 0, 1 | DECOMP_INLINE, 0x11CC},
-	{0x316A, 0, 1 | DECOMP_INLINE, 0x11CE},
-	{0x316B, 0, 1 | DECOMP_INLINE, 0x11D3},
-	{0x316C, 0, 1 | DECOMP_INLINE, 0x11D7},
-	{0x316D, 0, 1 | DECOMP_INLINE, 0x11D9},
-	{0x316E, 0, 1 | DECOMP_INLINE, 0x111C},
-	{0x316F, 0, 1 | DECOMP_INLINE, 0x11DD},
-	{0x3170, 0, 1 | DECOMP_INLINE, 0x11DF},
-	{0x3171, 0, 1 | DECOMP_INLINE, 0x111D},
-	{0x3172, 0, 1 | DECOMP_INLINE, 0x111E},
-	{0x3173, 0, 1 | DECOMP_INLINE, 0x1120},
-	{0x3174, 0, 1 | DECOMP_INLINE, 0x1122},
-	{0x3175, 0, 1 | DECOMP_INLINE, 0x1123},
-	{0x3176, 0, 1 | DECOMP_INLINE, 0x1127},
-	{0x3177, 0, 1 | DECOMP_INLINE, 0x1129},
-	{0x3178, 0, 1 | DECOMP_INLINE, 0x112B},
-	{0x3179, 0, 1 | DECOMP_INLINE, 0x112C},
-	{0x317A, 0, 1 | DECOMP_INLINE, 0x112D},
-	{0x317B, 0, 1 | DECOMP_INLINE, 0x112E},
-	{0x317C, 0, 1 | DECOMP_INLINE, 0x112F},
-	{0x317D, 0, 1 | DECOMP_INLINE, 0x1132},
-	{0x317E, 0, 1 | DECOMP_INLINE, 0x1136},
-	{0x317F, 0, 1 | DECOMP_INLINE, 0x1140},
-	{0x3180, 0, 1 | DECOMP_INLINE, 0x1147},
-	{0x3181, 0, 1 | DECOMP_INLINE, 0x114C},
-	{0x3182, 0, 1 | DECOMP_INLINE, 0x11F1},
-	{0x3183, 0, 1 | DECOMP_INLINE, 0x11F2},
-	{0x3184, 0, 1 | DECOMP_INLINE, 0x1157},
-	{0x3185, 0, 1 | DECOMP_INLINE, 0x1158},
-	{0x3186, 0, 1 | DECOMP_INLINE, 0x1159},
-	{0x3187, 0, 1 | DECOMP_INLINE, 0x1184},
-	{0x3188, 0, 1 | DECOMP_INLINE, 0x1185},
-	{0x3189, 0, 1 | DECOMP_INLINE, 0x1188},
-	{0x318A, 0, 1 | DECOMP_INLINE, 0x1191},
-	{0x318B, 0, 1 | DECOMP_INLINE, 0x1192},
-	{0x318C, 0, 1 | DECOMP_INLINE, 0x1194},
-	{0x318D, 0, 1 | DECOMP_INLINE, 0x119E},
-	{0x318E, 0, 1 | DECOMP_INLINE, 0x11A1},
-	{0x3192, 0, 1 | DECOMP_INLINE, 0x4E00},
-	{0x3193, 0, 1 | DECOMP_INLINE, 0x4E8C},
-	{0x3194, 0, 1 | DECOMP_INLINE, 0x4E09},
-	{0x3195, 0, 1 | DECOMP_INLINE, 0x56DB},
-	{0x3196, 0, 1 | DECOMP_INLINE, 0x4E0A},
-	{0x3197, 0, 1 | DECOMP_INLINE, 0x4E2D},
-	{0x3198, 0, 1 | DECOMP_INLINE, 0x4E0B},
-	{0x3199, 0, 1 | DECOMP_INLINE, 0x7532},
-	{0x319A, 0, 1 | DECOMP_INLINE, 0x4E59},
-	{0x319B, 0, 1 | DECOMP_INLINE, 0x4E19},
-	{0x319C, 0, 1 | DECOMP_INLINE, 0x4E01},
-	{0x319D, 0, 1 | DECOMP_INLINE, 0x5929},
-	{0x319E, 0, 1 | DECOMP_INLINE, 0x5730},
-	{0x319F, 0, 1 | DECOMP_INLINE, 0x4EBA},
-	{0x3200, 0, 3, 2441},
-	{0x3201, 0, 3, 2444},
-	{0x3202, 0, 3, 2447},
-	{0x3203, 0, 3, 2450},
-	{0x3204, 0, 3, 2453},
-	{0x3205, 0, 3, 2456},
-	{0x3206, 0, 3, 2459},
-	{0x3207, 0, 3, 2462},
-	{0x3208, 0, 3, 2465},
-	{0x3209, 0, 3, 2468},
-	{0x320A, 0, 3, 2471},
-	{0x320B, 0, 3, 2474},
-	{0x320C, 0, 3, 2477},
-	{0x320D, 0, 3, 2480},
-	{0x320E, 0, 4, 2483},
-	{0x320F, 0, 4, 2487},
-	{0x3210, 0, 4, 2491},
-	{0x3211, 0, 4, 2495},
-	{0x3212, 0, 4, 2499},
-	{0x3213, 0, 4, 2503},
-	{0x3214, 0, 4, 2507},
-	{0x3215, 0, 4, 2511},
-	{0x3216, 0, 4, 2515},
-	{0x3217, 0, 4, 2519},
-	{0x3218, 0, 4, 2523},
-	{0x3219, 0, 4, 2527},
-	{0x321A, 0, 4, 2531},
-	{0x321B, 0, 4, 2535},
-	{0x321C, 0, 4, 2539},
-	{0x321D, 0, 7, 2543},
-	{0x321E, 0, 6, 2550},
-	{0x3220, 0, 3, 2556},
-	{0x3221, 0, 3, 2559},
-	{0x3222, 0, 3, 2562},
-	{0x3223, 0, 3, 2565},
-	{0x3224, 0, 3, 2568},
-	{0x3225, 0, 3, 2571},
-	{0x3226, 0, 3, 2574},
-	{0x3227, 0, 3, 2577},
-	{0x3228, 0, 3, 2580},
-	{0x3229, 0, 3, 2583},
-	{0x322A, 0, 3, 2586},
-	{0x322B, 0, 3, 2589},
-	{0x322C, 0, 3, 2592},
-	{0x322D, 0, 3, 2595},
-	{0x322E, 0, 3, 2598},
-	{0x322F, 0, 3, 2601},
-	{0x3230, 0, 3, 2604},
-	{0x3231, 0, 3, 2607},
-	{0x3232, 0, 3, 2610},
-	{0x3233, 0, 3, 2613},
-	{0x3234, 0, 3, 2616},
-	{0x3235, 0, 3, 2619},
-	{0x3236, 0, 3, 2622},
-	{0x3237, 0, 3, 2625},
-	{0x3238, 0, 3, 2628},
-	{0x3239, 0, 3, 2631},
-	{0x323A, 0, 3, 2634},
-	{0x323B, 0, 3, 2637},
-	{0x323C, 0, 3, 2640},
-	{0x323D, 0, 3, 2643},
-	{0x323E, 0, 3, 2646},
-	{0x323F, 0, 3, 2649},
-	{0x3240, 0, 3, 2652},
-	{0x3241, 0, 3, 2655},
-	{0x3242, 0, 3, 2658},
-	{0x3243, 0, 3, 2661},
-	{0x3244, 0, 1 | DECOMP_INLINE, 0x554F},
-	{0x3245, 0, 1 | DECOMP_INLINE, 0x5E7C},
-	{0x3246, 0, 1 | DECOMP_INLINE, 0x6587},
-	{0x3247, 0, 1 | DECOMP_INLINE, 0x7B8F},
-	{0x3250, 0, 3, 2664},
-	{0x3251, 0, 2 | DECOMP_NO_COMPOSE, 2667},	/* compatibility mapping */
-	{0x3252, 0, 2 | DECOMP_NO_COMPOSE, 2669},	/* compatibility mapping */
-	{0x3253, 0, 2 | DECOMP_NO_COMPOSE, 2671},	/* compatibility mapping */
-	{0x3254, 0, 2 | DECOMP_NO_COMPOSE, 2673},	/* compatibility mapping */
-	{0x3255, 0, 2 | DECOMP_NO_COMPOSE, 2675},	/* compatibility mapping */
-	{0x3256, 0, 2 | DECOMP_NO_COMPOSE, 2677},	/* compatibility mapping */
-	{0x3257, 0, 2 | DECOMP_NO_COMPOSE, 2679},	/* compatibility mapping */
-	{0x3258, 0, 2 | DECOMP_NO_COMPOSE, 2681},	/* compatibility mapping */
-	{0x3259, 0, 2 | DECOMP_NO_COMPOSE, 2683},	/* compatibility mapping */
-	{0x325A, 0, 2 | DECOMP_NO_COMPOSE, 2685},	/* compatibility mapping */
-	{0x325B, 0, 2 | DECOMP_NO_COMPOSE, 2687},	/* compatibility mapping */
-	{0x325C, 0, 2 | DECOMP_NO_COMPOSE, 2689},	/* compatibility mapping */
-	{0x325D, 0, 2 | DECOMP_NO_COMPOSE, 2691},	/* compatibility mapping */
-	{0x325E, 0, 2 | DECOMP_NO_COMPOSE, 2693},	/* compatibility mapping */
-	{0x325F, 0, 2 | DECOMP_NO_COMPOSE, 2695},	/* compatibility mapping */
-	{0x3260, 0, 1 | DECOMP_INLINE, 0x1100},
-	{0x3261, 0, 1 | DECOMP_INLINE, 0x1102},
-	{0x3262, 0, 1 | DECOMP_INLINE, 0x1103},
-	{0x3263, 0, 1 | DECOMP_INLINE, 0x1105},
-	{0x3264, 0, 1 | DECOMP_INLINE, 0x1106},
-	{0x3265, 0, 1 | DECOMP_INLINE, 0x1107},
-	{0x3266, 0, 1 | DECOMP_INLINE, 0x1109},
-	{0x3267, 0, 1 | DECOMP_INLINE, 0x110B},
-	{0x3268, 0, 1 | DECOMP_INLINE, 0x110C},
-	{0x3269, 0, 1 | DECOMP_INLINE, 0x110E},
-	{0x326A, 0, 1 | DECOMP_INLINE, 0x110F},
-	{0x326B, 0, 1 | DECOMP_INLINE, 0x1110},
-	{0x326C, 0, 1 | DECOMP_INLINE, 0x1111},
-	{0x326D, 0, 1 | DECOMP_INLINE, 0x1112},
-	{0x326E, 0, 2 | DECOMP_NO_COMPOSE, 2697},	/* compatibility mapping */
-	{0x326F, 0, 2 | DECOMP_NO_COMPOSE, 2699},	/* compatibility mapping */
-	{0x3270, 0, 2 | DECOMP_NO_COMPOSE, 2701},	/* compatibility mapping */
-	{0x3271, 0, 2 | DECOMP_NO_COMPOSE, 2703},	/* compatibility mapping */
-	{0x3272, 0, 2 | DECOMP_NO_COMPOSE, 2705},	/* compatibility mapping */
-	{0x3273, 0, 2 | DECOMP_NO_COMPOSE, 2707},	/* compatibility mapping */
-	{0x3274, 0, 2 | DECOMP_NO_COMPOSE, 2709},	/* compatibility mapping */
-	{0x3275, 0, 2 | DECOMP_NO_COMPOSE, 2711},	/* compatibility mapping */
-	{0x3276, 0, 2 | DECOMP_NO_COMPOSE, 2713},	/* compatibility mapping */
-	{0x3277, 0, 2 | DECOMP_NO_COMPOSE, 2715},	/* compatibility mapping */
-	{0x3278, 0, 2 | DECOMP_NO_COMPOSE, 2717},	/* compatibility mapping */
-	{0x3279, 0, 2 | DECOMP_NO_COMPOSE, 2719},	/* compatibility mapping */
-	{0x327A, 0, 2 | DECOMP_NO_COMPOSE, 2721},	/* compatibility mapping */
-	{0x327B, 0, 2 | DECOMP_NO_COMPOSE, 2723},	/* compatibility mapping */
-	{0x327C, 0, 5, 2725},
-	{0x327D, 0, 4, 2730},
-	{0x327E, 0, 2 | DECOMP_NO_COMPOSE, 2734},	/* compatibility mapping */
-	{0x3280, 0, 1 | DECOMP_INLINE, 0x4E00},
-	{0x3281, 0, 1 | DECOMP_INLINE, 0x4E8C},
-	{0x3282, 0, 1 | DECOMP_INLINE, 0x4E09},
-	{0x3283, 0, 1 | DECOMP_INLINE, 0x56DB},
-	{0x3284, 0, 1 | DECOMP_INLINE, 0x4E94},
-	{0x3285, 0, 1 | DECOMP_INLINE, 0x516D},
-	{0x3286, 0, 1 | DECOMP_INLINE, 0x4E03},
-	{0x3287, 0, 1 | DECOMP_INLINE, 0x516B},
-	{0x3288, 0, 1 | DECOMP_INLINE, 0x4E5D},
-	{0x3289, 0, 1 | DECOMP_INLINE, 0x5341},
-	{0x328A, 0, 1 | DECOMP_INLINE, 0x6708},
-	{0x328B, 0, 1 | DECOMP_INLINE, 0x706B},
-	{0x328C, 0, 1 | DECOMP_INLINE, 0x6C34},
-	{0x328D, 0, 1 | DECOMP_INLINE, 0x6728},
-	{0x328E, 0, 1 | DECOMP_INLINE, 0x91D1},
-	{0x328F, 0, 1 | DECOMP_INLINE, 0x571F},
-	{0x3290, 0, 1 | DECOMP_INLINE, 0x65E5},
-	{0x3291, 0, 1 | DECOMP_INLINE, 0x682A},
-	{0x3292, 0, 1 | DECOMP_INLINE, 0x6709},
-	{0x3293, 0, 1 | DECOMP_INLINE, 0x793E},
-	{0x3294, 0, 1 | DECOMP_INLINE, 0x540D},
-	{0x3295, 0, 1 | DECOMP_INLINE, 0x7279},
-	{0x3296, 0, 1 | DECOMP_INLINE, 0x8CA1},
-	{0x3297, 0, 1 | DECOMP_INLINE, 0x795D},
-	{0x3298, 0, 1 | DECOMP_INLINE, 0x52B4},
-	{0x3299, 0, 1 | DECOMP_INLINE, 0x79D8},
-	{0x329A, 0, 1 | DECOMP_INLINE, 0x7537},
-	{0x329B, 0, 1 | DECOMP_INLINE, 0x5973},
-	{0x329C, 0, 1 | DECOMP_INLINE, 0x9069},
-	{0x329D, 0, 1 | DECOMP_INLINE, 0x512A},
-	{0x329E, 0, 1 | DECOMP_INLINE, 0x5370},
-	{0x329F, 0, 1 | DECOMP_INLINE, 0x6CE8},
-	{0x32A0, 0, 1 | DECOMP_INLINE, 0x9805},
-	{0x32A1, 0, 1 | DECOMP_INLINE, 0x4F11},
-	{0x32A2, 0, 1 | DECOMP_INLINE, 0x5199},
-	{0x32A3, 0, 1 | DECOMP_INLINE, 0x6B63},
-	{0x32A4, 0, 1 | DECOMP_INLINE, 0x4E0A},
-	{0x32A5, 0, 1 | DECOMP_INLINE, 0x4E2D},
-	{0x32A6, 0, 1 | DECOMP_INLINE, 0x4E0B},
-	{0x32A7, 0, 1 | DECOMP_INLINE, 0x5DE6},
-	{0x32A8, 0, 1 | DECOMP_INLINE, 0x53F3},
-	{0x32A9, 0, 1 | DECOMP_INLINE, 0x533B},
-	{0x32AA, 0, 1 | DECOMP_INLINE, 0x5B97},
-	{0x32AB, 0, 1 | DECOMP_INLINE, 0x5B66},
-	{0x32AC, 0, 1 | DECOMP_INLINE, 0x76E3},
-	{0x32AD, 0, 1 | DECOMP_INLINE, 0x4F01},
-	{0x32AE, 0, 1 | DECOMP_INLINE, 0x8CC7},
-	{0x32AF, 0, 1 | DECOMP_INLINE, 0x5354},
-	{0x32B0, 0, 1 | DECOMP_INLINE, 0x591C},
-	{0x32B1, 0, 2 | DECOMP_NO_COMPOSE, 2736},	/* compatibility mapping */
-	{0x32B2, 0, 2 | DECOMP_NO_COMPOSE, 2738},	/* compatibility mapping */
-	{0x32B3, 0, 2 | DECOMP_NO_COMPOSE, 2740},	/* compatibility mapping */
-	{0x32B4, 0, 2 | DECOMP_NO_COMPOSE, 2742},	/* compatibility mapping */
-	{0x32B5, 0, 2 | DECOMP_NO_COMPOSE, 2744},	/* compatibility mapping */
-	{0x32B6, 0, 2 | DECOMP_NO_COMPOSE, 2746},	/* compatibility mapping */
-	{0x32B7, 0, 2 | DECOMP_NO_COMPOSE, 2748},	/* compatibility mapping */
-	{0x32B8, 0, 2 | DECOMP_NO_COMPOSE, 2750},	/* compatibility mapping */
-	{0x32B9, 0, 2 | DECOMP_NO_COMPOSE, 2752},	/* compatibility mapping */
-	{0x32BA, 0, 2 | DECOMP_NO_COMPOSE, 2754},	/* compatibility mapping */
-	{0x32BB, 0, 2 | DECOMP_NO_COMPOSE, 2756},	/* compatibility mapping */
-	{0x32BC, 0, 2 | DECOMP_NO_COMPOSE, 2758},	/* compatibility mapping */
-	{0x32BD, 0, 2 | DECOMP_NO_COMPOSE, 2760},	/* compatibility mapping */
-	{0x32BE, 0, 2 | DECOMP_NO_COMPOSE, 2762},	/* compatibility mapping */
-	{0x32BF, 0, 2 | DECOMP_NO_COMPOSE, 2764},	/* compatibility mapping */
-	{0x32C0, 0, 2 | DECOMP_NO_COMPOSE, 2766},	/* compatibility mapping */
-	{0x32C1, 0, 2 | DECOMP_NO_COMPOSE, 2768},	/* compatibility mapping */
-	{0x32C2, 0, 2 | DECOMP_NO_COMPOSE, 2770},	/* compatibility mapping */
-	{0x32C3, 0, 2 | DECOMP_NO_COMPOSE, 2772},	/* compatibility mapping */
-	{0x32C4, 0, 2 | DECOMP_NO_COMPOSE, 2774},	/* compatibility mapping */
-	{0x32C5, 0, 2 | DECOMP_NO_COMPOSE, 2776},	/* compatibility mapping */
-	{0x32C6, 0, 2 | DECOMP_NO_COMPOSE, 2778},	/* compatibility mapping */
-	{0x32C7, 0, 2 | DECOMP_NO_COMPOSE, 2780},	/* compatibility mapping */
-	{0x32C8, 0, 2 | DECOMP_NO_COMPOSE, 2782},	/* compatibility mapping */
-	{0x32C9, 0, 3, 2784},
-	{0x32CA, 0, 3, 2787},
-	{0x32CB, 0, 3, 2790},
-	{0x32CC, 0, 2 | DECOMP_NO_COMPOSE, 2793},	/* compatibility mapping */
-	{0x32CD, 0, 3, 2795},
-	{0x32CE, 0, 2 | DECOMP_NO_COMPOSE, 2798},	/* compatibility mapping */
-	{0x32CF, 0, 3, 2800},
-	{0x32D0, 0, 1 | DECOMP_INLINE, 0x30A2},
-	{0x32D1, 0, 1 | DECOMP_INLINE, 0x30A4},
-	{0x32D2, 0, 1 | DECOMP_INLINE, 0x30A6},
-	{0x32D3, 0, 1 | DECOMP_INLINE, 0x30A8},
-	{0x32D4, 0, 1 | DECOMP_INLINE, 0x30AA},
-	{0x32D5, 0, 1 | DECOMP_INLINE, 0x30AB},
-	{0x32D6, 0, 1 | DECOMP_INLINE, 0x30AD},
-	{0x32D7, 0, 1 | DECOMP_INLINE, 0x30AF},
-	{0x32D8, 0, 1 | DECOMP_INLINE, 0x30B1},
-	{0x32D9, 0, 1 | DECOMP_INLINE, 0x30B3},
-	{0x32DA, 0, 1 | DECOMP_INLINE, 0x30B5},
-	{0x32DB, 0, 1 | DECOMP_INLINE, 0x30B7},
-	{0x32DC, 0, 1 | DECOMP_INLINE, 0x30B9},
-	{0x32DD, 0, 1 | DECOMP_INLINE, 0x30BB},
-	{0x32DE, 0, 1 | DECOMP_INLINE, 0x30BD},
-	{0x32DF, 0, 1 | DECOMP_INLINE, 0x30BF},
-	{0x32E0, 0, 1 | DECOMP_INLINE, 0x30C1},
-	{0x32E1, 0, 1 | DECOMP_INLINE, 0x30C4},
-	{0x32E2, 0, 1 | DECOMP_INLINE, 0x30C6},
-	{0x32E3, 0, 1 | DECOMP_INLINE, 0x30C8},
-	{0x32E4, 0, 1 | DECOMP_INLINE, 0x30CA},
-	{0x32E5, 0, 1 | DECOMP_INLINE, 0x30CB},
-	{0x32E6, 0, 1 | DECOMP_INLINE, 0x30CC},
-	{0x32E7, 0, 1 | DECOMP_INLINE, 0x30CD},
-	{0x32E8, 0, 1 | DECOMP_INLINE, 0x30CE},
-	{0x32E9, 0, 1 | DECOMP_INLINE, 0x30CF},
-	{0x32EA, 0, 1 | DECOMP_INLINE, 0x30D2},
-	{0x32EB, 0, 1 | DECOMP_INLINE, 0x30D5},
-	{0x32EC, 0, 1 | DECOMP_INLINE, 0x30D8},
-	{0x32ED, 0, 1 | DECOMP_INLINE, 0x30DB},
-	{0x32EE, 0, 1 | DECOMP_INLINE, 0x30DE},
-	{0x32EF, 0, 1 | DECOMP_INLINE, 0x30DF},
-	{0x32F0, 0, 1 | DECOMP_INLINE, 0x30E0},
-	{0x32F1, 0, 1 | DECOMP_INLINE, 0x30E1},
-	{0x32F2, 0, 1 | DECOMP_INLINE, 0x30E2},
-	{0x32F3, 0, 1 | DECOMP_INLINE, 0x30E4},
-	{0x32F4, 0, 1 | DECOMP_INLINE, 0x30E6},
-	{0x32F5, 0, 1 | DECOMP_INLINE, 0x30E8},
-	{0x32F6, 0, 1 | DECOMP_INLINE, 0x30E9},
-	{0x32F7, 0, 1 | DECOMP_INLINE, 0x30EA},
-	{0x32F8, 0, 1 | DECOMP_INLINE, 0x30EB},
-	{0x32F9, 0, 1 | DECOMP_INLINE, 0x30EC},
-	{0x32FA, 0, 1 | DECOMP_INLINE, 0x30ED},
-	{0x32FB, 0, 1 | DECOMP_INLINE, 0x30EF},
-	{0x32FC, 0, 1 | DECOMP_INLINE, 0x30F0},
-	{0x32FD, 0, 1 | DECOMP_INLINE, 0x30F1},
-	{0x32FE, 0, 1 | DECOMP_INLINE, 0x30F2},
-	{0x32FF, 0, 2 | DECOMP_NO_COMPOSE, 2803},	/* compatibility mapping */
-	{0x3300, 0, 4, 2805},
-	{0x3301, 0, 4, 2809},
-	{0x3302, 0, 4, 2813},
-	{0x3303, 0, 3, 2817},
-	{0x3304, 0, 4, 2820},
-	{0x3305, 0, 3, 2824},
-	{0x3306, 0, 3, 2827},
-	{0x3307, 0, 5, 2830},
-	{0x3308, 0, 4, 2835},
-	{0x3309, 0, 3, 2839},
-	{0x330A, 0, 3, 2842},
-	{0x330B, 0, 3, 2845},
-	{0x330C, 0, 4, 2848},
-	{0x330D, 0, 4, 2852},
-	{0x330E, 0, 3, 2856},
-	{0x330F, 0, 3, 2859},
-	{0x3310, 0, 2 | DECOMP_NO_COMPOSE, 2862},	/* compatibility mapping */
-	{0x3311, 0, 3, 2864},
-	{0x3312, 0, 4, 2867},
-	{0x3313, 0, 4, 2871},
-	{0x3314, 0, 2 | DECOMP_NO_COMPOSE, 2875},	/* compatibility mapping */
-	{0x3315, 0, 5, 2877},
-	{0x3316, 0, 6, 2882},
-	{0x3317, 0, 5, 2888},
-	{0x3318, 0, 3, 2893},
-	{0x3319, 0, 5, 2896},
-	{0x331A, 0, 5, 2901},
-	{0x331B, 0, 4, 2906},
-	{0x331C, 0, 3, 2910},
-	{0x331D, 0, 3, 2913},
-	{0x331E, 0, 3, 2916},
-	{0x331F, 0, 4, 2919},
-	{0x3320, 0, 5, 2923},
-	{0x3321, 0, 4, 2928},
-	{0x3322, 0, 3, 2932},
-	{0x3323, 0, 3, 2935},
-	{0x3324, 0, 3, 2938},
-	{0x3325, 0, 2 | DECOMP_NO_COMPOSE, 2941},	/* compatibility mapping */
-	{0x3326, 0, 2 | DECOMP_NO_COMPOSE, 2943},	/* compatibility mapping */
-	{0x3327, 0, 2 | DECOMP_NO_COMPOSE, 2945},	/* compatibility mapping */
-	{0x3328, 0, 2 | DECOMP_NO_COMPOSE, 2947},	/* compatibility mapping */
-	{0x3329, 0, 3, 2949},
-	{0x332A, 0, 3, 2952},
-	{0x332B, 0, 5, 2955},
-	{0x332C, 0, 3, 2960},
-	{0x332D, 0, 4, 2963},
-	{0x332E, 0, 5, 2967},
-	{0x332F, 0, 3, 2972},
-	{0x3330, 0, 2 | DECOMP_NO_COMPOSE, 2975},	/* compatibility mapping */
-	{0x3331, 0, 2 | DECOMP_NO_COMPOSE, 2977},	/* compatibility mapping */
-	{0x3332, 0, 5, 2979},
-	{0x3333, 0, 4, 2984},
-	{0x3334, 0, 5, 2988},
-	{0x3335, 0, 3, 2993},
-	{0x3336, 0, 5, 2996},
-	{0x3337, 0, 2 | DECOMP_NO_COMPOSE, 3001},	/* compatibility mapping */
-	{0x3338, 0, 3, 3003},
-	{0x3339, 0, 3, 3006},
-	{0x333A, 0, 3, 3009},
-	{0x333B, 0, 3, 3012},
-	{0x333C, 0, 3, 3015},
-	{0x333D, 0, 4, 3018},
-	{0x333E, 0, 3, 3022},
-	{0x333F, 0, 2 | DECOMP_NO_COMPOSE, 3025},	/* compatibility mapping */
-	{0x3340, 0, 3, 3027},
-	{0x3341, 0, 3, 3030},
-	{0x3342, 0, 3, 3033},
-	{0x3343, 0, 4, 3036},
-	{0x3344, 0, 3, 3040},
-	{0x3345, 0, 3, 3043},
-	{0x3346, 0, 3, 3046},
-	{0x3347, 0, 5, 3049},
-	{0x3348, 0, 4, 3054},
-	{0x3349, 0, 2 | DECOMP_NO_COMPOSE, 3058},	/* compatibility mapping */
-	{0x334A, 0, 5, 3060},
-	{0x334B, 0, 2 | DECOMP_NO_COMPOSE, 3065},	/* compatibility mapping */
-	{0x334C, 0, 4, 3067},
-	{0x334D, 0, 4, 3071},
-	{0x334E, 0, 3, 3075},
-	{0x334F, 0, 3, 3078},
-	{0x3350, 0, 3, 3081},
-	{0x3351, 0, 4, 3084},
-	{0x3352, 0, 2 | DECOMP_NO_COMPOSE, 3088},	/* compatibility mapping */
-	{0x3353, 0, 3, 3090},
-	{0x3354, 0, 4, 3093},
-	{0x3355, 0, 2 | DECOMP_NO_COMPOSE, 3097},	/* compatibility mapping */
-	{0x3356, 0, 5, 3099},
-	{0x3357, 0, 3, 3104},
-	{0x3358, 0, 2 | DECOMP_NO_COMPOSE, 3107},	/* compatibility mapping */
-	{0x3359, 0, 2 | DECOMP_NO_COMPOSE, 3109},	/* compatibility mapping */
-	{0x335A, 0, 2 | DECOMP_NO_COMPOSE, 3111},	/* compatibility mapping */
-	{0x335B, 0, 2 | DECOMP_NO_COMPOSE, 3113},	/* compatibility mapping */
-	{0x335C, 0, 2 | DECOMP_NO_COMPOSE, 3115},	/* compatibility mapping */
-	{0x335D, 0, 2 | DECOMP_NO_COMPOSE, 3117},	/* compatibility mapping */
-	{0x335E, 0, 2 | DECOMP_NO_COMPOSE, 3119},	/* compatibility mapping */
-	{0x335F, 0, 2 | DECOMP_NO_COMPOSE, 3121},	/* compatibility mapping */
-	{0x3360, 0, 2 | DECOMP_NO_COMPOSE, 3123},	/* compatibility mapping */
-	{0x3361, 0, 2 | DECOMP_NO_COMPOSE, 3125},	/* compatibility mapping */
-	{0x3362, 0, 3, 3127},
-	{0x3363, 0, 3, 3130},
-	{0x3364, 0, 3, 3133},
-	{0x3365, 0, 3, 3136},
-	{0x3366, 0, 3, 3139},
-	{0x3367, 0, 3, 3142},
-	{0x3368, 0, 3, 3145},
-	{0x3369, 0, 3, 3148},
-	{0x336A, 0, 3, 3151},
-	{0x336B, 0, 3, 3154},
-	{0x336C, 0, 3, 3157},
-	{0x336D, 0, 3, 3160},
-	{0x336E, 0, 3, 3163},
-	{0x336F, 0, 3, 3166},
-	{0x3370, 0, 3, 3169},
-	{0x3371, 0, 3, 3172},
-	{0x3372, 0, 2 | DECOMP_NO_COMPOSE, 3175},	/* compatibility mapping */
-	{0x3373, 0, 2 | DECOMP_NO_COMPOSE, 3177},	/* compatibility mapping */
-	{0x3374, 0, 3, 3179},
-	{0x3375, 0, 2 | DECOMP_NO_COMPOSE, 3182},	/* compatibility mapping */
-	{0x3376, 0, 2 | DECOMP_NO_COMPOSE, 3184},	/* compatibility mapping */
-	{0x3377, 0, 2 | DECOMP_NO_COMPOSE, 3186},	/* compatibility mapping */
-	{0x3378, 0, 3, 3188},
-	{0x3379, 0, 3, 3191},
-	{0x337A, 0, 2 | DECOMP_NO_COMPOSE, 3194},	/* compatibility mapping */
-	{0x337B, 0, 2 | DECOMP_NO_COMPOSE, 3196},	/* compatibility mapping */
-	{0x337C, 0, 2 | DECOMP_NO_COMPOSE, 3198},	/* compatibility mapping */
-	{0x337D, 0, 2 | DECOMP_NO_COMPOSE, 3200},	/* compatibility mapping */
-	{0x337E, 0, 2 | DECOMP_NO_COMPOSE, 3202},	/* compatibility mapping */
-	{0x337F, 0, 4, 3204},
-	{0x3380, 0, 2 | DECOMP_NO_COMPOSE, 3208},	/* compatibility mapping */
-	{0x3381, 0, 2 | DECOMP_NO_COMPOSE, 3210},	/* compatibility mapping */
-	{0x3382, 0, 2 | DECOMP_NO_COMPOSE, 3212},	/* compatibility mapping */
-	{0x3383, 0, 2 | DECOMP_NO_COMPOSE, 3214},	/* compatibility mapping */
-	{0x3384, 0, 2 | DECOMP_NO_COMPOSE, 3216},	/* compatibility mapping */
-	{0x3385, 0, 2 | DECOMP_NO_COMPOSE, 3218},	/* compatibility mapping */
-	{0x3386, 0, 2 | DECOMP_NO_COMPOSE, 3220},	/* compatibility mapping */
-	{0x3387, 0, 2 | DECOMP_NO_COMPOSE, 3222},	/* compatibility mapping */
-	{0x3388, 0, 3, 3224},
-	{0x3389, 0, 4, 3227},
-	{0x338A, 0, 2 | DECOMP_NO_COMPOSE, 3231},	/* compatibility mapping */
-	{0x338B, 0, 2 | DECOMP_NO_COMPOSE, 3233},	/* compatibility mapping */
-	{0x338C, 0, 2 | DECOMP_NO_COMPOSE, 3235},	/* compatibility mapping */
-	{0x338D, 0, 2 | DECOMP_NO_COMPOSE, 3237},	/* compatibility mapping */
-	{0x338E, 0, 2 | DECOMP_NO_COMPOSE, 3239},	/* compatibility mapping */
-	{0x338F, 0, 2 | DECOMP_NO_COMPOSE, 3241},	/* compatibility mapping */
-	{0x3390, 0, 2 | DECOMP_NO_COMPOSE, 3243},	/* compatibility mapping */
-	{0x3391, 0, 3, 3245},
-	{0x3392, 0, 3, 3248},
-	{0x3393, 0, 3, 3251},
-	{0x3394, 0, 3, 3254},
-	{0x3395, 0, 2 | DECOMP_NO_COMPOSE, 3257},	/* compatibility mapping */
-	{0x3396, 0, 2 | DECOMP_NO_COMPOSE, 3259},	/* compatibility mapping */
-	{0x3397, 0, 2 | DECOMP_NO_COMPOSE, 3261},	/* compatibility mapping */
-	{0x3398, 0, 2 | DECOMP_NO_COMPOSE, 3263},	/* compatibility mapping */
-	{0x3399, 0, 2 | DECOMP_NO_COMPOSE, 3265},	/* compatibility mapping */
-	{0x339A, 0, 2 | DECOMP_NO_COMPOSE, 3267},	/* compatibility mapping */
-	{0x339B, 0, 2 | DECOMP_NO_COMPOSE, 3269},	/* compatibility mapping */
-	{0x339C, 0, 2 | DECOMP_NO_COMPOSE, 3271},	/* compatibility mapping */
-	{0x339D, 0, 2 | DECOMP_NO_COMPOSE, 3273},	/* compatibility mapping */
-	{0x339E, 0, 2 | DECOMP_NO_COMPOSE, 3275},	/* compatibility mapping */
-	{0x339F, 0, 3, 3277},
-	{0x33A0, 0, 3, 3280},
-	{0x33A1, 0, 2 | DECOMP_NO_COMPOSE, 3283},	/* compatibility mapping */
-	{0x33A2, 0, 3, 3285},
-	{0x33A3, 0, 3, 3288},
-	{0x33A4, 0, 3, 3291},
-	{0x33A5, 0, 2 | DECOMP_NO_COMPOSE, 3294},	/* compatibility mapping */
-	{0x33A6, 0, 3, 3296},
-	{0x33A7, 0, 3, 3299},
-	{0x33A8, 0, 4, 3302},
-	{0x33A9, 0, 2 | DECOMP_NO_COMPOSE, 3306},	/* compatibility mapping */
-	{0x33AA, 0, 3, 3308},
-	{0x33AB, 0, 3, 3311},
-	{0x33AC, 0, 3, 3314},
-	{0x33AD, 0, 3, 3317},
-	{0x33AE, 0, 5, 3320},
-	{0x33AF, 0, 6, 3325},
-	{0x33B0, 0, 2 | DECOMP_NO_COMPOSE, 3331},	/* compatibility mapping */
-	{0x33B1, 0, 2 | DECOMP_NO_COMPOSE, 3333},	/* compatibility mapping */
-	{0x33B2, 0, 2 | DECOMP_NO_COMPOSE, 3335},	/* compatibility mapping */
-	{0x33B3, 0, 2 | DECOMP_NO_COMPOSE, 3337},	/* compatibility mapping */
-	{0x33B4, 0, 2 | DECOMP_NO_COMPOSE, 3339},	/* compatibility mapping */
-	{0x33B5, 0, 2 | DECOMP_NO_COMPOSE, 3341},	/* compatibility mapping */
-	{0x33B6, 0, 2 | DECOMP_NO_COMPOSE, 3343},	/* compatibility mapping */
-	{0x33B7, 0, 2 | DECOMP_NO_COMPOSE, 3345},	/* compatibility mapping */
-	{0x33B8, 0, 2 | DECOMP_NO_COMPOSE, 3347},	/* compatibility mapping */
-	{0x33B9, 0, 2 | DECOMP_NO_COMPOSE, 3349},	/* compatibility mapping */
-	{0x33BA, 0, 2 | DECOMP_NO_COMPOSE, 3351},	/* compatibility mapping */
-	{0x33BB, 0, 2 | DECOMP_NO_COMPOSE, 3353},	/* compatibility mapping */
-	{0x33BC, 0, 2 | DECOMP_NO_COMPOSE, 3355},	/* compatibility mapping */
-	{0x33BD, 0, 2 | DECOMP_NO_COMPOSE, 3357},	/* compatibility mapping */
-	{0x33BE, 0, 2 | DECOMP_NO_COMPOSE, 3359},	/* compatibility mapping */
-	{0x33BF, 0, 2 | DECOMP_NO_COMPOSE, 3361},	/* compatibility mapping */
-	{0x33C0, 0, 2 | DECOMP_NO_COMPOSE, 3363},	/* compatibility mapping */
-	{0x33C1, 0, 2 | DECOMP_NO_COMPOSE, 3365},	/* compatibility mapping */
-	{0x33C2, 0, 4, 3367},
-	{0x33C3, 0, 2 | DECOMP_NO_COMPOSE, 3371},	/* compatibility mapping */
-	{0x33C4, 0, 2 | DECOMP_NO_COMPOSE, 3373},	/* compatibility mapping */
-	{0x33C5, 0, 2 | DECOMP_NO_COMPOSE, 3375},	/* compatibility mapping */
-	{0x33C6, 0, 4, 3377},
-	{0x33C7, 0, 3, 3381},
-	{0x33C8, 0, 2 | DECOMP_NO_COMPOSE, 3384},	/* compatibility mapping */
-	{0x33C9, 0, 2 | DECOMP_NO_COMPOSE, 3386},	/* compatibility mapping */
-	{0x33CA, 0, 2 | DECOMP_NO_COMPOSE, 3388},	/* compatibility mapping */
-	{0x33CB, 0, 2 | DECOMP_NO_COMPOSE, 3390},	/* compatibility mapping */
-	{0x33CC, 0, 2 | DECOMP_NO_COMPOSE, 3392},	/* compatibility mapping */
-	{0x33CD, 0, 2 | DECOMP_NO_COMPOSE, 3394},	/* compatibility mapping */
-	{0x33CE, 0, 2 | DECOMP_NO_COMPOSE, 3396},	/* compatibility mapping */
-	{0x33CF, 0, 2 | DECOMP_NO_COMPOSE, 3398},	/* compatibility mapping */
-	{0x33D0, 0, 2 | DECOMP_NO_COMPOSE, 3400},	/* compatibility mapping */
-	{0x33D1, 0, 2 | DECOMP_NO_COMPOSE, 3402},	/* compatibility mapping */
-	{0x33D2, 0, 3, 3404},
-	{0x33D3, 0, 2 | DECOMP_NO_COMPOSE, 3407},	/* compatibility mapping */
-	{0x33D4, 0, 2 | DECOMP_NO_COMPOSE, 3409},	/* compatibility mapping */
-	{0x33D5, 0, 3, 3411},
-	{0x33D6, 0, 3, 3414},
-	{0x33D7, 0, 2 | DECOMP_NO_COMPOSE, 3417},	/* compatibility mapping */
-	{0x33D8, 0, 4, 3419},
-	{0x33D9, 0, 3, 3423},
-	{0x33DA, 0, 2 | DECOMP_NO_COMPOSE, 3426},	/* compatibility mapping */
-	{0x33DB, 0, 2 | DECOMP_NO_COMPOSE, 3428},	/* compatibility mapping */
-	{0x33DC, 0, 2 | DECOMP_NO_COMPOSE, 3430},	/* compatibility mapping */
-	{0x33DD, 0, 2 | DECOMP_NO_COMPOSE, 3432},	/* compatibility mapping */
-	{0x33DE, 0, 3, 3434},
-	{0x33DF, 0, 3, 3437},
-	{0x33E0, 0, 2 | DECOMP_NO_COMPOSE, 3440},	/* compatibility mapping */
-	{0x33E1, 0, 2 | DECOMP_NO_COMPOSE, 3442},	/* compatibility mapping */
-	{0x33E2, 0, 2 | DECOMP_NO_COMPOSE, 3444},	/* compatibility mapping */
-	{0x33E3, 0, 2 | DECOMP_NO_COMPOSE, 3446},	/* compatibility mapping */
-	{0x33E4, 0, 2 | DECOMP_NO_COMPOSE, 3448},	/* compatibility mapping */
-	{0x33E5, 0, 2 | DECOMP_NO_COMPOSE, 3450},	/* compatibility mapping */
-	{0x33E6, 0, 2 | DECOMP_NO_COMPOSE, 3452},	/* compatibility mapping */
-	{0x33E7, 0, 2 | DECOMP_NO_COMPOSE, 3454},	/* compatibility mapping */
-	{0x33E8, 0, 2 | DECOMP_NO_COMPOSE, 3456},	/* compatibility mapping */
-	{0x33E9, 0, 3, 3458},
-	{0x33EA, 0, 3, 3461},
-	{0x33EB, 0, 3, 3464},
-	{0x33EC, 0, 3, 3467},
-	{0x33ED, 0, 3, 3470},
-	{0x33EE, 0, 3, 3473},
-	{0x33EF, 0, 3, 3476},
-	{0x33F0, 0, 3, 3479},
-	{0x33F1, 0, 3, 3482},
-	{0x33F2, 0, 3, 3485},
-	{0x33F3, 0, 3, 3488},
-	{0x33F4, 0, 3, 3491},
-	{0x33F5, 0, 3, 3494},
-	{0x33F6, 0, 3, 3497},
-	{0x33F7, 0, 3, 3500},
-	{0x33F8, 0, 3, 3503},
-	{0x33F9, 0, 3, 3506},
-	{0x33FA, 0, 3, 3509},
-	{0x33FB, 0, 3, 3512},
-	{0x33FC, 0, 3, 3515},
-	{0x33FD, 0, 3, 3518},
-	{0x33FE, 0, 3, 3521},
-	{0x33FF, 0, 3, 3524},
+	{0x30FF, 0, 2 | DECOMP_COMPAT, 2439},
+	{0x3131, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1100},
+	{0x3132, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1101},
+	{0x3133, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11AA},
+	{0x3134, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1102},
+	{0x3135, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11AC},
+	{0x3136, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11AD},
+	{0x3137, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1103},
+	{0x3138, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1104},
+	{0x3139, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1105},
+	{0x313A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B0},
+	{0x313B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B1},
+	{0x313C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B2},
+	{0x313D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B3},
+	{0x313E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B4},
+	{0x313F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11B5},
+	{0x3140, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111A},
+	{0x3141, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1106},
+	{0x3142, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1107},
+	{0x3143, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1108},
+	{0x3144, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1121},
+	{0x3145, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1109},
+	{0x3146, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110A},
+	{0x3147, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110B},
+	{0x3148, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110C},
+	{0x3149, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110D},
+	{0x314A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110E},
+	{0x314B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110F},
+	{0x314C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1110},
+	{0x314D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1111},
+	{0x314E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1112},
+	{0x314F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1161},
+	{0x3150, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1162},
+	{0x3151, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1163},
+	{0x3152, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1164},
+	{0x3153, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1165},
+	{0x3154, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1166},
+	{0x3155, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1167},
+	{0x3156, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1168},
+	{0x3157, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1169},
+	{0x3158, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116A},
+	{0x3159, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116B},
+	{0x315A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116C},
+	{0x315B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116D},
+	{0x315C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116E},
+	{0x315D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x116F},
+	{0x315E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1170},
+	{0x315F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1171},
+	{0x3160, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1172},
+	{0x3161, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1173},
+	{0x3162, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1174},
+	{0x3163, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1175},
+	{0x3164, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1160},
+	{0x3165, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1114},
+	{0x3166, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1115},
+	{0x3167, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11C7},
+	{0x3168, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11C8},
+	{0x3169, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11CC},
+	{0x316A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11CE},
+	{0x316B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11D3},
+	{0x316C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11D7},
+	{0x316D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11D9},
+	{0x316E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111C},
+	{0x316F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11DD},
+	{0x3170, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11DF},
+	{0x3171, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111D},
+	{0x3172, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x111E},
+	{0x3173, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1120},
+	{0x3174, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1122},
+	{0x3175, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1123},
+	{0x3176, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1127},
+	{0x3177, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1129},
+	{0x3178, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112B},
+	{0x3179, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112C},
+	{0x317A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112D},
+	{0x317B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112E},
+	{0x317C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x112F},
+	{0x317D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1132},
+	{0x317E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1136},
+	{0x317F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1140},
+	{0x3180, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1147},
+	{0x3181, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x114C},
+	{0x3182, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11F1},
+	{0x3183, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11F2},
+	{0x3184, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1157},
+	{0x3185, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1158},
+	{0x3186, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1159},
+	{0x3187, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1184},
+	{0x3188, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1185},
+	{0x3189, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1188},
+	{0x318A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1191},
+	{0x318B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1192},
+	{0x318C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1194},
+	{0x318D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x119E},
+	{0x318E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x11A1},
+	{0x3192, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E00},
+	{0x3193, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E8C},
+	{0x3194, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E09},
+	{0x3195, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x56DB},
+	{0x3196, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E0A},
+	{0x3197, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E2D},
+	{0x3198, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E0B},
+	{0x3199, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7532},
+	{0x319A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E59},
+	{0x319B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E19},
+	{0x319C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E01},
+	{0x319D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5929},
+	{0x319E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5730},
+	{0x319F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4EBA},
+	{0x3200, 0, 3 | DECOMP_COMPAT, 2441},
+	{0x3201, 0, 3 | DECOMP_COMPAT, 2444},
+	{0x3202, 0, 3 | DECOMP_COMPAT, 2447},
+	{0x3203, 0, 3 | DECOMP_COMPAT, 2450},
+	{0x3204, 0, 3 | DECOMP_COMPAT, 2453},
+	{0x3205, 0, 3 | DECOMP_COMPAT, 2456},
+	{0x3206, 0, 3 | DECOMP_COMPAT, 2459},
+	{0x3207, 0, 3 | DECOMP_COMPAT, 2462},
+	{0x3208, 0, 3 | DECOMP_COMPAT, 2465},
+	{0x3209, 0, 3 | DECOMP_COMPAT, 2468},
+	{0x320A, 0, 3 | DECOMP_COMPAT, 2471},
+	{0x320B, 0, 3 | DECOMP_COMPAT, 2474},
+	{0x320C, 0, 3 | DECOMP_COMPAT, 2477},
+	{0x320D, 0, 3 | DECOMP_COMPAT, 2480},
+	{0x320E, 0, 4 | DECOMP_COMPAT, 2483},
+	{0x320F, 0, 4 | DECOMP_COMPAT, 2487},
+	{0x3210, 0, 4 | DECOMP_COMPAT, 2491},
+	{0x3211, 0, 4 | DECOMP_COMPAT, 2495},
+	{0x3212, 0, 4 | DECOMP_COMPAT, 2499},
+	{0x3213, 0, 4 | DECOMP_COMPAT, 2503},
+	{0x3214, 0, 4 | DECOMP_COMPAT, 2507},
+	{0x3215, 0, 4 | DECOMP_COMPAT, 2511},
+	{0x3216, 0, 4 | DECOMP_COMPAT, 2515},
+	{0x3217, 0, 4 | DECOMP_COMPAT, 2519},
+	{0x3218, 0, 4 | DECOMP_COMPAT, 2523},
+	{0x3219, 0, 4 | DECOMP_COMPAT, 2527},
+	{0x321A, 0, 4 | DECOMP_COMPAT, 2531},
+	{0x321B, 0, 4 | DECOMP_COMPAT, 2535},
+	{0x321C, 0, 4 | DECOMP_COMPAT, 2539},
+	{0x321D, 0, 7 | DECOMP_COMPAT, 2543},
+	{0x321E, 0, 6 | DECOMP_COMPAT, 2550},
+	{0x3220, 0, 3 | DECOMP_COMPAT, 2556},
+	{0x3221, 0, 3 | DECOMP_COMPAT, 2559},
+	{0x3222, 0, 3 | DECOMP_COMPAT, 2562},
+	{0x3223, 0, 3 | DECOMP_COMPAT, 2565},
+	{0x3224, 0, 3 | DECOMP_COMPAT, 2568},
+	{0x3225, 0, 3 | DECOMP_COMPAT, 2571},
+	{0x3226, 0, 3 | DECOMP_COMPAT, 2574},
+	{0x3227, 0, 3 | DECOMP_COMPAT, 2577},
+	{0x3228, 0, 3 | DECOMP_COMPAT, 2580},
+	{0x3229, 0, 3 | DECOMP_COMPAT, 2583},
+	{0x322A, 0, 3 | DECOMP_COMPAT, 2586},
+	{0x322B, 0, 3 | DECOMP_COMPAT, 2589},
+	{0x322C, 0, 3 | DECOMP_COMPAT, 2592},
+	{0x322D, 0, 3 | DECOMP_COMPAT, 2595},
+	{0x322E, 0, 3 | DECOMP_COMPAT, 2598},
+	{0x322F, 0, 3 | DECOMP_COMPAT, 2601},
+	{0x3230, 0, 3 | DECOMP_COMPAT, 2604},
+	{0x3231, 0, 3 | DECOMP_COMPAT, 2607},
+	{0x3232, 0, 3 | DECOMP_COMPAT, 2610},
+	{0x3233, 0, 3 | DECOMP_COMPAT, 2613},
+	{0x3234, 0, 3 | DECOMP_COMPAT, 2616},
+	{0x3235, 0, 3 | DECOMP_COMPAT, 2619},
+	{0x3236, 0, 3 | DECOMP_COMPAT, 2622},
+	{0x3237, 0, 3 | DECOMP_COMPAT, 2625},
+	{0x3238, 0, 3 | DECOMP_COMPAT, 2628},
+	{0x3239, 0, 3 | DECOMP_COMPAT, 2631},
+	{0x323A, 0, 3 | DECOMP_COMPAT, 2634},
+	{0x323B, 0, 3 | DECOMP_COMPAT, 2637},
+	{0x323C, 0, 3 | DECOMP_COMPAT, 2640},
+	{0x323D, 0, 3 | DECOMP_COMPAT, 2643},
+	{0x323E, 0, 3 | DECOMP_COMPAT, 2646},
+	{0x323F, 0, 3 | DECOMP_COMPAT, 2649},
+	{0x3240, 0, 3 | DECOMP_COMPAT, 2652},
+	{0x3241, 0, 3 | DECOMP_COMPAT, 2655},
+	{0x3242, 0, 3 | DECOMP_COMPAT, 2658},
+	{0x3243, 0, 3 | DECOMP_COMPAT, 2661},
+	{0x3244, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x554F},
+	{0x3245, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5E7C},
+	{0x3246, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6587},
+	{0x3247, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7B8F},
+	{0x3250, 0, 3 | DECOMP_COMPAT, 2664},
+	{0x3251, 0, 2 | DECOMP_COMPAT, 2667},
+	{0x3252, 0, 2 | DECOMP_COMPAT, 2669},
+	{0x3253, 0, 2 | DECOMP_COMPAT, 2671},
+	{0x3254, 0, 2 | DECOMP_COMPAT, 2673},
+	{0x3255, 0, 2 | DECOMP_COMPAT, 2675},
+	{0x3256, 0, 2 | DECOMP_COMPAT, 2677},
+	{0x3257, 0, 2 | DECOMP_COMPAT, 2679},
+	{0x3258, 0, 2 | DECOMP_COMPAT, 2681},
+	{0x3259, 0, 2 | DECOMP_COMPAT, 2683},
+	{0x325A, 0, 2 | DECOMP_COMPAT, 2685},
+	{0x325B, 0, 2 | DECOMP_COMPAT, 2687},
+	{0x325C, 0, 2 | DECOMP_COMPAT, 2689},
+	{0x325D, 0, 2 | DECOMP_COMPAT, 2691},
+	{0x325E, 0, 2 | DECOMP_COMPAT, 2693},
+	{0x325F, 0, 2 | DECOMP_COMPAT, 2695},
+	{0x3260, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1100},
+	{0x3261, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1102},
+	{0x3262, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1103},
+	{0x3263, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1105},
+	{0x3264, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1106},
+	{0x3265, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1107},
+	{0x3266, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1109},
+	{0x3267, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110B},
+	{0x3268, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110C},
+	{0x3269, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110E},
+	{0x326A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x110F},
+	{0x326B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1110},
+	{0x326C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1111},
+	{0x326D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x1112},
+	{0x326E, 0, 2 | DECOMP_COMPAT, 2697},
+	{0x326F, 0, 2 | DECOMP_COMPAT, 2699},
+	{0x3270, 0, 2 | DECOMP_COMPAT, 2701},
+	{0x3271, 0, 2 | DECOMP_COMPAT, 2703},
+	{0x3272, 0, 2 | DECOMP_COMPAT, 2705},
+	{0x3273, 0, 2 | DECOMP_COMPAT, 2707},
+	{0x3274, 0, 2 | DECOMP_COMPAT, 2709},
+	{0x3275, 0, 2 | DECOMP_COMPAT, 2711},
+	{0x3276, 0, 2 | DECOMP_COMPAT, 2713},
+	{0x3277, 0, 2 | DECOMP_COMPAT, 2715},
+	{0x3278, 0, 2 | DECOMP_COMPAT, 2717},
+	{0x3279, 0, 2 | DECOMP_COMPAT, 2719},
+	{0x327A, 0, 2 | DECOMP_COMPAT, 2721},
+	{0x327B, 0, 2 | DECOMP_COMPAT, 2723},
+	{0x327C, 0, 5 | DECOMP_COMPAT, 2725},
+	{0x327D, 0, 4 | DECOMP_COMPAT, 2730},
+	{0x327E, 0, 2 | DECOMP_COMPAT, 2734},
+	{0x3280, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E00},
+	{0x3281, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E8C},
+	{0x3282, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E09},
+	{0x3283, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x56DB},
+	{0x3284, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E94},
+	{0x3285, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x516D},
+	{0x3286, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E03},
+	{0x3287, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x516B},
+	{0x3288, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E5D},
+	{0x3289, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5341},
+	{0x328A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6708},
+	{0x328B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x706B},
+	{0x328C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6C34},
+	{0x328D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6728},
+	{0x328E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x91D1},
+	{0x328F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x571F},
+	{0x3290, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65E5},
+	{0x3291, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x682A},
+	{0x3292, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6709},
+	{0x3293, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x793E},
+	{0x3294, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x540D},
+	{0x3295, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7279},
+	{0x3296, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8CA1},
+	{0x3297, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x795D},
+	{0x3298, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x52B4},
+	{0x3299, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x79D8},
+	{0x329A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7537},
+	{0x329B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5973},
+	{0x329C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9069},
+	{0x329D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x512A},
+	{0x329E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5370},
+	{0x329F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6CE8},
+	{0x32A0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x9805},
+	{0x32A1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4F11},
+	{0x32A2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5199},
+	{0x32A3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6B63},
+	{0x32A4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E0A},
+	{0x32A5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E2D},
+	{0x32A6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E0B},
+	{0x32A7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DE6},
+	{0x32A8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53F3},
+	{0x32A9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x533B},
+	{0x32AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B97},
+	{0x32AB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B66},
+	{0x32AC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x76E3},
+	{0x32AD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4F01},
+	{0x32AE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8CC7},
+	{0x32AF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5354},
+	{0x32B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x591C},
+	{0x32B1, 0, 2 | DECOMP_COMPAT, 2736},
+	{0x32B2, 0, 2 | DECOMP_COMPAT, 2738},
+	{0x32B3, 0, 2 | DECOMP_COMPAT, 2740},
+	{0x32B4, 0, 2 | DECOMP_COMPAT, 2742},
+	{0x32B5, 0, 2 | DECOMP_COMPAT, 2744},
+	{0x32B6, 0, 2 | DECOMP_COMPAT, 2746},
+	{0x32B7, 0, 2 | DECOMP_COMPAT, 2748},
+	{0x32B8, 0, 2 | DECOMP_COMPAT, 2750},
+	{0x32B9, 0, 2 | DECOMP_COMPAT, 2752},
+	{0x32BA, 0, 2 | DECOMP_COMPAT, 2754},
+	{0x32BB, 0, 2 | DECOMP_COMPAT, 2756},
+	{0x32BC, 0, 2 | DECOMP_COMPAT, 2758},
+	{0x32BD, 0, 2 | DECOMP_COMPAT, 2760},
+	{0x32BE, 0, 2 | DECOMP_COMPAT, 2762},
+	{0x32BF, 0, 2 | DECOMP_COMPAT, 2764},
+	{0x32C0, 0, 2 | DECOMP_COMPAT, 2766},
+	{0x32C1, 0, 2 | DECOMP_COMPAT, 2768},
+	{0x32C2, 0, 2 | DECOMP_COMPAT, 2770},
+	{0x32C3, 0, 2 | DECOMP_COMPAT, 2772},
+	{0x32C4, 0, 2 | DECOMP_COMPAT, 2774},
+	{0x32C5, 0, 2 | DECOMP_COMPAT, 2776},
+	{0x32C6, 0, 2 | DECOMP_COMPAT, 2778},
+	{0x32C7, 0, 2 | DECOMP_COMPAT, 2780},
+	{0x32C8, 0, 2 | DECOMP_COMPAT, 2782},
+	{0x32C9, 0, 3 | DECOMP_COMPAT, 2784},
+	{0x32CA, 0, 3 | DECOMP_COMPAT, 2787},
+	{0x32CB, 0, 3 | DECOMP_COMPAT, 2790},
+	{0x32CC, 0, 2 | DECOMP_COMPAT, 2793},
+	{0x32CD, 0, 3 | DECOMP_COMPAT, 2795},
+	{0x32CE, 0, 2 | DECOMP_COMPAT, 2798},
+	{0x32CF, 0, 3 | DECOMP_COMPAT, 2800},
+	{0x32D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A2},
+	{0x32D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A4},
+	{0x32D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A6},
+	{0x32D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A8},
+	{0x32D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AA},
+	{0x32D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AB},
+	{0x32D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AD},
+	{0x32D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AF},
+	{0x32D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B1},
+	{0x32D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B3},
+	{0x32DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B5},
+	{0x32DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B7},
+	{0x32DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B9},
+	{0x32DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BB},
+	{0x32DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BD},
+	{0x32DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BF},
+	{0x32E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C1},
+	{0x32E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C4},
+	{0x32E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C6},
+	{0x32E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C8},
+	{0x32E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CA},
+	{0x32E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CB},
+	{0x32E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CC},
+	{0x32E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CD},
+	{0x32E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CE},
+	{0x32E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CF},
+	{0x32EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D2},
+	{0x32EB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D5},
+	{0x32EC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D8},
+	{0x32ED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DB},
+	{0x32EE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DE},
+	{0x32EF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DF},
+	{0x32F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E0},
+	{0x32F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E1},
+	{0x32F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E2},
+	{0x32F3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E4},
+	{0x32F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E6},
+	{0x32F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E8},
+	{0x32F6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E9},
+	{0x32F7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EA},
+	{0x32F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EB},
+	{0x32F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EC},
+	{0x32FA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30ED},
+	{0x32FB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EF},
+	{0x32FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F0},
+	{0x32FD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F1},
+	{0x32FE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F2},
+	{0x32FF, 0, 2 | DECOMP_COMPAT, 2803},
+	{0x3300, 0, 4 | DECOMP_COMPAT, 2805},
+	{0x3301, 0, 4 | DECOMP_COMPAT, 2809},
+	{0x3302, 0, 4 | DECOMP_COMPAT, 2813},
+	{0x3303, 0, 3 | DECOMP_COMPAT, 2817},
+	{0x3304, 0, 4 | DECOMP_COMPAT, 2820},
+	{0x3305, 0, 3 | DECOMP_COMPAT, 2824},
+	{0x3306, 0, 3 | DECOMP_COMPAT, 2827},
+	{0x3307, 0, 5 | DECOMP_COMPAT, 2830},
+	{0x3308, 0, 4 | DECOMP_COMPAT, 2835},
+	{0x3309, 0, 3 | DECOMP_COMPAT, 2839},
+	{0x330A, 0, 3 | DECOMP_COMPAT, 2842},
+	{0x330B, 0, 3 | DECOMP_COMPAT, 2845},
+	{0x330C, 0, 4 | DECOMP_COMPAT, 2848},
+	{0x330D, 0, 4 | DECOMP_COMPAT, 2852},
+	{0x330E, 0, 3 | DECOMP_COMPAT, 2856},
+	{0x330F, 0, 3 | DECOMP_COMPAT, 2859},
+	{0x3310, 0, 2 | DECOMP_COMPAT, 2862},
+	{0x3311, 0, 3 | DECOMP_COMPAT, 2864},
+	{0x3312, 0, 4 | DECOMP_COMPAT, 2867},
+	{0x3313, 0, 4 | DECOMP_COMPAT, 2871},
+	{0x3314, 0, 2 | DECOMP_COMPAT, 2875},
+	{0x3315, 0, 5 | DECOMP_COMPAT, 2877},
+	{0x3316, 0, 6 | DECOMP_COMPAT, 2882},
+	{0x3317, 0, 5 | DECOMP_COMPAT, 2888},
+	{0x3318, 0, 3 | DECOMP_COMPAT, 2893},
+	{0x3319, 0, 5 | DECOMP_COMPAT, 2896},
+	{0x331A, 0, 5 | DECOMP_COMPAT, 2901},
+	{0x331B, 0, 4 | DECOMP_COMPAT, 2906},
+	{0x331C, 0, 3 | DECOMP_COMPAT, 2910},
+	{0x331D, 0, 3 | DECOMP_COMPAT, 2913},
+	{0x331E, 0, 3 | DECOMP_COMPAT, 2916},
+	{0x331F, 0, 4 | DECOMP_COMPAT, 2919},
+	{0x3320, 0, 5 | DECOMP_COMPAT, 2923},
+	{0x3321, 0, 4 | DECOMP_COMPAT, 2928},
+	{0x3322, 0, 3 | DECOMP_COMPAT, 2932},
+	{0x3323, 0, 3 | DECOMP_COMPAT, 2935},
+	{0x3324, 0, 3 | DECOMP_COMPAT, 2938},
+	{0x3325, 0, 2 | DECOMP_COMPAT, 2941},
+	{0x3326, 0, 2 | DECOMP_COMPAT, 2943},
+	{0x3327, 0, 2 | DECOMP_COMPAT, 2945},
+	{0x3328, 0, 2 | DECOMP_COMPAT, 2947},
+	{0x3329, 0, 3 | DECOMP_COMPAT, 2949},
+	{0x332A, 0, 3 | DECOMP_COMPAT, 2952},
+	{0x332B, 0, 5 | DECOMP_COMPAT, 2955},
+	{0x332C, 0, 3 | DECOMP_COMPAT, 2960},
+	{0x332D, 0, 4 | DECOMP_COMPAT, 2963},
+	{0x332E, 0, 5 | DECOMP_COMPAT, 2967},
+	{0x332F, 0, 3 | DECOMP_COMPAT, 2972},
+	{0x3330, 0, 2 | DECOMP_COMPAT, 2975},
+	{0x3331, 0, 2 | DECOMP_COMPAT, 2977},
+	{0x3332, 0, 5 | DECOMP_COMPAT, 2979},
+	{0x3333, 0, 4 | DECOMP_COMPAT, 2984},
+	{0x3334, 0, 5 | DECOMP_COMPAT, 2988},
+	{0x3335, 0, 3 | DECOMP_COMPAT, 2993},
+	{0x3336, 0, 5 | DECOMP_COMPAT, 2996},
+	{0x3337, 0, 2 | DECOMP_COMPAT, 3001},
+	{0x3338, 0, 3 | DECOMP_COMPAT, 3003},
+	{0x3339, 0, 3 | DECOMP_COMPAT, 3006},
+	{0x333A, 0, 3 | DECOMP_COMPAT, 3009},
+	{0x333B, 0, 3 | DECOMP_COMPAT, 3012},
+	{0x333C, 0, 3 | DECOMP_COMPAT, 3015},
+	{0x333D, 0, 4 | DECOMP_COMPAT, 3018},
+	{0x333E, 0, 3 | DECOMP_COMPAT, 3022},
+	{0x333F, 0, 2 | DECOMP_COMPAT, 3025},
+	{0x3340, 0, 3 | DECOMP_COMPAT, 3027},
+	{0x3341, 0, 3 | DECOMP_COMPAT, 3030},
+	{0x3342, 0, 3 | DECOMP_COMPAT, 3033},
+	{0x3343, 0, 4 | DECOMP_COMPAT, 3036},
+	{0x3344, 0, 3 | DECOMP_COMPAT, 3040},
+	{0x3345, 0, 3 | DECOMP_COMPAT, 3043},
+	{0x3346, 0, 3 | DECOMP_COMPAT, 3046},
+	{0x3347, 0, 5 | DECOMP_COMPAT, 3049},
+	{0x3348, 0, 4 | DECOMP_COMPAT, 3054},
+	{0x3349, 0, 2 | DECOMP_COMPAT, 3058},
+	{0x334A, 0, 5 | DECOMP_COMPAT, 3060},
+	{0x334B, 0, 2 | DECOMP_COMPAT, 3065},
+	{0x334C, 0, 4 | DECOMP_COMPAT, 3067},
+	{0x334D, 0, 4 | DECOMP_COMPAT, 3071},
+	{0x334E, 0, 3 | DECOMP_COMPAT, 3075},
+	{0x334F, 0, 3 | DECOMP_COMPAT, 3078},
+	{0x3350, 0, 3 | DECOMP_COMPAT, 3081},
+	{0x3351, 0, 4 | DECOMP_COMPAT, 3084},
+	{0x3352, 0, 2 | DECOMP_COMPAT, 3088},
+	{0x3353, 0, 3 | DECOMP_COMPAT, 3090},
+	{0x3354, 0, 4 | DECOMP_COMPAT, 3093},
+	{0x3355, 0, 2 | DECOMP_COMPAT, 3097},
+	{0x3356, 0, 5 | DECOMP_COMPAT, 3099},
+	{0x3357, 0, 3 | DECOMP_COMPAT, 3104},
+	{0x3358, 0, 2 | DECOMP_COMPAT, 3107},
+	{0x3359, 0, 2 | DECOMP_COMPAT, 3109},
+	{0x335A, 0, 2 | DECOMP_COMPAT, 3111},
+	{0x335B, 0, 2 | DECOMP_COMPAT, 3113},
+	{0x335C, 0, 2 | DECOMP_COMPAT, 3115},
+	{0x335D, 0, 2 | DECOMP_COMPAT, 3117},
+	{0x335E, 0, 2 | DECOMP_COMPAT, 3119},
+	{0x335F, 0, 2 | DECOMP_COMPAT, 3121},
+	{0x3360, 0, 2 | DECOMP_COMPAT, 3123},
+	{0x3361, 0, 2 | DECOMP_COMPAT, 3125},
+	{0x3362, 0, 3 | DECOMP_COMPAT, 3127},
+	{0x3363, 0, 3 | DECOMP_COMPAT, 3130},
+	{0x3364, 0, 3 | DECOMP_COMPAT, 3133},
+	{0x3365, 0, 3 | DECOMP_COMPAT, 3136},
+	{0x3366, 0, 3 | DECOMP_COMPAT, 3139},
+	{0x3367, 0, 3 | DECOMP_COMPAT, 3142},
+	{0x3368, 0, 3 | DECOMP_COMPAT, 3145},
+	{0x3369, 0, 3 | DECOMP_COMPAT, 3148},
+	{0x336A, 0, 3 | DECOMP_COMPAT, 3151},
+	{0x336B, 0, 3 | DECOMP_COMPAT, 3154},
+	{0x336C, 0, 3 | DECOMP_COMPAT, 3157},
+	{0x336D, 0, 3 | DECOMP_COMPAT, 3160},
+	{0x336E, 0, 3 | DECOMP_COMPAT, 3163},
+	{0x336F, 0, 3 | DECOMP_COMPAT, 3166},
+	{0x3370, 0, 3 | DECOMP_COMPAT, 3169},
+	{0x3371, 0, 3 | DECOMP_COMPAT, 3172},
+	{0x3372, 0, 2 | DECOMP_COMPAT, 3175},
+	{0x3373, 0, 2 | DECOMP_COMPAT, 3177},
+	{0x3374, 0, 3 | DECOMP_COMPAT, 3179},
+	{0x3375, 0, 2 | DECOMP_COMPAT, 3182},
+	{0x3376, 0, 2 | DECOMP_COMPAT, 3184},
+	{0x3377, 0, 2 | DECOMP_COMPAT, 3186},
+	{0x3378, 0, 3 | DECOMP_COMPAT, 3188},
+	{0x3379, 0, 3 | DECOMP_COMPAT, 3191},
+	{0x337A, 0, 2 | DECOMP_COMPAT, 3194},
+	{0x337B, 0, 2 | DECOMP_COMPAT, 3196},
+	{0x337C, 0, 2 | DECOMP_COMPAT, 3198},
+	{0x337D, 0, 2 | DECOMP_COMPAT, 3200},
+	{0x337E, 0, 2 | DECOMP_COMPAT, 3202},
+	{0x337F, 0, 4 | DECOMP_COMPAT, 3204},
+	{0x3380, 0, 2 | DECOMP_COMPAT, 3208},
+	{0x3381, 0, 2 | DECOMP_COMPAT, 3210},
+	{0x3382, 0, 2 | DECOMP_COMPAT, 3212},
+	{0x3383, 0, 2 | DECOMP_COMPAT, 3214},
+	{0x3384, 0, 2 | DECOMP_COMPAT, 3216},
+	{0x3385, 0, 2 | DECOMP_COMPAT, 3218},
+	{0x3386, 0, 2 | DECOMP_COMPAT, 3220},
+	{0x3387, 0, 2 | DECOMP_COMPAT, 3222},
+	{0x3388, 0, 3 | DECOMP_COMPAT, 3224},
+	{0x3389, 0, 4 | DECOMP_COMPAT, 3227},
+	{0x338A, 0, 2 | DECOMP_COMPAT, 3231},
+	{0x338B, 0, 2 | DECOMP_COMPAT, 3233},
+	{0x338C, 0, 2 | DECOMP_COMPAT, 3235},
+	{0x338D, 0, 2 | DECOMP_COMPAT, 3237},
+	{0x338E, 0, 2 | DECOMP_COMPAT, 3239},
+	{0x338F, 0, 2 | DECOMP_COMPAT, 3241},
+	{0x3390, 0, 2 | DECOMP_COMPAT, 3243},
+	{0x3391, 0, 3 | DECOMP_COMPAT, 3245},
+	{0x3392, 0, 3 | DECOMP_COMPAT, 3248},
+	{0x3393, 0, 3 | DECOMP_COMPAT, 3251},
+	{0x3394, 0, 3 | DECOMP_COMPAT, 3254},
+	{0x3395, 0, 2 | DECOMP_COMPAT, 3257},
+	{0x3396, 0, 2 | DECOMP_COMPAT, 3259},
+	{0x3397, 0, 2 | DECOMP_COMPAT, 3261},
+	{0x3398, 0, 2 | DECOMP_COMPAT, 3263},
+	{0x3399, 0, 2 | DECOMP_COMPAT, 3265},
+	{0x339A, 0, 2 | DECOMP_COMPAT, 3267},
+	{0x339B, 0, 2 | DECOMP_COMPAT, 3269},
+	{0x339C, 0, 2 | DECOMP_COMPAT, 3271},
+	{0x339D, 0, 2 | DECOMP_COMPAT, 3273},
+	{0x339E, 0, 2 | DECOMP_COMPAT, 3275},
+	{0x339F, 0, 3 | DECOMP_COMPAT, 3277},
+	{0x33A0, 0, 3 | DECOMP_COMPAT, 3280},
+	{0x33A1, 0, 2 | DECOMP_COMPAT, 3283},
+	{0x33A2, 0, 3 | DECOMP_COMPAT, 3285},
+	{0x33A3, 0, 3 | DECOMP_COMPAT, 3288},
+	{0x33A4, 0, 3 | DECOMP_COMPAT, 3291},
+	{0x33A5, 0, 2 | DECOMP_COMPAT, 3294},
+	{0x33A6, 0, 3 | DECOMP_COMPAT, 3296},
+	{0x33A7, 0, 3 | DECOMP_COMPAT, 3299},
+	{0x33A8, 0, 4 | DECOMP_COMPAT, 3302},
+	{0x33A9, 0, 2 | DECOMP_COMPAT, 3306},
+	{0x33AA, 0, 3 | DECOMP_COMPAT, 3308},
+	{0x33AB, 0, 3 | DECOMP_COMPAT, 3311},
+	{0x33AC, 0, 3 | DECOMP_COMPAT, 3314},
+	{0x33AD, 0, 3 | DECOMP_COMPAT, 3317},
+	{0x33AE, 0, 5 | DECOMP_COMPAT, 3320},
+	{0x33AF, 0, 6 | DECOMP_COMPAT, 3325},
+	{0x33B0, 0, 2 | DECOMP_COMPAT, 3331},
+	{0x33B1, 0, 2 | DECOMP_COMPAT, 3333},
+	{0x33B2, 0, 2 | DECOMP_COMPAT, 3335},
+	{0x33B3, 0, 2 | DECOMP_COMPAT, 3337},
+	{0x33B4, 0, 2 | DECOMP_COMPAT, 3339},
+	{0x33B5, 0, 2 | DECOMP_COMPAT, 3341},
+	{0x33B6, 0, 2 | DECOMP_COMPAT, 3343},
+	{0x33B7, 0, 2 | DECOMP_COMPAT, 3345},
+	{0x33B8, 0, 2 | DECOMP_COMPAT, 3347},
+	{0x33B9, 0, 2 | DECOMP_COMPAT, 3349},
+	{0x33BA, 0, 2 | DECOMP_COMPAT, 3351},
+	{0x33BB, 0, 2 | DECOMP_COMPAT, 3353},
+	{0x33BC, 0, 2 | DECOMP_COMPAT, 3355},
+	{0x33BD, 0, 2 | DECOMP_COMPAT, 3357},
+	{0x33BE, 0, 2 | DECOMP_COMPAT, 3359},
+	{0x33BF, 0, 2 | DECOMP_COMPAT, 3361},
+	{0x33C0, 0, 2 | DECOMP_COMPAT, 3363},
+	{0x33C1, 0, 2 | DECOMP_COMPAT, 3365},
+	{0x33C2, 0, 4 | DECOMP_COMPAT, 3367},
+	{0x33C3, 0, 2 | DECOMP_COMPAT, 3371},
+	{0x33C4, 0, 2 | DECOMP_COMPAT, 3373},
+	{0x33C5, 0, 2 | DECOMP_COMPAT, 3375},
+	{0x33C6, 0, 4 | DECOMP_COMPAT, 3377},
+	{0x33C7, 0, 3 | DECOMP_COMPAT, 3381},
+	{0x33C8, 0, 2 | DECOMP_COMPAT, 3384},
+	{0x33C9, 0, 2 | DECOMP_COMPAT, 3386},
+	{0x33CA, 0, 2 | DECOMP_COMPAT, 3388},
+	{0x33CB, 0, 2 | DECOMP_COMPAT, 3390},
+	{0x33CC, 0, 2 | DECOMP_COMPAT, 3392},
+	{0x33CD, 0, 2 | DECOMP_COMPAT, 3394},
+	{0x33CE, 0, 2 | DECOMP_COMPAT, 3396},
+	{0x33CF, 0, 2 | DECOMP_COMPAT, 3398},
+	{0x33D0, 0, 2 | DECOMP_COMPAT, 3400},
+	{0x33D1, 0, 2 | DECOMP_COMPAT, 3402},
+	{0x33D2, 0, 3 | DECOMP_COMPAT, 3404},
+	{0x33D3, 0, 2 | DECOMP_COMPAT, 3407},
+	{0x33D4, 0, 2 | DECOMP_COMPAT, 3409},
+	{0x33D5, 0, 3 | DECOMP_COMPAT, 3411},
+	{0x33D6, 0, 3 | DECOMP_COMPAT, 3414},
+	{0x33D7, 0, 2 | DECOMP_COMPAT, 3417},
+	{0x33D8, 0, 4 | DECOMP_COMPAT, 3419},
+	{0x33D9, 0, 3 | DECOMP_COMPAT, 3423},
+	{0x33DA, 0, 2 | DECOMP_COMPAT, 3426},
+	{0x33DB, 0, 2 | DECOMP_COMPAT, 3428},
+	{0x33DC, 0, 2 | DECOMP_COMPAT, 3430},
+	{0x33DD, 0, 2 | DECOMP_COMPAT, 3432},
+	{0x33DE, 0, 3 | DECOMP_COMPAT, 3434},
+	{0x33DF, 0, 3 | DECOMP_COMPAT, 3437},
+	{0x33E0, 0, 2 | DECOMP_COMPAT, 3440},
+	{0x33E1, 0, 2 | DECOMP_COMPAT, 3442},
+	{0x33E2, 0, 2 | DECOMP_COMPAT, 3444},
+	{0x33E3, 0, 2 | DECOMP_COMPAT, 3446},
+	{0x33E4, 0, 2 | DECOMP_COMPAT, 3448},
+	{0x33E5, 0, 2 | DECOMP_COMPAT, 3450},
+	{0x33E6, 0, 2 | DECOMP_COMPAT, 3452},
+	{0x33E7, 0, 2 | DECOMP_COMPAT, 3454},
+	{0x33E8, 0, 2 | DECOMP_COMPAT, 3456},
+	{0x33E9, 0, 3 | DECOMP_COMPAT, 3458},
+	{0x33EA, 0, 3 | DECOMP_COMPAT, 3461},
+	{0x33EB, 0, 3 | DECOMP_COMPAT, 3464},
+	{0x33EC, 0, 3 | DECOMP_COMPAT, 3467},
+	{0x33ED, 0, 3 | DECOMP_COMPAT, 3470},
+	{0x33EE, 0, 3 | DECOMP_COMPAT, 3473},
+	{0x33EF, 0, 3 | DECOMP_COMPAT, 3476},
+	{0x33F0, 0, 3 | DECOMP_COMPAT, 3479},
+	{0x33F1, 0, 3 | DECOMP_COMPAT, 3482},
+	{0x33F2, 0, 3 | DECOMP_COMPAT, 3485},
+	{0x33F3, 0, 3 | DECOMP_COMPAT, 3488},
+	{0x33F4, 0, 3 | DECOMP_COMPAT, 3491},
+	{0x33F5, 0, 3 | DECOMP_COMPAT, 3494},
+	{0x33F6, 0, 3 | DECOMP_COMPAT, 3497},
+	{0x33F7, 0, 3 | DECOMP_COMPAT, 3500},
+	{0x33F8, 0, 3 | DECOMP_COMPAT, 3503},
+	{0x33F9, 0, 3 | DECOMP_COMPAT, 3506},
+	{0x33FA, 0, 3 | DECOMP_COMPAT, 3509},
+	{0x33FB, 0, 3 | DECOMP_COMPAT, 3512},
+	{0x33FC, 0, 3 | DECOMP_COMPAT, 3515},
+	{0x33FD, 0, 3 | DECOMP_COMPAT, 3518},
+	{0x33FE, 0, 3 | DECOMP_COMPAT, 3521},
+	{0x33FF, 0, 3 | DECOMP_COMPAT, 3524},
 	{0xA66F, 230, 0, 0},
 	{0xA674, 230, 0, 0},
 	{0xA675, 230, 0, 0},
@@ -2980,15 +2982,15 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0xA67B, 230, 0, 0},
 	{0xA67C, 230, 0, 0},
 	{0xA67D, 230, 0, 0},
-	{0xA69C, 0, 1 | DECOMP_INLINE, 0x044A},
-	{0xA69D, 0, 1 | DECOMP_INLINE, 0x044C},
+	{0xA69C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044A},
+	{0xA69D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x044C},
 	{0xA69E, 230, 0, 0},
 	{0xA69F, 230, 0, 0},
 	{0xA6F0, 230, 0, 0},
 	{0xA6F1, 230, 0, 0},
-	{0xA770, 0, 1 | DECOMP_INLINE, 0xA76F},
-	{0xA7F8, 0, 1 | DECOMP_INLINE, 0x0126},
-	{0xA7F9, 0, 1 | DECOMP_INLINE, 0x0153},
+	{0xA770, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA76F},
+	{0xA7F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0126},
+	{0xA7F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0153},
 	{0xA806, 9, 0, 0},
 	{0xA8C4, 9, 0, 0},
 	{0xA8E0, 230, 0, 0},
@@ -3025,10 +3027,10 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0xAABF, 230, 0, 0},
 	{0xAAC1, 230, 0, 0},
 	{0xAAF6, 9, 0, 0},
-	{0xAB5C, 0, 1 | DECOMP_INLINE, 0xA727},
-	{0xAB5D, 0, 1 | DECOMP_INLINE, 0xAB37},
-	{0xAB5E, 0, 1 | DECOMP_INLINE, 0x026B},
-	{0xAB5F, 0, 1 | DECOMP_INLINE, 0xAB52},
+	{0xAB5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xA727},
+	{0xAB5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xAB37},
+	{0xAB5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x026B},
+	{0xAB5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0xAB52},
 	{0xABED, 9, 0, 0},
 	{0xF900, 0, 1 | DECOMP_INLINE, 0x8C48},
 	{0xF901, 0, 1 | DECOMP_INLINE, 0x66F4},
@@ -3490,31 +3492,31 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0xFAD7, 0, 1, 3533},
 	{0xFAD8, 0, 1 | DECOMP_INLINE, 0x9F43},
 	{0xFAD9, 0, 1 | DECOMP_INLINE, 0x9F8E},
-	{0xFB00, 0, 2 | DECOMP_NO_COMPOSE, 3534},	/* compatibility mapping */
-	{0xFB01, 0, 2 | DECOMP_NO_COMPOSE, 3536},	/* compatibility mapping */
-	{0xFB02, 0, 2 | DECOMP_NO_COMPOSE, 3538},	/* compatibility mapping */
-	{0xFB03, 0, 3, 3540},
-	{0xFB04, 0, 3, 3543},
-	{0xFB05, 0, 2 | DECOMP_NO_COMPOSE, 3546},	/* compatibility mapping */
-	{0xFB06, 0, 2 | DECOMP_NO_COMPOSE, 3548},	/* compatibility mapping */
-	{0xFB13, 0, 2 | DECOMP_NO_COMPOSE, 3550},	/* compatibility mapping */
-	{0xFB14, 0, 2 | DECOMP_NO_COMPOSE, 3552},	/* compatibility mapping */
-	{0xFB15, 0, 2 | DECOMP_NO_COMPOSE, 3554},	/* compatibility mapping */
-	{0xFB16, 0, 2 | DECOMP_NO_COMPOSE, 3556},	/* compatibility mapping */
-	{0xFB17, 0, 2 | DECOMP_NO_COMPOSE, 3558},	/* compatibility mapping */
+	{0xFB00, 0, 2 | DECOMP_COMPAT, 3534},
+	{0xFB01, 0, 2 | DECOMP_COMPAT, 3536},
+	{0xFB02, 0, 2 | DECOMP_COMPAT, 3538},
+	{0xFB03, 0, 3 | DECOMP_COMPAT, 3540},
+	{0xFB04, 0, 3 | DECOMP_COMPAT, 3543},
+	{0xFB05, 0, 2 | DECOMP_COMPAT, 3546},
+	{0xFB06, 0, 2 | DECOMP_COMPAT, 3548},
+	{0xFB13, 0, 2 | DECOMP_COMPAT, 3550},
+	{0xFB14, 0, 2 | DECOMP_COMPAT, 3552},
+	{0xFB15, 0, 2 | DECOMP_COMPAT, 3554},
+	{0xFB16, 0, 2 | DECOMP_COMPAT, 3556},
+	{0xFB17, 0, 2 | DECOMP_COMPAT, 3558},
 	{0xFB1D, 0, 2 | DECOMP_NO_COMPOSE, 3560},	/* in exclusion list */
 	{0xFB1E, 26, 0, 0},
 	{0xFB1F, 0, 2 | DECOMP_NO_COMPOSE, 3562},	/* in exclusion list */
-	{0xFB20, 0, 1 | DECOMP_INLINE, 0x05E2},
-	{0xFB21, 0, 1 | DECOMP_INLINE, 0x05D0},
-	{0xFB22, 0, 1 | DECOMP_INLINE, 0x05D3},
-	{0xFB23, 0, 1 | DECOMP_INLINE, 0x05D4},
-	{0xFB24, 0, 1 | DECOMP_INLINE, 0x05DB},
-	{0xFB25, 0, 1 | DECOMP_INLINE, 0x05DC},
-	{0xFB26, 0, 1 | DECOMP_INLINE, 0x05DD},
-	{0xFB27, 0, 1 | DECOMP_INLINE, 0x05E8},
-	{0xFB28, 0, 1 | DECOMP_INLINE, 0x05EA},
-	{0xFB29, 0, 1 | DECOMP_INLINE, 0x002B},
+	{0xFB20, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05E2},
+	{0xFB21, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D0},
+	{0xFB22, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D3},
+	{0xFB23, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05D4},
+	{0xFB24, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05DB},
+	{0xFB25, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05DC},
+	{0xFB26, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05DD},
+	{0xFB27, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05E8},
+	{0xFB28, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x05EA},
+	{0xFB29, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002B},
 	{0xFB2A, 0, 2 | DECOMP_NO_COMPOSE, 3564},	/* in exclusion list */
 	{0xFB2B, 0, 2 | DECOMP_NO_COMPOSE, 3566},	/* in exclusion list */
 	{0xFB2C, 0, 2 | DECOMP_NO_COMPOSE, 3568},	/* in exclusion list */
@@ -3547,609 +3549,609 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0xFB4C, 0, 2 | DECOMP_NO_COMPOSE, 3622},	/* in exclusion list */
 	{0xFB4D, 0, 2 | DECOMP_NO_COMPOSE, 3624},	/* in exclusion list */
 	{0xFB4E, 0, 2 | DECOMP_NO_COMPOSE, 3626},	/* in exclusion list */
-	{0xFB4F, 0, 2 | DECOMP_NO_COMPOSE, 3628},	/* compatibility mapping */
-	{0xFB50, 0, 1 | DECOMP_INLINE, 0x0671},
-	{0xFB51, 0, 1 | DECOMP_INLINE, 0x0671},
-	{0xFB52, 0, 1 | DECOMP_INLINE, 0x067B},
-	{0xFB53, 0, 1 | DECOMP_INLINE, 0x067B},
-	{0xFB54, 0, 1 | DECOMP_INLINE, 0x067B},
-	{0xFB55, 0, 1 | DECOMP_INLINE, 0x067B},
-	{0xFB56, 0, 1 | DECOMP_INLINE, 0x067E},
-	{0xFB57, 0, 1 | DECOMP_INLINE, 0x067E},
-	{0xFB58, 0, 1 | DECOMP_INLINE, 0x067E},
-	{0xFB59, 0, 1 | DECOMP_INLINE, 0x067E},
-	{0xFB5A, 0, 1 | DECOMP_INLINE, 0x0680},
-	{0xFB5B, 0, 1 | DECOMP_INLINE, 0x0680},
-	{0xFB5C, 0, 1 | DECOMP_INLINE, 0x0680},
-	{0xFB5D, 0, 1 | DECOMP_INLINE, 0x0680},
-	{0xFB5E, 0, 1 | DECOMP_INLINE, 0x067A},
-	{0xFB5F, 0, 1 | DECOMP_INLINE, 0x067A},
-	{0xFB60, 0, 1 | DECOMP_INLINE, 0x067A},
-	{0xFB61, 0, 1 | DECOMP_INLINE, 0x067A},
-	{0xFB62, 0, 1 | DECOMP_INLINE, 0x067F},
-	{0xFB63, 0, 1 | DECOMP_INLINE, 0x067F},
-	{0xFB64, 0, 1 | DECOMP_INLINE, 0x067F},
-	{0xFB65, 0, 1 | DECOMP_INLINE, 0x067F},
-	{0xFB66, 0, 1 | DECOMP_INLINE, 0x0679},
-	{0xFB67, 0, 1 | DECOMP_INLINE, 0x0679},
-	{0xFB68, 0, 1 | DECOMP_INLINE, 0x0679},
-	{0xFB69, 0, 1 | DECOMP_INLINE, 0x0679},
-	{0xFB6A, 0, 1 | DECOMP_INLINE, 0x06A4},
-	{0xFB6B, 0, 1 | DECOMP_INLINE, 0x06A4},
-	{0xFB6C, 0, 1 | DECOMP_INLINE, 0x06A4},
-	{0xFB6D, 0, 1 | DECOMP_INLINE, 0x06A4},
-	{0xFB6E, 0, 1 | DECOMP_INLINE, 0x06A6},
-	{0xFB6F, 0, 1 | DECOMP_INLINE, 0x06A6},
-	{0xFB70, 0, 1 | DECOMP_INLINE, 0x06A6},
-	{0xFB71, 0, 1 | DECOMP_INLINE, 0x06A6},
-	{0xFB72, 0, 1 | DECOMP_INLINE, 0x0684},
-	{0xFB73, 0, 1 | DECOMP_INLINE, 0x0684},
-	{0xFB74, 0, 1 | DECOMP_INLINE, 0x0684},
-	{0xFB75, 0, 1 | DECOMP_INLINE, 0x0684},
-	{0xFB76, 0, 1 | DECOMP_INLINE, 0x0683},
-	{0xFB77, 0, 1 | DECOMP_INLINE, 0x0683},
-	{0xFB78, 0, 1 | DECOMP_INLINE, 0x0683},
-	{0xFB79, 0, 1 | DECOMP_INLINE, 0x0683},
-	{0xFB7A, 0, 1 | DECOMP_INLINE, 0x0686},
-	{0xFB7B, 0, 1 | DECOMP_INLINE, 0x0686},
-	{0xFB7C, 0, 1 | DECOMP_INLINE, 0x0686},
-	{0xFB7D, 0, 1 | DECOMP_INLINE, 0x0686},
-	{0xFB7E, 0, 1 | DECOMP_INLINE, 0x0687},
-	{0xFB7F, 0, 1 | DECOMP_INLINE, 0x0687},
-	{0xFB80, 0, 1 | DECOMP_INLINE, 0x0687},
-	{0xFB81, 0, 1 | DECOMP_INLINE, 0x0687},
-	{0xFB82, 0, 1 | DECOMP_INLINE, 0x068D},
-	{0xFB83, 0, 1 | DECOMP_INLINE, 0x068D},
-	{0xFB84, 0, 1 | DECOMP_INLINE, 0x068C},
-	{0xFB85, 0, 1 | DECOMP_INLINE, 0x068C},
-	{0xFB86, 0, 1 | DECOMP_INLINE, 0x068E},
-	{0xFB87, 0, 1 | DECOMP_INLINE, 0x068E},
-	{0xFB88, 0, 1 | DECOMP_INLINE, 0x0688},
-	{0xFB89, 0, 1 | DECOMP_INLINE, 0x0688},
-	{0xFB8A, 0, 1 | DECOMP_INLINE, 0x0698},
-	{0xFB8B, 0, 1 | DECOMP_INLINE, 0x0698},
-	{0xFB8C, 0, 1 | DECOMP_INLINE, 0x0691},
-	{0xFB8D, 0, 1 | DECOMP_INLINE, 0x0691},
-	{0xFB8E, 0, 1 | DECOMP_INLINE, 0x06A9},
-	{0xFB8F, 0, 1 | DECOMP_INLINE, 0x06A9},
-	{0xFB90, 0, 1 | DECOMP_INLINE, 0x06A9},
-	{0xFB91, 0, 1 | DECOMP_INLINE, 0x06A9},
-	{0xFB92, 0, 1 | DECOMP_INLINE, 0x06AF},
-	{0xFB93, 0, 1 | DECOMP_INLINE, 0x06AF},
-	{0xFB94, 0, 1 | DECOMP_INLINE, 0x06AF},
-	{0xFB95, 0, 1 | DECOMP_INLINE, 0x06AF},
-	{0xFB96, 0, 1 | DECOMP_INLINE, 0x06B3},
-	{0xFB97, 0, 1 | DECOMP_INLINE, 0x06B3},
-	{0xFB98, 0, 1 | DECOMP_INLINE, 0x06B3},
-	{0xFB99, 0, 1 | DECOMP_INLINE, 0x06B3},
-	{0xFB9A, 0, 1 | DECOMP_INLINE, 0x06B1},
-	{0xFB9B, 0, 1 | DECOMP_INLINE, 0x06B1},
-	{0xFB9C, 0, 1 | DECOMP_INLINE, 0x06B1},
-	{0xFB9D, 0, 1 | DECOMP_INLINE, 0x06B1},
-	{0xFB9E, 0, 1 | DECOMP_INLINE, 0x06BA},
-	{0xFB9F, 0, 1 | DECOMP_INLINE, 0x06BA},
-	{0xFBA0, 0, 1 | DECOMP_INLINE, 0x06BB},
-	{0xFBA1, 0, 1 | DECOMP_INLINE, 0x06BB},
-	{0xFBA2, 0, 1 | DECOMP_INLINE, 0x06BB},
-	{0xFBA3, 0, 1 | DECOMP_INLINE, 0x06BB},
-	{0xFBA4, 0, 1 | DECOMP_INLINE, 0x06C0},
-	{0xFBA5, 0, 1 | DECOMP_INLINE, 0x06C0},
-	{0xFBA6, 0, 1 | DECOMP_INLINE, 0x06C1},
-	{0xFBA7, 0, 1 | DECOMP_INLINE, 0x06C1},
-	{0xFBA8, 0, 1 | DECOMP_INLINE, 0x06C1},
-	{0xFBA9, 0, 1 | DECOMP_INLINE, 0x06C1},
-	{0xFBAA, 0, 1 | DECOMP_INLINE, 0x06BE},
-	{0xFBAB, 0, 1 | DECOMP_INLINE, 0x06BE},
-	{0xFBAC, 0, 1 | DECOMP_INLINE, 0x06BE},
-	{0xFBAD, 0, 1 | DECOMP_INLINE, 0x06BE},
-	{0xFBAE, 0, 1 | DECOMP_INLINE, 0x06D2},
-	{0xFBAF, 0, 1 | DECOMP_INLINE, 0x06D2},
-	{0xFBB0, 0, 1 | DECOMP_INLINE, 0x06D3},
-	{0xFBB1, 0, 1 | DECOMP_INLINE, 0x06D3},
-	{0xFBD3, 0, 1 | DECOMP_INLINE, 0x06AD},
-	{0xFBD4, 0, 1 | DECOMP_INLINE, 0x06AD},
-	{0xFBD5, 0, 1 | DECOMP_INLINE, 0x06AD},
-	{0xFBD6, 0, 1 | DECOMP_INLINE, 0x06AD},
-	{0xFBD7, 0, 1 | DECOMP_INLINE, 0x06C7},
-	{0xFBD8, 0, 1 | DECOMP_INLINE, 0x06C7},
-	{0xFBD9, 0, 1 | DECOMP_INLINE, 0x06C6},
-	{0xFBDA, 0, 1 | DECOMP_INLINE, 0x06C6},
-	{0xFBDB, 0, 1 | DECOMP_INLINE, 0x06C8},
-	{0xFBDC, 0, 1 | DECOMP_INLINE, 0x06C8},
-	{0xFBDD, 0, 1 | DECOMP_INLINE, 0x0677},
-	{0xFBDE, 0, 1 | DECOMP_INLINE, 0x06CB},
-	{0xFBDF, 0, 1 | DECOMP_INLINE, 0x06CB},
-	{0xFBE0, 0, 1 | DECOMP_INLINE, 0x06C5},
-	{0xFBE1, 0, 1 | DECOMP_INLINE, 0x06C5},
-	{0xFBE2, 0, 1 | DECOMP_INLINE, 0x06C9},
-	{0xFBE3, 0, 1 | DECOMP_INLINE, 0x06C9},
-	{0xFBE4, 0, 1 | DECOMP_INLINE, 0x06D0},
-	{0xFBE5, 0, 1 | DECOMP_INLINE, 0x06D0},
-	{0xFBE6, 0, 1 | DECOMP_INLINE, 0x06D0},
-	{0xFBE7, 0, 1 | DECOMP_INLINE, 0x06D0},
-	{0xFBE8, 0, 1 | DECOMP_INLINE, 0x0649},
-	{0xFBE9, 0, 1 | DECOMP_INLINE, 0x0649},
-	{0xFBEA, 0, 2 | DECOMP_NO_COMPOSE, 3630},	/* compatibility mapping */
-	{0xFBEB, 0, 2 | DECOMP_NO_COMPOSE, 3632},	/* compatibility mapping */
-	{0xFBEC, 0, 2 | DECOMP_NO_COMPOSE, 3634},	/* compatibility mapping */
-	{0xFBED, 0, 2 | DECOMP_NO_COMPOSE, 3636},	/* compatibility mapping */
-	{0xFBEE, 0, 2 | DECOMP_NO_COMPOSE, 3638},	/* compatibility mapping */
-	{0xFBEF, 0, 2 | DECOMP_NO_COMPOSE, 3640},	/* compatibility mapping */
-	{0xFBF0, 0, 2 | DECOMP_NO_COMPOSE, 3642},	/* compatibility mapping */
-	{0xFBF1, 0, 2 | DECOMP_NO_COMPOSE, 3644},	/* compatibility mapping */
-	{0xFBF2, 0, 2 | DECOMP_NO_COMPOSE, 3646},	/* compatibility mapping */
-	{0xFBF3, 0, 2 | DECOMP_NO_COMPOSE, 3648},	/* compatibility mapping */
-	{0xFBF4, 0, 2 | DECOMP_NO_COMPOSE, 3650},	/* compatibility mapping */
-	{0xFBF5, 0, 2 | DECOMP_NO_COMPOSE, 3652},	/* compatibility mapping */
-	{0xFBF6, 0, 2 | DECOMP_NO_COMPOSE, 3654},	/* compatibility mapping */
-	{0xFBF7, 0, 2 | DECOMP_NO_COMPOSE, 3656},	/* compatibility mapping */
-	{0xFBF8, 0, 2 | DECOMP_NO_COMPOSE, 3658},	/* compatibility mapping */
-	{0xFBF9, 0, 2 | DECOMP_NO_COMPOSE, 3660},	/* compatibility mapping */
-	{0xFBFA, 0, 2 | DECOMP_NO_COMPOSE, 3662},	/* compatibility mapping */
-	{0xFBFB, 0, 2 | DECOMP_NO_COMPOSE, 3664},	/* compatibility mapping */
-	{0xFBFC, 0, 1 | DECOMP_INLINE, 0x06CC},
-	{0xFBFD, 0, 1 | DECOMP_INLINE, 0x06CC},
-	{0xFBFE, 0, 1 | DECOMP_INLINE, 0x06CC},
-	{0xFBFF, 0, 1 | DECOMP_INLINE, 0x06CC},
-	{0xFC00, 0, 2 | DECOMP_NO_COMPOSE, 3666},	/* compatibility mapping */
-	{0xFC01, 0, 2 | DECOMP_NO_COMPOSE, 3668},	/* compatibility mapping */
-	{0xFC02, 0, 2 | DECOMP_NO_COMPOSE, 3670},	/* compatibility mapping */
-	{0xFC03, 0, 2 | DECOMP_NO_COMPOSE, 3672},	/* compatibility mapping */
-	{0xFC04, 0, 2 | DECOMP_NO_COMPOSE, 3674},	/* compatibility mapping */
-	{0xFC05, 0, 2 | DECOMP_NO_COMPOSE, 3676},	/* compatibility mapping */
-	{0xFC06, 0, 2 | DECOMP_NO_COMPOSE, 3678},	/* compatibility mapping */
-	{0xFC07, 0, 2 | DECOMP_NO_COMPOSE, 3680},	/* compatibility mapping */
-	{0xFC08, 0, 2 | DECOMP_NO_COMPOSE, 3682},	/* compatibility mapping */
-	{0xFC09, 0, 2 | DECOMP_NO_COMPOSE, 3684},	/* compatibility mapping */
-	{0xFC0A, 0, 2 | DECOMP_NO_COMPOSE, 3686},	/* compatibility mapping */
-	{0xFC0B, 0, 2 | DECOMP_NO_COMPOSE, 3688},	/* compatibility mapping */
-	{0xFC0C, 0, 2 | DECOMP_NO_COMPOSE, 3690},	/* compatibility mapping */
-	{0xFC0D, 0, 2 | DECOMP_NO_COMPOSE, 3692},	/* compatibility mapping */
-	{0xFC0E, 0, 2 | DECOMP_NO_COMPOSE, 3694},	/* compatibility mapping */
-	{0xFC0F, 0, 2 | DECOMP_NO_COMPOSE, 3696},	/* compatibility mapping */
-	{0xFC10, 0, 2 | DECOMP_NO_COMPOSE, 3698},	/* compatibility mapping */
-	{0xFC11, 0, 2 | DECOMP_NO_COMPOSE, 3700},	/* compatibility mapping */
-	{0xFC12, 0, 2 | DECOMP_NO_COMPOSE, 3702},	/* compatibility mapping */
-	{0xFC13, 0, 2 | DECOMP_NO_COMPOSE, 3704},	/* compatibility mapping */
-	{0xFC14, 0, 2 | DECOMP_NO_COMPOSE, 3706},	/* compatibility mapping */
-	{0xFC15, 0, 2 | DECOMP_NO_COMPOSE, 3708},	/* compatibility mapping */
-	{0xFC16, 0, 2 | DECOMP_NO_COMPOSE, 3710},	/* compatibility mapping */
-	{0xFC17, 0, 2 | DECOMP_NO_COMPOSE, 3712},	/* compatibility mapping */
-	{0xFC18, 0, 2 | DECOMP_NO_COMPOSE, 3714},	/* compatibility mapping */
-	{0xFC19, 0, 2 | DECOMP_NO_COMPOSE, 3716},	/* compatibility mapping */
-	{0xFC1A, 0, 2 | DECOMP_NO_COMPOSE, 3718},	/* compatibility mapping */
-	{0xFC1B, 0, 2 | DECOMP_NO_COMPOSE, 3720},	/* compatibility mapping */
-	{0xFC1C, 0, 2 | DECOMP_NO_COMPOSE, 3722},	/* compatibility mapping */
-	{0xFC1D, 0, 2 | DECOMP_NO_COMPOSE, 3724},	/* compatibility mapping */
-	{0xFC1E, 0, 2 | DECOMP_NO_COMPOSE, 3726},	/* compatibility mapping */
-	{0xFC1F, 0, 2 | DECOMP_NO_COMPOSE, 3728},	/* compatibility mapping */
-	{0xFC20, 0, 2 | DECOMP_NO_COMPOSE, 3730},	/* compatibility mapping */
-	{0xFC21, 0, 2 | DECOMP_NO_COMPOSE, 3732},	/* compatibility mapping */
-	{0xFC22, 0, 2 | DECOMP_NO_COMPOSE, 3734},	/* compatibility mapping */
-	{0xFC23, 0, 2 | DECOMP_NO_COMPOSE, 3736},	/* compatibility mapping */
-	{0xFC24, 0, 2 | DECOMP_NO_COMPOSE, 3738},	/* compatibility mapping */
-	{0xFC25, 0, 2 | DECOMP_NO_COMPOSE, 3740},	/* compatibility mapping */
-	{0xFC26, 0, 2 | DECOMP_NO_COMPOSE, 3742},	/* compatibility mapping */
-	{0xFC27, 0, 2 | DECOMP_NO_COMPOSE, 3744},	/* compatibility mapping */
-	{0xFC28, 0, 2 | DECOMP_NO_COMPOSE, 3746},	/* compatibility mapping */
-	{0xFC29, 0, 2 | DECOMP_NO_COMPOSE, 3748},	/* compatibility mapping */
-	{0xFC2A, 0, 2 | DECOMP_NO_COMPOSE, 3750},	/* compatibility mapping */
-	{0xFC2B, 0, 2 | DECOMP_NO_COMPOSE, 3752},	/* compatibility mapping */
-	{0xFC2C, 0, 2 | DECOMP_NO_COMPOSE, 3754},	/* compatibility mapping */
-	{0xFC2D, 0, 2 | DECOMP_NO_COMPOSE, 3756},	/* compatibility mapping */
-	{0xFC2E, 0, 2 | DECOMP_NO_COMPOSE, 3758},	/* compatibility mapping */
-	{0xFC2F, 0, 2 | DECOMP_NO_COMPOSE, 3760},	/* compatibility mapping */
-	{0xFC30, 0, 2 | DECOMP_NO_COMPOSE, 3762},	/* compatibility mapping */
-	{0xFC31, 0, 2 | DECOMP_NO_COMPOSE, 3764},	/* compatibility mapping */
-	{0xFC32, 0, 2 | DECOMP_NO_COMPOSE, 3766},	/* compatibility mapping */
-	{0xFC33, 0, 2 | DECOMP_NO_COMPOSE, 3768},	/* compatibility mapping */
-	{0xFC34, 0, 2 | DECOMP_NO_COMPOSE, 3770},	/* compatibility mapping */
-	{0xFC35, 0, 2 | DECOMP_NO_COMPOSE, 3772},	/* compatibility mapping */
-	{0xFC36, 0, 2 | DECOMP_NO_COMPOSE, 3774},	/* compatibility mapping */
-	{0xFC37, 0, 2 | DECOMP_NO_COMPOSE, 3776},	/* compatibility mapping */
-	{0xFC38, 0, 2 | DECOMP_NO_COMPOSE, 3778},	/* compatibility mapping */
-	{0xFC39, 0, 2 | DECOMP_NO_COMPOSE, 3780},	/* compatibility mapping */
-	{0xFC3A, 0, 2 | DECOMP_NO_COMPOSE, 3782},	/* compatibility mapping */
-	{0xFC3B, 0, 2 | DECOMP_NO_COMPOSE, 3784},	/* compatibility mapping */
-	{0xFC3C, 0, 2 | DECOMP_NO_COMPOSE, 3786},	/* compatibility mapping */
-	{0xFC3D, 0, 2 | DECOMP_NO_COMPOSE, 3788},	/* compatibility mapping */
-	{0xFC3E, 0, 2 | DECOMP_NO_COMPOSE, 3790},	/* compatibility mapping */
-	{0xFC3F, 0, 2 | DECOMP_NO_COMPOSE, 3792},	/* compatibility mapping */
-	{0xFC40, 0, 2 | DECOMP_NO_COMPOSE, 3794},	/* compatibility mapping */
-	{0xFC41, 0, 2 | DECOMP_NO_COMPOSE, 3796},	/* compatibility mapping */
-	{0xFC42, 0, 2 | DECOMP_NO_COMPOSE, 3798},	/* compatibility mapping */
-	{0xFC43, 0, 2 | DECOMP_NO_COMPOSE, 3800},	/* compatibility mapping */
-	{0xFC44, 0, 2 | DECOMP_NO_COMPOSE, 3802},	/* compatibility mapping */
-	{0xFC45, 0, 2 | DECOMP_NO_COMPOSE, 3804},	/* compatibility mapping */
-	{0xFC46, 0, 2 | DECOMP_NO_COMPOSE, 3806},	/* compatibility mapping */
-	{0xFC47, 0, 2 | DECOMP_NO_COMPOSE, 3808},	/* compatibility mapping */
-	{0xFC48, 0, 2 | DECOMP_NO_COMPOSE, 3810},	/* compatibility mapping */
-	{0xFC49, 0, 2 | DECOMP_NO_COMPOSE, 3812},	/* compatibility mapping */
-	{0xFC4A, 0, 2 | DECOMP_NO_COMPOSE, 3814},	/* compatibility mapping */
-	{0xFC4B, 0, 2 | DECOMP_NO_COMPOSE, 3816},	/* compatibility mapping */
-	{0xFC4C, 0, 2 | DECOMP_NO_COMPOSE, 3818},	/* compatibility mapping */
-	{0xFC4D, 0, 2 | DECOMP_NO_COMPOSE, 3820},	/* compatibility mapping */
-	{0xFC4E, 0, 2 | DECOMP_NO_COMPOSE, 3822},	/* compatibility mapping */
-	{0xFC4F, 0, 2 | DECOMP_NO_COMPOSE, 3824},	/* compatibility mapping */
-	{0xFC50, 0, 2 | DECOMP_NO_COMPOSE, 3826},	/* compatibility mapping */
-	{0xFC51, 0, 2 | DECOMP_NO_COMPOSE, 3828},	/* compatibility mapping */
-	{0xFC52, 0, 2 | DECOMP_NO_COMPOSE, 3830},	/* compatibility mapping */
-	{0xFC53, 0, 2 | DECOMP_NO_COMPOSE, 3832},	/* compatibility mapping */
-	{0xFC54, 0, 2 | DECOMP_NO_COMPOSE, 3834},	/* compatibility mapping */
-	{0xFC55, 0, 2 | DECOMP_NO_COMPOSE, 3836},	/* compatibility mapping */
-	{0xFC56, 0, 2 | DECOMP_NO_COMPOSE, 3838},	/* compatibility mapping */
-	{0xFC57, 0, 2 | DECOMP_NO_COMPOSE, 3840},	/* compatibility mapping */
-	{0xFC58, 0, 2 | DECOMP_NO_COMPOSE, 3842},	/* compatibility mapping */
-	{0xFC59, 0, 2 | DECOMP_NO_COMPOSE, 3844},	/* compatibility mapping */
-	{0xFC5A, 0, 2 | DECOMP_NO_COMPOSE, 3846},	/* compatibility mapping */
-	{0xFC5B, 0, 2 | DECOMP_NO_COMPOSE, 3848},	/* compatibility mapping */
-	{0xFC5C, 0, 2 | DECOMP_NO_COMPOSE, 3850},	/* compatibility mapping */
-	{0xFC5D, 0, 2 | DECOMP_NO_COMPOSE, 3852},	/* compatibility mapping */
-	{0xFC5E, 0, 3, 3854},
-	{0xFC5F, 0, 3, 3857},
-	{0xFC60, 0, 3, 3860},
-	{0xFC61, 0, 3, 3863},
-	{0xFC62, 0, 3, 3866},
-	{0xFC63, 0, 3, 3869},
-	{0xFC64, 0, 2 | DECOMP_NO_COMPOSE, 3872},	/* compatibility mapping */
-	{0xFC65, 0, 2 | DECOMP_NO_COMPOSE, 3874},	/* compatibility mapping */
-	{0xFC66, 0, 2 | DECOMP_NO_COMPOSE, 3876},	/* compatibility mapping */
-	{0xFC67, 0, 2 | DECOMP_NO_COMPOSE, 3878},	/* compatibility mapping */
-	{0xFC68, 0, 2 | DECOMP_NO_COMPOSE, 3880},	/* compatibility mapping */
-	{0xFC69, 0, 2 | DECOMP_NO_COMPOSE, 3882},	/* compatibility mapping */
-	{0xFC6A, 0, 2 | DECOMP_NO_COMPOSE, 3884},	/* compatibility mapping */
-	{0xFC6B, 0, 2 | DECOMP_NO_COMPOSE, 3886},	/* compatibility mapping */
-	{0xFC6C, 0, 2 | DECOMP_NO_COMPOSE, 3888},	/* compatibility mapping */
-	{0xFC6D, 0, 2 | DECOMP_NO_COMPOSE, 3890},	/* compatibility mapping */
-	{0xFC6E, 0, 2 | DECOMP_NO_COMPOSE, 3892},	/* compatibility mapping */
-	{0xFC6F, 0, 2 | DECOMP_NO_COMPOSE, 3894},	/* compatibility mapping */
-	{0xFC70, 0, 2 | DECOMP_NO_COMPOSE, 3896},	/* compatibility mapping */
-	{0xFC71, 0, 2 | DECOMP_NO_COMPOSE, 3898},	/* compatibility mapping */
-	{0xFC72, 0, 2 | DECOMP_NO_COMPOSE, 3900},	/* compatibility mapping */
-	{0xFC73, 0, 2 | DECOMP_NO_COMPOSE, 3902},	/* compatibility mapping */
-	{0xFC74, 0, 2 | DECOMP_NO_COMPOSE, 3904},	/* compatibility mapping */
-	{0xFC75, 0, 2 | DECOMP_NO_COMPOSE, 3906},	/* compatibility mapping */
-	{0xFC76, 0, 2 | DECOMP_NO_COMPOSE, 3908},	/* compatibility mapping */
-	{0xFC77, 0, 2 | DECOMP_NO_COMPOSE, 3910},	/* compatibility mapping */
-	{0xFC78, 0, 2 | DECOMP_NO_COMPOSE, 3912},	/* compatibility mapping */
-	{0xFC79, 0, 2 | DECOMP_NO_COMPOSE, 3914},	/* compatibility mapping */
-	{0xFC7A, 0, 2 | DECOMP_NO_COMPOSE, 3916},	/* compatibility mapping */
-	{0xFC7B, 0, 2 | DECOMP_NO_COMPOSE, 3918},	/* compatibility mapping */
-	{0xFC7C, 0, 2 | DECOMP_NO_COMPOSE, 3920},	/* compatibility mapping */
-	{0xFC7D, 0, 2 | DECOMP_NO_COMPOSE, 3922},	/* compatibility mapping */
-	{0xFC7E, 0, 2 | DECOMP_NO_COMPOSE, 3924},	/* compatibility mapping */
-	{0xFC7F, 0, 2 | DECOMP_NO_COMPOSE, 3926},	/* compatibility mapping */
-	{0xFC80, 0, 2 | DECOMP_NO_COMPOSE, 3928},	/* compatibility mapping */
-	{0xFC81, 0, 2 | DECOMP_NO_COMPOSE, 3930},	/* compatibility mapping */
-	{0xFC82, 0, 2 | DECOMP_NO_COMPOSE, 3932},	/* compatibility mapping */
-	{0xFC83, 0, 2 | DECOMP_NO_COMPOSE, 3934},	/* compatibility mapping */
-	{0xFC84, 0, 2 | DECOMP_NO_COMPOSE, 3936},	/* compatibility mapping */
-	{0xFC85, 0, 2 | DECOMP_NO_COMPOSE, 3938},	/* compatibility mapping */
-	{0xFC86, 0, 2 | DECOMP_NO_COMPOSE, 3940},	/* compatibility mapping */
-	{0xFC87, 0, 2 | DECOMP_NO_COMPOSE, 3942},	/* compatibility mapping */
-	{0xFC88, 0, 2 | DECOMP_NO_COMPOSE, 3944},	/* compatibility mapping */
-	{0xFC89, 0, 2 | DECOMP_NO_COMPOSE, 3946},	/* compatibility mapping */
-	{0xFC8A, 0, 2 | DECOMP_NO_COMPOSE, 3948},	/* compatibility mapping */
-	{0xFC8B, 0, 2 | DECOMP_NO_COMPOSE, 3950},	/* compatibility mapping */
-	{0xFC8C, 0, 2 | DECOMP_NO_COMPOSE, 3952},	/* compatibility mapping */
-	{0xFC8D, 0, 2 | DECOMP_NO_COMPOSE, 3954},	/* compatibility mapping */
-	{0xFC8E, 0, 2 | DECOMP_NO_COMPOSE, 3956},	/* compatibility mapping */
-	{0xFC8F, 0, 2 | DECOMP_NO_COMPOSE, 3958},	/* compatibility mapping */
-	{0xFC90, 0, 2 | DECOMP_NO_COMPOSE, 3960},	/* compatibility mapping */
-	{0xFC91, 0, 2 | DECOMP_NO_COMPOSE, 3962},	/* compatibility mapping */
-	{0xFC92, 0, 2 | DECOMP_NO_COMPOSE, 3964},	/* compatibility mapping */
-	{0xFC93, 0, 2 | DECOMP_NO_COMPOSE, 3966},	/* compatibility mapping */
-	{0xFC94, 0, 2 | DECOMP_NO_COMPOSE, 3968},	/* compatibility mapping */
-	{0xFC95, 0, 2 | DECOMP_NO_COMPOSE, 3970},	/* compatibility mapping */
-	{0xFC96, 0, 2 | DECOMP_NO_COMPOSE, 3972},	/* compatibility mapping */
-	{0xFC97, 0, 2 | DECOMP_NO_COMPOSE, 3974},	/* compatibility mapping */
-	{0xFC98, 0, 2 | DECOMP_NO_COMPOSE, 3976},	/* compatibility mapping */
-	{0xFC99, 0, 2 | DECOMP_NO_COMPOSE, 3978},	/* compatibility mapping */
-	{0xFC9A, 0, 2 | DECOMP_NO_COMPOSE, 3980},	/* compatibility mapping */
-	{0xFC9B, 0, 2 | DECOMP_NO_COMPOSE, 3982},	/* compatibility mapping */
-	{0xFC9C, 0, 2 | DECOMP_NO_COMPOSE, 3984},	/* compatibility mapping */
-	{0xFC9D, 0, 2 | DECOMP_NO_COMPOSE, 3986},	/* compatibility mapping */
-	{0xFC9E, 0, 2 | DECOMP_NO_COMPOSE, 3988},	/* compatibility mapping */
-	{0xFC9F, 0, 2 | DECOMP_NO_COMPOSE, 3990},	/* compatibility mapping */
-	{0xFCA0, 0, 2 | DECOMP_NO_COMPOSE, 3992},	/* compatibility mapping */
-	{0xFCA1, 0, 2 | DECOMP_NO_COMPOSE, 3994},	/* compatibility mapping */
-	{0xFCA2, 0, 2 | DECOMP_NO_COMPOSE, 3996},	/* compatibility mapping */
-	{0xFCA3, 0, 2 | DECOMP_NO_COMPOSE, 3998},	/* compatibility mapping */
-	{0xFCA4, 0, 2 | DECOMP_NO_COMPOSE, 4000},	/* compatibility mapping */
-	{0xFCA5, 0, 2 | DECOMP_NO_COMPOSE, 4002},	/* compatibility mapping */
-	{0xFCA6, 0, 2 | DECOMP_NO_COMPOSE, 4004},	/* compatibility mapping */
-	{0xFCA7, 0, 2 | DECOMP_NO_COMPOSE, 4006},	/* compatibility mapping */
-	{0xFCA8, 0, 2 | DECOMP_NO_COMPOSE, 4008},	/* compatibility mapping */
-	{0xFCA9, 0, 2 | DECOMP_NO_COMPOSE, 4010},	/* compatibility mapping */
-	{0xFCAA, 0, 2 | DECOMP_NO_COMPOSE, 4012},	/* compatibility mapping */
-	{0xFCAB, 0, 2 | DECOMP_NO_COMPOSE, 4014},	/* compatibility mapping */
-	{0xFCAC, 0, 2 | DECOMP_NO_COMPOSE, 4016},	/* compatibility mapping */
-	{0xFCAD, 0, 2 | DECOMP_NO_COMPOSE, 4018},	/* compatibility mapping */
-	{0xFCAE, 0, 2 | DECOMP_NO_COMPOSE, 4020},	/* compatibility mapping */
-	{0xFCAF, 0, 2 | DECOMP_NO_COMPOSE, 4022},	/* compatibility mapping */
-	{0xFCB0, 0, 2 | DECOMP_NO_COMPOSE, 4024},	/* compatibility mapping */
-	{0xFCB1, 0, 2 | DECOMP_NO_COMPOSE, 4026},	/* compatibility mapping */
-	{0xFCB2, 0, 2 | DECOMP_NO_COMPOSE, 4028},	/* compatibility mapping */
-	{0xFCB3, 0, 2 | DECOMP_NO_COMPOSE, 4030},	/* compatibility mapping */
-	{0xFCB4, 0, 2 | DECOMP_NO_COMPOSE, 4032},	/* compatibility mapping */
-	{0xFCB5, 0, 2 | DECOMP_NO_COMPOSE, 4034},	/* compatibility mapping */
-	{0xFCB6, 0, 2 | DECOMP_NO_COMPOSE, 4036},	/* compatibility mapping */
-	{0xFCB7, 0, 2 | DECOMP_NO_COMPOSE, 4038},	/* compatibility mapping */
-	{0xFCB8, 0, 2 | DECOMP_NO_COMPOSE, 4040},	/* compatibility mapping */
-	{0xFCB9, 0, 2 | DECOMP_NO_COMPOSE, 4042},	/* compatibility mapping */
-	{0xFCBA, 0, 2 | DECOMP_NO_COMPOSE, 4044},	/* compatibility mapping */
-	{0xFCBB, 0, 2 | DECOMP_NO_COMPOSE, 4046},	/* compatibility mapping */
-	{0xFCBC, 0, 2 | DECOMP_NO_COMPOSE, 4048},	/* compatibility mapping */
-	{0xFCBD, 0, 2 | DECOMP_NO_COMPOSE, 4050},	/* compatibility mapping */
-	{0xFCBE, 0, 2 | DECOMP_NO_COMPOSE, 4052},	/* compatibility mapping */
-	{0xFCBF, 0, 2 | DECOMP_NO_COMPOSE, 4054},	/* compatibility mapping */
-	{0xFCC0, 0, 2 | DECOMP_NO_COMPOSE, 4056},	/* compatibility mapping */
-	{0xFCC1, 0, 2 | DECOMP_NO_COMPOSE, 4058},	/* compatibility mapping */
-	{0xFCC2, 0, 2 | DECOMP_NO_COMPOSE, 4060},	/* compatibility mapping */
-	{0xFCC3, 0, 2 | DECOMP_NO_COMPOSE, 4062},	/* compatibility mapping */
-	{0xFCC4, 0, 2 | DECOMP_NO_COMPOSE, 4064},	/* compatibility mapping */
-	{0xFCC5, 0, 2 | DECOMP_NO_COMPOSE, 4066},	/* compatibility mapping */
-	{0xFCC6, 0, 2 | DECOMP_NO_COMPOSE, 4068},	/* compatibility mapping */
-	{0xFCC7, 0, 2 | DECOMP_NO_COMPOSE, 4070},	/* compatibility mapping */
-	{0xFCC8, 0, 2 | DECOMP_NO_COMPOSE, 4072},	/* compatibility mapping */
-	{0xFCC9, 0, 2 | DECOMP_NO_COMPOSE, 4074},	/* compatibility mapping */
-	{0xFCCA, 0, 2 | DECOMP_NO_COMPOSE, 4076},	/* compatibility mapping */
-	{0xFCCB, 0, 2 | DECOMP_NO_COMPOSE, 4078},	/* compatibility mapping */
-	{0xFCCC, 0, 2 | DECOMP_NO_COMPOSE, 4080},	/* compatibility mapping */
-	{0xFCCD, 0, 2 | DECOMP_NO_COMPOSE, 4082},	/* compatibility mapping */
-	{0xFCCE, 0, 2 | DECOMP_NO_COMPOSE, 4084},	/* compatibility mapping */
-	{0xFCCF, 0, 2 | DECOMP_NO_COMPOSE, 4086},	/* compatibility mapping */
-	{0xFCD0, 0, 2 | DECOMP_NO_COMPOSE, 4088},	/* compatibility mapping */
-	{0xFCD1, 0, 2 | DECOMP_NO_COMPOSE, 4090},	/* compatibility mapping */
-	{0xFCD2, 0, 2 | DECOMP_NO_COMPOSE, 4092},	/* compatibility mapping */
-	{0xFCD3, 0, 2 | DECOMP_NO_COMPOSE, 4094},	/* compatibility mapping */
-	{0xFCD4, 0, 2 | DECOMP_NO_COMPOSE, 4096},	/* compatibility mapping */
-	{0xFCD5, 0, 2 | DECOMP_NO_COMPOSE, 4098},	/* compatibility mapping */
-	{0xFCD6, 0, 2 | DECOMP_NO_COMPOSE, 4100},	/* compatibility mapping */
-	{0xFCD7, 0, 2 | DECOMP_NO_COMPOSE, 4102},	/* compatibility mapping */
-	{0xFCD8, 0, 2 | DECOMP_NO_COMPOSE, 4104},	/* compatibility mapping */
-	{0xFCD9, 0, 2 | DECOMP_NO_COMPOSE, 4106},	/* compatibility mapping */
-	{0xFCDA, 0, 2 | DECOMP_NO_COMPOSE, 4108},	/* compatibility mapping */
-	{0xFCDB, 0, 2 | DECOMP_NO_COMPOSE, 4110},	/* compatibility mapping */
-	{0xFCDC, 0, 2 | DECOMP_NO_COMPOSE, 4112},	/* compatibility mapping */
-	{0xFCDD, 0, 2 | DECOMP_NO_COMPOSE, 4114},	/* compatibility mapping */
-	{0xFCDE, 0, 2 | DECOMP_NO_COMPOSE, 4116},	/* compatibility mapping */
-	{0xFCDF, 0, 2 | DECOMP_NO_COMPOSE, 4118},	/* compatibility mapping */
-	{0xFCE0, 0, 2 | DECOMP_NO_COMPOSE, 4120},	/* compatibility mapping */
-	{0xFCE1, 0, 2 | DECOMP_NO_COMPOSE, 4122},	/* compatibility mapping */
-	{0xFCE2, 0, 2 | DECOMP_NO_COMPOSE, 4124},	/* compatibility mapping */
-	{0xFCE3, 0, 2 | DECOMP_NO_COMPOSE, 4126},	/* compatibility mapping */
-	{0xFCE4, 0, 2 | DECOMP_NO_COMPOSE, 4128},	/* compatibility mapping */
-	{0xFCE5, 0, 2 | DECOMP_NO_COMPOSE, 4130},	/* compatibility mapping */
-	{0xFCE6, 0, 2 | DECOMP_NO_COMPOSE, 4132},	/* compatibility mapping */
-	{0xFCE7, 0, 2 | DECOMP_NO_COMPOSE, 4134},	/* compatibility mapping */
-	{0xFCE8, 0, 2 | DECOMP_NO_COMPOSE, 4136},	/* compatibility mapping */
-	{0xFCE9, 0, 2 | DECOMP_NO_COMPOSE, 4138},	/* compatibility mapping */
-	{0xFCEA, 0, 2 | DECOMP_NO_COMPOSE, 4140},	/* compatibility mapping */
-	{0xFCEB, 0, 2 | DECOMP_NO_COMPOSE, 4142},	/* compatibility mapping */
-	{0xFCEC, 0, 2 | DECOMP_NO_COMPOSE, 4144},	/* compatibility mapping */
-	{0xFCED, 0, 2 | DECOMP_NO_COMPOSE, 4146},	/* compatibility mapping */
-	{0xFCEE, 0, 2 | DECOMP_NO_COMPOSE, 4148},	/* compatibility mapping */
-	{0xFCEF, 0, 2 | DECOMP_NO_COMPOSE, 4150},	/* compatibility mapping */
-	{0xFCF0, 0, 2 | DECOMP_NO_COMPOSE, 4152},	/* compatibility mapping */
-	{0xFCF1, 0, 2 | DECOMP_NO_COMPOSE, 4154},	/* compatibility mapping */
-	{0xFCF2, 0, 3, 4156},
-	{0xFCF3, 0, 3, 4159},
-	{0xFCF4, 0, 3, 4162},
-	{0xFCF5, 0, 2 | DECOMP_NO_COMPOSE, 4165},	/* compatibility mapping */
-	{0xFCF6, 0, 2 | DECOMP_NO_COMPOSE, 4167},	/* compatibility mapping */
-	{0xFCF7, 0, 2 | DECOMP_NO_COMPOSE, 4169},	/* compatibility mapping */
-	{0xFCF8, 0, 2 | DECOMP_NO_COMPOSE, 4171},	/* compatibility mapping */
-	{0xFCF9, 0, 2 | DECOMP_NO_COMPOSE, 4173},	/* compatibility mapping */
-	{0xFCFA, 0, 2 | DECOMP_NO_COMPOSE, 4175},	/* compatibility mapping */
-	{0xFCFB, 0, 2 | DECOMP_NO_COMPOSE, 4177},	/* compatibility mapping */
-	{0xFCFC, 0, 2 | DECOMP_NO_COMPOSE, 4179},	/* compatibility mapping */
-	{0xFCFD, 0, 2 | DECOMP_NO_COMPOSE, 4181},	/* compatibility mapping */
-	{0xFCFE, 0, 2 | DECOMP_NO_COMPOSE, 4183},	/* compatibility mapping */
-	{0xFCFF, 0, 2 | DECOMP_NO_COMPOSE, 4185},	/* compatibility mapping */
-	{0xFD00, 0, 2 | DECOMP_NO_COMPOSE, 4187},	/* compatibility mapping */
-	{0xFD01, 0, 2 | DECOMP_NO_COMPOSE, 4189},	/* compatibility mapping */
-	{0xFD02, 0, 2 | DECOMP_NO_COMPOSE, 4191},	/* compatibility mapping */
-	{0xFD03, 0, 2 | DECOMP_NO_COMPOSE, 4193},	/* compatibility mapping */
-	{0xFD04, 0, 2 | DECOMP_NO_COMPOSE, 4195},	/* compatibility mapping */
-	{0xFD05, 0, 2 | DECOMP_NO_COMPOSE, 4197},	/* compatibility mapping */
-	{0xFD06, 0, 2 | DECOMP_NO_COMPOSE, 4199},	/* compatibility mapping */
-	{0xFD07, 0, 2 | DECOMP_NO_COMPOSE, 4201},	/* compatibility mapping */
-	{0xFD08, 0, 2 | DECOMP_NO_COMPOSE, 4203},	/* compatibility mapping */
-	{0xFD09, 0, 2 | DECOMP_NO_COMPOSE, 4205},	/* compatibility mapping */
-	{0xFD0A, 0, 2 | DECOMP_NO_COMPOSE, 4207},	/* compatibility mapping */
-	{0xFD0B, 0, 2 | DECOMP_NO_COMPOSE, 4209},	/* compatibility mapping */
-	{0xFD0C, 0, 2 | DECOMP_NO_COMPOSE, 4211},	/* compatibility mapping */
-	{0xFD0D, 0, 2 | DECOMP_NO_COMPOSE, 4213},	/* compatibility mapping */
-	{0xFD0E, 0, 2 | DECOMP_NO_COMPOSE, 4215},	/* compatibility mapping */
-	{0xFD0F, 0, 2 | DECOMP_NO_COMPOSE, 4217},	/* compatibility mapping */
-	{0xFD10, 0, 2 | DECOMP_NO_COMPOSE, 4219},	/* compatibility mapping */
-	{0xFD11, 0, 2 | DECOMP_NO_COMPOSE, 4221},	/* compatibility mapping */
-	{0xFD12, 0, 2 | DECOMP_NO_COMPOSE, 4223},	/* compatibility mapping */
-	{0xFD13, 0, 2 | DECOMP_NO_COMPOSE, 4225},	/* compatibility mapping */
-	{0xFD14, 0, 2 | DECOMP_NO_COMPOSE, 4227},	/* compatibility mapping */
-	{0xFD15, 0, 2 | DECOMP_NO_COMPOSE, 4229},	/* compatibility mapping */
-	{0xFD16, 0, 2 | DECOMP_NO_COMPOSE, 4231},	/* compatibility mapping */
-	{0xFD17, 0, 2 | DECOMP_NO_COMPOSE, 4233},	/* compatibility mapping */
-	{0xFD18, 0, 2 | DECOMP_NO_COMPOSE, 4235},	/* compatibility mapping */
-	{0xFD19, 0, 2 | DECOMP_NO_COMPOSE, 4237},	/* compatibility mapping */
-	{0xFD1A, 0, 2 | DECOMP_NO_COMPOSE, 4239},	/* compatibility mapping */
-	{0xFD1B, 0, 2 | DECOMP_NO_COMPOSE, 4241},	/* compatibility mapping */
-	{0xFD1C, 0, 2 | DECOMP_NO_COMPOSE, 4243},	/* compatibility mapping */
-	{0xFD1D, 0, 2 | DECOMP_NO_COMPOSE, 4245},	/* compatibility mapping */
-	{0xFD1E, 0, 2 | DECOMP_NO_COMPOSE, 4247},	/* compatibility mapping */
-	{0xFD1F, 0, 2 | DECOMP_NO_COMPOSE, 4249},	/* compatibility mapping */
-	{0xFD20, 0, 2 | DECOMP_NO_COMPOSE, 4251},	/* compatibility mapping */
-	{0xFD21, 0, 2 | DECOMP_NO_COMPOSE, 4253},	/* compatibility mapping */
-	{0xFD22, 0, 2 | DECOMP_NO_COMPOSE, 4255},	/* compatibility mapping */
-	{0xFD23, 0, 2 | DECOMP_NO_COMPOSE, 4257},	/* compatibility mapping */
-	{0xFD24, 0, 2 | DECOMP_NO_COMPOSE, 4259},	/* compatibility mapping */
-	{0xFD25, 0, 2 | DECOMP_NO_COMPOSE, 4261},	/* compatibility mapping */
-	{0xFD26, 0, 2 | DECOMP_NO_COMPOSE, 4263},	/* compatibility mapping */
-	{0xFD27, 0, 2 | DECOMP_NO_COMPOSE, 4265},	/* compatibility mapping */
-	{0xFD28, 0, 2 | DECOMP_NO_COMPOSE, 4267},	/* compatibility mapping */
-	{0xFD29, 0, 2 | DECOMP_NO_COMPOSE, 4269},	/* compatibility mapping */
-	{0xFD2A, 0, 2 | DECOMP_NO_COMPOSE, 4271},	/* compatibility mapping */
-	{0xFD2B, 0, 2 | DECOMP_NO_COMPOSE, 4273},	/* compatibility mapping */
-	{0xFD2C, 0, 2 | DECOMP_NO_COMPOSE, 4275},	/* compatibility mapping */
-	{0xFD2D, 0, 2 | DECOMP_NO_COMPOSE, 4277},	/* compatibility mapping */
-	{0xFD2E, 0, 2 | DECOMP_NO_COMPOSE, 4279},	/* compatibility mapping */
-	{0xFD2F, 0, 2 | DECOMP_NO_COMPOSE, 4281},	/* compatibility mapping */
-	{0xFD30, 0, 2 | DECOMP_NO_COMPOSE, 4283},	/* compatibility mapping */
-	{0xFD31, 0, 2 | DECOMP_NO_COMPOSE, 4285},	/* compatibility mapping */
-	{0xFD32, 0, 2 | DECOMP_NO_COMPOSE, 4287},	/* compatibility mapping */
-	{0xFD33, 0, 2 | DECOMP_NO_COMPOSE, 4289},	/* compatibility mapping */
-	{0xFD34, 0, 2 | DECOMP_NO_COMPOSE, 4291},	/* compatibility mapping */
-	{0xFD35, 0, 2 | DECOMP_NO_COMPOSE, 4293},	/* compatibility mapping */
-	{0xFD36, 0, 2 | DECOMP_NO_COMPOSE, 4295},	/* compatibility mapping */
-	{0xFD37, 0, 2 | DECOMP_NO_COMPOSE, 4297},	/* compatibility mapping */
-	{0xFD38, 0, 2 | DECOMP_NO_COMPOSE, 4299},	/* compatibility mapping */
-	{0xFD39, 0, 2 | DECOMP_NO_COMPOSE, 4301},	/* compatibility mapping */
-	{0xFD3A, 0, 2 | DECOMP_NO_COMPOSE, 4303},	/* compatibility mapping */
-	{0xFD3B, 0, 2 | DECOMP_NO_COMPOSE, 4305},	/* compatibility mapping */
-	{0xFD3C, 0, 2 | DECOMP_NO_COMPOSE, 4307},	/* compatibility mapping */
-	{0xFD3D, 0, 2 | DECOMP_NO_COMPOSE, 4309},	/* compatibility mapping */
-	{0xFD50, 0, 3, 4311},
-	{0xFD51, 0, 3, 4314},
-	{0xFD52, 0, 3, 4317},
-	{0xFD53, 0, 3, 4320},
-	{0xFD54, 0, 3, 4323},
-	{0xFD55, 0, 3, 4326},
-	{0xFD56, 0, 3, 4329},
-	{0xFD57, 0, 3, 4332},
-	{0xFD58, 0, 3, 4335},
-	{0xFD59, 0, 3, 4338},
-	{0xFD5A, 0, 3, 4341},
-	{0xFD5B, 0, 3, 4344},
-	{0xFD5C, 0, 3, 4347},
-	{0xFD5D, 0, 3, 4350},
-	{0xFD5E, 0, 3, 4353},
-	{0xFD5F, 0, 3, 4356},
-	{0xFD60, 0, 3, 4359},
-	{0xFD61, 0, 3, 4362},
-	{0xFD62, 0, 3, 4365},
-	{0xFD63, 0, 3, 4368},
-	{0xFD64, 0, 3, 4371},
-	{0xFD65, 0, 3, 4374},
-	{0xFD66, 0, 3, 4377},
-	{0xFD67, 0, 3, 4380},
-	{0xFD68, 0, 3, 4383},
-	{0xFD69, 0, 3, 4386},
-	{0xFD6A, 0, 3, 4389},
-	{0xFD6B, 0, 3, 4392},
-	{0xFD6C, 0, 3, 4395},
-	{0xFD6D, 0, 3, 4398},
-	{0xFD6E, 0, 3, 4401},
-	{0xFD6F, 0, 3, 4404},
-	{0xFD70, 0, 3, 4407},
-	{0xFD71, 0, 3, 4410},
-	{0xFD72, 0, 3, 4413},
-	{0xFD73, 0, 3, 4416},
-	{0xFD74, 0, 3, 4419},
-	{0xFD75, 0, 3, 4422},
-	{0xFD76, 0, 3, 4425},
-	{0xFD77, 0, 3, 4428},
-	{0xFD78, 0, 3, 4431},
-	{0xFD79, 0, 3, 4434},
-	{0xFD7A, 0, 3, 4437},
-	{0xFD7B, 0, 3, 4440},
-	{0xFD7C, 0, 3, 4443},
-	{0xFD7D, 0, 3, 4446},
-	{0xFD7E, 0, 3, 4449},
-	{0xFD7F, 0, 3, 4452},
-	{0xFD80, 0, 3, 4455},
-	{0xFD81, 0, 3, 4458},
-	{0xFD82, 0, 3, 4461},
-	{0xFD83, 0, 3, 4464},
-	{0xFD84, 0, 3, 4467},
-	{0xFD85, 0, 3, 4470},
-	{0xFD86, 0, 3, 4473},
-	{0xFD87, 0, 3, 4476},
-	{0xFD88, 0, 3, 4479},
-	{0xFD89, 0, 3, 4482},
-	{0xFD8A, 0, 3, 4485},
-	{0xFD8B, 0, 3, 4488},
-	{0xFD8C, 0, 3, 4491},
-	{0xFD8D, 0, 3, 4494},
-	{0xFD8E, 0, 3, 4497},
-	{0xFD8F, 0, 3, 4500},
-	{0xFD92, 0, 3, 4503},
-	{0xFD93, 0, 3, 4506},
-	{0xFD94, 0, 3, 4509},
-	{0xFD95, 0, 3, 4512},
-	{0xFD96, 0, 3, 4515},
-	{0xFD97, 0, 3, 4518},
-	{0xFD98, 0, 3, 4521},
-	{0xFD99, 0, 3, 4524},
-	{0xFD9A, 0, 3, 4527},
-	{0xFD9B, 0, 3, 4530},
-	{0xFD9C, 0, 3, 4533},
-	{0xFD9D, 0, 3, 4536},
-	{0xFD9E, 0, 3, 4539},
-	{0xFD9F, 0, 3, 4542},
-	{0xFDA0, 0, 3, 4545},
-	{0xFDA1, 0, 3, 4548},
-	{0xFDA2, 0, 3, 4551},
-	{0xFDA3, 0, 3, 4554},
-	{0xFDA4, 0, 3, 4557},
-	{0xFDA5, 0, 3, 4560},
-	{0xFDA6, 0, 3, 4563},
-	{0xFDA7, 0, 3, 4566},
-	{0xFDA8, 0, 3, 4569},
-	{0xFDA9, 0, 3, 4572},
-	{0xFDAA, 0, 3, 4575},
-	{0xFDAB, 0, 3, 4578},
-	{0xFDAC, 0, 3, 4581},
-	{0xFDAD, 0, 3, 4584},
-	{0xFDAE, 0, 3, 4587},
-	{0xFDAF, 0, 3, 4590},
-	{0xFDB0, 0, 3, 4593},
-	{0xFDB1, 0, 3, 4596},
-	{0xFDB2, 0, 3, 4599},
-	{0xFDB3, 0, 3, 4602},
-	{0xFDB4, 0, 3, 4605},
-	{0xFDB5, 0, 3, 4608},
-	{0xFDB6, 0, 3, 4611},
-	{0xFDB7, 0, 3, 4614},
-	{0xFDB8, 0, 3, 4617},
-	{0xFDB9, 0, 3, 4620},
-	{0xFDBA, 0, 3, 4623},
-	{0xFDBB, 0, 3, 4626},
-	{0xFDBC, 0, 3, 4629},
-	{0xFDBD, 0, 3, 4632},
-	{0xFDBE, 0, 3, 4635},
-	{0xFDBF, 0, 3, 4638},
-	{0xFDC0, 0, 3, 4641},
-	{0xFDC1, 0, 3, 4644},
-	{0xFDC2, 0, 3, 4647},
-	{0xFDC3, 0, 3, 4650},
-	{0xFDC4, 0, 3, 4653},
-	{0xFDC5, 0, 3, 4656},
-	{0xFDC6, 0, 3, 4659},
-	{0xFDC7, 0, 3, 4662},
-	{0xFDF0, 0, 3, 4665},
-	{0xFDF1, 0, 3, 4668},
-	{0xFDF2, 0, 4, 4671},
-	{0xFDF3, 0, 4, 4675},
-	{0xFDF4, 0, 4, 4679},
-	{0xFDF5, 0, 4, 4683},
-	{0xFDF6, 0, 4, 4687},
-	{0xFDF7, 0, 4, 4691},
-	{0xFDF8, 0, 4, 4695},
-	{0xFDF9, 0, 3, 4699},
-	{0xFDFA, 0, 18, 4702},
-	{0xFDFB, 0, 8, 4720},
-	{0xFDFC, 0, 4, 4728},
-	{0xFE10, 0, 1 | DECOMP_INLINE, 0x002C},
-	{0xFE11, 0, 1 | DECOMP_INLINE, 0x3001},
-	{0xFE12, 0, 1 | DECOMP_INLINE, 0x3002},
-	{0xFE13, 0, 1 | DECOMP_INLINE, 0x003A},
-	{0xFE14, 0, 1 | DECOMP_INLINE, 0x003B},
-	{0xFE15, 0, 1 | DECOMP_INLINE, 0x0021},
-	{0xFE16, 0, 1 | DECOMP_INLINE, 0x003F},
-	{0xFE17, 0, 1 | DECOMP_INLINE, 0x3016},
-	{0xFE18, 0, 1 | DECOMP_INLINE, 0x3017},
-	{0xFE19, 0, 1 | DECOMP_INLINE, 0x2026},
+	{0xFB4F, 0, 2 | DECOMP_COMPAT, 3628},
+	{0xFB50, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0671},
+	{0xFB51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0671},
+	{0xFB52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067B},
+	{0xFB53, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067B},
+	{0xFB54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067B},
+	{0xFB55, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067B},
+	{0xFB56, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067E},
+	{0xFB57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067E},
+	{0xFB58, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067E},
+	{0xFB59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067E},
+	{0xFB5A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0680},
+	{0xFB5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0680},
+	{0xFB5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0680},
+	{0xFB5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0680},
+	{0xFB5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067A},
+	{0xFB5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067A},
+	{0xFB60, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067A},
+	{0xFB61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067A},
+	{0xFB62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067F},
+	{0xFB63, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067F},
+	{0xFB64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067F},
+	{0xFB65, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x067F},
+	{0xFB66, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0679},
+	{0xFB67, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0679},
+	{0xFB68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0679},
+	{0xFB69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0679},
+	{0xFB6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A4},
+	{0xFB6B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A4},
+	{0xFB6C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A4},
+	{0xFB6D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A4},
+	{0xFB6E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A6},
+	{0xFB6F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A6},
+	{0xFB70, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A6},
+	{0xFB71, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A6},
+	{0xFB72, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0684},
+	{0xFB73, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0684},
+	{0xFB74, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0684},
+	{0xFB75, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0684},
+	{0xFB76, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0683},
+	{0xFB77, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0683},
+	{0xFB78, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0683},
+	{0xFB79, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0683},
+	{0xFB7A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0686},
+	{0xFB7B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0686},
+	{0xFB7C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0686},
+	{0xFB7D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0686},
+	{0xFB7E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0687},
+	{0xFB7F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0687},
+	{0xFB80, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0687},
+	{0xFB81, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0687},
+	{0xFB82, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068D},
+	{0xFB83, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068D},
+	{0xFB84, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068C},
+	{0xFB85, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068C},
+	{0xFB86, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068E},
+	{0xFB87, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x068E},
+	{0xFB88, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0688},
+	{0xFB89, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0688},
+	{0xFB8A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0698},
+	{0xFB8B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0698},
+	{0xFB8C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0691},
+	{0xFB8D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0691},
+	{0xFB8E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A9},
+	{0xFB8F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A9},
+	{0xFB90, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A9},
+	{0xFB91, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A9},
+	{0xFB92, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AF},
+	{0xFB93, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AF},
+	{0xFB94, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AF},
+	{0xFB95, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AF},
+	{0xFB96, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B3},
+	{0xFB97, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B3},
+	{0xFB98, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B3},
+	{0xFB99, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B3},
+	{0xFB9A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B1},
+	{0xFB9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B1},
+	{0xFB9C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B1},
+	{0xFB9D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06B1},
+	{0xFB9E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BA},
+	{0xFB9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BA},
+	{0xFBA0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BB},
+	{0xFBA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BB},
+	{0xFBA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BB},
+	{0xFBA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BB},
+	{0xFBA4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C0},
+	{0xFBA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C0},
+	{0xFBA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C1},
+	{0xFBA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C1},
+	{0xFBA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C1},
+	{0xFBA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C1},
+	{0xFBAA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BE},
+	{0xFBAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BE},
+	{0xFBAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BE},
+	{0xFBAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BE},
+	{0xFBAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D2},
+	{0xFBAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D2},
+	{0xFBB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D3},
+	{0xFBB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D3},
+	{0xFBD3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AD},
+	{0xFBD4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AD},
+	{0xFBD5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AD},
+	{0xFBD6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06AD},
+	{0xFBD7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C7},
+	{0xFBD8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C7},
+	{0xFBD9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C6},
+	{0xFBDA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C6},
+	{0xFBDB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C8},
+	{0xFBDC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C8},
+	{0xFBDD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0677},
+	{0xFBDE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CB},
+	{0xFBDF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CB},
+	{0xFBE0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C5},
+	{0xFBE1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C5},
+	{0xFBE2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C9},
+	{0xFBE3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06C9},
+	{0xFBE4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D0},
+	{0xFBE5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D0},
+	{0xFBE6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D0},
+	{0xFBE7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06D0},
+	{0xFBE8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0649},
+	{0xFBE9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0649},
+	{0xFBEA, 0, 2 | DECOMP_COMPAT, 3630},
+	{0xFBEB, 0, 2 | DECOMP_COMPAT, 3632},
+	{0xFBEC, 0, 2 | DECOMP_COMPAT, 3634},
+	{0xFBED, 0, 2 | DECOMP_COMPAT, 3636},
+	{0xFBEE, 0, 2 | DECOMP_COMPAT, 3638},
+	{0xFBEF, 0, 2 | DECOMP_COMPAT, 3640},
+	{0xFBF0, 0, 2 | DECOMP_COMPAT, 3642},
+	{0xFBF1, 0, 2 | DECOMP_COMPAT, 3644},
+	{0xFBF2, 0, 2 | DECOMP_COMPAT, 3646},
+	{0xFBF3, 0, 2 | DECOMP_COMPAT, 3648},
+	{0xFBF4, 0, 2 | DECOMP_COMPAT, 3650},
+	{0xFBF5, 0, 2 | DECOMP_COMPAT, 3652},
+	{0xFBF6, 0, 2 | DECOMP_COMPAT, 3654},
+	{0xFBF7, 0, 2 | DECOMP_COMPAT, 3656},
+	{0xFBF8, 0, 2 | DECOMP_COMPAT, 3658},
+	{0xFBF9, 0, 2 | DECOMP_COMPAT, 3660},
+	{0xFBFA, 0, 2 | DECOMP_COMPAT, 3662},
+	{0xFBFB, 0, 2 | DECOMP_COMPAT, 3664},
+	{0xFBFC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CC},
+	{0xFBFD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CC},
+	{0xFBFE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CC},
+	{0xFBFF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06CC},
+	{0xFC00, 0, 2 | DECOMP_COMPAT, 3666},
+	{0xFC01, 0, 2 | DECOMP_COMPAT, 3668},
+	{0xFC02, 0, 2 | DECOMP_COMPAT, 3670},
+	{0xFC03, 0, 2 | DECOMP_COMPAT, 3672},
+	{0xFC04, 0, 2 | DECOMP_COMPAT, 3674},
+	{0xFC05, 0, 2 | DECOMP_COMPAT, 3676},
+	{0xFC06, 0, 2 | DECOMP_COMPAT, 3678},
+	{0xFC07, 0, 2 | DECOMP_COMPAT, 3680},
+	{0xFC08, 0, 2 | DECOMP_COMPAT, 3682},
+	{0xFC09, 0, 2 | DECOMP_COMPAT, 3684},
+	{0xFC0A, 0, 2 | DECOMP_COMPAT, 3686},
+	{0xFC0B, 0, 2 | DECOMP_COMPAT, 3688},
+	{0xFC0C, 0, 2 | DECOMP_COMPAT, 3690},
+	{0xFC0D, 0, 2 | DECOMP_COMPAT, 3692},
+	{0xFC0E, 0, 2 | DECOMP_COMPAT, 3694},
+	{0xFC0F, 0, 2 | DECOMP_COMPAT, 3696},
+	{0xFC10, 0, 2 | DECOMP_COMPAT, 3698},
+	{0xFC11, 0, 2 | DECOMP_COMPAT, 3700},
+	{0xFC12, 0, 2 | DECOMP_COMPAT, 3702},
+	{0xFC13, 0, 2 | DECOMP_COMPAT, 3704},
+	{0xFC14, 0, 2 | DECOMP_COMPAT, 3706},
+	{0xFC15, 0, 2 | DECOMP_COMPAT, 3708},
+	{0xFC16, 0, 2 | DECOMP_COMPAT, 3710},
+	{0xFC17, 0, 2 | DECOMP_COMPAT, 3712},
+	{0xFC18, 0, 2 | DECOMP_COMPAT, 3714},
+	{0xFC19, 0, 2 | DECOMP_COMPAT, 3716},
+	{0xFC1A, 0, 2 | DECOMP_COMPAT, 3718},
+	{0xFC1B, 0, 2 | DECOMP_COMPAT, 3720},
+	{0xFC1C, 0, 2 | DECOMP_COMPAT, 3722},
+	{0xFC1D, 0, 2 | DECOMP_COMPAT, 3724},
+	{0xFC1E, 0, 2 | DECOMP_COMPAT, 3726},
+	{0xFC1F, 0, 2 | DECOMP_COMPAT, 3728},
+	{0xFC20, 0, 2 | DECOMP_COMPAT, 3730},
+	{0xFC21, 0, 2 | DECOMP_COMPAT, 3732},
+	{0xFC22, 0, 2 | DECOMP_COMPAT, 3734},
+	{0xFC23, 0, 2 | DECOMP_COMPAT, 3736},
+	{0xFC24, 0, 2 | DECOMP_COMPAT, 3738},
+	{0xFC25, 0, 2 | DECOMP_COMPAT, 3740},
+	{0xFC26, 0, 2 | DECOMP_COMPAT, 3742},
+	{0xFC27, 0, 2 | DECOMP_COMPAT, 3744},
+	{0xFC28, 0, 2 | DECOMP_COMPAT, 3746},
+	{0xFC29, 0, 2 | DECOMP_COMPAT, 3748},
+	{0xFC2A, 0, 2 | DECOMP_COMPAT, 3750},
+	{0xFC2B, 0, 2 | DECOMP_COMPAT, 3752},
+	{0xFC2C, 0, 2 | DECOMP_COMPAT, 3754},
+	{0xFC2D, 0, 2 | DECOMP_COMPAT, 3756},
+	{0xFC2E, 0, 2 | DECOMP_COMPAT, 3758},
+	{0xFC2F, 0, 2 | DECOMP_COMPAT, 3760},
+	{0xFC30, 0, 2 | DECOMP_COMPAT, 3762},
+	{0xFC31, 0, 2 | DECOMP_COMPAT, 3764},
+	{0xFC32, 0, 2 | DECOMP_COMPAT, 3766},
+	{0xFC33, 0, 2 | DECOMP_COMPAT, 3768},
+	{0xFC34, 0, 2 | DECOMP_COMPAT, 3770},
+	{0xFC35, 0, 2 | DECOMP_COMPAT, 3772},
+	{0xFC36, 0, 2 | DECOMP_COMPAT, 3774},
+	{0xFC37, 0, 2 | DECOMP_COMPAT, 3776},
+	{0xFC38, 0, 2 | DECOMP_COMPAT, 3778},
+	{0xFC39, 0, 2 | DECOMP_COMPAT, 3780},
+	{0xFC3A, 0, 2 | DECOMP_COMPAT, 3782},
+	{0xFC3B, 0, 2 | DECOMP_COMPAT, 3784},
+	{0xFC3C, 0, 2 | DECOMP_COMPAT, 3786},
+	{0xFC3D, 0, 2 | DECOMP_COMPAT, 3788},
+	{0xFC3E, 0, 2 | DECOMP_COMPAT, 3790},
+	{0xFC3F, 0, 2 | DECOMP_COMPAT, 3792},
+	{0xFC40, 0, 2 | DECOMP_COMPAT, 3794},
+	{0xFC41, 0, 2 | DECOMP_COMPAT, 3796},
+	{0xFC42, 0, 2 | DECOMP_COMPAT, 3798},
+	{0xFC43, 0, 2 | DECOMP_COMPAT, 3800},
+	{0xFC44, 0, 2 | DECOMP_COMPAT, 3802},
+	{0xFC45, 0, 2 | DECOMP_COMPAT, 3804},
+	{0xFC46, 0, 2 | DECOMP_COMPAT, 3806},
+	{0xFC47, 0, 2 | DECOMP_COMPAT, 3808},
+	{0xFC48, 0, 2 | DECOMP_COMPAT, 3810},
+	{0xFC49, 0, 2 | DECOMP_COMPAT, 3812},
+	{0xFC4A, 0, 2 | DECOMP_COMPAT, 3814},
+	{0xFC4B, 0, 2 | DECOMP_COMPAT, 3816},
+	{0xFC4C, 0, 2 | DECOMP_COMPAT, 3818},
+	{0xFC4D, 0, 2 | DECOMP_COMPAT, 3820},
+	{0xFC4E, 0, 2 | DECOMP_COMPAT, 3822},
+	{0xFC4F, 0, 2 | DECOMP_COMPAT, 3824},
+	{0xFC50, 0, 2 | DECOMP_COMPAT, 3826},
+	{0xFC51, 0, 2 | DECOMP_COMPAT, 3828},
+	{0xFC52, 0, 2 | DECOMP_COMPAT, 3830},
+	{0xFC53, 0, 2 | DECOMP_COMPAT, 3832},
+	{0xFC54, 0, 2 | DECOMP_COMPAT, 3834},
+	{0xFC55, 0, 2 | DECOMP_COMPAT, 3836},
+	{0xFC56, 0, 2 | DECOMP_COMPAT, 3838},
+	{0xFC57, 0, 2 | DECOMP_COMPAT, 3840},
+	{0xFC58, 0, 2 | DECOMP_COMPAT, 3842},
+	{0xFC59, 0, 2 | DECOMP_COMPAT, 3844},
+	{0xFC5A, 0, 2 | DECOMP_COMPAT, 3846},
+	{0xFC5B, 0, 2 | DECOMP_COMPAT, 3848},
+	{0xFC5C, 0, 2 | DECOMP_COMPAT, 3850},
+	{0xFC5D, 0, 2 | DECOMP_COMPAT, 3852},
+	{0xFC5E, 0, 3 | DECOMP_COMPAT, 3854},
+	{0xFC5F, 0, 3 | DECOMP_COMPAT, 3857},
+	{0xFC60, 0, 3 | DECOMP_COMPAT, 3860},
+	{0xFC61, 0, 3 | DECOMP_COMPAT, 3863},
+	{0xFC62, 0, 3 | DECOMP_COMPAT, 3866},
+	{0xFC63, 0, 3 | DECOMP_COMPAT, 3869},
+	{0xFC64, 0, 2 | DECOMP_COMPAT, 3872},
+	{0xFC65, 0, 2 | DECOMP_COMPAT, 3874},
+	{0xFC66, 0, 2 | DECOMP_COMPAT, 3876},
+	{0xFC67, 0, 2 | DECOMP_COMPAT, 3878},
+	{0xFC68, 0, 2 | DECOMP_COMPAT, 3880},
+	{0xFC69, 0, 2 | DECOMP_COMPAT, 3882},
+	{0xFC6A, 0, 2 | DECOMP_COMPAT, 3884},
+	{0xFC6B, 0, 2 | DECOMP_COMPAT, 3886},
+	{0xFC6C, 0, 2 | DECOMP_COMPAT, 3888},
+	{0xFC6D, 0, 2 | DECOMP_COMPAT, 3890},
+	{0xFC6E, 0, 2 | DECOMP_COMPAT, 3892},
+	{0xFC6F, 0, 2 | DECOMP_COMPAT, 3894},
+	{0xFC70, 0, 2 | DECOMP_COMPAT, 3896},
+	{0xFC71, 0, 2 | DECOMP_COMPAT, 3898},
+	{0xFC72, 0, 2 | DECOMP_COMPAT, 3900},
+	{0xFC73, 0, 2 | DECOMP_COMPAT, 3902},
+	{0xFC74, 0, 2 | DECOMP_COMPAT, 3904},
+	{0xFC75, 0, 2 | DECOMP_COMPAT, 3906},
+	{0xFC76, 0, 2 | DECOMP_COMPAT, 3908},
+	{0xFC77, 0, 2 | DECOMP_COMPAT, 3910},
+	{0xFC78, 0, 2 | DECOMP_COMPAT, 3912},
+	{0xFC79, 0, 2 | DECOMP_COMPAT, 3914},
+	{0xFC7A, 0, 2 | DECOMP_COMPAT, 3916},
+	{0xFC7B, 0, 2 | DECOMP_COMPAT, 3918},
+	{0xFC7C, 0, 2 | DECOMP_COMPAT, 3920},
+	{0xFC7D, 0, 2 | DECOMP_COMPAT, 3922},
+	{0xFC7E, 0, 2 | DECOMP_COMPAT, 3924},
+	{0xFC7F, 0, 2 | DECOMP_COMPAT, 3926},
+	{0xFC80, 0, 2 | DECOMP_COMPAT, 3928},
+	{0xFC81, 0, 2 | DECOMP_COMPAT, 3930},
+	{0xFC82, 0, 2 | DECOMP_COMPAT, 3932},
+	{0xFC83, 0, 2 | DECOMP_COMPAT, 3934},
+	{0xFC84, 0, 2 | DECOMP_COMPAT, 3936},
+	{0xFC85, 0, 2 | DECOMP_COMPAT, 3938},
+	{0xFC86, 0, 2 | DECOMP_COMPAT, 3940},
+	{0xFC87, 0, 2 | DECOMP_COMPAT, 3942},
+	{0xFC88, 0, 2 | DECOMP_COMPAT, 3944},
+	{0xFC89, 0, 2 | DECOMP_COMPAT, 3946},
+	{0xFC8A, 0, 2 | DECOMP_COMPAT, 3948},
+	{0xFC8B, 0, 2 | DECOMP_COMPAT, 3950},
+	{0xFC8C, 0, 2 | DECOMP_COMPAT, 3952},
+	{0xFC8D, 0, 2 | DECOMP_COMPAT, 3954},
+	{0xFC8E, 0, 2 | DECOMP_COMPAT, 3956},
+	{0xFC8F, 0, 2 | DECOMP_COMPAT, 3958},
+	{0xFC90, 0, 2 | DECOMP_COMPAT, 3960},
+	{0xFC91, 0, 2 | DECOMP_COMPAT, 3962},
+	{0xFC92, 0, 2 | DECOMP_COMPAT, 3964},
+	{0xFC93, 0, 2 | DECOMP_COMPAT, 3966},
+	{0xFC94, 0, 2 | DECOMP_COMPAT, 3968},
+	{0xFC95, 0, 2 | DECOMP_COMPAT, 3970},
+	{0xFC96, 0, 2 | DECOMP_COMPAT, 3972},
+	{0xFC97, 0, 2 | DECOMP_COMPAT, 3974},
+	{0xFC98, 0, 2 | DECOMP_COMPAT, 3976},
+	{0xFC99, 0, 2 | DECOMP_COMPAT, 3978},
+	{0xFC9A, 0, 2 | DECOMP_COMPAT, 3980},
+	{0xFC9B, 0, 2 | DECOMP_COMPAT, 3982},
+	{0xFC9C, 0, 2 | DECOMP_COMPAT, 3984},
+	{0xFC9D, 0, 2 | DECOMP_COMPAT, 3986},
+	{0xFC9E, 0, 2 | DECOMP_COMPAT, 3988},
+	{0xFC9F, 0, 2 | DECOMP_COMPAT, 3990},
+	{0xFCA0, 0, 2 | DECOMP_COMPAT, 3992},
+	{0xFCA1, 0, 2 | DECOMP_COMPAT, 3994},
+	{0xFCA2, 0, 2 | DECOMP_COMPAT, 3996},
+	{0xFCA3, 0, 2 | DECOMP_COMPAT, 3998},
+	{0xFCA4, 0, 2 | DECOMP_COMPAT, 4000},
+	{0xFCA5, 0, 2 | DECOMP_COMPAT, 4002},
+	{0xFCA6, 0, 2 | DECOMP_COMPAT, 4004},
+	{0xFCA7, 0, 2 | DECOMP_COMPAT, 4006},
+	{0xFCA8, 0, 2 | DECOMP_COMPAT, 4008},
+	{0xFCA9, 0, 2 | DECOMP_COMPAT, 4010},
+	{0xFCAA, 0, 2 | DECOMP_COMPAT, 4012},
+	{0xFCAB, 0, 2 | DECOMP_COMPAT, 4014},
+	{0xFCAC, 0, 2 | DECOMP_COMPAT, 4016},
+	{0xFCAD, 0, 2 | DECOMP_COMPAT, 4018},
+	{0xFCAE, 0, 2 | DECOMP_COMPAT, 4020},
+	{0xFCAF, 0, 2 | DECOMP_COMPAT, 4022},
+	{0xFCB0, 0, 2 | DECOMP_COMPAT, 4024},
+	{0xFCB1, 0, 2 | DECOMP_COMPAT, 4026},
+	{0xFCB2, 0, 2 | DECOMP_COMPAT, 4028},
+	{0xFCB3, 0, 2 | DECOMP_COMPAT, 4030},
+	{0xFCB4, 0, 2 | DECOMP_COMPAT, 4032},
+	{0xFCB5, 0, 2 | DECOMP_COMPAT, 4034},
+	{0xFCB6, 0, 2 | DECOMP_COMPAT, 4036},
+	{0xFCB7, 0, 2 | DECOMP_COMPAT, 4038},
+	{0xFCB8, 0, 2 | DECOMP_COMPAT, 4040},
+	{0xFCB9, 0, 2 | DECOMP_COMPAT, 4042},
+	{0xFCBA, 0, 2 | DECOMP_COMPAT, 4044},
+	{0xFCBB, 0, 2 | DECOMP_COMPAT, 4046},
+	{0xFCBC, 0, 2 | DECOMP_COMPAT, 4048},
+	{0xFCBD, 0, 2 | DECOMP_COMPAT, 4050},
+	{0xFCBE, 0, 2 | DECOMP_COMPAT, 4052},
+	{0xFCBF, 0, 2 | DECOMP_COMPAT, 4054},
+	{0xFCC0, 0, 2 | DECOMP_COMPAT, 4056},
+	{0xFCC1, 0, 2 | DECOMP_COMPAT, 4058},
+	{0xFCC2, 0, 2 | DECOMP_COMPAT, 4060},
+	{0xFCC3, 0, 2 | DECOMP_COMPAT, 4062},
+	{0xFCC4, 0, 2 | DECOMP_COMPAT, 4064},
+	{0xFCC5, 0, 2 | DECOMP_COMPAT, 4066},
+	{0xFCC6, 0, 2 | DECOMP_COMPAT, 4068},
+	{0xFCC7, 0, 2 | DECOMP_COMPAT, 4070},
+	{0xFCC8, 0, 2 | DECOMP_COMPAT, 4072},
+	{0xFCC9, 0, 2 | DECOMP_COMPAT, 4074},
+	{0xFCCA, 0, 2 | DECOMP_COMPAT, 4076},
+	{0xFCCB, 0, 2 | DECOMP_COMPAT, 4078},
+	{0xFCCC, 0, 2 | DECOMP_COMPAT, 4080},
+	{0xFCCD, 0, 2 | DECOMP_COMPAT, 4082},
+	{0xFCCE, 0, 2 | DECOMP_COMPAT, 4084},
+	{0xFCCF, 0, 2 | DECOMP_COMPAT, 4086},
+	{0xFCD0, 0, 2 | DECOMP_COMPAT, 4088},
+	{0xFCD1, 0, 2 | DECOMP_COMPAT, 4090},
+	{0xFCD2, 0, 2 | DECOMP_COMPAT, 4092},
+	{0xFCD3, 0, 2 | DECOMP_COMPAT, 4094},
+	{0xFCD4, 0, 2 | DECOMP_COMPAT, 4096},
+	{0xFCD5, 0, 2 | DECOMP_COMPAT, 4098},
+	{0xFCD6, 0, 2 | DECOMP_COMPAT, 4100},
+	{0xFCD7, 0, 2 | DECOMP_COMPAT, 4102},
+	{0xFCD8, 0, 2 | DECOMP_COMPAT, 4104},
+	{0xFCD9, 0, 2 | DECOMP_COMPAT, 4106},
+	{0xFCDA, 0, 2 | DECOMP_COMPAT, 4108},
+	{0xFCDB, 0, 2 | DECOMP_COMPAT, 4110},
+	{0xFCDC, 0, 2 | DECOMP_COMPAT, 4112},
+	{0xFCDD, 0, 2 | DECOMP_COMPAT, 4114},
+	{0xFCDE, 0, 2 | DECOMP_COMPAT, 4116},
+	{0xFCDF, 0, 2 | DECOMP_COMPAT, 4118},
+	{0xFCE0, 0, 2 | DECOMP_COMPAT, 4120},
+	{0xFCE1, 0, 2 | DECOMP_COMPAT, 4122},
+	{0xFCE2, 0, 2 | DECOMP_COMPAT, 4124},
+	{0xFCE3, 0, 2 | DECOMP_COMPAT, 4126},
+	{0xFCE4, 0, 2 | DECOMP_COMPAT, 4128},
+	{0xFCE5, 0, 2 | DECOMP_COMPAT, 4130},
+	{0xFCE6, 0, 2 | DECOMP_COMPAT, 4132},
+	{0xFCE7, 0, 2 | DECOMP_COMPAT, 4134},
+	{0xFCE8, 0, 2 | DECOMP_COMPAT, 4136},
+	{0xFCE9, 0, 2 | DECOMP_COMPAT, 4138},
+	{0xFCEA, 0, 2 | DECOMP_COMPAT, 4140},
+	{0xFCEB, 0, 2 | DECOMP_COMPAT, 4142},
+	{0xFCEC, 0, 2 | DECOMP_COMPAT, 4144},
+	{0xFCED, 0, 2 | DECOMP_COMPAT, 4146},
+	{0xFCEE, 0, 2 | DECOMP_COMPAT, 4148},
+	{0xFCEF, 0, 2 | DECOMP_COMPAT, 4150},
+	{0xFCF0, 0, 2 | DECOMP_COMPAT, 4152},
+	{0xFCF1, 0, 2 | DECOMP_COMPAT, 4154},
+	{0xFCF2, 0, 3 | DECOMP_COMPAT, 4156},
+	{0xFCF3, 0, 3 | DECOMP_COMPAT, 4159},
+	{0xFCF4, 0, 3 | DECOMP_COMPAT, 4162},
+	{0xFCF5, 0, 2 | DECOMP_COMPAT, 4165},
+	{0xFCF6, 0, 2 | DECOMP_COMPAT, 4167},
+	{0xFCF7, 0, 2 | DECOMP_COMPAT, 4169},
+	{0xFCF8, 0, 2 | DECOMP_COMPAT, 4171},
+	{0xFCF9, 0, 2 | DECOMP_COMPAT, 4173},
+	{0xFCFA, 0, 2 | DECOMP_COMPAT, 4175},
+	{0xFCFB, 0, 2 | DECOMP_COMPAT, 4177},
+	{0xFCFC, 0, 2 | DECOMP_COMPAT, 4179},
+	{0xFCFD, 0, 2 | DECOMP_COMPAT, 4181},
+	{0xFCFE, 0, 2 | DECOMP_COMPAT, 4183},
+	{0xFCFF, 0, 2 | DECOMP_COMPAT, 4185},
+	{0xFD00, 0, 2 | DECOMP_COMPAT, 4187},
+	{0xFD01, 0, 2 | DECOMP_COMPAT, 4189},
+	{0xFD02, 0, 2 | DECOMP_COMPAT, 4191},
+	{0xFD03, 0, 2 | DECOMP_COMPAT, 4193},
+	{0xFD04, 0, 2 | DECOMP_COMPAT, 4195},
+	{0xFD05, 0, 2 | DECOMP_COMPAT, 4197},
+	{0xFD06, 0, 2 | DECOMP_COMPAT, 4199},
+	{0xFD07, 0, 2 | DECOMP_COMPAT, 4201},
+	{0xFD08, 0, 2 | DECOMP_COMPAT, 4203},
+	{0xFD09, 0, 2 | DECOMP_COMPAT, 4205},
+	{0xFD0A, 0, 2 | DECOMP_COMPAT, 4207},
+	{0xFD0B, 0, 2 | DECOMP_COMPAT, 4209},
+	{0xFD0C, 0, 2 | DECOMP_COMPAT, 4211},
+	{0xFD0D, 0, 2 | DECOMP_COMPAT, 4213},
+	{0xFD0E, 0, 2 | DECOMP_COMPAT, 4215},
+	{0xFD0F, 0, 2 | DECOMP_COMPAT, 4217},
+	{0xFD10, 0, 2 | DECOMP_COMPAT, 4219},
+	{0xFD11, 0, 2 | DECOMP_COMPAT, 4221},
+	{0xFD12, 0, 2 | DECOMP_COMPAT, 4223},
+	{0xFD13, 0, 2 | DECOMP_COMPAT, 4225},
+	{0xFD14, 0, 2 | DECOMP_COMPAT, 4227},
+	{0xFD15, 0, 2 | DECOMP_COMPAT, 4229},
+	{0xFD16, 0, 2 | DECOMP_COMPAT, 4231},
+	{0xFD17, 0, 2 | DECOMP_COMPAT, 4233},
+	{0xFD18, 0, 2 | DECOMP_COMPAT, 4235},
+	{0xFD19, 0, 2 | DECOMP_COMPAT, 4237},
+	{0xFD1A, 0, 2 | DECOMP_COMPAT, 4239},
+	{0xFD1B, 0, 2 | DECOMP_COMPAT, 4241},
+	{0xFD1C, 0, 2 | DECOMP_COMPAT, 4243},
+	{0xFD1D, 0, 2 | DECOMP_COMPAT, 4245},
+	{0xFD1E, 0, 2 | DECOMP_COMPAT, 4247},
+	{0xFD1F, 0, 2 | DECOMP_COMPAT, 4249},
+	{0xFD20, 0, 2 | DECOMP_COMPAT, 4251},
+	{0xFD21, 0, 2 | DECOMP_COMPAT, 4253},
+	{0xFD22, 0, 2 | DECOMP_COMPAT, 4255},
+	{0xFD23, 0, 2 | DECOMP_COMPAT, 4257},
+	{0xFD24, 0, 2 | DECOMP_COMPAT, 4259},
+	{0xFD25, 0, 2 | DECOMP_COMPAT, 4261},
+	{0xFD26, 0, 2 | DECOMP_COMPAT, 4263},
+	{0xFD27, 0, 2 | DECOMP_COMPAT, 4265},
+	{0xFD28, 0, 2 | DECOMP_COMPAT, 4267},
+	{0xFD29, 0, 2 | DECOMP_COMPAT, 4269},
+	{0xFD2A, 0, 2 | DECOMP_COMPAT, 4271},
+	{0xFD2B, 0, 2 | DECOMP_COMPAT, 4273},
+	{0xFD2C, 0, 2 | DECOMP_COMPAT, 4275},
+	{0xFD2D, 0, 2 | DECOMP_COMPAT, 4277},
+	{0xFD2E, 0, 2 | DECOMP_COMPAT, 4279},
+	{0xFD2F, 0, 2 | DECOMP_COMPAT, 4281},
+	{0xFD30, 0, 2 | DECOMP_COMPAT, 4283},
+	{0xFD31, 0, 2 | DECOMP_COMPAT, 4285},
+	{0xFD32, 0, 2 | DECOMP_COMPAT, 4287},
+	{0xFD33, 0, 2 | DECOMP_COMPAT, 4289},
+	{0xFD34, 0, 2 | DECOMP_COMPAT, 4291},
+	{0xFD35, 0, 2 | DECOMP_COMPAT, 4293},
+	{0xFD36, 0, 2 | DECOMP_COMPAT, 4295},
+	{0xFD37, 0, 2 | DECOMP_COMPAT, 4297},
+	{0xFD38, 0, 2 | DECOMP_COMPAT, 4299},
+	{0xFD39, 0, 2 | DECOMP_COMPAT, 4301},
+	{0xFD3A, 0, 2 | DECOMP_COMPAT, 4303},
+	{0xFD3B, 0, 2 | DECOMP_COMPAT, 4305},
+	{0xFD3C, 0, 2 | DECOMP_COMPAT, 4307},
+	{0xFD3D, 0, 2 | DECOMP_COMPAT, 4309},
+	{0xFD50, 0, 3 | DECOMP_COMPAT, 4311},
+	{0xFD51, 0, 3 | DECOMP_COMPAT, 4314},
+	{0xFD52, 0, 3 | DECOMP_COMPAT, 4317},
+	{0xFD53, 0, 3 | DECOMP_COMPAT, 4320},
+	{0xFD54, 0, 3 | DECOMP_COMPAT, 4323},
+	{0xFD55, 0, 3 | DECOMP_COMPAT, 4326},
+	{0xFD56, 0, 3 | DECOMP_COMPAT, 4329},
+	{0xFD57, 0, 3 | DECOMP_COMPAT, 4332},
+	{0xFD58, 0, 3 | DECOMP_COMPAT, 4335},
+	{0xFD59, 0, 3 | DECOMP_COMPAT, 4338},
+	{0xFD5A, 0, 3 | DECOMP_COMPAT, 4341},
+	{0xFD5B, 0, 3 | DECOMP_COMPAT, 4344},
+	{0xFD5C, 0, 3 | DECOMP_COMPAT, 4347},
+	{0xFD5D, 0, 3 | DECOMP_COMPAT, 4350},
+	{0xFD5E, 0, 3 | DECOMP_COMPAT, 4353},
+	{0xFD5F, 0, 3 | DECOMP_COMPAT, 4356},
+	{0xFD60, 0, 3 | DECOMP_COMPAT, 4359},
+	{0xFD61, 0, 3 | DECOMP_COMPAT, 4362},
+	{0xFD62, 0, 3 | DECOMP_COMPAT, 4365},
+	{0xFD63, 0, 3 | DECOMP_COMPAT, 4368},
+	{0xFD64, 0, 3 | DECOMP_COMPAT, 4371},
+	{0xFD65, 0, 3 | DECOMP_COMPAT, 4374},
+	{0xFD66, 0, 3 | DECOMP_COMPAT, 4377},
+	{0xFD67, 0, 3 | DECOMP_COMPAT, 4380},
+	{0xFD68, 0, 3 | DECOMP_COMPAT, 4383},
+	{0xFD69, 0, 3 | DECOMP_COMPAT, 4386},
+	{0xFD6A, 0, 3 | DECOMP_COMPAT, 4389},
+	{0xFD6B, 0, 3 | DECOMP_COMPAT, 4392},
+	{0xFD6C, 0, 3 | DECOMP_COMPAT, 4395},
+	{0xFD6D, 0, 3 | DECOMP_COMPAT, 4398},
+	{0xFD6E, 0, 3 | DECOMP_COMPAT, 4401},
+	{0xFD6F, 0, 3 | DECOMP_COMPAT, 4404},
+	{0xFD70, 0, 3 | DECOMP_COMPAT, 4407},
+	{0xFD71, 0, 3 | DECOMP_COMPAT, 4410},
+	{0xFD72, 0, 3 | DECOMP_COMPAT, 4413},
+	{0xFD73, 0, 3 | DECOMP_COMPAT, 4416},
+	{0xFD74, 0, 3 | DECOMP_COMPAT, 4419},
+	{0xFD75, 0, 3 | DECOMP_COMPAT, 4422},
+	{0xFD76, 0, 3 | DECOMP_COMPAT, 4425},
+	{0xFD77, 0, 3 | DECOMP_COMPAT, 4428},
+	{0xFD78, 0, 3 | DECOMP_COMPAT, 4431},
+	{0xFD79, 0, 3 | DECOMP_COMPAT, 4434},
+	{0xFD7A, 0, 3 | DECOMP_COMPAT, 4437},
+	{0xFD7B, 0, 3 | DECOMP_COMPAT, 4440},
+	{0xFD7C, 0, 3 | DECOMP_COMPAT, 4443},
+	{0xFD7D, 0, 3 | DECOMP_COMPAT, 4446},
+	{0xFD7E, 0, 3 | DECOMP_COMPAT, 4449},
+	{0xFD7F, 0, 3 | DECOMP_COMPAT, 4452},
+	{0xFD80, 0, 3 | DECOMP_COMPAT, 4455},
+	{0xFD81, 0, 3 | DECOMP_COMPAT, 4458},
+	{0xFD82, 0, 3 | DECOMP_COMPAT, 4461},
+	{0xFD83, 0, 3 | DECOMP_COMPAT, 4464},
+	{0xFD84, 0, 3 | DECOMP_COMPAT, 4467},
+	{0xFD85, 0, 3 | DECOMP_COMPAT, 4470},
+	{0xFD86, 0, 3 | DECOMP_COMPAT, 4473},
+	{0xFD87, 0, 3 | DECOMP_COMPAT, 4476},
+	{0xFD88, 0, 3 | DECOMP_COMPAT, 4479},
+	{0xFD89, 0, 3 | DECOMP_COMPAT, 4482},
+	{0xFD8A, 0, 3 | DECOMP_COMPAT, 4485},
+	{0xFD8B, 0, 3 | DECOMP_COMPAT, 4488},
+	{0xFD8C, 0, 3 | DECOMP_COMPAT, 4491},
+	{0xFD8D, 0, 3 | DECOMP_COMPAT, 4494},
+	{0xFD8E, 0, 3 | DECOMP_COMPAT, 4497},
+	{0xFD8F, 0, 3 | DECOMP_COMPAT, 4500},
+	{0xFD92, 0, 3 | DECOMP_COMPAT, 4503},
+	{0xFD93, 0, 3 | DECOMP_COMPAT, 4506},
+	{0xFD94, 0, 3 | DECOMP_COMPAT, 4509},
+	{0xFD95, 0, 3 | DECOMP_COMPAT, 4512},
+	{0xFD96, 0, 3 | DECOMP_COMPAT, 4515},
+	{0xFD97, 0, 3 | DECOMP_COMPAT, 4518},
+	{0xFD98, 0, 3 | DECOMP_COMPAT, 4521},
+	{0xFD99, 0, 3 | DECOMP_COMPAT, 4524},
+	{0xFD9A, 0, 3 | DECOMP_COMPAT, 4527},
+	{0xFD9B, 0, 3 | DECOMP_COMPAT, 4530},
+	{0xFD9C, 0, 3 | DECOMP_COMPAT, 4533},
+	{0xFD9D, 0, 3 | DECOMP_COMPAT, 4536},
+	{0xFD9E, 0, 3 | DECOMP_COMPAT, 4539},
+	{0xFD9F, 0, 3 | DECOMP_COMPAT, 4542},
+	{0xFDA0, 0, 3 | DECOMP_COMPAT, 4545},
+	{0xFDA1, 0, 3 | DECOMP_COMPAT, 4548},
+	{0xFDA2, 0, 3 | DECOMP_COMPAT, 4551},
+	{0xFDA3, 0, 3 | DECOMP_COMPAT, 4554},
+	{0xFDA4, 0, 3 | DECOMP_COMPAT, 4557},
+	{0xFDA5, 0, 3 | DECOMP_COMPAT, 4560},
+	{0xFDA6, 0, 3 | DECOMP_COMPAT, 4563},
+	{0xFDA7, 0, 3 | DECOMP_COMPAT, 4566},
+	{0xFDA8, 0, 3 | DECOMP_COMPAT, 4569},
+	{0xFDA9, 0, 3 | DECOMP_COMPAT, 4572},
+	{0xFDAA, 0, 3 | DECOMP_COMPAT, 4575},
+	{0xFDAB, 0, 3 | DECOMP_COMPAT, 4578},
+	{0xFDAC, 0, 3 | DECOMP_COMPAT, 4581},
+	{0xFDAD, 0, 3 | DECOMP_COMPAT, 4584},
+	{0xFDAE, 0, 3 | DECOMP_COMPAT, 4587},
+	{0xFDAF, 0, 3 | DECOMP_COMPAT, 4590},
+	{0xFDB0, 0, 3 | DECOMP_COMPAT, 4593},
+	{0xFDB1, 0, 3 | DECOMP_COMPAT, 4596},
+	{0xFDB2, 0, 3 | DECOMP_COMPAT, 4599},
+	{0xFDB3, 0, 3 | DECOMP_COMPAT, 4602},
+	{0xFDB4, 0, 3 | DECOMP_COMPAT, 4605},
+	{0xFDB5, 0, 3 | DECOMP_COMPAT, 4608},
+	{0xFDB6, 0, 3 | DECOMP_COMPAT, 4611},
+	{0xFDB7, 0, 3 | DECOMP_COMPAT, 4614},
+	{0xFDB8, 0, 3 | DECOMP_COMPAT, 4617},
+	{0xFDB9, 0, 3 | DECOMP_COMPAT, 4620},
+	{0xFDBA, 0, 3 | DECOMP_COMPAT, 4623},
+	{0xFDBB, 0, 3 | DECOMP_COMPAT, 4626},
+	{0xFDBC, 0, 3 | DECOMP_COMPAT, 4629},
+	{0xFDBD, 0, 3 | DECOMP_COMPAT, 4632},
+	{0xFDBE, 0, 3 | DECOMP_COMPAT, 4635},
+	{0xFDBF, 0, 3 | DECOMP_COMPAT, 4638},
+	{0xFDC0, 0, 3 | DECOMP_COMPAT, 4641},
+	{0xFDC1, 0, 3 | DECOMP_COMPAT, 4644},
+	{0xFDC2, 0, 3 | DECOMP_COMPAT, 4647},
+	{0xFDC3, 0, 3 | DECOMP_COMPAT, 4650},
+	{0xFDC4, 0, 3 | DECOMP_COMPAT, 4653},
+	{0xFDC5, 0, 3 | DECOMP_COMPAT, 4656},
+	{0xFDC6, 0, 3 | DECOMP_COMPAT, 4659},
+	{0xFDC7, 0, 3 | DECOMP_COMPAT, 4662},
+	{0xFDF0, 0, 3 | DECOMP_COMPAT, 4665},
+	{0xFDF1, 0, 3 | DECOMP_COMPAT, 4668},
+	{0xFDF2, 0, 4 | DECOMP_COMPAT, 4671},
+	{0xFDF3, 0, 4 | DECOMP_COMPAT, 4675},
+	{0xFDF4, 0, 4 | DECOMP_COMPAT, 4679},
+	{0xFDF5, 0, 4 | DECOMP_COMPAT, 4683},
+	{0xFDF6, 0, 4 | DECOMP_COMPAT, 4687},
+	{0xFDF7, 0, 4 | DECOMP_COMPAT, 4691},
+	{0xFDF8, 0, 4 | DECOMP_COMPAT, 4695},
+	{0xFDF9, 0, 3 | DECOMP_COMPAT, 4699},
+	{0xFDFA, 0, 18 | DECOMP_COMPAT, 4702},
+	{0xFDFB, 0, 8 | DECOMP_COMPAT, 4720},
+	{0xFDFC, 0, 4 | DECOMP_COMPAT, 4728},
+	{0xFE10, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002C},
+	{0xFE11, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3001},
+	{0xFE12, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3002},
+	{0xFE13, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003A},
+	{0xFE14, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003B},
+	{0xFE15, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0021},
+	{0xFE16, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003F},
+	{0xFE17, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3016},
+	{0xFE18, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3017},
+	{0xFE19, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2026},
 	{0xFE20, 230, 0, 0},
 	{0xFE21, 230, 0, 0},
 	{0xFE22, 230, 0, 0},
@@ -4166,426 +4168,426 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0xFE2D, 220, 0, 0},
 	{0xFE2E, 230, 0, 0},
 	{0xFE2F, 230, 0, 0},
-	{0xFE30, 0, 1 | DECOMP_INLINE, 0x2025},
-	{0xFE31, 0, 1 | DECOMP_INLINE, 0x2014},
-	{0xFE32, 0, 1 | DECOMP_INLINE, 0x2013},
-	{0xFE33, 0, 1 | DECOMP_INLINE, 0x005F},
-	{0xFE34, 0, 1 | DECOMP_INLINE, 0x005F},
-	{0xFE35, 0, 1 | DECOMP_INLINE, 0x0028},
-	{0xFE36, 0, 1 | DECOMP_INLINE, 0x0029},
-	{0xFE37, 0, 1 | DECOMP_INLINE, 0x007B},
-	{0xFE38, 0, 1 | DECOMP_INLINE, 0x007D},
-	{0xFE39, 0, 1 | DECOMP_INLINE, 0x3014},
-	{0xFE3A, 0, 1 | DECOMP_INLINE, 0x3015},
-	{0xFE3B, 0, 1 | DECOMP_INLINE, 0x3010},
-	{0xFE3C, 0, 1 | DECOMP_INLINE, 0x3011},
-	{0xFE3D, 0, 1 | DECOMP_INLINE, 0x300A},
-	{0xFE3E, 0, 1 | DECOMP_INLINE, 0x300B},
-	{0xFE3F, 0, 1 | DECOMP_INLINE, 0x3008},
-	{0xFE40, 0, 1 | DECOMP_INLINE, 0x3009},
-	{0xFE41, 0, 1 | DECOMP_INLINE, 0x300C},
-	{0xFE42, 0, 1 | DECOMP_INLINE, 0x300D},
-	{0xFE43, 0, 1 | DECOMP_INLINE, 0x300E},
-	{0xFE44, 0, 1 | DECOMP_INLINE, 0x300F},
-	{0xFE47, 0, 1 | DECOMP_INLINE, 0x005B},
-	{0xFE48, 0, 1 | DECOMP_INLINE, 0x005D},
-	{0xFE49, 0, 1 | DECOMP_INLINE, 0x203E},
-	{0xFE4A, 0, 1 | DECOMP_INLINE, 0x203E},
-	{0xFE4B, 0, 1 | DECOMP_INLINE, 0x203E},
-	{0xFE4C, 0, 1 | DECOMP_INLINE, 0x203E},
-	{0xFE4D, 0, 1 | DECOMP_INLINE, 0x005F},
-	{0xFE4E, 0, 1 | DECOMP_INLINE, 0x005F},
-	{0xFE4F, 0, 1 | DECOMP_INLINE, 0x005F},
-	{0xFE50, 0, 1 | DECOMP_INLINE, 0x002C},
-	{0xFE51, 0, 1 | DECOMP_INLINE, 0x3001},
-	{0xFE52, 0, 1 | DECOMP_INLINE, 0x002E},
-	{0xFE54, 0, 1 | DECOMP_INLINE, 0x003B},
-	{0xFE55, 0, 1 | DECOMP_INLINE, 0x003A},
-	{0xFE56, 0, 1 | DECOMP_INLINE, 0x003F},
-	{0xFE57, 0, 1 | DECOMP_INLINE, 0x0021},
-	{0xFE58, 0, 1 | DECOMP_INLINE, 0x2014},
-	{0xFE59, 0, 1 | DECOMP_INLINE, 0x0028},
-	{0xFE5A, 0, 1 | DECOMP_INLINE, 0x0029},
-	{0xFE5B, 0, 1 | DECOMP_INLINE, 0x007B},
-	{0xFE5C, 0, 1 | DECOMP_INLINE, 0x007D},
-	{0xFE5D, 0, 1 | DECOMP_INLINE, 0x3014},
-	{0xFE5E, 0, 1 | DECOMP_INLINE, 0x3015},
-	{0xFE5F, 0, 1 | DECOMP_INLINE, 0x0023},
-	{0xFE60, 0, 1 | DECOMP_INLINE, 0x0026},
-	{0xFE61, 0, 1 | DECOMP_INLINE, 0x002A},
-	{0xFE62, 0, 1 | DECOMP_INLINE, 0x002B},
-	{0xFE63, 0, 1 | DECOMP_INLINE, 0x002D},
-	{0xFE64, 0, 1 | DECOMP_INLINE, 0x003C},
-	{0xFE65, 0, 1 | DECOMP_INLINE, 0x003E},
-	{0xFE66, 0, 1 | DECOMP_INLINE, 0x003D},
-	{0xFE68, 0, 1 | DECOMP_INLINE, 0x005C},
-	{0xFE69, 0, 1 | DECOMP_INLINE, 0x0024},
-	{0xFE6A, 0, 1 | DECOMP_INLINE, 0x0025},
-	{0xFE6B, 0, 1 | DECOMP_INLINE, 0x0040},
-	{0xFE70, 0, 2 | DECOMP_NO_COMPOSE, 4732},	/* compatibility mapping */
-	{0xFE71, 0, 2 | DECOMP_NO_COMPOSE, 4734},	/* compatibility mapping */
-	{0xFE72, 0, 2 | DECOMP_NO_COMPOSE, 4736},	/* compatibility mapping */
-	{0xFE74, 0, 2 | DECOMP_NO_COMPOSE, 4738},	/* compatibility mapping */
-	{0xFE76, 0, 2 | DECOMP_NO_COMPOSE, 4740},	/* compatibility mapping */
-	{0xFE77, 0, 2 | DECOMP_NO_COMPOSE, 4742},	/* compatibility mapping */
-	{0xFE78, 0, 2 | DECOMP_NO_COMPOSE, 4744},	/* compatibility mapping */
-	{0xFE79, 0, 2 | DECOMP_NO_COMPOSE, 4746},	/* compatibility mapping */
-	{0xFE7A, 0, 2 | DECOMP_NO_COMPOSE, 4748},	/* compatibility mapping */
-	{0xFE7B, 0, 2 | DECOMP_NO_COMPOSE, 4750},	/* compatibility mapping */
-	{0xFE7C, 0, 2 | DECOMP_NO_COMPOSE, 4752},	/* compatibility mapping */
-	{0xFE7D, 0, 2 | DECOMP_NO_COMPOSE, 4754},	/* compatibility mapping */
-	{0xFE7E, 0, 2 | DECOMP_NO_COMPOSE, 4756},	/* compatibility mapping */
-	{0xFE7F, 0, 2 | DECOMP_NO_COMPOSE, 4758},	/* compatibility mapping */
-	{0xFE80, 0, 1 | DECOMP_INLINE, 0x0621},
-	{0xFE81, 0, 1 | DECOMP_INLINE, 0x0622},
-	{0xFE82, 0, 1 | DECOMP_INLINE, 0x0622},
-	{0xFE83, 0, 1 | DECOMP_INLINE, 0x0623},
-	{0xFE84, 0, 1 | DECOMP_INLINE, 0x0623},
-	{0xFE85, 0, 1 | DECOMP_INLINE, 0x0624},
-	{0xFE86, 0, 1 | DECOMP_INLINE, 0x0624},
-	{0xFE87, 0, 1 | DECOMP_INLINE, 0x0625},
-	{0xFE88, 0, 1 | DECOMP_INLINE, 0x0625},
-	{0xFE89, 0, 1 | DECOMP_INLINE, 0x0626},
-	{0xFE8A, 0, 1 | DECOMP_INLINE, 0x0626},
-	{0xFE8B, 0, 1 | DECOMP_INLINE, 0x0626},
-	{0xFE8C, 0, 1 | DECOMP_INLINE, 0x0626},
-	{0xFE8D, 0, 1 | DECOMP_INLINE, 0x0627},
-	{0xFE8E, 0, 1 | DECOMP_INLINE, 0x0627},
-	{0xFE8F, 0, 1 | DECOMP_INLINE, 0x0628},
-	{0xFE90, 0, 1 | DECOMP_INLINE, 0x0628},
-	{0xFE91, 0, 1 | DECOMP_INLINE, 0x0628},
-	{0xFE92, 0, 1 | DECOMP_INLINE, 0x0628},
-	{0xFE93, 0, 1 | DECOMP_INLINE, 0x0629},
-	{0xFE94, 0, 1 | DECOMP_INLINE, 0x0629},
-	{0xFE95, 0, 1 | DECOMP_INLINE, 0x062A},
-	{0xFE96, 0, 1 | DECOMP_INLINE, 0x062A},
-	{0xFE97, 0, 1 | DECOMP_INLINE, 0x062A},
-	{0xFE98, 0, 1 | DECOMP_INLINE, 0x062A},
-	{0xFE99, 0, 1 | DECOMP_INLINE, 0x062B},
-	{0xFE9A, 0, 1 | DECOMP_INLINE, 0x062B},
-	{0xFE9B, 0, 1 | DECOMP_INLINE, 0x062B},
-	{0xFE9C, 0, 1 | DECOMP_INLINE, 0x062B},
-	{0xFE9D, 0, 1 | DECOMP_INLINE, 0x062C},
-	{0xFE9E, 0, 1 | DECOMP_INLINE, 0x062C},
-	{0xFE9F, 0, 1 | DECOMP_INLINE, 0x062C},
-	{0xFEA0, 0, 1 | DECOMP_INLINE, 0x062C},
-	{0xFEA1, 0, 1 | DECOMP_INLINE, 0x062D},
-	{0xFEA2, 0, 1 | DECOMP_INLINE, 0x062D},
-	{0xFEA3, 0, 1 | DECOMP_INLINE, 0x062D},
-	{0xFEA4, 0, 1 | DECOMP_INLINE, 0x062D},
-	{0xFEA5, 0, 1 | DECOMP_INLINE, 0x062E},
-	{0xFEA6, 0, 1 | DECOMP_INLINE, 0x062E},
-	{0xFEA7, 0, 1 | DECOMP_INLINE, 0x062E},
-	{0xFEA8, 0, 1 | DECOMP_INLINE, 0x062E},
-	{0xFEA9, 0, 1 | DECOMP_INLINE, 0x062F},
-	{0xFEAA, 0, 1 | DECOMP_INLINE, 0x062F},
-	{0xFEAB, 0, 1 | DECOMP_INLINE, 0x0630},
-	{0xFEAC, 0, 1 | DECOMP_INLINE, 0x0630},
-	{0xFEAD, 0, 1 | DECOMP_INLINE, 0x0631},
-	{0xFEAE, 0, 1 | DECOMP_INLINE, 0x0631},
-	{0xFEAF, 0, 1 | DECOMP_INLINE, 0x0632},
-	{0xFEB0, 0, 1 | DECOMP_INLINE, 0x0632},
-	{0xFEB1, 0, 1 | DECOMP_INLINE, 0x0633},
-	{0xFEB2, 0, 1 | DECOMP_INLINE, 0x0633},
-	{0xFEB3, 0, 1 | DECOMP_INLINE, 0x0633},
-	{0xFEB4, 0, 1 | DECOMP_INLINE, 0x0633},
-	{0xFEB5, 0, 1 | DECOMP_INLINE, 0x0634},
-	{0xFEB6, 0, 1 | DECOMP_INLINE, 0x0634},
-	{0xFEB7, 0, 1 | DECOMP_INLINE, 0x0634},
-	{0xFEB8, 0, 1 | DECOMP_INLINE, 0x0634},
-	{0xFEB9, 0, 1 | DECOMP_INLINE, 0x0635},
-	{0xFEBA, 0, 1 | DECOMP_INLINE, 0x0635},
-	{0xFEBB, 0, 1 | DECOMP_INLINE, 0x0635},
-	{0xFEBC, 0, 1 | DECOMP_INLINE, 0x0635},
-	{0xFEBD, 0, 1 | DECOMP_INLINE, 0x0636},
-	{0xFEBE, 0, 1 | DECOMP_INLINE, 0x0636},
-	{0xFEBF, 0, 1 | DECOMP_INLINE, 0x0636},
-	{0xFEC0, 0, 1 | DECOMP_INLINE, 0x0636},
-	{0xFEC1, 0, 1 | DECOMP_INLINE, 0x0637},
-	{0xFEC2, 0, 1 | DECOMP_INLINE, 0x0637},
-	{0xFEC3, 0, 1 | DECOMP_INLINE, 0x0637},
-	{0xFEC4, 0, 1 | DECOMP_INLINE, 0x0637},
-	{0xFEC5, 0, 1 | DECOMP_INLINE, 0x0638},
-	{0xFEC6, 0, 1 | DECOMP_INLINE, 0x0638},
-	{0xFEC7, 0, 1 | DECOMP_INLINE, 0x0638},
-	{0xFEC8, 0, 1 | DECOMP_INLINE, 0x0638},
-	{0xFEC9, 0, 1 | DECOMP_INLINE, 0x0639},
-	{0xFECA, 0, 1 | DECOMP_INLINE, 0x0639},
-	{0xFECB, 0, 1 | DECOMP_INLINE, 0x0639},
-	{0xFECC, 0, 1 | DECOMP_INLINE, 0x0639},
-	{0xFECD, 0, 1 | DECOMP_INLINE, 0x063A},
-	{0xFECE, 0, 1 | DECOMP_INLINE, 0x063A},
-	{0xFECF, 0, 1 | DECOMP_INLINE, 0x063A},
-	{0xFED0, 0, 1 | DECOMP_INLINE, 0x063A},
-	{0xFED1, 0, 1 | DECOMP_INLINE, 0x0641},
-	{0xFED2, 0, 1 | DECOMP_INLINE, 0x0641},
-	{0xFED3, 0, 1 | DECOMP_INLINE, 0x0641},
-	{0xFED4, 0, 1 | DECOMP_INLINE, 0x0641},
-	{0xFED5, 0, 1 | DECOMP_INLINE, 0x0642},
-	{0xFED6, 0, 1 | DECOMP_INLINE, 0x0642},
-	{0xFED7, 0, 1 | DECOMP_INLINE, 0x0642},
-	{0xFED8, 0, 1 | DECOMP_INLINE, 0x0642},
-	{0xFED9, 0, 1 | DECOMP_INLINE, 0x0643},
-	{0xFEDA, 0, 1 | DECOMP_INLINE, 0x0643},
-	{0xFEDB, 0, 1 | DECOMP_INLINE, 0x0643},
-	{0xFEDC, 0, 1 | DECOMP_INLINE, 0x0643},
-	{0xFEDD, 0, 1 | DECOMP_INLINE, 0x0644},
-	{0xFEDE, 0, 1 | DECOMP_INLINE, 0x0644},
-	{0xFEDF, 0, 1 | DECOMP_INLINE, 0x0644},
-	{0xFEE0, 0, 1 | DECOMP_INLINE, 0x0644},
-	{0xFEE1, 0, 1 | DECOMP_INLINE, 0x0645},
-	{0xFEE2, 0, 1 | DECOMP_INLINE, 0x0645},
-	{0xFEE3, 0, 1 | DECOMP_INLINE, 0x0645},
-	{0xFEE4, 0, 1 | DECOMP_INLINE, 0x0645},
-	{0xFEE5, 0, 1 | DECOMP_INLINE, 0x0646},
-	{0xFEE6, 0, 1 | DECOMP_INLINE, 0x0646},
-	{0xFEE7, 0, 1 | DECOMP_INLINE, 0x0646},
-	{0xFEE8, 0, 1 | DECOMP_INLINE, 0x0646},
-	{0xFEE9, 0, 1 | DECOMP_INLINE, 0x0647},
-	{0xFEEA, 0, 1 | DECOMP_INLINE, 0x0647},
-	{0xFEEB, 0, 1 | DECOMP_INLINE, 0x0647},
-	{0xFEEC, 0, 1 | DECOMP_INLINE, 0x0647},
-	{0xFEED, 0, 1 | DECOMP_INLINE, 0x0648},
-	{0xFEEE, 0, 1 | DECOMP_INLINE, 0x0648},
-	{0xFEEF, 0, 1 | DECOMP_INLINE, 0x0649},
-	{0xFEF0, 0, 1 | DECOMP_INLINE, 0x0649},
-	{0xFEF1, 0, 1 | DECOMP_INLINE, 0x064A},
-	{0xFEF2, 0, 1 | DECOMP_INLINE, 0x064A},
-	{0xFEF3, 0, 1 | DECOMP_INLINE, 0x064A},
-	{0xFEF4, 0, 1 | DECOMP_INLINE, 0x064A},
-	{0xFEF5, 0, 2 | DECOMP_NO_COMPOSE, 4760},	/* compatibility mapping */
-	{0xFEF6, 0, 2 | DECOMP_NO_COMPOSE, 4762},	/* compatibility mapping */
-	{0xFEF7, 0, 2 | DECOMP_NO_COMPOSE, 4764},	/* compatibility mapping */
-	{0xFEF8, 0, 2 | DECOMP_NO_COMPOSE, 4766},	/* compatibility mapping */
-	{0xFEF9, 0, 2 | DECOMP_NO_COMPOSE, 4768},	/* compatibility mapping */
-	{0xFEFA, 0, 2 | DECOMP_NO_COMPOSE, 4770},	/* compatibility mapping */
-	{0xFEFB, 0, 2 | DECOMP_NO_COMPOSE, 4772},	/* compatibility mapping */
-	{0xFEFC, 0, 2 | DECOMP_NO_COMPOSE, 4774},	/* compatibility mapping */
-	{0xFF01, 0, 1 | DECOMP_INLINE, 0x0021},
-	{0xFF02, 0, 1 | DECOMP_INLINE, 0x0022},
-	{0xFF03, 0, 1 | DECOMP_INLINE, 0x0023},
-	{0xFF04, 0, 1 | DECOMP_INLINE, 0x0024},
-	{0xFF05, 0, 1 | DECOMP_INLINE, 0x0025},
-	{0xFF06, 0, 1 | DECOMP_INLINE, 0x0026},
-	{0xFF07, 0, 1 | DECOMP_INLINE, 0x0027},
-	{0xFF08, 0, 1 | DECOMP_INLINE, 0x0028},
-	{0xFF09, 0, 1 | DECOMP_INLINE, 0x0029},
-	{0xFF0A, 0, 1 | DECOMP_INLINE, 0x002A},
-	{0xFF0B, 0, 1 | DECOMP_INLINE, 0x002B},
-	{0xFF0C, 0, 1 | DECOMP_INLINE, 0x002C},
-	{0xFF0D, 0, 1 | DECOMP_INLINE, 0x002D},
-	{0xFF0E, 0, 1 | DECOMP_INLINE, 0x002E},
-	{0xFF0F, 0, 1 | DECOMP_INLINE, 0x002F},
-	{0xFF10, 0, 1 | DECOMP_INLINE, 0x0030},
-	{0xFF11, 0, 1 | DECOMP_INLINE, 0x0031},
-	{0xFF12, 0, 1 | DECOMP_INLINE, 0x0032},
-	{0xFF13, 0, 1 | DECOMP_INLINE, 0x0033},
-	{0xFF14, 0, 1 | DECOMP_INLINE, 0x0034},
-	{0xFF15, 0, 1 | DECOMP_INLINE, 0x0035},
-	{0xFF16, 0, 1 | DECOMP_INLINE, 0x0036},
-	{0xFF17, 0, 1 | DECOMP_INLINE, 0x0037},
-	{0xFF18, 0, 1 | DECOMP_INLINE, 0x0038},
-	{0xFF19, 0, 1 | DECOMP_INLINE, 0x0039},
-	{0xFF1A, 0, 1 | DECOMP_INLINE, 0x003A},
-	{0xFF1B, 0, 1 | DECOMP_INLINE, 0x003B},
-	{0xFF1C, 0, 1 | DECOMP_INLINE, 0x003C},
-	{0xFF1D, 0, 1 | DECOMP_INLINE, 0x003D},
-	{0xFF1E, 0, 1 | DECOMP_INLINE, 0x003E},
-	{0xFF1F, 0, 1 | DECOMP_INLINE, 0x003F},
-	{0xFF20, 0, 1 | DECOMP_INLINE, 0x0040},
-	{0xFF21, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0xFF22, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0xFF23, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0xFF24, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0xFF25, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0xFF26, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0xFF27, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0xFF28, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0xFF29, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0xFF2A, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0xFF2B, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0xFF2C, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0xFF2D, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0xFF2E, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0xFF2F, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0xFF30, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0xFF31, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0xFF32, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0xFF33, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0xFF34, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0xFF35, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0xFF36, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0xFF37, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0xFF38, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0xFF39, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0xFF3A, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0xFF3B, 0, 1 | DECOMP_INLINE, 0x005B},
-	{0xFF3C, 0, 1 | DECOMP_INLINE, 0x005C},
-	{0xFF3D, 0, 1 | DECOMP_INLINE, 0x005D},
-	{0xFF3E, 0, 1 | DECOMP_INLINE, 0x005E},
-	{0xFF3F, 0, 1 | DECOMP_INLINE, 0x005F},
-	{0xFF40, 0, 1 | DECOMP_INLINE, 0x0060},
-	{0xFF41, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0xFF42, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0xFF43, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0xFF44, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0xFF45, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0xFF46, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0xFF47, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0xFF48, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0xFF49, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0xFF4A, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0xFF4B, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0xFF4C, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0xFF4D, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0xFF4E, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0xFF4F, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0xFF50, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0xFF51, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0xFF52, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0xFF53, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0xFF54, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0xFF55, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0xFF56, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0xFF57, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0xFF58, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0xFF59, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0xFF5A, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0xFF5B, 0, 1 | DECOMP_INLINE, 0x007B},
-	{0xFF5C, 0, 1 | DECOMP_INLINE, 0x007C},
-	{0xFF5D, 0, 1 | DECOMP_INLINE, 0x007D},
-	{0xFF5E, 0, 1 | DECOMP_INLINE, 0x007E},
-	{0xFF5F, 0, 1 | DECOMP_INLINE, 0x2985},
-	{0xFF60, 0, 1 | DECOMP_INLINE, 0x2986},
-	{0xFF61, 0, 1 | DECOMP_INLINE, 0x3002},
-	{0xFF62, 0, 1 | DECOMP_INLINE, 0x300C},
-	{0xFF63, 0, 1 | DECOMP_INLINE, 0x300D},
-	{0xFF64, 0, 1 | DECOMP_INLINE, 0x3001},
-	{0xFF65, 0, 1 | DECOMP_INLINE, 0x30FB},
-	{0xFF66, 0, 1 | DECOMP_INLINE, 0x30F2},
-	{0xFF67, 0, 1 | DECOMP_INLINE, 0x30A1},
-	{0xFF68, 0, 1 | DECOMP_INLINE, 0x30A3},
-	{0xFF69, 0, 1 | DECOMP_INLINE, 0x30A5},
-	{0xFF6A, 0, 1 | DECOMP_INLINE, 0x30A7},
-	{0xFF6B, 0, 1 | DECOMP_INLINE, 0x30A9},
-	{0xFF6C, 0, 1 | DECOMP_INLINE, 0x30E3},
-	{0xFF6D, 0, 1 | DECOMP_INLINE, 0x30E5},
-	{0xFF6E, 0, 1 | DECOMP_INLINE, 0x30E7},
-	{0xFF6F, 0, 1 | DECOMP_INLINE, 0x30C3},
-	{0xFF70, 0, 1 | DECOMP_INLINE, 0x30FC},
-	{0xFF71, 0, 1 | DECOMP_INLINE, 0x30A2},
-	{0xFF72, 0, 1 | DECOMP_INLINE, 0x30A4},
-	{0xFF73, 0, 1 | DECOMP_INLINE, 0x30A6},
-	{0xFF74, 0, 1 | DECOMP_INLINE, 0x30A8},
-	{0xFF75, 0, 1 | DECOMP_INLINE, 0x30AA},
-	{0xFF76, 0, 1 | DECOMP_INLINE, 0x30AB},
-	{0xFF77, 0, 1 | DECOMP_INLINE, 0x30AD},
-	{0xFF78, 0, 1 | DECOMP_INLINE, 0x30AF},
-	{0xFF79, 0, 1 | DECOMP_INLINE, 0x30B1},
-	{0xFF7A, 0, 1 | DECOMP_INLINE, 0x30B3},
-	{0xFF7B, 0, 1 | DECOMP_INLINE, 0x30B5},
-	{0xFF7C, 0, 1 | DECOMP_INLINE, 0x30B7},
-	{0xFF7D, 0, 1 | DECOMP_INLINE, 0x30B9},
-	{0xFF7E, 0, 1 | DECOMP_INLINE, 0x30BB},
-	{0xFF7F, 0, 1 | DECOMP_INLINE, 0x30BD},
-	{0xFF80, 0, 1 | DECOMP_INLINE, 0x30BF},
-	{0xFF81, 0, 1 | DECOMP_INLINE, 0x30C1},
-	{0xFF82, 0, 1 | DECOMP_INLINE, 0x30C4},
-	{0xFF83, 0, 1 | DECOMP_INLINE, 0x30C6},
-	{0xFF84, 0, 1 | DECOMP_INLINE, 0x30C8},
-	{0xFF85, 0, 1 | DECOMP_INLINE, 0x30CA},
-	{0xFF86, 0, 1 | DECOMP_INLINE, 0x30CB},
-	{0xFF87, 0, 1 | DECOMP_INLINE, 0x30CC},
-	{0xFF88, 0, 1 | DECOMP_INLINE, 0x30CD},
-	{0xFF89, 0, 1 | DECOMP_INLINE, 0x30CE},
-	{0xFF8A, 0, 1 | DECOMP_INLINE, 0x30CF},
-	{0xFF8B, 0, 1 | DECOMP_INLINE, 0x30D2},
-	{0xFF8C, 0, 1 | DECOMP_INLINE, 0x30D5},
-	{0xFF8D, 0, 1 | DECOMP_INLINE, 0x30D8},
-	{0xFF8E, 0, 1 | DECOMP_INLINE, 0x30DB},
-	{0xFF8F, 0, 1 | DECOMP_INLINE, 0x30DE},
-	{0xFF90, 0, 1 | DECOMP_INLINE, 0x30DF},
-	{0xFF91, 0, 1 | DECOMP_INLINE, 0x30E0},
-	{0xFF92, 0, 1 | DECOMP_INLINE, 0x30E1},
-	{0xFF93, 0, 1 | DECOMP_INLINE, 0x30E2},
-	{0xFF94, 0, 1 | DECOMP_INLINE, 0x30E4},
-	{0xFF95, 0, 1 | DECOMP_INLINE, 0x30E6},
-	{0xFF96, 0, 1 | DECOMP_INLINE, 0x30E8},
-	{0xFF97, 0, 1 | DECOMP_INLINE, 0x30E9},
-	{0xFF98, 0, 1 | DECOMP_INLINE, 0x30EA},
-	{0xFF99, 0, 1 | DECOMP_INLINE, 0x30EB},
-	{0xFF9A, 0, 1 | DECOMP_INLINE, 0x30EC},
-	{0xFF9B, 0, 1 | DECOMP_INLINE, 0x30ED},
-	{0xFF9C, 0, 1 | DECOMP_INLINE, 0x30EF},
-	{0xFF9D, 0, 1 | DECOMP_INLINE, 0x30F3},
-	{0xFF9E, 0, 1 | DECOMP_INLINE, 0x3099},
-	{0xFF9F, 0, 1 | DECOMP_INLINE, 0x309A},
-	{0xFFA0, 0, 1 | DECOMP_INLINE, 0x3164},
-	{0xFFA1, 0, 1 | DECOMP_INLINE, 0x3131},
-	{0xFFA2, 0, 1 | DECOMP_INLINE, 0x3132},
-	{0xFFA3, 0, 1 | DECOMP_INLINE, 0x3133},
-	{0xFFA4, 0, 1 | DECOMP_INLINE, 0x3134},
-	{0xFFA5, 0, 1 | DECOMP_INLINE, 0x3135},
-	{0xFFA6, 0, 1 | DECOMP_INLINE, 0x3136},
-	{0xFFA7, 0, 1 | DECOMP_INLINE, 0x3137},
-	{0xFFA8, 0, 1 | DECOMP_INLINE, 0x3138},
-	{0xFFA9, 0, 1 | DECOMP_INLINE, 0x3139},
-	{0xFFAA, 0, 1 | DECOMP_INLINE, 0x313A},
-	{0xFFAB, 0, 1 | DECOMP_INLINE, 0x313B},
-	{0xFFAC, 0, 1 | DECOMP_INLINE, 0x313C},
-	{0xFFAD, 0, 1 | DECOMP_INLINE, 0x313D},
-	{0xFFAE, 0, 1 | DECOMP_INLINE, 0x313E},
-	{0xFFAF, 0, 1 | DECOMP_INLINE, 0x313F},
-	{0xFFB0, 0, 1 | DECOMP_INLINE, 0x3140},
-	{0xFFB1, 0, 1 | DECOMP_INLINE, 0x3141},
-	{0xFFB2, 0, 1 | DECOMP_INLINE, 0x3142},
-	{0xFFB3, 0, 1 | DECOMP_INLINE, 0x3143},
-	{0xFFB4, 0, 1 | DECOMP_INLINE, 0x3144},
-	{0xFFB5, 0, 1 | DECOMP_INLINE, 0x3145},
-	{0xFFB6, 0, 1 | DECOMP_INLINE, 0x3146},
-	{0xFFB7, 0, 1 | DECOMP_INLINE, 0x3147},
-	{0xFFB8, 0, 1 | DECOMP_INLINE, 0x3148},
-	{0xFFB9, 0, 1 | DECOMP_INLINE, 0x3149},
-	{0xFFBA, 0, 1 | DECOMP_INLINE, 0x314A},
-	{0xFFBB, 0, 1 | DECOMP_INLINE, 0x314B},
-	{0xFFBC, 0, 1 | DECOMP_INLINE, 0x314C},
-	{0xFFBD, 0, 1 | DECOMP_INLINE, 0x314D},
-	{0xFFBE, 0, 1 | DECOMP_INLINE, 0x314E},
-	{0xFFC2, 0, 1 | DECOMP_INLINE, 0x314F},
-	{0xFFC3, 0, 1 | DECOMP_INLINE, 0x3150},
-	{0xFFC4, 0, 1 | DECOMP_INLINE, 0x3151},
-	{0xFFC5, 0, 1 | DECOMP_INLINE, 0x3152},
-	{0xFFC6, 0, 1 | DECOMP_INLINE, 0x3153},
-	{0xFFC7, 0, 1 | DECOMP_INLINE, 0x3154},
-	{0xFFCA, 0, 1 | DECOMP_INLINE, 0x3155},
-	{0xFFCB, 0, 1 | DECOMP_INLINE, 0x3156},
-	{0xFFCC, 0, 1 | DECOMP_INLINE, 0x3157},
-	{0xFFCD, 0, 1 | DECOMP_INLINE, 0x3158},
-	{0xFFCE, 0, 1 | DECOMP_INLINE, 0x3159},
-	{0xFFCF, 0, 1 | DECOMP_INLINE, 0x315A},
-	{0xFFD2, 0, 1 | DECOMP_INLINE, 0x315B},
-	{0xFFD3, 0, 1 | DECOMP_INLINE, 0x315C},
-	{0xFFD4, 0, 1 | DECOMP_INLINE, 0x315D},
-	{0xFFD5, 0, 1 | DECOMP_INLINE, 0x315E},
-	{0xFFD6, 0, 1 | DECOMP_INLINE, 0x315F},
-	{0xFFD7, 0, 1 | DECOMP_INLINE, 0x3160},
-	{0xFFDA, 0, 1 | DECOMP_INLINE, 0x3161},
-	{0xFFDB, 0, 1 | DECOMP_INLINE, 0x3162},
-	{0xFFDC, 0, 1 | DECOMP_INLINE, 0x3163},
-	{0xFFE0, 0, 1 | DECOMP_INLINE, 0x00A2},
-	{0xFFE1, 0, 1 | DECOMP_INLINE, 0x00A3},
-	{0xFFE2, 0, 1 | DECOMP_INLINE, 0x00AC},
-	{0xFFE3, 0, 1 | DECOMP_INLINE, 0x00AF},
-	{0xFFE4, 0, 1 | DECOMP_INLINE, 0x00A6},
-	{0xFFE5, 0, 1 | DECOMP_INLINE, 0x00A5},
-	{0xFFE6, 0, 1 | DECOMP_INLINE, 0x20A9},
-	{0xFFE8, 0, 1 | DECOMP_INLINE, 0x2502},
-	{0xFFE9, 0, 1 | DECOMP_INLINE, 0x2190},
-	{0xFFEA, 0, 1 | DECOMP_INLINE, 0x2191},
-	{0xFFEB, 0, 1 | DECOMP_INLINE, 0x2192},
-	{0xFFEC, 0, 1 | DECOMP_INLINE, 0x2193},
-	{0xFFED, 0, 1 | DECOMP_INLINE, 0x25A0},
-	{0xFFEE, 0, 1 | DECOMP_INLINE, 0x25CB},
+	{0xFE30, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2025},
+	{0xFE31, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2014},
+	{0xFE32, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2013},
+	{0xFE33, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
+	{0xFE34, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
+	{0xFE35, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0028},
+	{0xFE36, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0029},
+	{0xFE37, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007B},
+	{0xFE38, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007D},
+	{0xFE39, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3014},
+	{0xFE3A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3015},
+	{0xFE3B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3010},
+	{0xFE3C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3011},
+	{0xFE3D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300A},
+	{0xFE3E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300B},
+	{0xFE3F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3008},
+	{0xFE40, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3009},
+	{0xFE41, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300C},
+	{0xFE42, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300D},
+	{0xFE43, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300E},
+	{0xFE44, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300F},
+	{0xFE47, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005B},
+	{0xFE48, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005D},
+	{0xFE49, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x203E},
+	{0xFE4A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x203E},
+	{0xFE4B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x203E},
+	{0xFE4C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x203E},
+	{0xFE4D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
+	{0xFE4E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
+	{0xFE4F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
+	{0xFE50, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002C},
+	{0xFE51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3001},
+	{0xFE52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002E},
+	{0xFE54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003B},
+	{0xFE55, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003A},
+	{0xFE56, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003F},
+	{0xFE57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0021},
+	{0xFE58, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2014},
+	{0xFE59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0028},
+	{0xFE5A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0029},
+	{0xFE5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007B},
+	{0xFE5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007D},
+	{0xFE5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3014},
+	{0xFE5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3015},
+	{0xFE5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0023},
+	{0xFE60, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0026},
+	{0xFE61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002A},
+	{0xFE62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002B},
+	{0xFE63, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002D},
+	{0xFE64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003C},
+	{0xFE65, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003E},
+	{0xFE66, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003D},
+	{0xFE68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005C},
+	{0xFE69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0024},
+	{0xFE6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0025},
+	{0xFE6B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0040},
+	{0xFE70, 0, 2 | DECOMP_COMPAT, 4732},
+	{0xFE71, 0, 2 | DECOMP_COMPAT, 4734},
+	{0xFE72, 0, 2 | DECOMP_COMPAT, 4736},
+	{0xFE74, 0, 2 | DECOMP_COMPAT, 4738},
+	{0xFE76, 0, 2 | DECOMP_COMPAT, 4740},
+	{0xFE77, 0, 2 | DECOMP_COMPAT, 4742},
+	{0xFE78, 0, 2 | DECOMP_COMPAT, 4744},
+	{0xFE79, 0, 2 | DECOMP_COMPAT, 4746},
+	{0xFE7A, 0, 2 | DECOMP_COMPAT, 4748},
+	{0xFE7B, 0, 2 | DECOMP_COMPAT, 4750},
+	{0xFE7C, 0, 2 | DECOMP_COMPAT, 4752},
+	{0xFE7D, 0, 2 | DECOMP_COMPAT, 4754},
+	{0xFE7E, 0, 2 | DECOMP_COMPAT, 4756},
+	{0xFE7F, 0, 2 | DECOMP_COMPAT, 4758},
+	{0xFE80, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0621},
+	{0xFE81, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0622},
+	{0xFE82, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0622},
+	{0xFE83, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0623},
+	{0xFE84, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0623},
+	{0xFE85, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0624},
+	{0xFE86, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0624},
+	{0xFE87, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0625},
+	{0xFE88, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0625},
+	{0xFE89, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0626},
+	{0xFE8A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0626},
+	{0xFE8B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0626},
+	{0xFE8C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0626},
+	{0xFE8D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0627},
+	{0xFE8E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0627},
+	{0xFE8F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
+	{0xFE90, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
+	{0xFE91, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
+	{0xFE92, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
+	{0xFE93, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0629},
+	{0xFE94, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0629},
+	{0xFE95, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
+	{0xFE96, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
+	{0xFE97, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
+	{0xFE98, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
+	{0xFE99, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
+	{0xFE9A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
+	{0xFE9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
+	{0xFE9C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
+	{0xFE9D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
+	{0xFE9E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
+	{0xFE9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
+	{0xFEA0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
+	{0xFEA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
+	{0xFEA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
+	{0xFEA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
+	{0xFEA4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
+	{0xFEA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
+	{0xFEA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
+	{0xFEA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
+	{0xFEA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
+	{0xFEA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062F},
+	{0xFEAA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062F},
+	{0xFEAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0630},
+	{0xFEAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0630},
+	{0xFEAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0631},
+	{0xFEAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0631},
+	{0xFEAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0632},
+	{0xFEB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0632},
+	{0xFEB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
+	{0xFEB2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
+	{0xFEB3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
+	{0xFEB4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
+	{0xFEB5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
+	{0xFEB6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
+	{0xFEB7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
+	{0xFEB8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
+	{0xFEB9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
+	{0xFEBA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
+	{0xFEBB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
+	{0xFEBC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
+	{0xFEBD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
+	{0xFEBE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
+	{0xFEBF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
+	{0xFEC0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
+	{0xFEC1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
+	{0xFEC2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
+	{0xFEC3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
+	{0xFEC4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
+	{0xFEC5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
+	{0xFEC6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
+	{0xFEC7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
+	{0xFEC8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
+	{0xFEC9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
+	{0xFECA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
+	{0xFECB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
+	{0xFECC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
+	{0xFECD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
+	{0xFECE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
+	{0xFECF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
+	{0xFED0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
+	{0xFED1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
+	{0xFED2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
+	{0xFED3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
+	{0xFED4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
+	{0xFED5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
+	{0xFED6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
+	{0xFED7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
+	{0xFED8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
+	{0xFED9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
+	{0xFEDA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
+	{0xFEDB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
+	{0xFEDC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
+	{0xFEDD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
+	{0xFEDE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
+	{0xFEDF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
+	{0xFEE0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
+	{0xFEE1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
+	{0xFEE2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
+	{0xFEE3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
+	{0xFEE4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
+	{0xFEE5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
+	{0xFEE6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
+	{0xFEE7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
+	{0xFEE8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
+	{0xFEE9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
+	{0xFEEA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
+	{0xFEEB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
+	{0xFEEC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
+	{0xFEED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0648},
+	{0xFEEE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0648},
+	{0xFEEF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0649},
+	{0xFEF0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0649},
+	{0xFEF1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
+	{0xFEF2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
+	{0xFEF3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
+	{0xFEF4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
+	{0xFEF5, 0, 2 | DECOMP_COMPAT, 4760},
+	{0xFEF6, 0, 2 | DECOMP_COMPAT, 4762},
+	{0xFEF7, 0, 2 | DECOMP_COMPAT, 4764},
+	{0xFEF8, 0, 2 | DECOMP_COMPAT, 4766},
+	{0xFEF9, 0, 2 | DECOMP_COMPAT, 4768},
+	{0xFEFA, 0, 2 | DECOMP_COMPAT, 4770},
+	{0xFEFB, 0, 2 | DECOMP_COMPAT, 4772},
+	{0xFEFC, 0, 2 | DECOMP_COMPAT, 4774},
+	{0xFF01, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0021},
+	{0xFF02, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0022},
+	{0xFF03, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0023},
+	{0xFF04, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0024},
+	{0xFF05, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0025},
+	{0xFF06, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0026},
+	{0xFF07, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0027},
+	{0xFF08, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0028},
+	{0xFF09, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0029},
+	{0xFF0A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002A},
+	{0xFF0B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002B},
+	{0xFF0C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002C},
+	{0xFF0D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002D},
+	{0xFF0E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002E},
+	{0xFF0F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x002F},
+	{0xFF10, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
+	{0xFF11, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
+	{0xFF12, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
+	{0xFF13, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
+	{0xFF14, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
+	{0xFF15, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
+	{0xFF16, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
+	{0xFF17, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
+	{0xFF18, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
+	{0xFF19, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
+	{0xFF1A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003A},
+	{0xFF1B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003B},
+	{0xFF1C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003C},
+	{0xFF1D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003D},
+	{0xFF1E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003E},
+	{0xFF1F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x003F},
+	{0xFF20, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0040},
+	{0xFF21, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0xFF22, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0xFF23, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0xFF24, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0xFF25, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0xFF26, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0xFF27, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0xFF28, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0xFF29, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0xFF2A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0xFF2B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0xFF2C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0xFF2D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0xFF2E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0xFF2F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0xFF30, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0xFF31, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0xFF32, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0xFF33, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0xFF34, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0xFF35, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0xFF36, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0xFF37, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0xFF38, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0xFF39, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0xFF3A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0xFF3B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005B},
+	{0xFF3C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005C},
+	{0xFF3D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005D},
+	{0xFF3E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005E},
+	{0xFF3F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005F},
+	{0xFF40, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0060},
+	{0xFF41, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0xFF42, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0xFF43, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0xFF44, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0xFF45, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0xFF46, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0xFF47, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0xFF48, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0xFF49, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0xFF4A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0xFF4B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0xFF4C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0xFF4D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0xFF4E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0xFF4F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0xFF50, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0xFF51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0xFF52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0xFF53, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0xFF54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0xFF55, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0xFF56, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0xFF57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0xFF58, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0xFF59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0xFF5A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0xFF5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007B},
+	{0xFF5C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007C},
+	{0xFF5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007D},
+	{0xFF5E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007E},
+	{0xFF5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2985},
+	{0xFF60, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2986},
+	{0xFF61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3002},
+	{0xFF62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300C},
+	{0xFF63, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x300D},
+	{0xFF64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3001},
+	{0xFF65, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30FB},
+	{0xFF66, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F2},
+	{0xFF67, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A1},
+	{0xFF68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A3},
+	{0xFF69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A5},
+	{0xFF6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A7},
+	{0xFF6B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A9},
+	{0xFF6C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E3},
+	{0xFF6D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E5},
+	{0xFF6E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E7},
+	{0xFF6F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C3},
+	{0xFF70, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30FC},
+	{0xFF71, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A2},
+	{0xFF72, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A4},
+	{0xFF73, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A6},
+	{0xFF74, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30A8},
+	{0xFF75, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AA},
+	{0xFF76, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AB},
+	{0xFF77, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AD},
+	{0xFF78, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30AF},
+	{0xFF79, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B1},
+	{0xFF7A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B3},
+	{0xFF7B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B5},
+	{0xFF7C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B7},
+	{0xFF7D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B9},
+	{0xFF7E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BB},
+	{0xFF7F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BD},
+	{0xFF80, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30BF},
+	{0xFF81, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C1},
+	{0xFF82, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C4},
+	{0xFF83, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C6},
+	{0xFF84, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C8},
+	{0xFF85, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CA},
+	{0xFF86, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CB},
+	{0xFF87, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CC},
+	{0xFF88, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CD},
+	{0xFF89, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CE},
+	{0xFF8A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30CF},
+	{0xFF8B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D2},
+	{0xFF8C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D5},
+	{0xFF8D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30D8},
+	{0xFF8E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DB},
+	{0xFF8F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DE},
+	{0xFF90, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30DF},
+	{0xFF91, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E0},
+	{0xFF92, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E1},
+	{0xFF93, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E2},
+	{0xFF94, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E4},
+	{0xFF95, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E6},
+	{0xFF96, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E8},
+	{0xFF97, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30E9},
+	{0xFF98, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EA},
+	{0xFF99, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EB},
+	{0xFF9A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EC},
+	{0xFF9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30ED},
+	{0xFF9C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30EF},
+	{0xFF9D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30F3},
+	{0xFF9E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3099},
+	{0xFF9F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x309A},
+	{0xFFA0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3164},
+	{0xFFA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3131},
+	{0xFFA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3132},
+	{0xFFA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3133},
+	{0xFFA4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3134},
+	{0xFFA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3135},
+	{0xFFA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3136},
+	{0xFFA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3137},
+	{0xFFA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3138},
+	{0xFFA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3139},
+	{0xFFAA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313A},
+	{0xFFAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313B},
+	{0xFFAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313C},
+	{0xFFAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313D},
+	{0xFFAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313E},
+	{0xFFAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x313F},
+	{0xFFB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3140},
+	{0xFFB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3141},
+	{0xFFB2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3142},
+	{0xFFB3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3143},
+	{0xFFB4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3144},
+	{0xFFB5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3145},
+	{0xFFB6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3146},
+	{0xFFB7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3147},
+	{0xFFB8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3148},
+	{0xFFB9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3149},
+	{0xFFBA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314A},
+	{0xFFBB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314B},
+	{0xFFBC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314C},
+	{0xFFBD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314D},
+	{0xFFBE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314E},
+	{0xFFC2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x314F},
+	{0xFFC3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3150},
+	{0xFFC4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3151},
+	{0xFFC5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3152},
+	{0xFFC6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3153},
+	{0xFFC7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3154},
+	{0xFFCA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3155},
+	{0xFFCB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3156},
+	{0xFFCC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3157},
+	{0xFFCD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3158},
+	{0xFFCE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3159},
+	{0xFFCF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315A},
+	{0xFFD2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315B},
+	{0xFFD3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315C},
+	{0xFFD4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315D},
+	{0xFFD5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315E},
+	{0xFFD6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x315F},
+	{0xFFD7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3160},
+	{0xFFDA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3161},
+	{0xFFDB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3162},
+	{0xFFDC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x3163},
+	{0xFFE0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A2},
+	{0xFFE1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A3},
+	{0xFFE2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00AC},
+	{0xFFE3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00AF},
+	{0xFFE4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A6},
+	{0xFFE5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x00A5},
+	{0xFFE6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x20A9},
+	{0xFFE8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2502},
+	{0xFFE9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2190},
+	{0xFFEA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2191},
+	{0xFFEB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2192},
+	{0xFFEC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2193},
+	{0xFFED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x25A0},
+	{0xFFEE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x25CB},
 	{0x101FD, 220, 0, 0},
 	{0x102E0, 220, 0, 0},
 	{0x10376, 230, 0, 0},
@@ -4740,1002 +4742,1002 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x1D242, 230, 0, 0},
 	{0x1D243, 230, 0, 0},
 	{0x1D244, 230, 0, 0},
-	{0x1D400, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D401, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D402, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1D403, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D404, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D405, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D406, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D407, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1D408, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D409, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D40A, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D40B, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D40C, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D40D, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D40E, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D40F, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D410, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D411, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1D412, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D413, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D414, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D415, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D416, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D417, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D418, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D419, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1D41A, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D41B, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D41C, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D41D, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D41E, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D41F, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D420, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D421, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D422, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D423, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D424, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D425, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D426, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D427, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D428, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D429, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D42A, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D42B, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D42C, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D42D, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D42E, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D42F, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D430, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D431, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D432, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D433, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D434, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D435, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D436, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1D437, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D438, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D439, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D43A, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D43B, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1D43C, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D43D, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D43E, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D43F, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D440, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D441, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D442, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D443, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D444, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D445, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1D446, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D447, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D448, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D449, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D44A, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D44B, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D44C, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D44D, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1D44E, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D44F, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D450, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D451, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D452, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D453, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D454, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D456, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D457, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D458, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D459, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D45A, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D45B, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D45C, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D45D, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D45E, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D45F, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D460, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D461, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D462, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D463, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D464, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D465, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D466, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D467, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D468, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D469, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D46A, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1D46B, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D46C, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D46D, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D46E, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D46F, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1D470, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D471, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D472, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D473, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D474, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D475, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D476, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D477, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D478, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D479, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1D47A, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D47B, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D47C, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D47D, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D47E, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D47F, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D480, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D481, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1D482, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D483, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D484, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D485, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D486, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D487, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D488, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D489, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D48A, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D48B, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D48C, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D48D, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D48E, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D48F, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D490, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D491, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D492, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D493, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D494, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D495, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D496, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D497, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D498, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D499, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D49A, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D49B, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D49C, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D49E, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1D49F, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D4A2, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D4A5, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D4A6, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D4A9, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D4AA, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D4AB, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D4AC, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D4AE, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D4AF, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D4B0, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D4B1, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D4B2, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D4B3, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D4B4, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D4B5, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1D4B6, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D4B7, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D4B8, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D4B9, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D4BB, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D4BD, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D4BE, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D4BF, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D4C0, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D4C1, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D4C2, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D4C3, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D4C5, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D4C6, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D4C7, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D4C8, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D4C9, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D4CA, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D4CB, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D4CC, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D4CD, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D4CE, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D4CF, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D4D0, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D4D1, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D4D2, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1D4D3, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D4D4, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D4D5, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D4D6, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D4D7, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1D4D8, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D4D9, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D4DA, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D4DB, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D4DC, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D4DD, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D4DE, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D4DF, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D4E0, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D4E1, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1D4E2, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D4E3, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D4E4, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D4E5, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D4E6, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D4E7, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D4E8, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D4E9, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1D4EA, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D4EB, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D4EC, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D4ED, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D4EE, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D4EF, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D4F0, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D4F1, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D4F2, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D4F3, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D4F4, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D4F5, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D4F6, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D4F7, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D4F8, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D4F9, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D4FA, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D4FB, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D4FC, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D4FD, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D4FE, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D4FF, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D500, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D501, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D502, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D503, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D504, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D505, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D507, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D508, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D509, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D50A, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D50D, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D50E, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D50F, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D510, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D511, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D512, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D513, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D514, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D516, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D517, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D518, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D519, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D51A, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D51B, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D51C, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D51E, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D51F, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D520, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D521, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D522, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D523, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D524, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D525, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D526, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D527, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D528, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D529, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D52A, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D52B, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D52C, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D52D, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D52E, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D52F, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D530, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D531, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D532, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D533, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D534, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D535, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D536, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D537, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D538, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D539, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D53B, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D53C, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D53D, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D53E, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D540, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D541, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D542, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D543, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D544, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D546, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D54A, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D54B, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D54C, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D54D, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D54E, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D54F, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D550, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D552, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D553, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D554, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D555, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D556, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D557, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D558, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D559, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D55A, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D55B, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D55C, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D55D, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D55E, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D55F, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D560, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D561, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D562, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D563, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D564, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D565, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D566, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D567, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D568, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D569, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D56A, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D56B, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D56C, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D56D, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D56E, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1D56F, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D570, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D571, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D572, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D573, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1D574, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D575, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D576, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D577, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D578, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D579, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D57A, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D57B, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D57C, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D57D, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1D57E, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D57F, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D580, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D581, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D582, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D583, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D584, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D585, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1D586, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D587, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D588, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D589, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D58A, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D58B, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D58C, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D58D, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D58E, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D58F, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D590, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D591, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D592, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D593, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D594, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D595, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D596, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D597, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D598, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D599, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D59A, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D59B, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D59C, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D59D, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D59E, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D59F, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D5A0, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D5A1, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D5A2, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1D5A3, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D5A4, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D5A5, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D5A6, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D5A7, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1D5A8, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D5A9, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D5AA, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D5AB, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D5AC, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D5AD, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D5AE, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D5AF, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D5B0, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D5B1, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1D5B2, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D5B3, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D5B4, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D5B5, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D5B6, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D5B7, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D5B8, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D5B9, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1D5BA, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D5BB, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D5BC, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D5BD, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D5BE, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D5BF, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D5C0, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D5C1, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D5C2, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D5C3, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D5C4, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D5C5, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D5C6, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D5C7, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D5C8, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D5C9, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D5CA, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D5CB, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D5CC, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D5CD, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D5CE, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D5CF, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D5D0, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D5D1, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D5D2, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D5D3, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D5D4, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D5D5, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D5D6, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1D5D7, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D5D8, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D5D9, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D5DA, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D5DB, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1D5DC, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D5DD, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D5DE, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D5DF, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D5E0, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D5E1, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D5E2, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D5E3, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D5E4, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D5E5, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1D5E6, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D5E7, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D5E8, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D5E9, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D5EA, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D5EB, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D5EC, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D5ED, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1D5EE, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D5EF, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D5F0, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D5F1, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D5F2, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D5F3, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D5F4, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D5F5, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D5F6, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D5F7, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D5F8, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D5F9, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D5FA, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D5FB, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D5FC, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D5FD, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D5FE, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D5FF, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D600, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D601, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D602, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D603, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D604, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D605, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D606, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D607, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D608, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D609, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D60A, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1D60B, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D60C, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D60D, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D60E, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D60F, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1D610, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D611, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D612, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D613, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D614, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D615, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D616, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D617, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D618, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D619, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1D61A, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D61B, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D61C, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D61D, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D61E, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D61F, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D620, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D621, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1D622, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D623, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D624, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D625, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D626, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D627, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D628, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D629, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D62A, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D62B, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D62C, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D62D, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D62E, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D62F, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D630, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D631, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D632, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D633, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D634, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D635, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D636, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D637, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D638, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D639, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D63A, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D63B, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D63C, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D63D, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D63E, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1D63F, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D640, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D641, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D642, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D643, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1D644, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D645, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D646, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D647, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D648, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D649, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D64A, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D64B, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D64C, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D64D, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1D64E, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D64F, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D650, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D651, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D652, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D653, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D654, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D655, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1D656, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D657, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D658, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D659, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D65A, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D65B, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D65C, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D65D, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D65E, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D65F, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D660, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D661, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D662, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D663, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D664, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D665, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D666, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D667, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D668, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D669, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D66A, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D66B, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D66C, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D66D, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D66E, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D66F, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D670, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1D671, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1D672, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1D673, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1D674, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1D675, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1D676, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1D677, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1D678, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1D679, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1D67A, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1D67B, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1D67C, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1D67D, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1D67E, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1D67F, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1D680, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1D681, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1D682, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1D683, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1D684, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1D685, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1D686, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1D687, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1D688, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1D689, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1D68A, 0, 1 | DECOMP_INLINE, 0x0061},
-	{0x1D68B, 0, 1 | DECOMP_INLINE, 0x0062},
-	{0x1D68C, 0, 1 | DECOMP_INLINE, 0x0063},
-	{0x1D68D, 0, 1 | DECOMP_INLINE, 0x0064},
-	{0x1D68E, 0, 1 | DECOMP_INLINE, 0x0065},
-	{0x1D68F, 0, 1 | DECOMP_INLINE, 0x0066},
-	{0x1D690, 0, 1 | DECOMP_INLINE, 0x0067},
-	{0x1D691, 0, 1 | DECOMP_INLINE, 0x0068},
-	{0x1D692, 0, 1 | DECOMP_INLINE, 0x0069},
-	{0x1D693, 0, 1 | DECOMP_INLINE, 0x006A},
-	{0x1D694, 0, 1 | DECOMP_INLINE, 0x006B},
-	{0x1D695, 0, 1 | DECOMP_INLINE, 0x006C},
-	{0x1D696, 0, 1 | DECOMP_INLINE, 0x006D},
-	{0x1D697, 0, 1 | DECOMP_INLINE, 0x006E},
-	{0x1D698, 0, 1 | DECOMP_INLINE, 0x006F},
-	{0x1D699, 0, 1 | DECOMP_INLINE, 0x0070},
-	{0x1D69A, 0, 1 | DECOMP_INLINE, 0x0071},
-	{0x1D69B, 0, 1 | DECOMP_INLINE, 0x0072},
-	{0x1D69C, 0, 1 | DECOMP_INLINE, 0x0073},
-	{0x1D69D, 0, 1 | DECOMP_INLINE, 0x0074},
-	{0x1D69E, 0, 1 | DECOMP_INLINE, 0x0075},
-	{0x1D69F, 0, 1 | DECOMP_INLINE, 0x0076},
-	{0x1D6A0, 0, 1 | DECOMP_INLINE, 0x0077},
-	{0x1D6A1, 0, 1 | DECOMP_INLINE, 0x0078},
-	{0x1D6A2, 0, 1 | DECOMP_INLINE, 0x0079},
-	{0x1D6A3, 0, 1 | DECOMP_INLINE, 0x007A},
-	{0x1D6A4, 0, 1 | DECOMP_INLINE, 0x0131},
-	{0x1D6A5, 0, 1 | DECOMP_INLINE, 0x0237},
-	{0x1D6A8, 0, 1 | DECOMP_INLINE, 0x0391},
-	{0x1D6A9, 0, 1 | DECOMP_INLINE, 0x0392},
-	{0x1D6AA, 0, 1 | DECOMP_INLINE, 0x0393},
-	{0x1D6AB, 0, 1 | DECOMP_INLINE, 0x0394},
-	{0x1D6AC, 0, 1 | DECOMP_INLINE, 0x0395},
-	{0x1D6AD, 0, 1 | DECOMP_INLINE, 0x0396},
-	{0x1D6AE, 0, 1 | DECOMP_INLINE, 0x0397},
-	{0x1D6AF, 0, 1 | DECOMP_INLINE, 0x0398},
-	{0x1D6B0, 0, 1 | DECOMP_INLINE, 0x0399},
-	{0x1D6B1, 0, 1 | DECOMP_INLINE, 0x039A},
-	{0x1D6B2, 0, 1 | DECOMP_INLINE, 0x039B},
-	{0x1D6B3, 0, 1 | DECOMP_INLINE, 0x039C},
-	{0x1D6B4, 0, 1 | DECOMP_INLINE, 0x039D},
-	{0x1D6B5, 0, 1 | DECOMP_INLINE, 0x039E},
-	{0x1D6B6, 0, 1 | DECOMP_INLINE, 0x039F},
-	{0x1D6B7, 0, 1 | DECOMP_INLINE, 0x03A0},
-	{0x1D6B8, 0, 1 | DECOMP_INLINE, 0x03A1},
-	{0x1D6B9, 0, 1 | DECOMP_INLINE, 0x03F4},
-	{0x1D6BA, 0, 1 | DECOMP_INLINE, 0x03A3},
-	{0x1D6BB, 0, 1 | DECOMP_INLINE, 0x03A4},
-	{0x1D6BC, 0, 1 | DECOMP_INLINE, 0x03A5},
-	{0x1D6BD, 0, 1 | DECOMP_INLINE, 0x03A6},
-	{0x1D6BE, 0, 1 | DECOMP_INLINE, 0x03A7},
-	{0x1D6BF, 0, 1 | DECOMP_INLINE, 0x03A8},
-	{0x1D6C0, 0, 1 | DECOMP_INLINE, 0x03A9},
-	{0x1D6C1, 0, 1 | DECOMP_INLINE, 0x2207},
-	{0x1D6C2, 0, 1 | DECOMP_INLINE, 0x03B1},
-	{0x1D6C3, 0, 1 | DECOMP_INLINE, 0x03B2},
-	{0x1D6C4, 0, 1 | DECOMP_INLINE, 0x03B3},
-	{0x1D6C5, 0, 1 | DECOMP_INLINE, 0x03B4},
-	{0x1D6C6, 0, 1 | DECOMP_INLINE, 0x03B5},
-	{0x1D6C7, 0, 1 | DECOMP_INLINE, 0x03B6},
-	{0x1D6C8, 0, 1 | DECOMP_INLINE, 0x03B7},
-	{0x1D6C9, 0, 1 | DECOMP_INLINE, 0x03B8},
-	{0x1D6CA, 0, 1 | DECOMP_INLINE, 0x03B9},
-	{0x1D6CB, 0, 1 | DECOMP_INLINE, 0x03BA},
-	{0x1D6CC, 0, 1 | DECOMP_INLINE, 0x03BB},
-	{0x1D6CD, 0, 1 | DECOMP_INLINE, 0x03BC},
-	{0x1D6CE, 0, 1 | DECOMP_INLINE, 0x03BD},
-	{0x1D6CF, 0, 1 | DECOMP_INLINE, 0x03BE},
-	{0x1D6D0, 0, 1 | DECOMP_INLINE, 0x03BF},
-	{0x1D6D1, 0, 1 | DECOMP_INLINE, 0x03C0},
-	{0x1D6D2, 0, 1 | DECOMP_INLINE, 0x03C1},
-	{0x1D6D3, 0, 1 | DECOMP_INLINE, 0x03C2},
-	{0x1D6D4, 0, 1 | DECOMP_INLINE, 0x03C3},
-	{0x1D6D5, 0, 1 | DECOMP_INLINE, 0x03C4},
-	{0x1D6D6, 0, 1 | DECOMP_INLINE, 0x03C5},
-	{0x1D6D7, 0, 1 | DECOMP_INLINE, 0x03C6},
-	{0x1D6D8, 0, 1 | DECOMP_INLINE, 0x03C7},
-	{0x1D6D9, 0, 1 | DECOMP_INLINE, 0x03C8},
-	{0x1D6DA, 0, 1 | DECOMP_INLINE, 0x03C9},
-	{0x1D6DB, 0, 1 | DECOMP_INLINE, 0x2202},
-	{0x1D6DC, 0, 1 | DECOMP_INLINE, 0x03F5},
-	{0x1D6DD, 0, 1 | DECOMP_INLINE, 0x03D1},
-	{0x1D6DE, 0, 1 | DECOMP_INLINE, 0x03F0},
-	{0x1D6DF, 0, 1 | DECOMP_INLINE, 0x03D5},
-	{0x1D6E0, 0, 1 | DECOMP_INLINE, 0x03F1},
-	{0x1D6E1, 0, 1 | DECOMP_INLINE, 0x03D6},
-	{0x1D6E2, 0, 1 | DECOMP_INLINE, 0x0391},
-	{0x1D6E3, 0, 1 | DECOMP_INLINE, 0x0392},
-	{0x1D6E4, 0, 1 | DECOMP_INLINE, 0x0393},
-	{0x1D6E5, 0, 1 | DECOMP_INLINE, 0x0394},
-	{0x1D6E6, 0, 1 | DECOMP_INLINE, 0x0395},
-	{0x1D6E7, 0, 1 | DECOMP_INLINE, 0x0396},
-	{0x1D6E8, 0, 1 | DECOMP_INLINE, 0x0397},
-	{0x1D6E9, 0, 1 | DECOMP_INLINE, 0x0398},
-	{0x1D6EA, 0, 1 | DECOMP_INLINE, 0x0399},
-	{0x1D6EB, 0, 1 | DECOMP_INLINE, 0x039A},
-	{0x1D6EC, 0, 1 | DECOMP_INLINE, 0x039B},
-	{0x1D6ED, 0, 1 | DECOMP_INLINE, 0x039C},
-	{0x1D6EE, 0, 1 | DECOMP_INLINE, 0x039D},
-	{0x1D6EF, 0, 1 | DECOMP_INLINE, 0x039E},
-	{0x1D6F0, 0, 1 | DECOMP_INLINE, 0x039F},
-	{0x1D6F1, 0, 1 | DECOMP_INLINE, 0x03A0},
-	{0x1D6F2, 0, 1 | DECOMP_INLINE, 0x03A1},
-	{0x1D6F3, 0, 1 | DECOMP_INLINE, 0x03F4},
-	{0x1D6F4, 0, 1 | DECOMP_INLINE, 0x03A3},
-	{0x1D6F5, 0, 1 | DECOMP_INLINE, 0x03A4},
-	{0x1D6F6, 0, 1 | DECOMP_INLINE, 0x03A5},
-	{0x1D6F7, 0, 1 | DECOMP_INLINE, 0x03A6},
-	{0x1D6F8, 0, 1 | DECOMP_INLINE, 0x03A7},
-	{0x1D6F9, 0, 1 | DECOMP_INLINE, 0x03A8},
-	{0x1D6FA, 0, 1 | DECOMP_INLINE, 0x03A9},
-	{0x1D6FB, 0, 1 | DECOMP_INLINE, 0x2207},
-	{0x1D6FC, 0, 1 | DECOMP_INLINE, 0x03B1},
-	{0x1D6FD, 0, 1 | DECOMP_INLINE, 0x03B2},
-	{0x1D6FE, 0, 1 | DECOMP_INLINE, 0x03B3},
-	{0x1D6FF, 0, 1 | DECOMP_INLINE, 0x03B4},
-	{0x1D700, 0, 1 | DECOMP_INLINE, 0x03B5},
-	{0x1D701, 0, 1 | DECOMP_INLINE, 0x03B6},
-	{0x1D702, 0, 1 | DECOMP_INLINE, 0x03B7},
-	{0x1D703, 0, 1 | DECOMP_INLINE, 0x03B8},
-	{0x1D704, 0, 1 | DECOMP_INLINE, 0x03B9},
-	{0x1D705, 0, 1 | DECOMP_INLINE, 0x03BA},
-	{0x1D706, 0, 1 | DECOMP_INLINE, 0x03BB},
-	{0x1D707, 0, 1 | DECOMP_INLINE, 0x03BC},
-	{0x1D708, 0, 1 | DECOMP_INLINE, 0x03BD},
-	{0x1D709, 0, 1 | DECOMP_INLINE, 0x03BE},
-	{0x1D70A, 0, 1 | DECOMP_INLINE, 0x03BF},
-	{0x1D70B, 0, 1 | DECOMP_INLINE, 0x03C0},
-	{0x1D70C, 0, 1 | DECOMP_INLINE, 0x03C1},
-	{0x1D70D, 0, 1 | DECOMP_INLINE, 0x03C2},
-	{0x1D70E, 0, 1 | DECOMP_INLINE, 0x03C3},
-	{0x1D70F, 0, 1 | DECOMP_INLINE, 0x03C4},
-	{0x1D710, 0, 1 | DECOMP_INLINE, 0x03C5},
-	{0x1D711, 0, 1 | DECOMP_INLINE, 0x03C6},
-	{0x1D712, 0, 1 | DECOMP_INLINE, 0x03C7},
-	{0x1D713, 0, 1 | DECOMP_INLINE, 0x03C8},
-	{0x1D714, 0, 1 | DECOMP_INLINE, 0x03C9},
-	{0x1D715, 0, 1 | DECOMP_INLINE, 0x2202},
-	{0x1D716, 0, 1 | DECOMP_INLINE, 0x03F5},
-	{0x1D717, 0, 1 | DECOMP_INLINE, 0x03D1},
-	{0x1D718, 0, 1 | DECOMP_INLINE, 0x03F0},
-	{0x1D719, 0, 1 | DECOMP_INLINE, 0x03D5},
-	{0x1D71A, 0, 1 | DECOMP_INLINE, 0x03F1},
-	{0x1D71B, 0, 1 | DECOMP_INLINE, 0x03D6},
-	{0x1D71C, 0, 1 | DECOMP_INLINE, 0x0391},
-	{0x1D71D, 0, 1 | DECOMP_INLINE, 0x0392},
-	{0x1D71E, 0, 1 | DECOMP_INLINE, 0x0393},
-	{0x1D71F, 0, 1 | DECOMP_INLINE, 0x0394},
-	{0x1D720, 0, 1 | DECOMP_INLINE, 0x0395},
-	{0x1D721, 0, 1 | DECOMP_INLINE, 0x0396},
-	{0x1D722, 0, 1 | DECOMP_INLINE, 0x0397},
-	{0x1D723, 0, 1 | DECOMP_INLINE, 0x0398},
-	{0x1D724, 0, 1 | DECOMP_INLINE, 0x0399},
-	{0x1D725, 0, 1 | DECOMP_INLINE, 0x039A},
-	{0x1D726, 0, 1 | DECOMP_INLINE, 0x039B},
-	{0x1D727, 0, 1 | DECOMP_INLINE, 0x039C},
-	{0x1D728, 0, 1 | DECOMP_INLINE, 0x039D},
-	{0x1D729, 0, 1 | DECOMP_INLINE, 0x039E},
-	{0x1D72A, 0, 1 | DECOMP_INLINE, 0x039F},
-	{0x1D72B, 0, 1 | DECOMP_INLINE, 0x03A0},
-	{0x1D72C, 0, 1 | DECOMP_INLINE, 0x03A1},
-	{0x1D72D, 0, 1 | DECOMP_INLINE, 0x03F4},
-	{0x1D72E, 0, 1 | DECOMP_INLINE, 0x03A3},
-	{0x1D72F, 0, 1 | DECOMP_INLINE, 0x03A4},
-	{0x1D730, 0, 1 | DECOMP_INLINE, 0x03A5},
-	{0x1D731, 0, 1 | DECOMP_INLINE, 0x03A6},
-	{0x1D732, 0, 1 | DECOMP_INLINE, 0x03A7},
-	{0x1D733, 0, 1 | DECOMP_INLINE, 0x03A8},
-	{0x1D734, 0, 1 | DECOMP_INLINE, 0x03A9},
-	{0x1D735, 0, 1 | DECOMP_INLINE, 0x2207},
-	{0x1D736, 0, 1 | DECOMP_INLINE, 0x03B1},
-	{0x1D737, 0, 1 | DECOMP_INLINE, 0x03B2},
-	{0x1D738, 0, 1 | DECOMP_INLINE, 0x03B3},
-	{0x1D739, 0, 1 | DECOMP_INLINE, 0x03B4},
-	{0x1D73A, 0, 1 | DECOMP_INLINE, 0x03B5},
-	{0x1D73B, 0, 1 | DECOMP_INLINE, 0x03B6},
-	{0x1D73C, 0, 1 | DECOMP_INLINE, 0x03B7},
-	{0x1D73D, 0, 1 | DECOMP_INLINE, 0x03B8},
-	{0x1D73E, 0, 1 | DECOMP_INLINE, 0x03B9},
-	{0x1D73F, 0, 1 | DECOMP_INLINE, 0x03BA},
-	{0x1D740, 0, 1 | DECOMP_INLINE, 0x03BB},
-	{0x1D741, 0, 1 | DECOMP_INLINE, 0x03BC},
-	{0x1D742, 0, 1 | DECOMP_INLINE, 0x03BD},
-	{0x1D743, 0, 1 | DECOMP_INLINE, 0x03BE},
-	{0x1D744, 0, 1 | DECOMP_INLINE, 0x03BF},
-	{0x1D745, 0, 1 | DECOMP_INLINE, 0x03C0},
-	{0x1D746, 0, 1 | DECOMP_INLINE, 0x03C1},
-	{0x1D747, 0, 1 | DECOMP_INLINE, 0x03C2},
-	{0x1D748, 0, 1 | DECOMP_INLINE, 0x03C3},
-	{0x1D749, 0, 1 | DECOMP_INLINE, 0x03C4},
-	{0x1D74A, 0, 1 | DECOMP_INLINE, 0x03C5},
-	{0x1D74B, 0, 1 | DECOMP_INLINE, 0x03C6},
-	{0x1D74C, 0, 1 | DECOMP_INLINE, 0x03C7},
-	{0x1D74D, 0, 1 | DECOMP_INLINE, 0x03C8},
-	{0x1D74E, 0, 1 | DECOMP_INLINE, 0x03C9},
-	{0x1D74F, 0, 1 | DECOMP_INLINE, 0x2202},
-	{0x1D750, 0, 1 | DECOMP_INLINE, 0x03F5},
-	{0x1D751, 0, 1 | DECOMP_INLINE, 0x03D1},
-	{0x1D752, 0, 1 | DECOMP_INLINE, 0x03F0},
-	{0x1D753, 0, 1 | DECOMP_INLINE, 0x03D5},
-	{0x1D754, 0, 1 | DECOMP_INLINE, 0x03F1},
-	{0x1D755, 0, 1 | DECOMP_INLINE, 0x03D6},
-	{0x1D756, 0, 1 | DECOMP_INLINE, 0x0391},
-	{0x1D757, 0, 1 | DECOMP_INLINE, 0x0392},
-	{0x1D758, 0, 1 | DECOMP_INLINE, 0x0393},
-	{0x1D759, 0, 1 | DECOMP_INLINE, 0x0394},
-	{0x1D75A, 0, 1 | DECOMP_INLINE, 0x0395},
-	{0x1D75B, 0, 1 | DECOMP_INLINE, 0x0396},
-	{0x1D75C, 0, 1 | DECOMP_INLINE, 0x0397},
-	{0x1D75D, 0, 1 | DECOMP_INLINE, 0x0398},
-	{0x1D75E, 0, 1 | DECOMP_INLINE, 0x0399},
-	{0x1D75F, 0, 1 | DECOMP_INLINE, 0x039A},
-	{0x1D760, 0, 1 | DECOMP_INLINE, 0x039B},
-	{0x1D761, 0, 1 | DECOMP_INLINE, 0x039C},
-	{0x1D762, 0, 1 | DECOMP_INLINE, 0x039D},
-	{0x1D763, 0, 1 | DECOMP_INLINE, 0x039E},
-	{0x1D764, 0, 1 | DECOMP_INLINE, 0x039F},
-	{0x1D765, 0, 1 | DECOMP_INLINE, 0x03A0},
-	{0x1D766, 0, 1 | DECOMP_INLINE, 0x03A1},
-	{0x1D767, 0, 1 | DECOMP_INLINE, 0x03F4},
-	{0x1D768, 0, 1 | DECOMP_INLINE, 0x03A3},
-	{0x1D769, 0, 1 | DECOMP_INLINE, 0x03A4},
-	{0x1D76A, 0, 1 | DECOMP_INLINE, 0x03A5},
-	{0x1D76B, 0, 1 | DECOMP_INLINE, 0x03A6},
-	{0x1D76C, 0, 1 | DECOMP_INLINE, 0x03A7},
-	{0x1D76D, 0, 1 | DECOMP_INLINE, 0x03A8},
-	{0x1D76E, 0, 1 | DECOMP_INLINE, 0x03A9},
-	{0x1D76F, 0, 1 | DECOMP_INLINE, 0x2207},
-	{0x1D770, 0, 1 | DECOMP_INLINE, 0x03B1},
-	{0x1D771, 0, 1 | DECOMP_INLINE, 0x03B2},
-	{0x1D772, 0, 1 | DECOMP_INLINE, 0x03B3},
-	{0x1D773, 0, 1 | DECOMP_INLINE, 0x03B4},
-	{0x1D774, 0, 1 | DECOMP_INLINE, 0x03B5},
-	{0x1D775, 0, 1 | DECOMP_INLINE, 0x03B6},
-	{0x1D776, 0, 1 | DECOMP_INLINE, 0x03B7},
-	{0x1D777, 0, 1 | DECOMP_INLINE, 0x03B8},
-	{0x1D778, 0, 1 | DECOMP_INLINE, 0x03B9},
-	{0x1D779, 0, 1 | DECOMP_INLINE, 0x03BA},
-	{0x1D77A, 0, 1 | DECOMP_INLINE, 0x03BB},
-	{0x1D77B, 0, 1 | DECOMP_INLINE, 0x03BC},
-	{0x1D77C, 0, 1 | DECOMP_INLINE, 0x03BD},
-	{0x1D77D, 0, 1 | DECOMP_INLINE, 0x03BE},
-	{0x1D77E, 0, 1 | DECOMP_INLINE, 0x03BF},
-	{0x1D77F, 0, 1 | DECOMP_INLINE, 0x03C0},
-	{0x1D780, 0, 1 | DECOMP_INLINE, 0x03C1},
-	{0x1D781, 0, 1 | DECOMP_INLINE, 0x03C2},
-	{0x1D782, 0, 1 | DECOMP_INLINE, 0x03C3},
-	{0x1D783, 0, 1 | DECOMP_INLINE, 0x03C4},
-	{0x1D784, 0, 1 | DECOMP_INLINE, 0x03C5},
-	{0x1D785, 0, 1 | DECOMP_INLINE, 0x03C6},
-	{0x1D786, 0, 1 | DECOMP_INLINE, 0x03C7},
-	{0x1D787, 0, 1 | DECOMP_INLINE, 0x03C8},
-	{0x1D788, 0, 1 | DECOMP_INLINE, 0x03C9},
-	{0x1D789, 0, 1 | DECOMP_INLINE, 0x2202},
-	{0x1D78A, 0, 1 | DECOMP_INLINE, 0x03F5},
-	{0x1D78B, 0, 1 | DECOMP_INLINE, 0x03D1},
-	{0x1D78C, 0, 1 | DECOMP_INLINE, 0x03F0},
-	{0x1D78D, 0, 1 | DECOMP_INLINE, 0x03D5},
-	{0x1D78E, 0, 1 | DECOMP_INLINE, 0x03F1},
-	{0x1D78F, 0, 1 | DECOMP_INLINE, 0x03D6},
-	{0x1D790, 0, 1 | DECOMP_INLINE, 0x0391},
-	{0x1D791, 0, 1 | DECOMP_INLINE, 0x0392},
-	{0x1D792, 0, 1 | DECOMP_INLINE, 0x0393},
-	{0x1D793, 0, 1 | DECOMP_INLINE, 0x0394},
-	{0x1D794, 0, 1 | DECOMP_INLINE, 0x0395},
-	{0x1D795, 0, 1 | DECOMP_INLINE, 0x0396},
-	{0x1D796, 0, 1 | DECOMP_INLINE, 0x0397},
-	{0x1D797, 0, 1 | DECOMP_INLINE, 0x0398},
-	{0x1D798, 0, 1 | DECOMP_INLINE, 0x0399},
-	{0x1D799, 0, 1 | DECOMP_INLINE, 0x039A},
-	{0x1D79A, 0, 1 | DECOMP_INLINE, 0x039B},
-	{0x1D79B, 0, 1 | DECOMP_INLINE, 0x039C},
-	{0x1D79C, 0, 1 | DECOMP_INLINE, 0x039D},
-	{0x1D79D, 0, 1 | DECOMP_INLINE, 0x039E},
-	{0x1D79E, 0, 1 | DECOMP_INLINE, 0x039F},
-	{0x1D79F, 0, 1 | DECOMP_INLINE, 0x03A0},
-	{0x1D7A0, 0, 1 | DECOMP_INLINE, 0x03A1},
-	{0x1D7A1, 0, 1 | DECOMP_INLINE, 0x03F4},
-	{0x1D7A2, 0, 1 | DECOMP_INLINE, 0x03A3},
-	{0x1D7A3, 0, 1 | DECOMP_INLINE, 0x03A4},
-	{0x1D7A4, 0, 1 | DECOMP_INLINE, 0x03A5},
-	{0x1D7A5, 0, 1 | DECOMP_INLINE, 0x03A6},
-	{0x1D7A6, 0, 1 | DECOMP_INLINE, 0x03A7},
-	{0x1D7A7, 0, 1 | DECOMP_INLINE, 0x03A8},
-	{0x1D7A8, 0, 1 | DECOMP_INLINE, 0x03A9},
-	{0x1D7A9, 0, 1 | DECOMP_INLINE, 0x2207},
-	{0x1D7AA, 0, 1 | DECOMP_INLINE, 0x03B1},
-	{0x1D7AB, 0, 1 | DECOMP_INLINE, 0x03B2},
-	{0x1D7AC, 0, 1 | DECOMP_INLINE, 0x03B3},
-	{0x1D7AD, 0, 1 | DECOMP_INLINE, 0x03B4},
-	{0x1D7AE, 0, 1 | DECOMP_INLINE, 0x03B5},
-	{0x1D7AF, 0, 1 | DECOMP_INLINE, 0x03B6},
-	{0x1D7B0, 0, 1 | DECOMP_INLINE, 0x03B7},
-	{0x1D7B1, 0, 1 | DECOMP_INLINE, 0x03B8},
-	{0x1D7B2, 0, 1 | DECOMP_INLINE, 0x03B9},
-	{0x1D7B3, 0, 1 | DECOMP_INLINE, 0x03BA},
-	{0x1D7B4, 0, 1 | DECOMP_INLINE, 0x03BB},
-	{0x1D7B5, 0, 1 | DECOMP_INLINE, 0x03BC},
-	{0x1D7B6, 0, 1 | DECOMP_INLINE, 0x03BD},
-	{0x1D7B7, 0, 1 | DECOMP_INLINE, 0x03BE},
-	{0x1D7B8, 0, 1 | DECOMP_INLINE, 0x03BF},
-	{0x1D7B9, 0, 1 | DECOMP_INLINE, 0x03C0},
-	{0x1D7BA, 0, 1 | DECOMP_INLINE, 0x03C1},
-	{0x1D7BB, 0, 1 | DECOMP_INLINE, 0x03C2},
-	{0x1D7BC, 0, 1 | DECOMP_INLINE, 0x03C3},
-	{0x1D7BD, 0, 1 | DECOMP_INLINE, 0x03C4},
-	{0x1D7BE, 0, 1 | DECOMP_INLINE, 0x03C5},
-	{0x1D7BF, 0, 1 | DECOMP_INLINE, 0x03C6},
-	{0x1D7C0, 0, 1 | DECOMP_INLINE, 0x03C7},
-	{0x1D7C1, 0, 1 | DECOMP_INLINE, 0x03C8},
-	{0x1D7C2, 0, 1 | DECOMP_INLINE, 0x03C9},
-	{0x1D7C3, 0, 1 | DECOMP_INLINE, 0x2202},
-	{0x1D7C4, 0, 1 | DECOMP_INLINE, 0x03F5},
-	{0x1D7C5, 0, 1 | DECOMP_INLINE, 0x03D1},
-	{0x1D7C6, 0, 1 | DECOMP_INLINE, 0x03F0},
-	{0x1D7C7, 0, 1 | DECOMP_INLINE, 0x03D5},
-	{0x1D7C8, 0, 1 | DECOMP_INLINE, 0x03F1},
-	{0x1D7C9, 0, 1 | DECOMP_INLINE, 0x03D6},
-	{0x1D7CA, 0, 1 | DECOMP_INLINE, 0x03DC},
-	{0x1D7CB, 0, 1 | DECOMP_INLINE, 0x03DD},
-	{0x1D7CE, 0, 1 | DECOMP_INLINE, 0x0030},
-	{0x1D7CF, 0, 1 | DECOMP_INLINE, 0x0031},
-	{0x1D7D0, 0, 1 | DECOMP_INLINE, 0x0032},
-	{0x1D7D1, 0, 1 | DECOMP_INLINE, 0x0033},
-	{0x1D7D2, 0, 1 | DECOMP_INLINE, 0x0034},
-	{0x1D7D3, 0, 1 | DECOMP_INLINE, 0x0035},
-	{0x1D7D4, 0, 1 | DECOMP_INLINE, 0x0036},
-	{0x1D7D5, 0, 1 | DECOMP_INLINE, 0x0037},
-	{0x1D7D6, 0, 1 | DECOMP_INLINE, 0x0038},
-	{0x1D7D7, 0, 1 | DECOMP_INLINE, 0x0039},
-	{0x1D7D8, 0, 1 | DECOMP_INLINE, 0x0030},
-	{0x1D7D9, 0, 1 | DECOMP_INLINE, 0x0031},
-	{0x1D7DA, 0, 1 | DECOMP_INLINE, 0x0032},
-	{0x1D7DB, 0, 1 | DECOMP_INLINE, 0x0033},
-	{0x1D7DC, 0, 1 | DECOMP_INLINE, 0x0034},
-	{0x1D7DD, 0, 1 | DECOMP_INLINE, 0x0035},
-	{0x1D7DE, 0, 1 | DECOMP_INLINE, 0x0036},
-	{0x1D7DF, 0, 1 | DECOMP_INLINE, 0x0037},
-	{0x1D7E0, 0, 1 | DECOMP_INLINE, 0x0038},
-	{0x1D7E1, 0, 1 | DECOMP_INLINE, 0x0039},
-	{0x1D7E2, 0, 1 | DECOMP_INLINE, 0x0030},
-	{0x1D7E3, 0, 1 | DECOMP_INLINE, 0x0031},
-	{0x1D7E4, 0, 1 | DECOMP_INLINE, 0x0032},
-	{0x1D7E5, 0, 1 | DECOMP_INLINE, 0x0033},
-	{0x1D7E6, 0, 1 | DECOMP_INLINE, 0x0034},
-	{0x1D7E7, 0, 1 | DECOMP_INLINE, 0x0035},
-	{0x1D7E8, 0, 1 | DECOMP_INLINE, 0x0036},
-	{0x1D7E9, 0, 1 | DECOMP_INLINE, 0x0037},
-	{0x1D7EA, 0, 1 | DECOMP_INLINE, 0x0038},
-	{0x1D7EB, 0, 1 | DECOMP_INLINE, 0x0039},
-	{0x1D7EC, 0, 1 | DECOMP_INLINE, 0x0030},
-	{0x1D7ED, 0, 1 | DECOMP_INLINE, 0x0031},
-	{0x1D7EE, 0, 1 | DECOMP_INLINE, 0x0032},
-	{0x1D7EF, 0, 1 | DECOMP_INLINE, 0x0033},
-	{0x1D7F0, 0, 1 | DECOMP_INLINE, 0x0034},
-	{0x1D7F1, 0, 1 | DECOMP_INLINE, 0x0035},
-	{0x1D7F2, 0, 1 | DECOMP_INLINE, 0x0036},
-	{0x1D7F3, 0, 1 | DECOMP_INLINE, 0x0037},
-	{0x1D7F4, 0, 1 | DECOMP_INLINE, 0x0038},
-	{0x1D7F5, 0, 1 | DECOMP_INLINE, 0x0039},
-	{0x1D7F6, 0, 1 | DECOMP_INLINE, 0x0030},
-	{0x1D7F7, 0, 1 | DECOMP_INLINE, 0x0031},
-	{0x1D7F8, 0, 1 | DECOMP_INLINE, 0x0032},
-	{0x1D7F9, 0, 1 | DECOMP_INLINE, 0x0033},
-	{0x1D7FA, 0, 1 | DECOMP_INLINE, 0x0034},
-	{0x1D7FB, 0, 1 | DECOMP_INLINE, 0x0035},
-	{0x1D7FC, 0, 1 | DECOMP_INLINE, 0x0036},
-	{0x1D7FD, 0, 1 | DECOMP_INLINE, 0x0037},
-	{0x1D7FE, 0, 1 | DECOMP_INLINE, 0x0038},
-	{0x1D7FF, 0, 1 | DECOMP_INLINE, 0x0039},
+	{0x1D400, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D401, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D402, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1D403, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D404, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D405, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D406, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D407, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1D408, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D409, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D40A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D40B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D40C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D40D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D40E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D40F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D410, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D411, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1D412, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D413, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D414, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D415, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D416, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D417, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D418, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D419, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1D41A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D41B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D41C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D41D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D41E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D41F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D420, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D421, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D422, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D423, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D424, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D425, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D426, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D427, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D428, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D429, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D42A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D42B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D42C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D42D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D42E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D42F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D430, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D431, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D432, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D433, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D434, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D435, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D436, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1D437, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D438, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D439, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D43A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D43B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1D43C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D43D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D43E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D43F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D440, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D441, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D442, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D443, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D444, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D445, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1D446, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D447, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D448, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D449, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D44A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D44B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D44C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D44D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1D44E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D44F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D450, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D451, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D452, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D453, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D454, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D456, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D457, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D458, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D459, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D45A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D45B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D45C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D45D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D45E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D45F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D460, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D461, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D462, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D463, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D464, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D465, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D466, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D467, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D468, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D469, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D46A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1D46B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D46C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D46D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D46E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D46F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1D470, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D471, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D472, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D473, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D474, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D475, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D476, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D477, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D478, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D479, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1D47A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D47B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D47C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D47D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D47E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D47F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D480, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D481, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1D482, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D483, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D484, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D485, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D486, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D487, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D488, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D489, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D48A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D48B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D48C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D48D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D48E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D48F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D490, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D491, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D492, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D493, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D494, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D495, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D496, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D497, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D498, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D499, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D49A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D49B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D49C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D49E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1D49F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D4A2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D4A5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D4A6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D4A9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D4AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D4AB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D4AC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D4AE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D4AF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D4B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D4B1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D4B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D4B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D4B4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D4B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1D4B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D4B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D4B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D4B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D4BB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D4BD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D4BE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D4BF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D4C0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D4C1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D4C2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D4C3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D4C5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D4C6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D4C7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D4C8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D4C9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D4CA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D4CB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D4CC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D4CD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D4CE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D4CF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D4D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D4D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D4D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1D4D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D4D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D4D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D4D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D4D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1D4D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D4D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D4DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D4DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D4DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D4DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D4DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D4DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D4E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D4E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1D4E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D4E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D4E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D4E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D4E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D4E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D4E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D4E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1D4EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D4EB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D4EC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D4ED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D4EE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D4EF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D4F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D4F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D4F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D4F3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D4F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D4F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D4F6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D4F7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D4F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D4F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D4FA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D4FB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D4FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D4FD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D4FE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D4FF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D500, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D501, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D502, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D503, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D504, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D505, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D507, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D508, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D509, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D50A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D50D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D50E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D50F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D510, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D511, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D512, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D513, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D514, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D516, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D517, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D518, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D519, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D51A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D51B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D51C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D51E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D51F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D520, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D521, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D522, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D523, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D524, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D525, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D526, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D527, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D528, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D529, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D52A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D52B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D52C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D52D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D52E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D52F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D530, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D531, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D532, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D533, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D534, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D535, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D536, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D537, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D538, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D539, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D53B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D53C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D53D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D53E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D540, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D541, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D542, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D543, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D544, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D546, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D54A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D54B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D54C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D54D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D54E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D54F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D550, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D552, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D553, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D554, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D555, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D556, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D557, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D558, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D559, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D55A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D55B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D55C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D55D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D55E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D55F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D560, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D561, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D562, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D563, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D564, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D565, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D566, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D567, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D568, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D569, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D56A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D56B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D56C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D56D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D56E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1D56F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D570, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D571, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D572, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D573, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1D574, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D575, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D576, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D577, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D578, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D579, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D57A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D57B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D57C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D57D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1D57E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D57F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D580, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D581, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D582, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D583, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D584, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D585, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1D586, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D587, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D588, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D589, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D58A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D58B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D58C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D58D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D58E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D58F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D590, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D591, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D592, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D593, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D594, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D595, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D596, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D597, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D598, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D599, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D59A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D59B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D59C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D59D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D59E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D59F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D5A0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D5A1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D5A2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1D5A3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D5A4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D5A5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D5A6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D5A7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1D5A8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D5A9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D5AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D5AB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D5AC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D5AD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D5AE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D5AF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D5B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D5B1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1D5B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D5B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D5B4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D5B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D5B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D5B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D5B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D5B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1D5BA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D5BB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D5BC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D5BD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D5BE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D5BF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D5C0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D5C1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D5C2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D5C3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D5C4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D5C5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D5C6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D5C7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D5C8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D5C9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D5CA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D5CB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D5CC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D5CD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D5CE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D5CF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D5D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D5D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D5D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D5D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D5D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D5D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D5D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1D5D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D5D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D5D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D5DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D5DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1D5DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D5DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D5DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D5DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D5E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D5E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D5E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D5E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D5E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D5E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1D5E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D5E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D5E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D5E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D5EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D5EB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D5EC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D5ED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1D5EE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D5EF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D5F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D5F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D5F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D5F3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D5F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D5F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D5F6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D5F7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D5F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D5F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D5FA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D5FB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D5FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D5FD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D5FE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D5FF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D600, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D601, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D602, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D603, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D604, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D605, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D606, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D607, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D608, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D609, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D60A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1D60B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D60C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D60D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D60E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D60F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1D610, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D611, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D612, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D613, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D614, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D615, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D616, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D617, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D618, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D619, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1D61A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D61B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D61C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D61D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D61E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D61F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D620, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D621, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1D622, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D623, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D624, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D625, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D626, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D627, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D628, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D629, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D62A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D62B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D62C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D62D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D62E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D62F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D630, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D631, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D632, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D633, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D634, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D635, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D636, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D637, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D638, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D639, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D63A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D63B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D63C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D63D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D63E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1D63F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D640, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D641, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D642, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D643, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1D644, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D645, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D646, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D647, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D648, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D649, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D64A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D64B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D64C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D64D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1D64E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D64F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D650, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D651, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D652, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D653, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D654, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D655, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1D656, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D657, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D658, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D659, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D65A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D65B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D65C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D65D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D65E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D65F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D660, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D661, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D662, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D663, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D664, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D665, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D666, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D667, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D668, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D669, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D66A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D66B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D66C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D66D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D66E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D66F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D670, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1D671, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1D672, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1D673, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1D674, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1D675, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1D676, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1D677, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1D678, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1D679, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1D67A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1D67B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1D67C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1D67D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1D67E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1D67F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1D680, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1D681, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1D682, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1D683, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1D684, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1D685, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1D686, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1D687, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1D688, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1D689, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1D68A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0061},
+	{0x1D68B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0062},
+	{0x1D68C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0063},
+	{0x1D68D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0064},
+	{0x1D68E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0065},
+	{0x1D68F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0066},
+	{0x1D690, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0067},
+	{0x1D691, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0068},
+	{0x1D692, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0069},
+	{0x1D693, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006A},
+	{0x1D694, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006B},
+	{0x1D695, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006C},
+	{0x1D696, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006D},
+	{0x1D697, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006E},
+	{0x1D698, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x006F},
+	{0x1D699, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0070},
+	{0x1D69A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0071},
+	{0x1D69B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0072},
+	{0x1D69C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0073},
+	{0x1D69D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0074},
+	{0x1D69E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0075},
+	{0x1D69F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0076},
+	{0x1D6A0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0077},
+	{0x1D6A1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0078},
+	{0x1D6A2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0079},
+	{0x1D6A3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x007A},
+	{0x1D6A4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0131},
+	{0x1D6A5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0237},
+	{0x1D6A8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0391},
+	{0x1D6A9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0392},
+	{0x1D6AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
+	{0x1D6AB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0394},
+	{0x1D6AC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0395},
+	{0x1D6AD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0396},
+	{0x1D6AE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0397},
+	{0x1D6AF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
+	{0x1D6B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0399},
+	{0x1D6B1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039A},
+	{0x1D6B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039B},
+	{0x1D6B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039C},
+	{0x1D6B4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039D},
+	{0x1D6B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039E},
+	{0x1D6B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039F},
+	{0x1D6B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
+	{0x1D6B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A1},
+	{0x1D6B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F4},
+	{0x1D6BA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
+	{0x1D6BB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A4},
+	{0x1D6BC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
+	{0x1D6BD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A6},
+	{0x1D6BE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A7},
+	{0x1D6BF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A8},
+	{0x1D6C0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A9},
+	{0x1D6C1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2207},
+	{0x1D6C2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B1},
+	{0x1D6C3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
+	{0x1D6C4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
+	{0x1D6C5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
+	{0x1D6C6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
+	{0x1D6C7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B6},
+	{0x1D6C8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B7},
+	{0x1D6C9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
+	{0x1D6CA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B9},
+	{0x1D6CB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
+	{0x1D6CC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BB},
+	{0x1D6CD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
+	{0x1D6CE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BD},
+	{0x1D6CF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BE},
+	{0x1D6D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BF},
+	{0x1D6D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
+	{0x1D6D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
+	{0x1D6D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
+	{0x1D6D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C3},
+	{0x1D6D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C4},
+	{0x1D6D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C5},
+	{0x1D6D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
+	{0x1D6D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
+	{0x1D6D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C8},
+	{0x1D6DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C9},
+	{0x1D6DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2202},
+	{0x1D6DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F5},
+	{0x1D6DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D1},
+	{0x1D6DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F0},
+	{0x1D6DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D5},
+	{0x1D6E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F1},
+	{0x1D6E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D6},
+	{0x1D6E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0391},
+	{0x1D6E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0392},
+	{0x1D6E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
+	{0x1D6E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0394},
+	{0x1D6E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0395},
+	{0x1D6E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0396},
+	{0x1D6E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0397},
+	{0x1D6E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
+	{0x1D6EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0399},
+	{0x1D6EB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039A},
+	{0x1D6EC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039B},
+	{0x1D6ED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039C},
+	{0x1D6EE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039D},
+	{0x1D6EF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039E},
+	{0x1D6F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039F},
+	{0x1D6F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
+	{0x1D6F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A1},
+	{0x1D6F3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F4},
+	{0x1D6F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
+	{0x1D6F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A4},
+	{0x1D6F6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
+	{0x1D6F7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A6},
+	{0x1D6F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A7},
+	{0x1D6F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A8},
+	{0x1D6FA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A9},
+	{0x1D6FB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2207},
+	{0x1D6FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B1},
+	{0x1D6FD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
+	{0x1D6FE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
+	{0x1D6FF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
+	{0x1D700, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
+	{0x1D701, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B6},
+	{0x1D702, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B7},
+	{0x1D703, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
+	{0x1D704, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B9},
+	{0x1D705, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
+	{0x1D706, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BB},
+	{0x1D707, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
+	{0x1D708, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BD},
+	{0x1D709, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BE},
+	{0x1D70A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BF},
+	{0x1D70B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
+	{0x1D70C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
+	{0x1D70D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
+	{0x1D70E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C3},
+	{0x1D70F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C4},
+	{0x1D710, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C5},
+	{0x1D711, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
+	{0x1D712, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
+	{0x1D713, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C8},
+	{0x1D714, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C9},
+	{0x1D715, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2202},
+	{0x1D716, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F5},
+	{0x1D717, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D1},
+	{0x1D718, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F0},
+	{0x1D719, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D5},
+	{0x1D71A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F1},
+	{0x1D71B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D6},
+	{0x1D71C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0391},
+	{0x1D71D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0392},
+	{0x1D71E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
+	{0x1D71F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0394},
+	{0x1D720, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0395},
+	{0x1D721, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0396},
+	{0x1D722, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0397},
+	{0x1D723, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
+	{0x1D724, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0399},
+	{0x1D725, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039A},
+	{0x1D726, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039B},
+	{0x1D727, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039C},
+	{0x1D728, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039D},
+	{0x1D729, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039E},
+	{0x1D72A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039F},
+	{0x1D72B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
+	{0x1D72C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A1},
+	{0x1D72D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F4},
+	{0x1D72E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
+	{0x1D72F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A4},
+	{0x1D730, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
+	{0x1D731, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A6},
+	{0x1D732, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A7},
+	{0x1D733, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A8},
+	{0x1D734, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A9},
+	{0x1D735, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2207},
+	{0x1D736, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B1},
+	{0x1D737, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
+	{0x1D738, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
+	{0x1D739, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
+	{0x1D73A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
+	{0x1D73B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B6},
+	{0x1D73C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B7},
+	{0x1D73D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
+	{0x1D73E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B9},
+	{0x1D73F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
+	{0x1D740, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BB},
+	{0x1D741, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
+	{0x1D742, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BD},
+	{0x1D743, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BE},
+	{0x1D744, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BF},
+	{0x1D745, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
+	{0x1D746, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
+	{0x1D747, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
+	{0x1D748, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C3},
+	{0x1D749, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C4},
+	{0x1D74A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C5},
+	{0x1D74B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
+	{0x1D74C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
+	{0x1D74D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C8},
+	{0x1D74E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C9},
+	{0x1D74F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2202},
+	{0x1D750, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F5},
+	{0x1D751, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D1},
+	{0x1D752, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F0},
+	{0x1D753, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D5},
+	{0x1D754, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F1},
+	{0x1D755, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D6},
+	{0x1D756, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0391},
+	{0x1D757, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0392},
+	{0x1D758, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
+	{0x1D759, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0394},
+	{0x1D75A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0395},
+	{0x1D75B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0396},
+	{0x1D75C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0397},
+	{0x1D75D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
+	{0x1D75E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0399},
+	{0x1D75F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039A},
+	{0x1D760, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039B},
+	{0x1D761, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039C},
+	{0x1D762, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039D},
+	{0x1D763, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039E},
+	{0x1D764, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039F},
+	{0x1D765, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
+	{0x1D766, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A1},
+	{0x1D767, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F4},
+	{0x1D768, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
+	{0x1D769, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A4},
+	{0x1D76A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
+	{0x1D76B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A6},
+	{0x1D76C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A7},
+	{0x1D76D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A8},
+	{0x1D76E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A9},
+	{0x1D76F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2207},
+	{0x1D770, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B1},
+	{0x1D771, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
+	{0x1D772, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
+	{0x1D773, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
+	{0x1D774, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
+	{0x1D775, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B6},
+	{0x1D776, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B7},
+	{0x1D777, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
+	{0x1D778, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B9},
+	{0x1D779, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
+	{0x1D77A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BB},
+	{0x1D77B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
+	{0x1D77C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BD},
+	{0x1D77D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BE},
+	{0x1D77E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BF},
+	{0x1D77F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
+	{0x1D780, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
+	{0x1D781, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
+	{0x1D782, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C3},
+	{0x1D783, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C4},
+	{0x1D784, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C5},
+	{0x1D785, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
+	{0x1D786, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
+	{0x1D787, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C8},
+	{0x1D788, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C9},
+	{0x1D789, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2202},
+	{0x1D78A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F5},
+	{0x1D78B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D1},
+	{0x1D78C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F0},
+	{0x1D78D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D5},
+	{0x1D78E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F1},
+	{0x1D78F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D6},
+	{0x1D790, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0391},
+	{0x1D791, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0392},
+	{0x1D792, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0393},
+	{0x1D793, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0394},
+	{0x1D794, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0395},
+	{0x1D795, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0396},
+	{0x1D796, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0397},
+	{0x1D797, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0398},
+	{0x1D798, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0399},
+	{0x1D799, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039A},
+	{0x1D79A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039B},
+	{0x1D79B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039C},
+	{0x1D79C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039D},
+	{0x1D79D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039E},
+	{0x1D79E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x039F},
+	{0x1D79F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A0},
+	{0x1D7A0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A1},
+	{0x1D7A1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F4},
+	{0x1D7A2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A3},
+	{0x1D7A3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A4},
+	{0x1D7A4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A5},
+	{0x1D7A5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A6},
+	{0x1D7A6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A7},
+	{0x1D7A7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A8},
+	{0x1D7A8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03A9},
+	{0x1D7A9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2207},
+	{0x1D7AA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B1},
+	{0x1D7AB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B2},
+	{0x1D7AC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B3},
+	{0x1D7AD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B4},
+	{0x1D7AE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B5},
+	{0x1D7AF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B6},
+	{0x1D7B0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B7},
+	{0x1D7B1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B8},
+	{0x1D7B2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03B9},
+	{0x1D7B3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BA},
+	{0x1D7B4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BB},
+	{0x1D7B5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BC},
+	{0x1D7B6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BD},
+	{0x1D7B7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BE},
+	{0x1D7B8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03BF},
+	{0x1D7B9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C0},
+	{0x1D7BA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C1},
+	{0x1D7BB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C2},
+	{0x1D7BC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C3},
+	{0x1D7BD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C4},
+	{0x1D7BE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C5},
+	{0x1D7BF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C6},
+	{0x1D7C0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C7},
+	{0x1D7C1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C8},
+	{0x1D7C2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03C9},
+	{0x1D7C3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x2202},
+	{0x1D7C4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F5},
+	{0x1D7C5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D1},
+	{0x1D7C6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F0},
+	{0x1D7C7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D5},
+	{0x1D7C8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03F1},
+	{0x1D7C9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03D6},
+	{0x1D7CA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03DC},
+	{0x1D7CB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x03DD},
+	{0x1D7CE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
+	{0x1D7CF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
+	{0x1D7D0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
+	{0x1D7D1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
+	{0x1D7D2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
+	{0x1D7D3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
+	{0x1D7D4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
+	{0x1D7D5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
+	{0x1D7D6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
+	{0x1D7D7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
+	{0x1D7D8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
+	{0x1D7D9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
+	{0x1D7DA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
+	{0x1D7DB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
+	{0x1D7DC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
+	{0x1D7DD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
+	{0x1D7DE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
+	{0x1D7DF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
+	{0x1D7E0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
+	{0x1D7E1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
+	{0x1D7E2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
+	{0x1D7E3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
+	{0x1D7E4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
+	{0x1D7E5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
+	{0x1D7E6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
+	{0x1D7E7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
+	{0x1D7E8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
+	{0x1D7E9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
+	{0x1D7EA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
+	{0x1D7EB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
+	{0x1D7EC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
+	{0x1D7ED, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
+	{0x1D7EE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
+	{0x1D7EF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
+	{0x1D7F0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
+	{0x1D7F1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
+	{0x1D7F2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
+	{0x1D7F3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
+	{0x1D7F4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
+	{0x1D7F5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
+	{0x1D7F6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0030},
+	{0x1D7F7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0031},
+	{0x1D7F8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0032},
+	{0x1D7F9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0033},
+	{0x1D7FA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0034},
+	{0x1D7FB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0035},
+	{0x1D7FC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0036},
+	{0x1D7FD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0037},
+	{0x1D7FE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0038},
+	{0x1D7FF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0039},
 	{0x1E000, 230, 0, 0},
 	{0x1E001, 230, 0, 0},
 	{0x1E002, 230, 0, 0},
@@ -5799,283 +5801,283 @@ static const pg_unicode_decomposition UnicodeDecompMain[6582] =
 	{0x1E948, 230, 0, 0},
 	{0x1E949, 230, 0, 0},
 	{0x1E94A, 7, 0, 0},
-	{0x1EE00, 0, 1 | DECOMP_INLINE, 0x0627},
-	{0x1EE01, 0, 1 | DECOMP_INLINE, 0x0628},
-	{0x1EE02, 0, 1 | DECOMP_INLINE, 0x062C},
-	{0x1EE03, 0, 1 | DECOMP_INLINE, 0x062F},
-	{0x1EE05, 0, 1 | DECOMP_INLINE, 0x0648},
-	{0x1EE06, 0, 1 | DECOMP_INLINE, 0x0632},
-	{0x1EE07, 0, 1 | DECOMP_INLINE, 0x062D},
-	{0x1EE08, 0, 1 | DECOMP_INLINE, 0x0637},
-	{0x1EE09, 0, 1 | DECOMP_INLINE, 0x064A},
-	{0x1EE0A, 0, 1 | DECOMP_INLINE, 0x0643},
-	{0x1EE0B, 0, 1 | DECOMP_INLINE, 0x0644},
-	{0x1EE0C, 0, 1 | DECOMP_INLINE, 0x0645},
-	{0x1EE0D, 0, 1 | DECOMP_INLINE, 0x0646},
-	{0x1EE0E, 0, 1 | DECOMP_INLINE, 0x0633},
-	{0x1EE0F, 0, 1 | DECOMP_INLINE, 0x0639},
-	{0x1EE10, 0, 1 | DECOMP_INLINE, 0x0641},
-	{0x1EE11, 0, 1 | DECOMP_INLINE, 0x0635},
-	{0x1EE12, 0, 1 | DECOMP_INLINE, 0x0642},
-	{0x1EE13, 0, 1 | DECOMP_INLINE, 0x0631},
-	{0x1EE14, 0, 1 | DECOMP_INLINE, 0x0634},
-	{0x1EE15, 0, 1 | DECOMP_INLINE, 0x062A},
-	{0x1EE16, 0, 1 | DECOMP_INLINE, 0x062B},
-	{0x1EE17, 0, 1 | DECOMP_INLINE, 0x062E},
-	{0x1EE18, 0, 1 | DECOMP_INLINE, 0x0630},
-	{0x1EE19, 0, 1 | DECOMP_INLINE, 0x0636},
-	{0x1EE1A, 0, 1 | DECOMP_INLINE, 0x0638},
-	{0x1EE1B, 0, 1 | DECOMP_INLINE, 0x063A},
-	{0x1EE1C, 0, 1 | DECOMP_INLINE, 0x066E},
-	{0x1EE1D, 0, 1 | DECOMP_INLINE, 0x06BA},
-	{0x1EE1E, 0, 1 | DECOMP_INLINE, 0x06A1},
-	{0x1EE1F, 0, 1 | DECOMP_INLINE, 0x066F},
-	{0x1EE21, 0, 1 | DECOMP_INLINE, 0x0628},
-	{0x1EE22, 0, 1 | DECOMP_INLINE, 0x062C},
-	{0x1EE24, 0, 1 | DECOMP_INLINE, 0x0647},
-	{0x1EE27, 0, 1 | DECOMP_INLINE, 0x062D},
-	{0x1EE29, 0, 1 | DECOMP_INLINE, 0x064A},
-	{0x1EE2A, 0, 1 | DECOMP_INLINE, 0x0643},
-	{0x1EE2B, 0, 1 | DECOMP_INLINE, 0x0644},
-	{0x1EE2C, 0, 1 | DECOMP_INLINE, 0x0645},
-	{0x1EE2D, 0, 1 | DECOMP_INLINE, 0x0646},
-	{0x1EE2E, 0, 1 | DECOMP_INLINE, 0x0633},
-	{0x1EE2F, 0, 1 | DECOMP_INLINE, 0x0639},
-	{0x1EE30, 0, 1 | DECOMP_INLINE, 0x0641},
-	{0x1EE31, 0, 1 | DECOMP_INLINE, 0x0635},
-	{0x1EE32, 0, 1 | DECOMP_INLINE, 0x0642},
-	{0x1EE34, 0, 1 | DECOMP_INLINE, 0x0634},
-	{0x1EE35, 0, 1 | DECOMP_INLINE, 0x062A},
-	{0x1EE36, 0, 1 | DECOMP_INLINE, 0x062B},
-	{0x1EE37, 0, 1 | DECOMP_INLINE, 0x062E},
-	{0x1EE39, 0, 1 | DECOMP_INLINE, 0x0636},
-	{0x1EE3B, 0, 1 | DECOMP_INLINE, 0x063A},
-	{0x1EE42, 0, 1 | DECOMP_INLINE, 0x062C},
-	{0x1EE47, 0, 1 | DECOMP_INLINE, 0x062D},
-	{0x1EE49, 0, 1 | DECOMP_INLINE, 0x064A},
-	{0x1EE4B, 0, 1 | DECOMP_INLINE, 0x0644},
-	{0x1EE4D, 0, 1 | DECOMP_INLINE, 0x0646},
-	{0x1EE4E, 0, 1 | DECOMP_INLINE, 0x0633},
-	{0x1EE4F, 0, 1 | DECOMP_INLINE, 0x0639},
-	{0x1EE51, 0, 1 | DECOMP_INLINE, 0x0635},
-	{0x1EE52, 0, 1 | DECOMP_INLINE, 0x0642},
-	{0x1EE54, 0, 1 | DECOMP_INLINE, 0x0634},
-	{0x1EE57, 0, 1 | DECOMP_INLINE, 0x062E},
-	{0x1EE59, 0, 1 | DECOMP_INLINE, 0x0636},
-	{0x1EE5B, 0, 1 | DECOMP_INLINE, 0x063A},
-	{0x1EE5D, 0, 1 | DECOMP_INLINE, 0x06BA},
-	{0x1EE5F, 0, 1 | DECOMP_INLINE, 0x066F},
-	{0x1EE61, 0, 1 | DECOMP_INLINE, 0x0628},
-	{0x1EE62, 0, 1 | DECOMP_INLINE, 0x062C},
-	{0x1EE64, 0, 1 | DECOMP_INLINE, 0x0647},
-	{0x1EE67, 0, 1 | DECOMP_INLINE, 0x062D},
-	{0x1EE68, 0, 1 | DECOMP_INLINE, 0x0637},
-	{0x1EE69, 0, 1 | DECOMP_INLINE, 0x064A},
-	{0x1EE6A, 0, 1 | DECOMP_INLINE, 0x0643},
-	{0x1EE6C, 0, 1 | DECOMP_INLINE, 0x0645},
-	{0x1EE6D, 0, 1 | DECOMP_INLINE, 0x0646},
-	{0x1EE6E, 0, 1 | DECOMP_INLINE, 0x0633},
-	{0x1EE6F, 0, 1 | DECOMP_INLINE, 0x0639},
-	{0x1EE70, 0, 1 | DECOMP_INLINE, 0x0641},
-	{0x1EE71, 0, 1 | DECOMP_INLINE, 0x0635},
-	{0x1EE72, 0, 1 | DECOMP_INLINE, 0x0642},
-	{0x1EE74, 0, 1 | DECOMP_INLINE, 0x0634},
-	{0x1EE75, 0, 1 | DECOMP_INLINE, 0x062A},
-	{0x1EE76, 0, 1 | DECOMP_INLINE, 0x062B},
-	{0x1EE77, 0, 1 | DECOMP_INLINE, 0x062E},
-	{0x1EE79, 0, 1 | DECOMP_INLINE, 0x0636},
-	{0x1EE7A, 0, 1 | DECOMP_INLINE, 0x0638},
-	{0x1EE7B, 0, 1 | DECOMP_INLINE, 0x063A},
-	{0x1EE7C, 0, 1 | DECOMP_INLINE, 0x066E},
-	{0x1EE7E, 0, 1 | DECOMP_INLINE, 0x06A1},
-	{0x1EE80, 0, 1 | DECOMP_INLINE, 0x0627},
-	{0x1EE81, 0, 1 | DECOMP_INLINE, 0x0628},
-	{0x1EE82, 0, 1 | DECOMP_INLINE, 0x062C},
-	{0x1EE83, 0, 1 | DECOMP_INLINE, 0x062F},
-	{0x1EE84, 0, 1 | DECOMP_INLINE, 0x0647},
-	{0x1EE85, 0, 1 | DECOMP_INLINE, 0x0648},
-	{0x1EE86, 0, 1 | DECOMP_INLINE, 0x0632},
-	{0x1EE87, 0, 1 | DECOMP_INLINE, 0x062D},
-	{0x1EE88, 0, 1 | DECOMP_INLINE, 0x0637},
-	{0x1EE89, 0, 1 | DECOMP_INLINE, 0x064A},
-	{0x1EE8B, 0, 1 | DECOMP_INLINE, 0x0644},
-	{0x1EE8C, 0, 1 | DECOMP_INLINE, 0x0645},
-	{0x1EE8D, 0, 1 | DECOMP_INLINE, 0x0646},
-	{0x1EE8E, 0, 1 | DECOMP_INLINE, 0x0633},
-	{0x1EE8F, 0, 1 | DECOMP_INLINE, 0x0639},
-	{0x1EE90, 0, 1 | DECOMP_INLINE, 0x0641},
-	{0x1EE91, 0, 1 | DECOMP_INLINE, 0x0635},
-	{0x1EE92, 0, 1 | DECOMP_INLINE, 0x0642},
-	{0x1EE93, 0, 1 | DECOMP_INLINE, 0x0631},
-	{0x1EE94, 0, 1 | DECOMP_INLINE, 0x0634},
-	{0x1EE95, 0, 1 | DECOMP_INLINE, 0x062A},
-	{0x1EE96, 0, 1 | DECOMP_INLINE, 0x062B},
-	{0x1EE97, 0, 1 | DECOMP_INLINE, 0x062E},
-	{0x1EE98, 0, 1 | DECOMP_INLINE, 0x0630},
-	{0x1EE99, 0, 1 | DECOMP_INLINE, 0x0636},
-	{0x1EE9A, 0, 1 | DECOMP_INLINE, 0x0638},
-	{0x1EE9B, 0, 1 | DECOMP_INLINE, 0x063A},
-	{0x1EEA1, 0, 1 | DECOMP_INLINE, 0x0628},
-	{0x1EEA2, 0, 1 | DECOMP_INLINE, 0x062C},
-	{0x1EEA3, 0, 1 | DECOMP_INLINE, 0x062F},
-	{0x1EEA5, 0, 1 | DECOMP_INLINE, 0x0648},
-	{0x1EEA6, 0, 1 | DECOMP_INLINE, 0x0632},
-	{0x1EEA7, 0, 1 | DECOMP_INLINE, 0x062D},
-	{0x1EEA8, 0, 1 | DECOMP_INLINE, 0x0637},
-	{0x1EEA9, 0, 1 | DECOMP_INLINE, 0x064A},
-	{0x1EEAB, 0, 1 | DECOMP_INLINE, 0x0644},
-	{0x1EEAC, 0, 1 | DECOMP_INLINE, 0x0645},
-	{0x1EEAD, 0, 1 | DECOMP_INLINE, 0x0646},
-	{0x1EEAE, 0, 1 | DECOMP_INLINE, 0x0633},
-	{0x1EEAF, 0, 1 | DECOMP_INLINE, 0x0639},
-	{0x1EEB0, 0, 1 | DECOMP_INLINE, 0x0641},
-	{0x1EEB1, 0, 1 | DECOMP_INLINE, 0x0635},
-	{0x1EEB2, 0, 1 | DECOMP_INLINE, 0x0642},
-	{0x1EEB3, 0, 1 | DECOMP_INLINE, 0x0631},
-	{0x1EEB4, 0, 1 | DECOMP_INLINE, 0x0634},
-	{0x1EEB5, 0, 1 | DECOMP_INLINE, 0x062A},
-	{0x1EEB6, 0, 1 | DECOMP_INLINE, 0x062B},
-	{0x1EEB7, 0, 1 | DECOMP_INLINE, 0x062E},
-	{0x1EEB8, 0, 1 | DECOMP_INLINE, 0x0630},
-	{0x1EEB9, 0, 1 | DECOMP_INLINE, 0x0636},
-	{0x1EEBA, 0, 1 | DECOMP_INLINE, 0x0638},
-	{0x1EEBB, 0, 1 | DECOMP_INLINE, 0x063A},
-	{0x1F100, 0, 2 | DECOMP_NO_COMPOSE, 4826},	/* compatibility mapping */
-	{0x1F101, 0, 2 | DECOMP_NO_COMPOSE, 4828},	/* compatibility mapping */
-	{0x1F102, 0, 2 | DECOMP_NO_COMPOSE, 4830},	/* compatibility mapping */
-	{0x1F103, 0, 2 | DECOMP_NO_COMPOSE, 4832},	/* compatibility mapping */
-	{0x1F104, 0, 2 | DECOMP_NO_COMPOSE, 4834},	/* compatibility mapping */
-	{0x1F105, 0, 2 | DECOMP_NO_COMPOSE, 4836},	/* compatibility mapping */
-	{0x1F106, 0, 2 | DECOMP_NO_COMPOSE, 4838},	/* compatibility mapping */
-	{0x1F107, 0, 2 | DECOMP_NO_COMPOSE, 4840},	/* compatibility mapping */
-	{0x1F108, 0, 2 | DECOMP_NO_COMPOSE, 4842},	/* compatibility mapping */
-	{0x1F109, 0, 2 | DECOMP_NO_COMPOSE, 4844},	/* compatibility mapping */
-	{0x1F10A, 0, 2 | DECOMP_NO_COMPOSE, 4846},	/* compatibility mapping */
-	{0x1F110, 0, 3, 4848},
-	{0x1F111, 0, 3, 4851},
-	{0x1F112, 0, 3, 4854},
-	{0x1F113, 0, 3, 4857},
-	{0x1F114, 0, 3, 4860},
-	{0x1F115, 0, 3, 4863},
-	{0x1F116, 0, 3, 4866},
-	{0x1F117, 0, 3, 4869},
-	{0x1F118, 0, 3, 4872},
-	{0x1F119, 0, 3, 4875},
-	{0x1F11A, 0, 3, 4878},
-	{0x1F11B, 0, 3, 4881},
-	{0x1F11C, 0, 3, 4884},
-	{0x1F11D, 0, 3, 4887},
-	{0x1F11E, 0, 3, 4890},
-	{0x1F11F, 0, 3, 4893},
-	{0x1F120, 0, 3, 4896},
-	{0x1F121, 0, 3, 4899},
-	{0x1F122, 0, 3, 4902},
-	{0x1F123, 0, 3, 4905},
-	{0x1F124, 0, 3, 4908},
-	{0x1F125, 0, 3, 4911},
-	{0x1F126, 0, 3, 4914},
-	{0x1F127, 0, 3, 4917},
-	{0x1F128, 0, 3, 4920},
-	{0x1F129, 0, 3, 4923},
-	{0x1F12A, 0, 3, 4926},
-	{0x1F12B, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1F12C, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1F12D, 0, 2 | DECOMP_NO_COMPOSE, 4929},	/* compatibility mapping */
-	{0x1F12E, 0, 2 | DECOMP_NO_COMPOSE, 4931},	/* compatibility mapping */
-	{0x1F130, 0, 1 | DECOMP_INLINE, 0x0041},
-	{0x1F131, 0, 1 | DECOMP_INLINE, 0x0042},
-	{0x1F132, 0, 1 | DECOMP_INLINE, 0x0043},
-	{0x1F133, 0, 1 | DECOMP_INLINE, 0x0044},
-	{0x1F134, 0, 1 | DECOMP_INLINE, 0x0045},
-	{0x1F135, 0, 1 | DECOMP_INLINE, 0x0046},
-	{0x1F136, 0, 1 | DECOMP_INLINE, 0x0047},
-	{0x1F137, 0, 1 | DECOMP_INLINE, 0x0048},
-	{0x1F138, 0, 1 | DECOMP_INLINE, 0x0049},
-	{0x1F139, 0, 1 | DECOMP_INLINE, 0x004A},
-	{0x1F13A, 0, 1 | DECOMP_INLINE, 0x004B},
-	{0x1F13B, 0, 1 | DECOMP_INLINE, 0x004C},
-	{0x1F13C, 0, 1 | DECOMP_INLINE, 0x004D},
-	{0x1F13D, 0, 1 | DECOMP_INLINE, 0x004E},
-	{0x1F13E, 0, 1 | DECOMP_INLINE, 0x004F},
-	{0x1F13F, 0, 1 | DECOMP_INLINE, 0x0050},
-	{0x1F140, 0, 1 | DECOMP_INLINE, 0x0051},
-	{0x1F141, 0, 1 | DECOMP_INLINE, 0x0052},
-	{0x1F142, 0, 1 | DECOMP_INLINE, 0x0053},
-	{0x1F143, 0, 1 | DECOMP_INLINE, 0x0054},
-	{0x1F144, 0, 1 | DECOMP_INLINE, 0x0055},
-	{0x1F145, 0, 1 | DECOMP_INLINE, 0x0056},
-	{0x1F146, 0, 1 | DECOMP_INLINE, 0x0057},
-	{0x1F147, 0, 1 | DECOMP_INLINE, 0x0058},
-	{0x1F148, 0, 1 | DECOMP_INLINE, 0x0059},
-	{0x1F149, 0, 1 | DECOMP_INLINE, 0x005A},
-	{0x1F14A, 0, 2 | DECOMP_NO_COMPOSE, 4933},	/* compatibility mapping */
-	{0x1F14B, 0, 2 | DECOMP_NO_COMPOSE, 4935},	/* compatibility mapping */
-	{0x1F14C, 0, 2 | DECOMP_NO_COMPOSE, 4937},	/* compatibility mapping */
-	{0x1F14D, 0, 2 | DECOMP_NO_COMPOSE, 4939},	/* compatibility mapping */
-	{0x1F14E, 0, 3, 4941},
-	{0x1F14F, 0, 2 | DECOMP_NO_COMPOSE, 4944},	/* compatibility mapping */
-	{0x1F16A, 0, 2 | DECOMP_NO_COMPOSE, 4946},	/* compatibility mapping */
-	{0x1F16B, 0, 2 | DECOMP_NO_COMPOSE, 4948},	/* compatibility mapping */
-	{0x1F16C, 0, 2 | DECOMP_NO_COMPOSE, 4950},	/* compatibility mapping */
-	{0x1F190, 0, 2 | DECOMP_NO_COMPOSE, 4952},	/* compatibility mapping */
-	{0x1F200, 0, 2 | DECOMP_NO_COMPOSE, 4954},	/* compatibility mapping */
-	{0x1F201, 0, 2 | DECOMP_NO_COMPOSE, 4956},	/* compatibility mapping */
-	{0x1F202, 0, 1 | DECOMP_INLINE, 0x30B5},
-	{0x1F210, 0, 1 | DECOMP_INLINE, 0x624B},
-	{0x1F211, 0, 1 | DECOMP_INLINE, 0x5B57},
-	{0x1F212, 0, 1 | DECOMP_INLINE, 0x53CC},
-	{0x1F213, 0, 1 | DECOMP_INLINE, 0x30C7},
-	{0x1F214, 0, 1 | DECOMP_INLINE, 0x4E8C},
-	{0x1F215, 0, 1 | DECOMP_INLINE, 0x591A},
-	{0x1F216, 0, 1 | DECOMP_INLINE, 0x89E3},
-	{0x1F217, 0, 1 | DECOMP_INLINE, 0x5929},
-	{0x1F218, 0, 1 | DECOMP_INLINE, 0x4EA4},
-	{0x1F219, 0, 1 | DECOMP_INLINE, 0x6620},
-	{0x1F21A, 0, 1 | DECOMP_INLINE, 0x7121},
-	{0x1F21B, 0, 1 | DECOMP_INLINE, 0x6599},
-	{0x1F21C, 0, 1 | DECOMP_INLINE, 0x524D},
-	{0x1F21D, 0, 1 | DECOMP_INLINE, 0x5F8C},
-	{0x1F21E, 0, 1 | DECOMP_INLINE, 0x518D},
-	{0x1F21F, 0, 1 | DECOMP_INLINE, 0x65B0},
-	{0x1F220, 0, 1 | DECOMP_INLINE, 0x521D},
-	{0x1F221, 0, 1 | DECOMP_INLINE, 0x7D42},
-	{0x1F222, 0, 1 | DECOMP_INLINE, 0x751F},
-	{0x1F223, 0, 1 | DECOMP_INLINE, 0x8CA9},
-	{0x1F224, 0, 1 | DECOMP_INLINE, 0x58F0},
-	{0x1F225, 0, 1 | DECOMP_INLINE, 0x5439},
-	{0x1F226, 0, 1 | DECOMP_INLINE, 0x6F14},
-	{0x1F227, 0, 1 | DECOMP_INLINE, 0x6295},
-	{0x1F228, 0, 1 | DECOMP_INLINE, 0x6355},
-	{0x1F229, 0, 1 | DECOMP_INLINE, 0x4E00},
-	{0x1F22A, 0, 1 | DECOMP_INLINE, 0x4E09},
-	{0x1F22B, 0, 1 | DECOMP_INLINE, 0x904A},
-	{0x1F22C, 0, 1 | DECOMP_INLINE, 0x5DE6},
-	{0x1F22D, 0, 1 | DECOMP_INLINE, 0x4E2D},
-	{0x1F22E, 0, 1 | DECOMP_INLINE, 0x53F3},
-	{0x1F22F, 0, 1 | DECOMP_INLINE, 0x6307},
-	{0x1F230, 0, 1 | DECOMP_INLINE, 0x8D70},
-	{0x1F231, 0, 1 | DECOMP_INLINE, 0x6253},
-	{0x1F232, 0, 1 | DECOMP_INLINE, 0x7981},
-	{0x1F233, 0, 1 | DECOMP_INLINE, 0x7A7A},
-	{0x1F234, 0, 1 | DECOMP_INLINE, 0x5408},
-	{0x1F235, 0, 1 | DECOMP_INLINE, 0x6E80},
-	{0x1F236, 0, 1 | DECOMP_INLINE, 0x6709},
-	{0x1F237, 0, 1 | DECOMP_INLINE, 0x6708},
-	{0x1F238, 0, 1 | DECOMP_INLINE, 0x7533},
-	{0x1F239, 0, 1 | DECOMP_INLINE, 0x5272},
-	{0x1F23A, 0, 1 | DECOMP_INLINE, 0x55B6},
-	{0x1F23B, 0, 1 | DECOMP_INLINE, 0x914D},
-	{0x1F240, 0, 3, 4958},
-	{0x1F241, 0, 3, 4961},
-	{0x1F242, 0, 3, 4964},
-	{0x1F243, 0, 3, 4967},
-	{0x1F244, 0, 3, 4970},
-	{0x1F245, 0, 3, 4973},
-	{0x1F246, 0, 3, 4976},
-	{0x1F247, 0, 3, 4979},
-	{0x1F248, 0, 3, 4982},
-	{0x1F250, 0, 1 | DECOMP_INLINE, 0x5F97},
-	{0x1F251, 0, 1 | DECOMP_INLINE, 0x53EF},
+	{0x1EE00, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0627},
+	{0x1EE01, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
+	{0x1EE02, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
+	{0x1EE03, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062F},
+	{0x1EE05, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0648},
+	{0x1EE06, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0632},
+	{0x1EE07, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
+	{0x1EE08, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
+	{0x1EE09, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
+	{0x1EE0A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
+	{0x1EE0B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
+	{0x1EE0C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
+	{0x1EE0D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
+	{0x1EE0E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
+	{0x1EE0F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
+	{0x1EE10, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
+	{0x1EE11, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
+	{0x1EE12, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
+	{0x1EE13, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0631},
+	{0x1EE14, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
+	{0x1EE15, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
+	{0x1EE16, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
+	{0x1EE17, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
+	{0x1EE18, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0630},
+	{0x1EE19, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
+	{0x1EE1A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
+	{0x1EE1B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
+	{0x1EE1C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x066E},
+	{0x1EE1D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BA},
+	{0x1EE1E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A1},
+	{0x1EE1F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x066F},
+	{0x1EE21, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
+	{0x1EE22, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
+	{0x1EE24, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
+	{0x1EE27, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
+	{0x1EE29, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
+	{0x1EE2A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
+	{0x1EE2B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
+	{0x1EE2C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
+	{0x1EE2D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
+	{0x1EE2E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
+	{0x1EE2F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
+	{0x1EE30, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
+	{0x1EE31, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
+	{0x1EE32, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
+	{0x1EE34, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
+	{0x1EE35, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
+	{0x1EE36, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
+	{0x1EE37, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
+	{0x1EE39, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
+	{0x1EE3B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
+	{0x1EE42, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
+	{0x1EE47, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
+	{0x1EE49, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
+	{0x1EE4B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
+	{0x1EE4D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
+	{0x1EE4E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
+	{0x1EE4F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
+	{0x1EE51, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
+	{0x1EE52, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
+	{0x1EE54, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
+	{0x1EE57, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
+	{0x1EE59, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
+	{0x1EE5B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
+	{0x1EE5D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06BA},
+	{0x1EE5F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x066F},
+	{0x1EE61, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
+	{0x1EE62, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
+	{0x1EE64, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
+	{0x1EE67, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
+	{0x1EE68, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
+	{0x1EE69, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
+	{0x1EE6A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0643},
+	{0x1EE6C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
+	{0x1EE6D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
+	{0x1EE6E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
+	{0x1EE6F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
+	{0x1EE70, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
+	{0x1EE71, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
+	{0x1EE72, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
+	{0x1EE74, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
+	{0x1EE75, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
+	{0x1EE76, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
+	{0x1EE77, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
+	{0x1EE79, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
+	{0x1EE7A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
+	{0x1EE7B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
+	{0x1EE7C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x066E},
+	{0x1EE7E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x06A1},
+	{0x1EE80, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0627},
+	{0x1EE81, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
+	{0x1EE82, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
+	{0x1EE83, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062F},
+	{0x1EE84, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0647},
+	{0x1EE85, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0648},
+	{0x1EE86, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0632},
+	{0x1EE87, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
+	{0x1EE88, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
+	{0x1EE89, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
+	{0x1EE8B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
+	{0x1EE8C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
+	{0x1EE8D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
+	{0x1EE8E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
+	{0x1EE8F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
+	{0x1EE90, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
+	{0x1EE91, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
+	{0x1EE92, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
+	{0x1EE93, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0631},
+	{0x1EE94, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
+	{0x1EE95, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
+	{0x1EE96, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
+	{0x1EE97, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
+	{0x1EE98, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0630},
+	{0x1EE99, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
+	{0x1EE9A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
+	{0x1EE9B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
+	{0x1EEA1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0628},
+	{0x1EEA2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062C},
+	{0x1EEA3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062F},
+	{0x1EEA5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0648},
+	{0x1EEA6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0632},
+	{0x1EEA7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062D},
+	{0x1EEA8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0637},
+	{0x1EEA9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x064A},
+	{0x1EEAB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0644},
+	{0x1EEAC, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0645},
+	{0x1EEAD, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0646},
+	{0x1EEAE, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0633},
+	{0x1EEAF, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0639},
+	{0x1EEB0, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0641},
+	{0x1EEB1, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0635},
+	{0x1EEB2, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0642},
+	{0x1EEB3, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0631},
+	{0x1EEB4, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0634},
+	{0x1EEB5, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062A},
+	{0x1EEB6, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062B},
+	{0x1EEB7, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x062E},
+	{0x1EEB8, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0630},
+	{0x1EEB9, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0636},
+	{0x1EEBA, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0638},
+	{0x1EEBB, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x063A},
+	{0x1F100, 0, 2 | DECOMP_COMPAT, 4826},
+	{0x1F101, 0, 2 | DECOMP_COMPAT, 4828},
+	{0x1F102, 0, 2 | DECOMP_COMPAT, 4830},
+	{0x1F103, 0, 2 | DECOMP_COMPAT, 4832},
+	{0x1F104, 0, 2 | DECOMP_COMPAT, 4834},
+	{0x1F105, 0, 2 | DECOMP_COMPAT, 4836},
+	{0x1F106, 0, 2 | DECOMP_COMPAT, 4838},
+	{0x1F107, 0, 2 | DECOMP_COMPAT, 4840},
+	{0x1F108, 0, 2 | DECOMP_COMPAT, 4842},
+	{0x1F109, 0, 2 | DECOMP_COMPAT, 4844},
+	{0x1F10A, 0, 2 | DECOMP_COMPAT, 4846},
+	{0x1F110, 0, 3 | DECOMP_COMPAT, 4848},
+	{0x1F111, 0, 3 | DECOMP_COMPAT, 4851},
+	{0x1F112, 0, 3 | DECOMP_COMPAT, 4854},
+	{0x1F113, 0, 3 | DECOMP_COMPAT, 4857},
+	{0x1F114, 0, 3 | DECOMP_COMPAT, 4860},
+	{0x1F115, 0, 3 | DECOMP_COMPAT, 4863},
+	{0x1F116, 0, 3 | DECOMP_COMPAT, 4866},
+	{0x1F117, 0, 3 | DECOMP_COMPAT, 4869},
+	{0x1F118, 0, 3 | DECOMP_COMPAT, 4872},
+	{0x1F119, 0, 3 | DECOMP_COMPAT, 4875},
+	{0x1F11A, 0, 3 | DECOMP_COMPAT, 4878},
+	{0x1F11B, 0, 3 | DECOMP_COMPAT, 4881},
+	{0x1F11C, 0, 3 | DECOMP_COMPAT, 4884},
+	{0x1F11D, 0, 3 | DECOMP_COMPAT, 4887},
+	{0x1F11E, 0, 3 | DECOMP_COMPAT, 4890},
+	{0x1F11F, 0, 3 | DECOMP_COMPAT, 4893},
+	{0x1F120, 0, 3 | DECOMP_COMPAT, 4896},
+	{0x1F121, 0, 3 | DECOMP_COMPAT, 4899},
+	{0x1F122, 0, 3 | DECOMP_COMPAT, 4902},
+	{0x1F123, 0, 3 | DECOMP_COMPAT, 4905},
+	{0x1F124, 0, 3 | DECOMP_COMPAT, 4908},
+	{0x1F125, 0, 3 | DECOMP_COMPAT, 4911},
+	{0x1F126, 0, 3 | DECOMP_COMPAT, 4914},
+	{0x1F127, 0, 3 | DECOMP_COMPAT, 4917},
+	{0x1F128, 0, 3 | DECOMP_COMPAT, 4920},
+	{0x1F129, 0, 3 | DECOMP_COMPAT, 4923},
+	{0x1F12A, 0, 3 | DECOMP_COMPAT, 4926},
+	{0x1F12B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1F12C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1F12D, 0, 2 | DECOMP_COMPAT, 4929},
+	{0x1F12E, 0, 2 | DECOMP_COMPAT, 4931},
+	{0x1F130, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0041},
+	{0x1F131, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0042},
+	{0x1F132, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0043},
+	{0x1F133, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0044},
+	{0x1F134, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0045},
+	{0x1F135, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0046},
+	{0x1F136, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0047},
+	{0x1F137, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0048},
+	{0x1F138, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0049},
+	{0x1F139, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004A},
+	{0x1F13A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004B},
+	{0x1F13B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004C},
+	{0x1F13C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004D},
+	{0x1F13D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004E},
+	{0x1F13E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x004F},
+	{0x1F13F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0050},
+	{0x1F140, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0051},
+	{0x1F141, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0052},
+	{0x1F142, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0053},
+	{0x1F143, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0054},
+	{0x1F144, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0055},
+	{0x1F145, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0056},
+	{0x1F146, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0057},
+	{0x1F147, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0058},
+	{0x1F148, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x0059},
+	{0x1F149, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x005A},
+	{0x1F14A, 0, 2 | DECOMP_COMPAT, 4933},
+	{0x1F14B, 0, 2 | DECOMP_COMPAT, 4935},
+	{0x1F14C, 0, 2 | DECOMP_COMPAT, 4937},
+	{0x1F14D, 0, 2 | DECOMP_COMPAT, 4939},
+	{0x1F14E, 0, 3 | DECOMP_COMPAT, 4941},
+	{0x1F14F, 0, 2 | DECOMP_COMPAT, 4944},
+	{0x1F16A, 0, 2 | DECOMP_COMPAT, 4946},
+	{0x1F16B, 0, 2 | DECOMP_COMPAT, 4948},
+	{0x1F16C, 0, 2 | DECOMP_COMPAT, 4950},
+	{0x1F190, 0, 2 | DECOMP_COMPAT, 4952},
+	{0x1F200, 0, 2 | DECOMP_COMPAT, 4954},
+	{0x1F201, 0, 2 | DECOMP_COMPAT, 4956},
+	{0x1F202, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30B5},
+	{0x1F210, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x624B},
+	{0x1F211, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5B57},
+	{0x1F212, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53CC},
+	{0x1F213, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x30C7},
+	{0x1F214, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E8C},
+	{0x1F215, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x591A},
+	{0x1F216, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x89E3},
+	{0x1F217, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5929},
+	{0x1F218, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4EA4},
+	{0x1F219, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6620},
+	{0x1F21A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7121},
+	{0x1F21B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6599},
+	{0x1F21C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x524D},
+	{0x1F21D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F8C},
+	{0x1F21E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x518D},
+	{0x1F21F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x65B0},
+	{0x1F220, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x521D},
+	{0x1F221, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7D42},
+	{0x1F222, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x751F},
+	{0x1F223, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8CA9},
+	{0x1F224, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x58F0},
+	{0x1F225, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5439},
+	{0x1F226, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6F14},
+	{0x1F227, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6295},
+	{0x1F228, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6355},
+	{0x1F229, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E00},
+	{0x1F22A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E09},
+	{0x1F22B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x904A},
+	{0x1F22C, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5DE6},
+	{0x1F22D, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x4E2D},
+	{0x1F22E, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53F3},
+	{0x1F22F, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6307},
+	{0x1F230, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x8D70},
+	{0x1F231, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6253},
+	{0x1F232, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7981},
+	{0x1F233, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7A7A},
+	{0x1F234, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5408},
+	{0x1F235, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6E80},
+	{0x1F236, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6709},
+	{0x1F237, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x6708},
+	{0x1F238, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x7533},
+	{0x1F239, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5272},
+	{0x1F23A, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x55B6},
+	{0x1F23B, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x914D},
+	{0x1F240, 0, 3 | DECOMP_COMPAT, 4958},
+	{0x1F241, 0, 3 | DECOMP_COMPAT, 4961},
+	{0x1F242, 0, 3 | DECOMP_COMPAT, 4964},
+	{0x1F243, 0, 3 | DECOMP_COMPAT, 4967},
+	{0x1F244, 0, 3 | DECOMP_COMPAT, 4970},
+	{0x1F245, 0, 3 | DECOMP_COMPAT, 4973},
+	{0x1F246, 0, 3 | DECOMP_COMPAT, 4976},
+	{0x1F247, 0, 3 | DECOMP_COMPAT, 4979},
+	{0x1F248, 0, 3 | DECOMP_COMPAT, 4982},
+	{0x1F250, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x5F97},
+	{0x1F251, 0, 1 | DECOMP_COMPAT | DECOMP_INLINE, 0x53EF},
 	{0x2F800, 0, 1 | DECOMP_INLINE, 0x4E3D},
 	{0x2F801, 0, 1 | DECOMP_INLINE, 0x4E38},
 	{0x2F802, 0, 1 | DECOMP_INLINE, 0x4E41},
-- 
2.24.0

